! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
! Auxiliary Routines File
!
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
!
! File                 : gckpp_Util.f90
! Time                 : Fri Mar 13 14:32:09 2020
! Working directory    : /n/home05/msulprizio/GC/Code.GCHP/KPP/SOA_SVPOA
! Equation file        : gckpp.kpp
! Output root filename : gckpp
!
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_Util

  USE gckpp_Parameters
  IMPLICIT NONE

CONTAINS



! User INLINED Utility Functions

! End INLINED Utility Functions

! Utility Functions from KPP_HOME/util/util
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
! UTIL - Utility functions
!   Arguments :
!
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

! ****************************************************************
!
! InitSaveData - Opens the data file for writing
!   Parameters :
!
! ****************************************************************

      SUBROUTINE InitSaveData ()

      USE gckpp_Parameters

      open(10, file='gckpp.dat')

      END SUBROUTINE InitSaveData

! End of InitSaveData function
! ****************************************************************

! ****************************************************************
!
! SaveData - Write LOOKAT species in the data file
!   Parameters :
!
! ****************************************************************

      SUBROUTINE SaveData ()

      USE gckpp_Global
      USE gckpp_Monitor

      INTEGER i

      WRITE(10,999) (TIME-TSTART)/3600.D0,  &
                   (C(LOOKAT(i))/CFACTOR, i=1,NLOOKAT)
999   FORMAT(E24.16,100(1X,E24.16))

      END SUBROUTINE SaveData

! End of SaveData function
! ****************************************************************

! ****************************************************************
!
! CloseSaveData - Close the data file
!   Parameters :
!
! ****************************************************************

      SUBROUTINE CloseSaveData ()

      USE gckpp_Parameters

      CLOSE(10)

      END SUBROUTINE CloseSaveData

! End of CloseSaveData function
! ****************************************************************

! ****************************************************************
!
! GenerateMatlab - Generates MATLAB file to load the data file
!   Parameters :
!                It will have a character string to prefix each
!                species name with.
!
! ****************************************************************

      SUBROUTINE GenerateMatlab ( PREFIX )

      USE gckpp_Parameters
      USE gckpp_Global
      USE gckpp_Monitor


      CHARACTER(LEN=8) PREFIX
      INTEGER i

      open(20, file='gckpp.m')
      write(20,*) 'load gckpp.dat;'
      write(20,990) PREFIX
990   FORMAT(A1,'c = gckpp;')
      write(20,*) 'clear gckpp;'
      write(20,991) PREFIX, PREFIX
991   FORMAT(A1,'t=',A1,'c(:,1);')
      write(20,992) PREFIX
992   FORMAT(A1,'c(:,1)=[];')

      do i=1,NLOOKAT
        write(20,993) PREFIX, SPC_NAMES(LOOKAT(i)), PREFIX, i
993     FORMAT(A1,A6,' = ',A1,'c(:,',I2,');')
      end do

      CLOSE(20)

      END SUBROUTINE GenerateMatlab

! End of GenerateMatlab function
! ****************************************************************


! End Utility Functions from KPP_HOME/util/util
! End of UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
! Shuffle_user2kpp - function to copy concentrations from USER to KPP
!   Arguments :
!      V_USER    - Concentration of variable species in USER's order
!      V         - Concentrations of variable species (local)
!
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE Shuffle_user2kpp ( V_USER, V )

! V_USER - Concentration of variable species in USER's order
  REAL(kind=dp) :: V_USER(NVAR)
! V - Concentrations of variable species (local)
  REAL(kind=dp) :: V(NVAR)

  V(235) = V_USER(1)
  V(184) = V_USER(2)
  V(159) = V_USER(3)
  V(6) = V_USER(4)
  V(227) = V_USER(5)
  V(87) = V_USER(6)
  V(218) = V_USER(7)
  V(157) = V_USER(8)
  V(234) = V_USER(9)
  V(43) = V_USER(10)
  V(232) = V_USER(11)
  V(105) = V_USER(12)
  V(96) = V_USER(13)
  V(48) = V_USER(14)
  V(131) = V_USER(15)
  V(183) = V_USER(16)
  V(54) = V_USER(17)
  V(114) = V_USER(18)
  V(113) = V_USER(19)
  V(121) = V_USER(20)
  V(98) = V_USER(21)
  V(119) = V_USER(22)
  V(115) = V_USER(23)
  V(39) = V_USER(24)
  V(62) = V_USER(25)
  V(1) = V_USER(26)
  V(2) = V_USER(27)
  V(3) = V_USER(28)
  V(224) = V_USER(29)
  V(194) = V_USER(30)
  V(49) = V_USER(31)
  V(173) = V_USER(32)
  V(78) = V_USER(33)
  V(44) = V_USER(34)
  V(40) = V_USER(35)
  V(63) = V_USER(36)
  V(239) = V_USER(37)
  V(106) = V_USER(38)
  V(59) = V_USER(39)
  V(77) = V_USER(40)
  V(176) = V_USER(41)
  V(225) = V_USER(42)
  V(82) = V_USER(43)
  V(226) = V_USER(44)
  V(7) = V_USER(45)
  V(79) = V_USER(46)
  V(111) = V_USER(47)
  V(172) = V_USER(48)
  V(75) = V_USER(49)
  V(178) = V_USER(50)
  V(86) = V_USER(51)
  V(201) = V_USER(52)
  V(182) = V_USER(53)
  V(134) = V_USER(54)
  V(215) = V_USER(55)
  V(204) = V_USER(56)
  V(158) = V_USER(57)
  V(223) = V_USER(58)
  V(164) = V_USER(59)
  V(50) = V_USER(60)
  V(55) = V_USER(61)
  V(64) = V_USER(62)
  V(68) = V_USER(63)
  V(191) = V_USER(64)
  V(80) = V_USER(65)
  V(237) = V_USER(66)
  V(162) = V_USER(67)
  V(161) = V_USER(68)
  V(91) = V_USER(69)
  V(109) = V_USER(70)
  V(154) = V_USER(71)
  V(93) = V_USER(72)
  V(156) = V_USER(73)
  V(95) = V_USER(74)
  V(102) = V_USER(75)
  V(103) = V_USER(76)
  V(143) = V_USER(77)
  V(175) = V_USER(78)
  V(146) = V_USER(79)
  V(41) = V_USER(80)
  V(45) = V_USER(81)
  V(38) = V_USER(82)
  V(51) = V_USER(83)
  V(144) = V_USER(84)
  V(160) = V_USER(85)
  V(60) = V_USER(86)
  V(206) = V_USER(87)
  V(122) = V_USER(88)
  V(170) = V_USER(89)
  V(84) = V_USER(90)
  V(101) = V_USER(91)
  V(116) = V_USER(92)
  V(199) = V_USER(93)
  V(139) = V_USER(94)
  V(140) = V_USER(95)
  V(135) = V_USER(96)
  V(209) = V_USER(97)
  V(120) = V_USER(98)
  V(110) = V_USER(99)
  V(196) = V_USER(100)
  V(107) = V_USER(101)
  V(195) = V_USER(102)
  V(90) = V_USER(103)
  V(190) = V_USER(104)
  V(117) = V_USER(105)
  V(118) = V_USER(106)
  V(181) = V_USER(107)
  V(217) = V_USER(108)
  V(216) = V_USER(109)
  V(185) = V_USER(110)
  V(152) = V_USER(111)
  V(150) = V_USER(112)
  V(151) = V_USER(113)
  V(155) = V_USER(114)
  V(99) = V_USER(115)
  V(8) = V_USER(116)
  V(52) = V_USER(117)
  V(210) = V_USER(118)
  V(211) = V_USER(119)
  V(149) = V_USER(120)
  V(130) = V_USER(121)
  V(179) = V_USER(122)
  V(81) = V_USER(123)
  V(65) = V_USER(124)
  V(136) = V_USER(125)
  V(66) = V_USER(126)
  V(9) = V_USER(127)
  V(10) = V_USER(128)
  V(189) = V_USER(129)
  V(138) = V_USER(130)
  V(123) = V_USER(131)
  V(180) = V_USER(132)
  V(208) = V_USER(133)
  V(219) = V_USER(134)
  V(11) = V_USER(135)
  V(12) = V_USER(136)
  V(145) = V_USER(137)
  V(192) = V_USER(138)
  V(13) = V_USER(139)
  V(14) = V_USER(140)
  V(15) = V_USER(141)
  V(16) = V_USER(142)
  V(19) = V_USER(143)
  V(20) = V_USER(144)
  V(22) = V_USER(145)
  V(21) = V_USER(146)
  V(23) = V_USER(147)
  V(24) = V_USER(148)
  V(214) = V_USER(149)
  V(174) = V_USER(150)
  V(112) = V_USER(151)
  V(213) = V_USER(152)
  V(58) = V_USER(153)
  V(231) = V_USER(154)
  V(108) = V_USER(155)
  V(133) = V_USER(156)
  V(166) = V_USER(157)
  V(147) = V_USER(158)
  V(197) = V_USER(159)
  V(168) = V_USER(160)
  V(193) = V_USER(161)
  V(67) = V_USER(162)
  V(200) = V_USER(163)
  V(236) = V_USER(164)
  V(186) = V_USER(165)
  V(42) = V_USER(166)
  V(148) = V_USER(167)
  V(165) = V_USER(168)
  V(100) = V_USER(169)
  V(124) = V_USER(170)
  V(61) = V_USER(171)
  V(25) = V_USER(172)
  V(125) = V_USER(173)
  V(126) = V_USER(174)
  V(212) = V_USER(175)
  V(92) = V_USER(176)
  V(141) = V_USER(177)
  V(153) = V_USER(178)
  V(198) = V_USER(179)
  V(205) = V_USER(180)
  V(169) = V_USER(181)
  V(127) = V_USER(182)
  V(97) = V_USER(183)
  V(18) = V_USER(184)
  V(4) = V_USER(185)
  V(5) = V_USER(186)
  V(233) = V_USER(187)
  V(228) = V_USER(188)
  V(229) = V_USER(189)
  V(69) = V_USER(190)
  V(17) = V_USER(191)
  V(238) = V_USER(193)
  V(85) = V_USER(194)
  V(230) = V_USER(195)
  V(70) = V_USER(196)
  V(188) = V_USER(197)
  V(187) = V_USER(198)
  V(221) = V_USER(199)
  V(56) = V_USER(200)
  V(207) = V_USER(201)
  V(94) = V_USER(202)
  V(177) = V_USER(203)
  V(88) = V_USER(204)
  V(46) = V_USER(205)
  V(171) = V_USER(206)
  V(163) = V_USER(207)
  V(222) = V_USER(208)
  V(89) = V_USER(209)
  V(83) = V_USER(210)
  V(203) = V_USER(211)
  V(167) = V_USER(212)
  V(220) = V_USER(213)
  V(71) = V_USER(214)
  V(72) = V_USER(215)
  V(73) = V_USER(216)
  V(202) = V_USER(217)
  V(240) = V_USER(218)
  V(128) = V_USER(219)
  V(132) = V_USER(220)
  V(142) = V_USER(221)
  V(137) = V_USER(222)
  V(129) = V_USER(223)
  V(74) = V_USER(224)
  V(104) = V_USER(225)
  V(26) = V_USER(226)
  V(27) = V_USER(227)
  V(28) = V_USER(228)
  V(29) = V_USER(229)
  V(30) = V_USER(230)
  V(47) = V_USER(231)
  V(53) = V_USER(232)
  V(76) = V_USER(233)
  V(57) = V_USER(234)
  V(31) = V_USER(235)
  V(32) = V_USER(236)
  V(33) = V_USER(237)
  V(34) = V_USER(238)
  V(35) = V_USER(239)

END SUBROUTINE Shuffle_user2kpp

! End of Shuffle_user2kpp function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
! Shuffle_kpp2user - function to restore concentrations from KPP to USER
!   Arguments :
!      V         - Concentrations of variable species (local)
!      V_USER    - Concentration of variable species in USER's order
!
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE Shuffle_kpp2user ( V, V_USER )

! V - Concentrations of variable species (local)
  REAL(kind=dp) :: V(NVAR)
! V_USER - Concentration of variable species in USER's order
  REAL(kind=dp) :: V_USER(NVAR)

  V_USER(1) = V(235)
  V_USER(2) = V(184)
  V_USER(3) = V(159)
  V_USER(4) = V(6)
  V_USER(5) = V(227)
  V_USER(6) = V(87)
  V_USER(7) = V(218)
  V_USER(8) = V(157)
  V_USER(9) = V(234)
  V_USER(10) = V(43)
  V_USER(11) = V(232)
  V_USER(12) = V(105)
  V_USER(13) = V(96)
  V_USER(14) = V(48)
  V_USER(15) = V(131)
  V_USER(16) = V(183)
  V_USER(17) = V(54)
  V_USER(18) = V(114)
  V_USER(19) = V(113)
  V_USER(20) = V(121)
  V_USER(21) = V(98)
  V_USER(22) = V(119)
  V_USER(23) = V(115)
  V_USER(24) = V(39)
  V_USER(25) = V(62)
  V_USER(26) = V(1)
  V_USER(27) = V(2)
  V_USER(28) = V(3)
  V_USER(29) = V(224)
  V_USER(30) = V(194)
  V_USER(31) = V(49)
  V_USER(32) = V(173)
  V_USER(33) = V(78)
  V_USER(34) = V(44)
  V_USER(35) = V(40)
  V_USER(36) = V(63)
  V_USER(37) = V(239)
  V_USER(38) = V(106)
  V_USER(39) = V(59)
  V_USER(40) = V(77)
  V_USER(41) = V(176)
  V_USER(42) = V(225)
  V_USER(43) = V(82)
  V_USER(44) = V(226)
  V_USER(45) = V(7)
  V_USER(46) = V(79)
  V_USER(47) = V(111)
  V_USER(48) = V(172)
  V_USER(49) = V(75)
  V_USER(50) = V(178)
  V_USER(51) = V(86)
  V_USER(52) = V(201)
  V_USER(53) = V(182)
  V_USER(54) = V(134)
  V_USER(55) = V(215)
  V_USER(56) = V(204)
  V_USER(57) = V(158)
  V_USER(58) = V(223)
  V_USER(59) = V(164)
  V_USER(60) = V(50)
  V_USER(61) = V(55)
  V_USER(62) = V(64)
  V_USER(63) = V(68)
  V_USER(64) = V(191)
  V_USER(65) = V(80)
  V_USER(66) = V(237)
  V_USER(67) = V(162)
  V_USER(68) = V(161)
  V_USER(69) = V(91)
  V_USER(70) = V(109)
  V_USER(71) = V(154)
  V_USER(72) = V(93)
  V_USER(73) = V(156)
  V_USER(74) = V(95)
  V_USER(75) = V(102)
  V_USER(76) = V(103)
  V_USER(77) = V(143)
  V_USER(78) = V(175)
  V_USER(79) = V(146)
  V_USER(80) = V(41)
  V_USER(81) = V(45)
  V_USER(82) = V(38)
  V_USER(83) = V(51)
  V_USER(84) = V(144)
  V_USER(85) = V(160)
  V_USER(86) = V(60)
  V_USER(87) = V(206)
  V_USER(88) = V(122)
  V_USER(89) = V(170)
  V_USER(90) = V(84)
  V_USER(91) = V(101)
  V_USER(92) = V(116)
  V_USER(93) = V(199)
  V_USER(94) = V(139)
  V_USER(95) = V(140)
  V_USER(96) = V(135)
  V_USER(97) = V(209)
  V_USER(98) = V(120)
  V_USER(99) = V(110)
  V_USER(100) = V(196)
  V_USER(101) = V(107)
  V_USER(102) = V(195)
  V_USER(103) = V(90)
  V_USER(104) = V(190)
  V_USER(105) = V(117)
  V_USER(106) = V(118)
  V_USER(107) = V(181)
  V_USER(108) = V(217)
  V_USER(109) = V(216)
  V_USER(110) = V(185)
  V_USER(111) = V(152)
  V_USER(112) = V(150)
  V_USER(113) = V(151)
  V_USER(114) = V(155)
  V_USER(115) = V(99)
  V_USER(116) = V(8)
  V_USER(117) = V(52)
  V_USER(118) = V(210)
  V_USER(119) = V(211)
  V_USER(120) = V(149)
  V_USER(121) = V(130)
  V_USER(122) = V(179)
  V_USER(123) = V(81)
  V_USER(124) = V(65)
  V_USER(125) = V(136)
  V_USER(126) = V(66)
  V_USER(127) = V(9)
  V_USER(128) = V(10)
  V_USER(129) = V(189)
  V_USER(130) = V(138)
  V_USER(131) = V(123)
  V_USER(132) = V(180)
  V_USER(133) = V(208)
  V_USER(134) = V(219)
  V_USER(135) = V(11)
  V_USER(136) = V(12)
  V_USER(137) = V(145)
  V_USER(138) = V(192)
  V_USER(139) = V(13)
  V_USER(140) = V(14)
  V_USER(141) = V(15)
  V_USER(142) = V(16)
  V_USER(143) = V(19)
  V_USER(144) = V(20)
  V_USER(145) = V(22)
  V_USER(146) = V(21)
  V_USER(147) = V(23)
  V_USER(148) = V(24)
  V_USER(149) = V(214)
  V_USER(150) = V(174)
  V_USER(151) = V(112)
  V_USER(152) = V(213)
  V_USER(153) = V(58)
  V_USER(154) = V(231)
  V_USER(155) = V(108)
  V_USER(156) = V(133)
  V_USER(157) = V(166)
  V_USER(158) = V(147)
  V_USER(159) = V(197)
  V_USER(160) = V(168)
  V_USER(161) = V(193)
  V_USER(162) = V(67)
  V_USER(163) = V(200)
  V_USER(164) = V(236)
  V_USER(165) = V(186)
  V_USER(166) = V(42)
  V_USER(167) = V(148)
  V_USER(168) = V(165)
  V_USER(169) = V(100)
  V_USER(170) = V(124)
  V_USER(171) = V(61)
  V_USER(172) = V(25)
  V_USER(173) = V(125)
  V_USER(174) = V(126)
  V_USER(175) = V(212)
  V_USER(176) = V(92)
  V_USER(177) = V(141)
  V_USER(178) = V(153)
  V_USER(179) = V(198)
  V_USER(180) = V(205)
  V_USER(181) = V(169)
  V_USER(182) = V(127)
  V_USER(183) = V(97)
  V_USER(184) = V(18)
  V_USER(185) = V(4)
  V_USER(186) = V(5)
  V_USER(187) = V(233)
  V_USER(188) = V(228)
  V_USER(189) = V(229)
  V_USER(190) = V(69)
  V_USER(191) = V(17)
  V_USER(193) = V(238)
  V_USER(194) = V(85)
  V_USER(195) = V(230)
  V_USER(196) = V(70)
  V_USER(197) = V(188)
  V_USER(198) = V(187)
  V_USER(199) = V(221)
  V_USER(200) = V(56)
  V_USER(201) = V(207)
  V_USER(202) = V(94)
  V_USER(203) = V(177)
  V_USER(204) = V(88)
  V_USER(205) = V(46)
  V_USER(206) = V(171)
  V_USER(207) = V(163)
  V_USER(208) = V(222)
  V_USER(209) = V(89)
  V_USER(210) = V(83)
  V_USER(211) = V(203)
  V_USER(212) = V(167)
  V_USER(213) = V(220)
  V_USER(214) = V(71)
  V_USER(215) = V(72)
  V_USER(216) = V(73)
  V_USER(217) = V(202)
  V_USER(218) = V(240)
  V_USER(219) = V(128)
  V_USER(220) = V(132)
  V_USER(221) = V(142)
  V_USER(222) = V(137)
  V_USER(223) = V(129)
  V_USER(224) = V(74)
  V_USER(225) = V(104)
  V_USER(226) = V(26)
  V_USER(227) = V(27)
  V_USER(228) = V(28)
  V_USER(229) = V(29)
  V_USER(230) = V(30)
  V_USER(231) = V(47)
  V_USER(232) = V(53)
  V_USER(233) = V(76)
  V_USER(234) = V(57)
  V_USER(235) = V(31)
  V_USER(236) = V(32)
  V_USER(237) = V(33)
  V_USER(238) = V(34)
  V_USER(239) = V(35)

END SUBROUTINE Shuffle_kpp2user

! End of Shuffle_kpp2user function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
! GetMass - compute total mass of selected atoms
!   Arguments :
!      CL        - Concentration of all species (local)
!      Mass      - value of mass balance
!
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE GetMass ( CL, Mass )

! CL - Concentration of all species (local)
  REAL(kind=dp) :: CL(NSPEC)
! Mass - value of mass balance
  REAL(kind=dp) :: Mass(1)


END SUBROUTINE GetMass

! End of GetMass function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

! Get_OHreactivity - returns the OH reactivity
! The OH reactivity is defined as the inverse of its lifetime.
! This routine was auto-generated using script OHreact_parser.py.
! Generated on 2020-03-13
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE Get_OHreactivity ( CC, RR, OHreact )

! CC - Concentrations of species (local)
  REAL(kind=dp) :: CC(NSPEC)
! RR - reaction rates (local)
  REAL(kind=dp) :: RR(NREACT)
! OHreact - OH reactivity [s-1]
  REAL(kind=dp) :: OHreact

  OHreact = RR(2)*CC(238) + 2*RR(6) + 2*RR(7) + RR(8)*CC(237) + RR(9)*CC(134) &
          + RR(12)*CC(242) + RR(13)*CC(226) + RR(14)*CC(241) + RR(20)*CC(100) + RR(21)*CC(100) &
          + RR(22)*CC(157) + RR(23)*CC(157) + RR(24)*CC(224) + RR(25)*CC(228) + RR(26)*CC(191) &
          + RR(27)*CC(233) + RR(28)*CC(68) + RR(31)*CC(80) + RR(34)*CC(229) + RR(37)*CC(164) &
          + RR(38)*CC(186) + RR(41)*CC(227) + RR(46)*CC(121) + RR(50)*CC(98) + RR(51)*CC(98) &
          + RR(55)*CC(87) + RR(65)*CC(167) + RR(66)*CC(159) + RR(67)*CC(202) + RR(72)*CC(184) &
          + RR(81)*CC(193) + RR(91)*CC(111) + RR(92)*CC(129) + RR(102)*CC(222) + RR(104)*CC(201) &
          + RR(105)*CC(201) + RR(107)*CC(182) + RR(108)*CC(200) + RR(111)*CC(215) + RR(112)*CC(215) &
          + RR(119)*CC(89) + RR(120)*CC(86) + RR(121)*CC(72) + RR(122)*CC(73) + RR(123)*CC(71) &
          + RR(124)*CC(74) + RR(125)*CC(88) + RR(126)*CC(22) + RR(127)*CC(58) + RR(152)*CC(79) &
          + RR(153)*CC(79) + RR(155)*CC(104) + RR(159)*CC(204) + RR(164)*CC(105) + RR(165)*CC(183) &
          + RR(174)*CC(40) + RR(175)*CC(39) + RR(176)*CC(49) + RR(177)*CC(106) + RR(179)*CC(225) &
          + RR(180)*CC(225) + RR(181)*CC(85) + RR(182)*CC(59) + RR(183)*CC(223) + RR(184)*CC(161) &
          + RR(185)*CC(77) + RR(186)*CC(176) + RR(187)*CC(78) + RR(188)*CC(62) + RR(189)*CC(63) &
          + RR(252)*CC(146) + RR(253)*CC(50) + RR(254)*CC(91) + RR(261)*CC(44) + RR(262)*CC(172) &
          + RR(263)*CC(163) + RR(277)*CC(43) + RR(278)*CC(47) + RR(279)*CC(76) + RR(287)*CC(125) &
          + RR(288)*CC(126) + RR(298)*CC(145) + RR(306)*CC(94) + RR(320)*CC(148) + RR(321)*CC(165) &
          + RR(327)*CC(109) + RR(328)*CC(67) + RR(329)*CC(75) + RR(330)*CC(66) + RR(331)*CC(69) &
          + RR(333)*CC(189) + RR(334)*CC(189) + RR(335)*CC(189) + RR(336)*CC(189) + RR(363)*CC(154) &
          + RR(364)*CC(156) + RR(365)*CC(102) + RR(366)*CC(103) + RR(367)*CC(158) + RR(368)*CC(144) &
          + RR(369)*CC(84) + RR(370)*CC(128) + RR(371)*CC(128) + RR(372)*CC(132) + RR(373)*CC(132) &
          + RR(374)*CC(128) + RR(375)*CC(132) + RR(376)*CC(142) + RR(377)*CC(137) + RR(390)*CC(90) &
          + RR(391)*CC(110) + RR(392)*CC(110) + RR(393)*CC(107) + RR(394)*CC(107) + RR(413)*CC(117) &
          + RR(414)*CC(117) + RR(415)*CC(118) + RR(416)*CC(118) + RR(417)*CC(190) + RR(418)*CC(190) &
          + RR(419)*CC(181) + RR(420)*CC(181) + RR(421)*CC(190) + RR(422)*CC(181) + RR(460)*CC(149) &
          + RR(461)*CC(130) + RR(462)*CC(149) + RR(463)*CC(130) + RR(464)*CC(130) + RR(465)*CC(149) &
          + RR(466)*CC(130) + RR(467)*CC(130) + RR(476)*CC(206) + RR(477)*CC(206) + RR(480)*CC(209) &
          + RR(483)*CC(212) + RR(485)*CC(214) + RR(486)*CC(214) + RR(489)*CC(205) + RR(490)*CC(198) &
          + RR(491)*CC(197) + RR(492)*CC(166) + RR(493)*CC(147) + RR(500)*CC(133) + RR(501)*CC(127) &
          + RR(502)*CC(92) + RR(503)*CC(153) + RR(504)*CC(141) + RR(505)*CC(108) + RR(511)*CC(112) &
          + RR(523)*CC(124) + RR(524)*CC(64) + RR(525)*CC(170) + RR(526)*CC(101) + RR(527)*CC(116) &
          + RR(528)*CC(135) + RR(529)*CC(180) + RR(530)*CC(208) + RR(532)*CC(83) + RR(533)*CC(55) &
          + RR(535)*CC(143) + RR(536)*CC(143) + RR(537)*CC(18)

END SUBROUTINE Get_OHreactivity
! End of Get_OHreactivity subroutine
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

END MODULE gckpp_Util
