! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Fri Mar 13 14:31:50 2020
! Working directory    : /n/home05/msulprizio/GC/Code.GCHP/KPP/Standard
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(26) = X(26)-JVS(109)*X(4)-JVS(110)*X(5)
  X(55) = X(55)-JVS(415)*X(43)
  X(56) = X(56)-JVS(420)*X(37)
  X(80) = X(80)-JVS(508)*X(33)-JVS(509)*X(35)-JVS(510)*X(41)
  X(95) = X(95)-JVS(578)*X(68)
  X(97) = X(97)-JVS(590)*X(4)-JVS(591)*X(5)-JVS(592)*X(76)
  X(126) = X(126)-JVS(752)*X(58)-JVS(753)*X(60)-JVS(754)*X(75)
  X(135) = X(135)-JVS(803)*X(125)
  X(139) = X(139)-JVS(822)*X(96)-JVS(823)*X(115)
  X(145) = X(145)-JVS(863)*X(130)
  X(148) = X(148)-JVS(880)*X(127)
  X(151) = X(151)-JVS(896)*X(104)-JVS(897)*X(115)
  X(153) = X(153)-JVS(912)*X(152)
  X(155) = X(155)-JVS(927)*X(103)-JVS(928)*X(111)-JVS(929)*X(112)-JVS(930)*X(116)-JVS(931)*X(120)-JVS(932)*X(125)&
             &-JVS(933)*X(127)-JVS(934)*X(134)-JVS(935)*X(140)-JVS(936)*X(143)-JVS(937)*X(147)-JVS(938)*X(152)
  X(156) = X(156)-JVS(952)*X(149)
  X(160) = X(160)-JVS(991)*X(53)-JVS(992)*X(76)-JVS(993)*X(146)
  X(161) = X(161)-JVS(1001)*X(95)
  X(163) = X(163)-JVS(1018)*X(140)-JVS(1019)*X(152)
  X(164) = X(164)-JVS(1025)*X(143)-JVS(1026)*X(147)
  X(165) = X(165)-JVS(1032)*X(104)-JVS(1033)*X(115)-JVS(1034)*X(118)-JVS(1035)*X(144)
  X(167) = X(167)-JVS(1056)*X(134)
  X(168) = X(168)-JVS(1062)*X(152)
  X(169) = X(169)-JVS(1068)*X(140)-JVS(1069)*X(143)
  X(170) = X(170)-JVS(1076)*X(147)
  X(171) = X(171)-JVS(1082)*X(147)-JVS(1083)*X(152)
  X(172) = X(172)-JVS(1093)*X(137)-JVS(1094)*X(138)-JVS(1095)*X(154)
  X(173) = X(173)-JVS(1108)*X(103)-JVS(1109)*X(143)-JVS(1110)*X(147)-JVS(1111)*X(152)
  X(174) = X(174)-JVS(1120)*X(147)-JVS(1121)*X(164)-JVS(1122)*X(167)
  X(175) = X(175)-JVS(1136)*X(102)-JVS(1137)*X(132)-JVS(1138)*X(133)-JVS(1139)*X(149)-JVS(1140)*X(156)-JVS(1141)*X(167)
  X(176) = X(176)-JVS(1158)*X(129)-JVS(1159)*X(148)-JVS(1160)*X(170)
  X(179) = X(179)-JVS(1192)*X(102)
  X(180) = X(180)-JVS(1201)*X(128)-JVS(1202)*X(168)
  X(181) = X(181)-JVS(1212)*X(129)-JVS(1213)*X(170)
  X(182) = X(182)-JVS(1223)*X(130)-JVS(1224)*X(163)-JVS(1225)*X(164)-JVS(1226)*X(169)-JVS(1227)*X(173)
  X(183) = X(183)-JVS(1238)*X(121)-JVS(1239)*X(136)
  X(184) = X(184)-JVS(1248)*X(132)-JVS(1249)*X(133)-JVS(1250)*X(150)-JVS(1251)*X(167)
  X(185) = X(185)-JVS(1265)*X(101)
  X(186) = X(186)-JVS(1275)*X(73)-JVS(1276)*X(74)-JVS(1277)*X(121)-JVS(1278)*X(136)-JVS(1279)*X(144)-JVS(1280)*X(154)&
             &-JVS(1281)*X(168)-JVS(1282)*X(170)-JVS(1283)*X(183)
  X(187) = X(187)-JVS(1305)*X(178)-JVS(1306)*X(179)-JVS(1307)*X(185)
  X(188) = X(188)-JVS(1329)*X(1)-JVS(1330)*X(2)-JVS(1331)*X(3)-JVS(1332)*X(35)-JVS(1333)*X(38)-JVS(1334)*X(52)-JVS(1335)&
             &*X(53)-JVS(1336)*X(62)-JVS(1337)*X(64)-JVS(1338)*X(76)-JVS(1339)*X(80)-JVS(1340)*X(113)-JVS(1341)*X(146)&
             &-JVS(1342)*X(160)
  X(189) = X(189)-JVS(1353)*X(37)-JVS(1354)*X(43)-JVS(1355)*X(86)-JVS(1356)*X(139)-JVS(1357)*X(144)-JVS(1358)*X(145)&
             &-JVS(1359)*X(153)-JVS(1360)*X(163)-JVS(1361)*X(164)-JVS(1362)*X(165)-JVS(1363)*X(167)-JVS(1364)*X(168)&
             &-JVS(1365)*X(169)-JVS(1366)*X(170)-JVS(1367)*X(182)
  X(191) = X(191)-JVS(1393)*X(135)-JVS(1394)*X(148)-JVS(1395)*X(149)-JVS(1396)*X(150)-JVS(1397)*X(167)-JVS(1398)*X(173)&
             &-JVS(1399)*X(190)
  X(192) = X(192)-JVS(1413)*X(77)-JVS(1414)*X(83)
  X(193) = X(193)-JVS(1427)*X(137)-JVS(1428)*X(138)-JVS(1429)*X(154)
  X(194) = X(194)-JVS(1439)*X(137)-JVS(1440)*X(138)-JVS(1441)*X(154)-JVS(1442)*X(193)
  X(195) = X(195)-JVS(1451)*X(142)
  X(196) = X(196)-JVS(1461)*X(178)-JVS(1462)*X(179)-JVS(1463)*X(185)-JVS(1464)*X(194)-JVS(1465)*X(195)
  X(197) = X(197)-JVS(1489)*X(35)-JVS(1490)*X(41)-JVS(1491)*X(80)-JVS(1492)*X(113)-JVS(1493)*X(146)-JVS(1494)*X(160)&
             &-JVS(1495)*X(188)
  X(198) = X(198)-JVS(1505)*X(162)
  X(200) = X(200)-JVS(1520)*X(42)-JVS(1521)*X(84)
  X(202) = X(202)-JVS(1538)*X(114)-JVS(1539)*X(122)-JVS(1540)*X(124)-JVS(1541)*X(158)
  X(203) = X(203)-JVS(1554)*X(154)
  X(204) = X(204)-JVS(1563)*X(137)-JVS(1564)*X(138)-JVS(1565)*X(154)
  X(205) = X(205)-JVS(1575)*X(115)-JVS(1576)*X(116)-JVS(1577)*X(120)-JVS(1578)*X(125)-JVS(1579)*X(127)-JVS(1580)*X(140)&
             &-JVS(1581)*X(143)-JVS(1582)*X(171)-JVS(1583)*X(190)-JVS(1584)*X(199)
  X(206) = X(206)-JVS(1595)*X(115)-JVS(1596)*X(116)-JVS(1597)*X(120)-JVS(1598)*X(125)-JVS(1599)*X(127)-JVS(1600)*X(140)&
             &-JVS(1601)*X(143)-JVS(1602)*X(171)-JVS(1603)*X(190)-JVS(1604)*X(199)-JVS(1605)*X(205)
  X(207) = X(207)-JVS(1615)*X(111)-JVS(1616)*X(140)-JVS(1617)*X(145)-JVS(1618)*X(152)-JVS(1619)*X(163)-JVS(1620)*X(164)&
             &-JVS(1621)*X(168)-JVS(1622)*X(169)-JVS(1623)*X(171)-JVS(1624)*X(180)-JVS(1625)*X(190)-JVS(1626)*X(191)&
             &-JVS(1627)*X(198)-JVS(1628)*X(199)-JVS(1629)*X(201)-JVS(1630)*X(205)-JVS(1631)*X(206)
  X(208) = X(208)-JVS(1648)*X(112)-JVS(1649)*X(143)-JVS(1650)*X(145)-JVS(1651)*X(147)-JVS(1652)*X(163)-JVS(1653)*X(164)&
             &-JVS(1654)*X(169)-JVS(1655)*X(170)-JVS(1656)*X(171)-JVS(1657)*X(181)-JVS(1658)*X(182)-JVS(1659)*X(190)&
             &-JVS(1660)*X(191)-JVS(1661)*X(198)-JVS(1662)*X(199)-JVS(1663)*X(201)-JVS(1664)*X(205)-JVS(1665)*X(206)
  X(209) = X(209)-JVS(1682)*X(68)-JVS(1683)*X(87)-JVS(1684)*X(99)-JVS(1685)*X(131)-JVS(1686)*X(161)-JVS(1687)*X(197)
  X(210) = X(210)-JVS(1704)*X(126)
  X(211) = X(211)-JVS(1716)*X(137)-JVS(1717)*X(138)
  X(212) = X(212)-JVS(1726)*X(36)-JVS(1727)*X(75)-JVS(1728)*X(90)-JVS(1729)*X(100)-JVS(1730)*X(119)-JVS(1731)*X(122)&
             &-JVS(1732)*X(124)-JVS(1733)*X(125)-JVS(1734)*X(127)-JVS(1735)*X(131)-JVS(1736)*X(134)-JVS(1737)*X(142)&
             &-JVS(1738)*X(146)-JVS(1739)*X(156)-JVS(1740)*X(158)-JVS(1741)*X(159)-JVS(1742)*X(160)-JVS(1743)*X(162)&
             &-JVS(1744)*X(167)-JVS(1745)*X(176)-JVS(1746)*X(177)-JVS(1747)*X(181)-JVS(1748)*X(184)-JVS(1749)*X(188)&
             &-JVS(1750)*X(189)-JVS(1751)*X(190)-JVS(1752)*X(191)-JVS(1753)*X(193)-JVS(1754)*X(194)-JVS(1755)*X(197)&
             &-JVS(1756)*X(198)-JVS(1757)*X(199)-JVS(1758)*X(201)-JVS(1759)*X(202)-JVS(1760)*X(203)-JVS(1761)*X(205)&
             &-JVS(1762)*X(206)-JVS(1763)*X(207)-JVS(1764)*X(211)
  X(213) = X(213)-JVS(1802)*X(110)-JVS(1803)*X(134)-JVS(1804)*X(162)
  X(214) = X(214)-JVS(1816)*X(82)-JVS(1817)*X(109)-JVS(1818)*X(200)
  X(215) = X(215)-JVS(1834)*X(122)-JVS(1835)*X(124)-JVS(1836)*X(202)
  X(216) = X(216)-JVS(1850)*X(130)-JVS(1851)*X(132)-JVS(1852)*X(145)-JVS(1853)*X(148)-JVS(1854)*X(149)-JVS(1855)*X(163)&
             &-JVS(1856)*X(164)-JVS(1857)*X(169)-JVS(1858)*X(180)-JVS(1859)*X(182)-JVS(1860)*X(190)-JVS(1861)*X(191)&
             &-JVS(1862)*X(198)-JVS(1863)*X(199)-JVS(1864)*X(201)-JVS(1865)*X(205)-JVS(1866)*X(206)-JVS(1867)*X(207)&
             &-JVS(1868)*X(213)
  X(217) = X(217)-JVS(1888)*X(43)-JVS(1889)*X(74)-JVS(1890)*X(86)-JVS(1891)*X(121)-JVS(1892)*X(136)-JVS(1893)*X(139)&
             &-JVS(1894)*X(144)-JVS(1895)*X(145)-JVS(1896)*X(147)-JVS(1897)*X(152)-JVS(1898)*X(155)-JVS(1899)*X(163)&
             &-JVS(1900)*X(164)-JVS(1901)*X(165)-JVS(1902)*X(168)-JVS(1903)*X(169)-JVS(1904)*X(170)-JVS(1905)*X(171)&
             &-JVS(1906)*X(174)-JVS(1907)*X(175)-JVS(1908)*X(179)-JVS(1909)*X(180)-JVS(1910)*X(181)-JVS(1911)*X(182)&
             &-JVS(1912)*X(183)-JVS(1913)*X(190)-JVS(1914)*X(191)-JVS(1915)*X(198)-JVS(1916)*X(199)-JVS(1917)*X(201)&
             &-JVS(1918)*X(204)-JVS(1919)*X(205)-JVS(1920)*X(206)-JVS(1921)*X(207)-JVS(1922)*X(208)-JVS(1923)*X(213)
  X(218) = X(218)-JVS(1949)*X(110)-JVS(1950)*X(134)-JVS(1951)*X(190)-JVS(1952)*X(199)
  X(219) = X(219)-JVS(1965)*X(128)-JVS(1966)*X(135)-JVS(1967)*X(150)-JVS(1968)*X(167)-JVS(1969)*X(168)-JVS(1970)*X(180)&
             &-JVS(1971)*X(190)-JVS(1972)*X(198)-JVS(1973)*X(201)-JVS(1974)*X(213)-JVS(1975)*X(218)
  X(220) = X(220)-JVS(1993)*X(134)-JVS(1994)*X(135)-JVS(1995)*X(148)-JVS(1996)*X(149)-JVS(1997)*X(150)-JVS(1998)*X(162)&
             &-JVS(1999)*X(163)-JVS(2000)*X(164)-JVS(2001)*X(167)-JVS(2002)*X(169)-JVS(2003)*X(190)-JVS(2004)*X(198)&
             &-JVS(2005)*X(199)-JVS(2006)*X(213)
  X(221) = X(221)-JVS(2019)*X(132)-JVS(2020)*X(135)-JVS(2021)*X(148)-JVS(2022)*X(149)-JVS(2023)*X(150)-JVS(2024)*X(167)&
             &-JVS(2025)*X(190)-JVS(2026)*X(198)-JVS(2027)*X(199)-JVS(2028)*X(213)-JVS(2029)*X(220)
  X(222) = X(222)-JVS(2041)*X(162)-JVS(2042)*X(201)
  X(223) = X(223)-JVS(2053)*X(134)-JVS(2054)*X(201)-JVS(2055)*X(222)
  X(224) = X(224)-JVS(2065)*X(134)-JVS(2066)*X(143)-JVS(2067)*X(147)-JVS(2068)*X(201)-JVS(2069)*X(223)
  X(225) = X(225)-JVS(2080)*X(134)-JVS(2081)*X(140)-JVS(2082)*X(152)-JVS(2083)*X(201)-JVS(2084)*X(223)-JVS(2085)*X(224)
  X(226) = X(226)-JVS(2095)*X(108)-JVS(2096)*X(112)-JVS(2097)*X(125)-JVS(2098)*X(143)-JVS(2099)*X(147)-JVS(2100)*X(154)&
             &-JVS(2101)*X(162)-JVS(2102)*X(170)-JVS(2103)*X(201)-JVS(2104)*X(203)-JVS(2105)*X(221)-JVS(2106)*X(222)&
             &-JVS(2107)*X(223)-JVS(2108)*X(224)-JVS(2109)*X(225)
  X(227) = X(227)-JVS(2119)*X(176)-JVS(2120)*X(181)-JVS(2121)*X(201)-JVS(2122)*X(218)-JVS(2123)*X(220)-JVS(2124)*X(221)&
             &-JVS(2125)*X(222)-JVS(2126)*X(223)-JVS(2127)*X(224)-JVS(2128)*X(225)-JVS(2129)*X(226)
  X(228) = X(228)-JVS(2140)*X(101)-JVS(2141)*X(118)-JVS(2142)*X(119)-JVS(2143)*X(121)-JVS(2144)*X(130)-JVS(2145)*X(136)&
             &-JVS(2146)*X(145)-JVS(2147)*X(148)-JVS(2148)*X(150)-JVS(2149)*X(155)-JVS(2150)*X(159)-JVS(2151)*X(163)&
             &-JVS(2152)*X(164)-JVS(2153)*X(168)-JVS(2154)*X(169)-JVS(2155)*X(170)-JVS(2156)*X(173)-JVS(2157)*X(176)&
             &-JVS(2158)*X(177)-JVS(2159)*X(181)-JVS(2160)*X(182)-JVS(2161)*X(183)-JVS(2162)*X(185)-JVS(2163)*X(190)&
             &-JVS(2164)*X(193)-JVS(2165)*X(194)-JVS(2166)*X(198)-JVS(2167)*X(199)-JVS(2168)*X(201)-JVS(2169)*X(203)&
             &-JVS(2170)*X(205)-JVS(2171)*X(206)-JVS(2172)*X(208)-JVS(2173)*X(211)-JVS(2174)*X(213)-JVS(2175)*X(218)&
             &-JVS(2176)*X(220)-JVS(2177)*X(221)-JVS(2178)*X(222)-JVS(2179)*X(223)-JVS(2180)*X(224)-JVS(2181)*X(225)&
             &-JVS(2182)*X(226)-JVS(2183)*X(227)
  X(229) = X(229)-JVS(2197)*X(107)-JVS(2198)*X(111)-JVS(2199)*X(127)-JVS(2200)*X(140)-JVS(2201)*X(152)-JVS(2202)*X(162)&
             &-JVS(2203)*X(168)-JVS(2204)*X(201)-JVS(2205)*X(221)-JVS(2206)*X(222)-JVS(2207)*X(223)-JVS(2208)*X(224)&
             &-JVS(2209)*X(225)
  X(230) = X(230)-JVS(2219)*X(174)-JVS(2220)*X(192)-JVS(2221)*X(198)-JVS(2222)*X(201)-JVS(2223)*X(204)-JVS(2224)*X(208)&
             &-JVS(2225)*X(211)-JVS(2226)*X(218)-JVS(2227)*X(220)-JVS(2228)*X(221)-JVS(2229)*X(222)-JVS(2230)*X(223)&
             &-JVS(2231)*X(224)-JVS(2232)*X(225)-JVS(2233)*X(226)
  X(231) = X(231)-JVS(2249)*X(105)-JVS(2250)*X(137)-JVS(2251)*X(138)-JVS(2252)*X(159)-JVS(2253)*X(193)-JVS(2254)*X(194)&
             &-JVS(2255)*X(203)-JVS(2256)*X(204)-JVS(2257)*X(211)
  X(232) = X(232)-JVS(2268)*X(98)-JVS(2269)*X(154)-JVS(2270)*X(195)-JVS(2271)*X(200)-JVS(2272)*X(229)-JVS(2273)*X(231)
  X(233) = X(233)-JVS(2288)*X(178)-JVS(2289)*X(204)-JVS(2290)*X(231)
  X(234) = X(234)-JVS(2300)*X(81)-JVS(2301)*X(100)-JVS(2302)*X(105)-JVS(2303)*X(178)-JVS(2304)*X(203)-JVS(2305)*X(211)&
             &-JVS(2306)*X(233)
  X(235) = X(235)-JVS(2316)*X(83)-JVS(2317)*X(109)-JVS(2318)*X(200)-JVS(2319)*X(229)-JVS(2320)*X(231)-JVS(2321)*X(233)&
             &-JVS(2322)*X(234)
  X(236) = X(236)-JVS(2335)*X(154)-JVS(2336)*X(203)-JVS(2337)*X(229)
  X(237) = X(237)-JVS(2348)*X(79)-JVS(2349)*X(81)-JVS(2350)*X(82)-JVS(2351)*X(102)-JVS(2352)*X(105)-JVS(2353)*X(137)&
             &-JVS(2354)*X(138)-JVS(2355)*X(141)-JVS(2356)*X(177)-JVS(2357)*X(178)-JVS(2358)*X(179)-JVS(2359)*X(185)&
             &-JVS(2360)*X(193)-JVS(2361)*X(194)-JVS(2362)*X(203)-JVS(2363)*X(204)-JVS(2364)*X(211)-JVS(2365)*X(214)&
             &-JVS(2366)*X(229)-JVS(2367)*X(231)-JVS(2368)*X(233)-JVS(2369)*X(234)-JVS(2370)*X(235)-JVS(2371)*X(236)
  X(238) = X(238)-JVS(2383)*X(126)-JVS(2384)*X(201)-JVS(2385)*X(210)-JVS(2386)*X(226)-JVS(2387)*X(229)-JVS(2388)*X(236)
  X(239) = X(239)-JVS(2403)*X(59)-JVS(2404)*X(63)-JVS(2405)*X(74)-JVS(2406)*X(94)-JVS(2407)*X(121)-JVS(2408)*X(136)&
             &-JVS(2409)*X(139)-JVS(2410)*X(144)-JVS(2411)*X(151)-JVS(2412)*X(152)-JVS(2413)*X(165)-JVS(2414)*X(168)&
             &-JVS(2415)*X(170)-JVS(2416)*X(173)-JVS(2417)*X(174)-JVS(2418)*X(175)-JVS(2419)*X(178)-JVS(2420)*X(179)&
             &-JVS(2421)*X(180)-JVS(2422)*X(182)-JVS(2423)*X(183)-JVS(2424)*X(184)-JVS(2425)*X(185)-JVS(2426)*X(190)&
             &-JVS(2427)*X(192)-JVS(2428)*X(193)-JVS(2429)*X(194)-JVS(2430)*X(195)-JVS(2431)*X(198)-JVS(2432)*X(199)&
             &-JVS(2433)*X(200)-JVS(2434)*X(201)-JVS(2435)*X(203)-JVS(2436)*X(204)-JVS(2437)*X(205)-JVS(2438)*X(206)&
             &-JVS(2439)*X(207)-JVS(2440)*X(208)-JVS(2441)*X(211)-JVS(2442)*X(213)-JVS(2443)*X(214)-JVS(2444)*X(217)&
             &-JVS(2445)*X(218)-JVS(2446)*X(219)-JVS(2447)*X(220)-JVS(2448)*X(221)-JVS(2449)*X(222)-JVS(2450)*X(223)&
             &-JVS(2451)*X(224)-JVS(2452)*X(225)-JVS(2453)*X(226)-JVS(2454)*X(227)-JVS(2455)*X(228)-JVS(2456)*X(229)&
             &-JVS(2457)*X(230)-JVS(2458)*X(231)-JVS(2459)*X(232)-JVS(2460)*X(233)-JVS(2461)*X(234)-JVS(2462)*X(235)&
             &-JVS(2463)*X(236)-JVS(2464)*X(237)
  X(240) = X(240)-JVS(2476)*X(58)-JVS(2477)*X(67)-JVS(2478)*X(70)-JVS(2479)*X(91)-JVS(2480)*X(96)-JVS(2481)*X(111)&
             &-JVS(2482)*X(112)-JVS(2483)*X(115)-JVS(2484)*X(118)-JVS(2485)*X(121)-JVS(2486)*X(133)-JVS(2487)*X(136)&
             &-JVS(2488)*X(137)-JVS(2489)*X(138)-JVS(2490)*X(139)-JVS(2491)*X(140)-JVS(2492)*X(143)-JVS(2493)*X(144)&
             &-JVS(2494)*X(147)-JVS(2495)*X(151)-JVS(2496)*X(152)-JVS(2497)*X(153)-JVS(2498)*X(154)-JVS(2499)*X(155)&
             &-JVS(2500)*X(156)-JVS(2501)*X(163)-JVS(2502)*X(165)-JVS(2503)*X(167)-JVS(2504)*X(168)-JVS(2505)*X(170)&
             &-JVS(2506)*X(171)-JVS(2507)*X(173)-JVS(2508)*X(176)-JVS(2509)*X(180)-JVS(2510)*X(181)-JVS(2511)*X(182)&
             &-JVS(2512)*X(183)-JVS(2513)*X(184)-JVS(2514)*X(189)-JVS(2515)*X(190)-JVS(2516)*X(191)-JVS(2517)*X(192)&
             &-JVS(2518)*X(198)-JVS(2519)*X(199)-JVS(2520)*X(201)-JVS(2521)*X(205)-JVS(2522)*X(206)-JVS(2523)*X(207)&
             &-JVS(2524)*X(208)-JVS(2525)*X(210)-JVS(2526)*X(211)-JVS(2527)*X(213)-JVS(2528)*X(216)-JVS(2529)*X(217)&
             &-JVS(2530)*X(218)-JVS(2531)*X(219)-JVS(2532)*X(220)-JVS(2533)*X(221)-JVS(2534)*X(222)-JVS(2535)*X(223)&
             &-JVS(2536)*X(224)-JVS(2537)*X(225)-JVS(2538)*X(226)-JVS(2539)*X(227)-JVS(2540)*X(228)-JVS(2541)*X(229)&
             &-JVS(2542)*X(230)-JVS(2543)*X(231)-JVS(2544)*X(233)-JVS(2545)*X(234)-JVS(2546)*X(235)-JVS(2547)*X(236)&
             &-JVS(2548)*X(237)-JVS(2549)*X(238)-JVS(2550)*X(239)
  X(241) = X(241)-JVS(2565)*X(84)-JVS(2566)*X(85)-JVS(2567)*X(98)-JVS(2568)*X(101)-JVS(2569)*X(117)-JVS(2570)*X(126)&
             &-JVS(2571)*X(178)-JVS(2572)*X(179)-JVS(2573)*X(185)-JVS(2574)*X(195)-JVS(2575)*X(200)-JVS(2576)*X(204)&
             &-JVS(2577)*X(210)-JVS(2578)*X(229)-JVS(2579)*X(231)-JVS(2580)*X(232)-JVS(2581)*X(233)-JVS(2582)*X(234)&
             &-JVS(2583)*X(236)-JVS(2584)*X(237)-JVS(2585)*X(238)-JVS(2586)*X(239)-JVS(2587)*X(240)
  X(242) = X(242)-JVS(2601)*X(37)-JVS(2602)*X(43)-JVS(2603)*X(65)-JVS(2604)*X(73)-JVS(2605)*X(75)-JVS(2606)*X(78)&
             &-JVS(2607)*X(86)-JVS(2608)*X(101)-JVS(2609)*X(121)-JVS(2610)*X(123)-JVS(2611)*X(125)-JVS(2612)*X(126)&
             &-JVS(2613)*X(127)-JVS(2614)*X(135)-JVS(2615)*X(140)-JVS(2616)*X(143)-JVS(2617)*X(147)-JVS(2618)*X(148)&
             &-JVS(2619)*X(149)-JVS(2620)*X(150)-JVS(2621)*X(151)-JVS(2622)*X(152)-JVS(2623)*X(153)-JVS(2624)*X(154)&
             &-JVS(2625)*X(155)-JVS(2626)*X(162)-JVS(2627)*X(163)-JVS(2628)*X(164)-JVS(2629)*X(166)-JVS(2630)*X(167)&
             &-JVS(2631)*X(168)-JVS(2632)*X(170)-JVS(2633)*X(173)-JVS(2634)*X(174)-JVS(2635)*X(175)-JVS(2636)*X(178)&
             &-JVS(2637)*X(179)-JVS(2638)*X(180)-JVS(2639)*X(181)-JVS(2640)*X(182)-JVS(2641)*X(183)-JVS(2642)*X(184)&
             &-JVS(2643)*X(185)-JVS(2644)*X(189)-JVS(2645)*X(190)-JVS(2646)*X(193)-JVS(2647)*X(194)-JVS(2648)*X(195)&
             &-JVS(2649)*X(196)-JVS(2650)*X(198)-JVS(2651)*X(199)-JVS(2652)*X(200)-JVS(2653)*X(201)-JVS(2654)*X(203)&
             &-JVS(2655)*X(204)-JVS(2656)*X(205)-JVS(2657)*X(206)-JVS(2658)*X(207)-JVS(2659)*X(208)-JVS(2660)*X(210)&
             &-JVS(2661)*X(211)-JVS(2662)*X(213)-JVS(2663)*X(214)-JVS(2664)*X(216)-JVS(2665)*X(218)-JVS(2666)*X(219)&
             &-JVS(2667)*X(220)-JVS(2668)*X(221)-JVS(2669)*X(222)-JVS(2670)*X(223)-JVS(2671)*X(224)-JVS(2672)*X(225)&
             &-JVS(2673)*X(226)-JVS(2674)*X(227)-JVS(2675)*X(228)-JVS(2676)*X(229)-JVS(2677)*X(230)-JVS(2678)*X(231)&
             &-JVS(2679)*X(232)-JVS(2680)*X(233)-JVS(2681)*X(234)-JVS(2682)*X(235)-JVS(2683)*X(236)-JVS(2684)*X(237)&
             &-JVS(2685)*X(238)-JVS(2686)*X(239)-JVS(2687)*X(240)-JVS(2688)*X(241)
  X(243) = X(243)-JVS(2703)*X(38)-JVS(2704)*X(59)-JVS(2705)*X(63)-JVS(2706)*X(65)-JVS(2707)*X(75)-JVS(2708)*X(91)&
             &-JVS(2709)*X(92)-JVS(2710)*X(121)-JVS(2711)*X(123)-JVS(2712)*X(166)-JVS(2713)*X(178)-JVS(2714)*X(179)&
             &-JVS(2715)*X(183)-JVS(2716)*X(185)-JVS(2717)*X(187)-JVS(2718)*X(192)-JVS(2719)*X(193)-JVS(2720)*X(194)&
             &-JVS(2721)*X(195)-JVS(2722)*X(200)-JVS(2723)*X(201)-JVS(2724)*X(203)-JVS(2725)*X(204)-JVS(2726)*X(210)&
             &-JVS(2727)*X(211)-JVS(2728)*X(214)-JVS(2729)*X(222)-JVS(2730)*X(223)-JVS(2731)*X(224)-JVS(2732)*X(225)&
             &-JVS(2733)*X(226)-JVS(2734)*X(227)-JVS(2735)*X(228)-JVS(2736)*X(229)-JVS(2737)*X(230)-JVS(2738)*X(231)&
             &-JVS(2739)*X(232)-JVS(2740)*X(233)-JVS(2741)*X(234)-JVS(2742)*X(235)-JVS(2743)*X(236)-JVS(2744)*X(237)&
             &-JVS(2745)*X(238)-JVS(2746)*X(239)-JVS(2747)*X(240)-JVS(2748)*X(241)-JVS(2749)*X(242)
  X(244) = X(244)-JVS(2763)*X(53)-JVS(2764)*X(54)-JVS(2765)*X(55)-JVS(2766)*X(56)-JVS(2767)*X(57)-JVS(2768)*X(61)&
             &-JVS(2769)*X(80)-JVS(2770)*X(86)-JVS(2771)*X(97)-JVS(2772)*X(107)-JVS(2773)*X(108)-JVS(2774)*X(128)-JVS(2775)&
             &*X(129)-JVS(2776)*X(132)-JVS(2777)*X(133)-JVS(2778)*X(135)-JVS(2779)*X(148)-JVS(2780)*X(149)-JVS(2781)*X(150)&
             &-JVS(2782)*X(163)-JVS(2783)*X(164)-JVS(2784)*X(167)-JVS(2785)*X(168)-JVS(2786)*X(169)-JVS(2787)*X(170)&
             &-JVS(2788)*X(173)-JVS(2789)*X(178)-JVS(2790)*X(179)-JVS(2791)*X(180)-JVS(2792)*X(181)-JVS(2793)*X(183)&
             &-JVS(2794)*X(185)-JVS(2795)*X(188)-JVS(2796)*X(190)-JVS(2797)*X(193)-JVS(2798)*X(194)-JVS(2799)*X(195)&
             &-JVS(2800)*X(197)-JVS(2801)*X(198)-JVS(2802)*X(199)-JVS(2803)*X(200)-JVS(2804)*X(201)-JVS(2805)*X(203)&
             &-JVS(2806)*X(204)-JVS(2807)*X(205)-JVS(2808)*X(206)-JVS(2809)*X(210)-JVS(2810)*X(211)-JVS(2811)*X(213)&
             &-JVS(2812)*X(214)-JVS(2813)*X(218)-JVS(2814)*X(220)-JVS(2815)*X(221)-JVS(2816)*X(222)-JVS(2817)*X(223)&
             &-JVS(2818)*X(224)-JVS(2819)*X(225)-JVS(2820)*X(226)-JVS(2821)*X(227)-JVS(2822)*X(229)-JVS(2823)*X(230)&
             &-JVS(2824)*X(231)-JVS(2825)*X(232)-JVS(2826)*X(233)-JVS(2827)*X(234)-JVS(2828)*X(235)-JVS(2829)*X(236)&
             &-JVS(2830)*X(237)-JVS(2831)*X(238)-JVS(2832)*X(239)-JVS(2833)*X(240)-JVS(2834)*X(241)-JVS(2835)*X(242)&
             &-JVS(2836)*X(243)
  X(245) = X(245)-JVS(2850)*X(109)-JVS(2851)*X(142)-JVS(2852)*X(192)-JVS(2853)*X(202)-JVS(2854)*X(209)-JVS(2855)*X(211)&
             &-JVS(2856)*X(215)-JVS(2857)*X(233)-JVS(2858)*X(234)-JVS(2859)*X(235)-JVS(2860)*X(236)-JVS(2861)*X(237)&
             &-JVS(2862)*X(239)-JVS(2863)*X(241)-JVS(2864)*X(242)-JVS(2865)*X(243)-JVS(2866)*X(244)
  X(246) = X(246)-JVS(2881)*X(59)-JVS(2882)*X(65)-JVS(2883)*X(75)-JVS(2884)*X(86)-JVS(2885)*X(93)-JVS(2886)*X(100)&
             &-JVS(2887)*X(119)-JVS(2888)*X(131)-JVS(2889)*X(136)-JVS(2890)*X(137)-JVS(2891)*X(138)-JVS(2892)*X(142)&
             &-JVS(2893)*X(146)-JVS(2894)*X(154)-JVS(2895)*X(158)-JVS(2896)*X(159)-JVS(2897)*X(160)-JVS(2898)*X(177)&
             &-JVS(2899)*X(183)-JVS(2900)*X(184)-JVS(2901)*X(188)-JVS(2902)*X(189)-JVS(2903)*X(190)-JVS(2904)*X(193)&
             &-JVS(2905)*X(194)-JVS(2906)*X(197)-JVS(2907)*X(198)-JVS(2908)*X(199)-JVS(2909)*X(201)-JVS(2910)*X(203)&
             &-JVS(2911)*X(205)-JVS(2912)*X(206)-JVS(2913)*X(207)-JVS(2914)*X(210)-JVS(2915)*X(211)-JVS(2916)*X(212)&
             &-JVS(2917)*X(213)-JVS(2918)*X(215)-JVS(2919)*X(216)-JVS(2920)*X(217)-JVS(2921)*X(218)-JVS(2922)*X(219)&
             &-JVS(2923)*X(220)-JVS(2924)*X(221)-JVS(2925)*X(222)-JVS(2926)*X(223)-JVS(2927)*X(224)-JVS(2928)*X(225)&
             &-JVS(2929)*X(226)-JVS(2930)*X(227)-JVS(2931)*X(228)-JVS(2932)*X(229)-JVS(2933)*X(230)-JVS(2934)*X(231)&
             &-JVS(2935)*X(233)-JVS(2936)*X(234)-JVS(2937)*X(235)-JVS(2938)*X(236)-JVS(2939)*X(237)-JVS(2940)*X(238)&
             &-JVS(2941)*X(239)-JVS(2942)*X(240)-JVS(2943)*X(241)-JVS(2944)*X(242)-JVS(2945)*X(243)-JVS(2946)*X(244)&
             &-JVS(2947)*X(245)
  X(247) = X(247)-JVS(2961)*X(4)-JVS(2962)*X(5)-JVS(2963)*X(42)-JVS(2964)*X(44)-JVS(2965)*X(57)-JVS(2966)*X(59)&
             &-JVS(2967)*X(65)-JVS(2968)*X(76)-JVS(2969)*X(77)-JVS(2970)*X(78)-JVS(2971)*X(79)-JVS(2972)*X(80)-JVS(2973)&
             &*X(85)-JVS(2974)*X(87)-JVS(2975)*X(93)-JVS(2976)*X(97)-JVS(2977)*X(102)-JVS(2978)*X(107)-JVS(2979)*X(108)&
             &-JVS(2980)*X(119)-JVS(2981)*X(125)-JVS(2982)*X(127)-JVS(2983)*X(128)-JVS(2984)*X(129)-JVS(2985)*X(131)&
             &-JVS(2986)*X(132)-JVS(2987)*X(133)-JVS(2988)*X(134)-JVS(2989)*X(135)-JVS(2990)*X(136)-JVS(2991)*X(146)&
             &-JVS(2992)*X(148)-JVS(2993)*X(149)-JVS(2994)*X(150)-JVS(2995)*X(158)-JVS(2996)*X(159)-JVS(2997)*X(160)&
             &-JVS(2998)*X(162)-JVS(2999)*X(163)-JVS(3000)*X(164)-JVS(3001)*X(167)-JVS(3002)*X(168)-JVS(3003)*X(169)&
             &-JVS(3004)*X(170)-JVS(3005)*X(173)-JVS(3006)*X(175)-JVS(3007)*X(176)-JVS(3008)*X(177)-JVS(3009)*X(178)&
             &-JVS(3010)*X(179)-JVS(3011)*X(180)-JVS(3012)*X(181)-JVS(3013)*X(183)-JVS(3014)*X(184)-JVS(3015)*X(185)&
             &-JVS(3016)*X(188)-JVS(3017)*X(190)-JVS(3018)*X(191)-JVS(3019)*X(193)-JVS(3020)*X(194)-JVS(3021)*X(195)&
             &-JVS(3022)*X(197)-JVS(3023)*X(198)-JVS(3024)*X(199)-JVS(3025)*X(200)-JVS(3026)*X(201)-JVS(3027)*X(203)&
             &-JVS(3028)*X(204)-JVS(3029)*X(205)-JVS(3030)*X(206)-JVS(3031)*X(210)-JVS(3032)*X(211)-JVS(3033)*X(212)&
             &-JVS(3034)*X(213)-JVS(3035)*X(214)-JVS(3036)*X(215)-JVS(3037)*X(216)-JVS(3038)*X(217)-JVS(3039)*X(218)&
             &-JVS(3040)*X(219)-JVS(3041)*X(220)-JVS(3042)*X(221)-JVS(3043)*X(222)-JVS(3044)*X(223)-JVS(3045)*X(224)&
             &-JVS(3046)*X(225)-JVS(3047)*X(226)-JVS(3048)*X(227)-JVS(3049)*X(228)-JVS(3050)*X(229)-JVS(3051)*X(230)&
             &-JVS(3052)*X(231)-JVS(3053)*X(232)-JVS(3054)*X(233)-JVS(3055)*X(234)-JVS(3056)*X(235)-JVS(3057)*X(236)&
             &-JVS(3058)*X(237)-JVS(3059)*X(238)-JVS(3060)*X(239)-JVS(3061)*X(240)-JVS(3062)*X(241)-JVS(3063)*X(242)&
             &-JVS(3064)*X(243)-JVS(3065)*X(244)-JVS(3066)*X(245)-JVS(3067)*X(246)
  X(248) = X(248)-JVS(3080)*X(55)-JVS(3081)*X(56)-JVS(3082)*X(61)-JVS(3083)*X(65)-JVS(3084)*X(67)-JVS(3085)*X(70)&
             &-JVS(3086)*X(73)-JVS(3087)*X(77)-JVS(3088)*X(78)-JVS(3089)*X(79)-JVS(3090)*X(81)-JVS(3091)*X(82)-JVS(3092)&
             &*X(83)-JVS(3093)*X(84)-JVS(3094)*X(85)-JVS(3095)*X(86)-JVS(3096)*X(91)-JVS(3097)*X(92)-JVS(3098)*X(93)&
             &-JVS(3099)*X(94)-JVS(3100)*X(96)-JVS(3101)*X(98)-JVS(3102)*X(101)-JVS(3103)*X(102)-JVS(3104)*X(103)-JVS(3105)&
             &*X(104)-JVS(3106)*X(105)-JVS(3107)*X(107)-JVS(3108)*X(108)-JVS(3109)*X(110)-JVS(3110)*X(111)-JVS(3111)*X(112)&
             &-JVS(3112)*X(115)-JVS(3113)*X(116)-JVS(3114)*X(117)-JVS(3115)*X(118)-JVS(3116)*X(120)-JVS(3117)*X(123)&
             &-JVS(3118)*X(125)-JVS(3119)*X(126)-JVS(3120)*X(127)-JVS(3121)*X(128)-JVS(3122)*X(129)-JVS(3123)*X(130)&
             &-JVS(3124)*X(132)-JVS(3125)*X(133)-JVS(3126)*X(134)-JVS(3127)*X(135)-JVS(3128)*X(137)-JVS(3129)*X(138)&
             &-JVS(3130)*X(139)-JVS(3131)*X(140)-JVS(3132)*X(141)-JVS(3133)*X(143)-JVS(3134)*X(144)-JVS(3135)*X(145)&
             &-JVS(3136)*X(147)-JVS(3137)*X(148)-JVS(3138)*X(149)-JVS(3139)*X(150)-JVS(3140)*X(151)-JVS(3141)*X(152)&
             &-JVS(3142)*X(153)-JVS(3143)*X(154)-JVS(3144)*X(156)-JVS(3145)*X(157)-JVS(3146)*X(162)-JVS(3147)*X(163)&
             &-JVS(3148)*X(164)-JVS(3149)*X(165)-JVS(3150)*X(166)-JVS(3151)*X(167)-JVS(3152)*X(168)-JVS(3153)*X(169)&
             &-JVS(3154)*X(170)-JVS(3155)*X(171)-JVS(3156)*X(172)-JVS(3157)*X(173)-JVS(3158)*X(176)-JVS(3159)*X(178)&
             &-JVS(3160)*X(179)-JVS(3161)*X(180)-JVS(3162)*X(181)-JVS(3163)*X(182)-JVS(3164)*X(183)-JVS(3165)*X(184)&
             &-JVS(3166)*X(185)-JVS(3167)*X(186)-JVS(3168)*X(188)-JVS(3169)*X(189)-JVS(3170)*X(190)-JVS(3171)*X(191)&
             &-JVS(3172)*X(193)-JVS(3173)*X(194)-JVS(3174)*X(195)-JVS(3175)*X(196)-JVS(3176)*X(197)-JVS(3177)*X(198)&
             &-JVS(3178)*X(199)-JVS(3179)*X(200)-JVS(3180)*X(201)-JVS(3181)*X(203)-JVS(3182)*X(204)-JVS(3183)*X(205)&
             &-JVS(3184)*X(206)-JVS(3185)*X(207)-JVS(3186)*X(208)-JVS(3187)*X(210)-JVS(3188)*X(211)-JVS(3189)*X(213)&
             &-JVS(3190)*X(214)-JVS(3191)*X(216)-JVS(3192)*X(217)-JVS(3193)*X(218)-JVS(3194)*X(219)-JVS(3195)*X(220)&
             &-JVS(3196)*X(221)-JVS(3197)*X(222)-JVS(3198)*X(223)-JVS(3199)*X(224)-JVS(3200)*X(225)-JVS(3201)*X(226)&
             &-JVS(3202)*X(227)-JVS(3203)*X(228)-JVS(3204)*X(229)-JVS(3205)*X(230)-JVS(3206)*X(231)-JVS(3207)*X(232)&
             &-JVS(3208)*X(233)-JVS(3209)*X(234)-JVS(3210)*X(235)-JVS(3211)*X(236)-JVS(3212)*X(237)-JVS(3213)*X(238)&
             &-JVS(3214)*X(239)-JVS(3215)*X(240)-JVS(3216)*X(241)-JVS(3217)*X(242)-JVS(3218)*X(243)-JVS(3219)*X(244)&
             &-JVS(3220)*X(245)-JVS(3221)*X(246)-JVS(3222)*X(247)
  X(249) = X(249)-JVS(3234)*X(2)-JVS(3235)*X(39)-JVS(3236)*X(40)-JVS(3237)*X(44)-JVS(3238)*X(51)-JVS(3239)*X(52)&
             &-JVS(3240)*X(66)-JVS(3241)*X(69)-JVS(3242)*X(76)-JVS(3243)*X(92)-JVS(3244)*X(106)-JVS(3245)*X(109)-JVS(3246)&
             &*X(113)-JVS(3247)*X(114)-JVS(3248)*X(122)-JVS(3249)*X(124)-JVS(3250)*X(142)-JVS(3251)*X(146)-JVS(3252)*X(158)&
             &-JVS(3253)*X(160)-JVS(3254)*X(188)-JVS(3255)*X(192)-JVS(3256)*X(197)-JVS(3257)*X(202)-JVS(3258)*X(209)&
             &-JVS(3259)*X(211)-JVS(3260)*X(215)-JVS(3261)*X(233)-JVS(3262)*X(234)-JVS(3263)*X(235)-JVS(3264)*X(236)&
             &-JVS(3265)*X(237)-JVS(3266)*X(239)-JVS(3267)*X(241)-JVS(3268)*X(242)-JVS(3269)*X(243)-JVS(3270)*X(244)&
             &-JVS(3271)*X(245)-JVS(3272)*X(246)-JVS(3273)*X(247)-JVS(3274)*X(248)
  X(250) = X(250)-JVS(3285)*X(34)-JVS(3286)*X(38)-JVS(3287)*X(58)-JVS(3288)*X(60)-JVS(3289)*X(62)-JVS(3290)*X(63)&
             &-JVS(3291)*X(66)-JVS(3292)*X(67)-JVS(3293)*X(68)-JVS(3294)*X(69)-JVS(3295)*X(70)-JVS(3296)*X(71)-JVS(3297)&
             &*X(72)-JVS(3298)*X(73)-JVS(3299)*X(74)-JVS(3300)*X(75)-JVS(3301)*X(77)-JVS(3302)*X(78)-JVS(3303)*X(79)&
             &-JVS(3304)*X(81)-JVS(3305)*X(82)-JVS(3306)*X(83)-JVS(3307)*X(84)-JVS(3308)*X(85)-JVS(3309)*X(87)-JVS(3310)&
             &*X(88)-JVS(3311)*X(89)-JVS(3312)*X(91)-JVS(3313)*X(92)-JVS(3314)*X(93)-JVS(3315)*X(94)-JVS(3316)*X(96)&
             &-JVS(3317)*X(97)-JVS(3318)*X(98)-JVS(3319)*X(99)-JVS(3320)*X(100)-JVS(3321)*X(101)-JVS(3322)*X(102)-JVS(3323)&
             &*X(103)-JVS(3324)*X(104)-JVS(3325)*X(105)-JVS(3326)*X(107)-JVS(3327)*X(108)-JVS(3328)*X(109)-JVS(3329)*X(111)&
             &-JVS(3330)*X(112)-JVS(3331)*X(113)-JVS(3332)*X(114)-JVS(3333)*X(115)-JVS(3334)*X(116)-JVS(3335)*X(117)&
             &-JVS(3336)*X(118)-JVS(3337)*X(119)-JVS(3338)*X(120)-JVS(3339)*X(121)-JVS(3340)*X(122)-JVS(3341)*X(123)&
             &-JVS(3342)*X(124)-JVS(3343)*X(125)-JVS(3344)*X(126)-JVS(3345)*X(127)-JVS(3346)*X(128)-JVS(3347)*X(129)&
             &-JVS(3348)*X(130)-JVS(3349)*X(131)-JVS(3350)*X(132)-JVS(3351)*X(133)-JVS(3352)*X(134)-JVS(3353)*X(135)&
             &-JVS(3354)*X(136)-JVS(3355)*X(137)-JVS(3356)*X(138)-JVS(3357)*X(139)-JVS(3358)*X(140)-JVS(3359)*X(141)&
             &-JVS(3360)*X(142)-JVS(3361)*X(143)-JVS(3362)*X(144)-JVS(3363)*X(145)-JVS(3364)*X(147)-JVS(3365)*X(148)&
             &-JVS(3366)*X(149)-JVS(3367)*X(150)-JVS(3368)*X(151)-JVS(3369)*X(152)-JVS(3370)*X(153)-JVS(3371)*X(154)&
             &-JVS(3372)*X(156)-JVS(3373)*X(157)-JVS(3374)*X(158)-JVS(3375)*X(159)-JVS(3376)*X(160)-JVS(3377)*X(161)&
             &-JVS(3378)*X(162)-JVS(3379)*X(163)-JVS(3380)*X(164)-JVS(3381)*X(166)-JVS(3382)*X(167)-JVS(3383)*X(168)&
             &-JVS(3384)*X(169)-JVS(3385)*X(170)-JVS(3386)*X(171)-JVS(3387)*X(172)-JVS(3388)*X(173)-JVS(3389)*X(174)&
             &-JVS(3390)*X(175)-JVS(3391)*X(176)-JVS(3392)*X(177)-JVS(3393)*X(178)-JVS(3394)*X(179)-JVS(3395)*X(180)&
             &-JVS(3396)*X(181)-JVS(3397)*X(182)-JVS(3398)*X(183)-JVS(3399)*X(184)-JVS(3400)*X(185)-JVS(3401)*X(186)&
             &-JVS(3402)*X(187)-JVS(3403)*X(188)-JVS(3404)*X(189)-JVS(3405)*X(190)-JVS(3406)*X(191)-JVS(3407)*X(192)&
             &-JVS(3408)*X(193)-JVS(3409)*X(194)-JVS(3410)*X(195)-JVS(3411)*X(196)-JVS(3412)*X(197)-JVS(3413)*X(198)&
             &-JVS(3414)*X(199)-JVS(3415)*X(200)-JVS(3416)*X(201)-JVS(3417)*X(202)-JVS(3418)*X(203)-JVS(3419)*X(204)&
             &-JVS(3420)*X(205)-JVS(3421)*X(206)-JVS(3422)*X(207)-JVS(3423)*X(208)-JVS(3424)*X(209)-JVS(3425)*X(210)&
             &-JVS(3426)*X(211)-JVS(3427)*X(212)-JVS(3428)*X(213)-JVS(3429)*X(214)-JVS(3430)*X(215)-JVS(3431)*X(216)&
             &-JVS(3432)*X(217)-JVS(3433)*X(218)-JVS(3434)*X(219)-JVS(3435)*X(220)-JVS(3436)*X(221)-JVS(3437)*X(222)&
             &-JVS(3438)*X(223)-JVS(3439)*X(224)-JVS(3440)*X(225)-JVS(3441)*X(226)-JVS(3442)*X(227)-JVS(3443)*X(228)&
             &-JVS(3444)*X(229)-JVS(3445)*X(230)-JVS(3446)*X(231)-JVS(3447)*X(232)-JVS(3448)*X(233)-JVS(3449)*X(234)&
             &-JVS(3450)*X(235)-JVS(3451)*X(236)-JVS(3452)*X(237)-JVS(3453)*X(238)-JVS(3454)*X(239)-JVS(3455)*X(240)&
             &-JVS(3456)*X(241)-JVS(3457)*X(242)-JVS(3458)*X(243)-JVS(3459)*X(244)-JVS(3460)*X(245)-JVS(3461)*X(246)&
             &-JVS(3462)*X(247)-JVS(3463)*X(248)-JVS(3464)*X(249)
  X(251) = X(251)-JVS(3474)*X(39)-JVS(3475)*X(40)-JVS(3476)*X(51)-JVS(3477)*X(66)-JVS(3478)*X(69)-JVS(3479)*X(92)&
             &-JVS(3480)*X(158)-JVS(3481)*X(188)-JVS(3482)*X(197)-JVS(3483)*X(202)-JVS(3484)*X(215)-JVS(3485)*X(244)&
             &-JVS(3486)*X(245)-JVS(3487)*X(246)-JVS(3488)*X(247)-JVS(3489)*X(248)-JVS(3490)*X(249)-JVS(3491)*X(250)
  X(252) = X(252)-JVS(3500)*X(67)-JVS(3501)*X(70)-JVS(3502)*X(91)-JVS(3503)*X(100)-JVS(3504)*X(109)-JVS(3505)*X(117)&
             &-JVS(3506)*X(123)-JVS(3507)*X(131)-JVS(3508)*X(142)-JVS(3509)*X(158)-JVS(3510)*X(166)-JVS(3511)*X(172)&
             &-JVS(3512)*X(186)-JVS(3513)*X(187)-JVS(3514)*X(192)-JVS(3515)*X(195)-JVS(3516)*X(196)-JVS(3517)*X(201)&
             &-JVS(3518)*X(202)-JVS(3519)*X(203)-JVS(3520)*X(204)-JVS(3521)*X(209)-JVS(3522)*X(210)-JVS(3523)*X(211)&
             &-JVS(3524)*X(214)-JVS(3525)*X(215)-JVS(3526)*X(216)-JVS(3527)*X(218)-JVS(3528)*X(219)-JVS(3529)*X(220)&
             &-JVS(3530)*X(221)-JVS(3531)*X(222)-JVS(3532)*X(223)-JVS(3533)*X(224)-JVS(3534)*X(225)-JVS(3535)*X(226)&
             &-JVS(3536)*X(227)-JVS(3537)*X(228)-JVS(3538)*X(229)-JVS(3539)*X(230)-JVS(3540)*X(231)-JVS(3541)*X(232)&
             &-JVS(3542)*X(233)-JVS(3543)*X(234)-JVS(3544)*X(235)-JVS(3545)*X(236)-JVS(3546)*X(237)-JVS(3547)*X(238)&
             &-JVS(3548)*X(239)-JVS(3549)*X(240)-JVS(3550)*X(241)-JVS(3551)*X(242)-JVS(3552)*X(243)-JVS(3553)*X(244)&
             &-JVS(3554)*X(245)-JVS(3555)*X(246)-JVS(3556)*X(247)-JVS(3557)*X(248)-JVS(3558)*X(249)-JVS(3559)*X(250)&
             &-JVS(3560)*X(251)
  X(253) = X(253)-JVS(3568)*X(45)-JVS(3569)*X(46)-JVS(3570)*X(47)-JVS(3571)*X(48)-JVS(3572)*X(49)-JVS(3573)*X(50)&
             &-JVS(3574)*X(51)-JVS(3575)*X(68)-JVS(3576)*X(71)-JVS(3577)*X(72)-JVS(3578)*X(88)-JVS(3579)*X(89)-JVS(3580)&
             &*X(95)-JVS(3581)*X(99)-JVS(3582)*X(161)-JVS(3583)*X(195)-JVS(3584)*X(197)-JVS(3585)*X(209)-JVS(3586)*X(215)&
             &-JVS(3587)*X(232)-JVS(3588)*X(233)-JVS(3589)*X(234)-JVS(3590)*X(237)-JVS(3591)*X(239)-JVS(3592)*X(241)&
             &-JVS(3593)*X(242)-JVS(3594)*X(243)-JVS(3595)*X(244)-JVS(3596)*X(245)-JVS(3597)*X(246)-JVS(3598)*X(247)&
             &-JVS(3599)*X(248)-JVS(3600)*X(249)-JVS(3601)*X(250)-JVS(3602)*X(251)-JVS(3603)*X(252)
  X(254) = X(254)-JVS(3610)*X(39)-JVS(3611)*X(40)-JVS(3612)*X(45)-JVS(3613)*X(46)-JVS(3614)*X(47)-JVS(3615)*X(48)&
             &-JVS(3616)*X(49)-JVS(3617)*X(50)-JVS(3618)*X(51)-JVS(3619)*X(54)-JVS(3620)*X(57)-JVS(3621)*X(66)-JVS(3622)&
             &*X(69)-JVS(3623)*X(71)-JVS(3624)*X(72)-JVS(3625)*X(88)-JVS(3626)*X(89)-JVS(3627)*X(92)-JVS(3628)*X(161)&
             &-JVS(3629)*X(166)-JVS(3630)*X(209)-JVS(3631)*X(215)-JVS(3632)*X(236)-JVS(3633)*X(239)-JVS(3634)*X(241)&
             &-JVS(3635)*X(242)-JVS(3636)*X(243)-JVS(3637)*X(244)-JVS(3638)*X(245)-JVS(3639)*X(246)-JVS(3640)*X(247)&
             &-JVS(3641)*X(248)-JVS(3642)*X(249)-JVS(3643)*X(250)-JVS(3644)*X(251)-JVS(3645)*X(252)-JVS(3646)*X(253)
  X(255) = X(255)-JVS(3652)*X(3)-JVS(3653)*X(34)-JVS(3654)*X(45)-JVS(3655)*X(46)-JVS(3656)*X(47)-JVS(3657)*X(48)&
             &-JVS(3658)*X(49)-JVS(3659)*X(50)-JVS(3660)*X(51)-JVS(3661)*X(64)-JVS(3662)*X(67)-JVS(3663)*X(68)-JVS(3664)&
             &*X(70)-JVS(3665)*X(71)-JVS(3666)*X(72)-JVS(3667)*X(76)-JVS(3668)*X(87)-JVS(3669)*X(88)-JVS(3670)*X(89)&
             &-JVS(3671)*X(91)-JVS(3672)*X(95)-JVS(3673)*X(100)-JVS(3674)*X(106)-JVS(3675)*X(109)-JVS(3676)*X(113)-JVS(3677)&
             &*X(117)-JVS(3678)*X(122)-JVS(3679)*X(123)-JVS(3680)*X(124)-JVS(3681)*X(131)-JVS(3682)*X(142)-JVS(3683)*X(146)&
             &-JVS(3684)*X(158)-JVS(3685)*X(160)-JVS(3686)*X(161)-JVS(3687)*X(166)-JVS(3688)*X(172)-JVS(3689)*X(186)&
             &-JVS(3690)*X(187)-JVS(3691)*X(188)-JVS(3692)*X(192)-JVS(3693)*X(195)-JVS(3694)*X(196)-JVS(3695)*X(197)&
             &-JVS(3696)*X(201)-JVS(3697)*X(202)-JVS(3698)*X(203)-JVS(3699)*X(204)-JVS(3700)*X(209)-JVS(3701)*X(210)&
             &-JVS(3702)*X(211)-JVS(3703)*X(214)-JVS(3704)*X(215)-JVS(3705)*X(216)-JVS(3706)*X(218)-JVS(3707)*X(219)&
             &-JVS(3708)*X(220)-JVS(3709)*X(221)-JVS(3710)*X(222)-JVS(3711)*X(223)-JVS(3712)*X(224)-JVS(3713)*X(225)&
             &-JVS(3714)*X(226)-JVS(3715)*X(227)-JVS(3716)*X(228)-JVS(3717)*X(229)-JVS(3718)*X(230)-JVS(3719)*X(231)&
             &-JVS(3720)*X(232)-JVS(3721)*X(233)-JVS(3722)*X(234)-JVS(3723)*X(235)-JVS(3724)*X(236)-JVS(3725)*X(237)&
             &-JVS(3726)*X(238)-JVS(3727)*X(239)-JVS(3728)*X(240)-JVS(3729)*X(241)-JVS(3730)*X(242)-JVS(3731)*X(243)&
             &-JVS(3732)*X(244)-JVS(3733)*X(245)-JVS(3734)*X(246)-JVS(3735)*X(247)-JVS(3736)*X(248)-JVS(3737)*X(249)&
             &-JVS(3738)*X(250)-JVS(3739)*X(251)-JVS(3740)*X(252)-JVS(3741)*X(253)-JVS(3742)*X(254)
  X(256) = X(256)-JVS(3747)*X(34)-JVS(3748)*X(38)-JVS(3749)*X(62)-JVS(3750)*X(71)-JVS(3751)*X(72)-JVS(3752)*X(88)&
             &-JVS(3753)*X(89)-JVS(3754)*X(91)-JVS(3755)*X(92)-JVS(3756)*X(93)-JVS(3757)*X(97)-JVS(3758)*X(113)-JVS(3759)&
             &*X(123)-JVS(3760)*X(131)-JVS(3761)*X(142)-JVS(3762)*X(157)-JVS(3763)*X(158)-JVS(3764)*X(160)-JVS(3765)*X(166)&
             &-JVS(3766)*X(172)-JVS(3767)*X(174)-JVS(3768)*X(186)-JVS(3769)*X(187)-JVS(3770)*X(188)-JVS(3771)*X(192)&
             &-JVS(3772)*X(195)-JVS(3773)*X(197)-JVS(3774)*X(198)-JVS(3775)*X(201)-JVS(3776)*X(202)-JVS(3777)*X(204)&
             &-JVS(3778)*X(208)-JVS(3779)*X(209)-JVS(3780)*X(210)-JVS(3781)*X(211)-JVS(3782)*X(212)-JVS(3783)*X(213)&
             &-JVS(3784)*X(214)-JVS(3785)*X(215)-JVS(3786)*X(216)-JVS(3787)*X(217)-JVS(3788)*X(218)-JVS(3789)*X(219)&
             &-JVS(3790)*X(220)-JVS(3791)*X(221)-JVS(3792)*X(222)-JVS(3793)*X(223)-JVS(3794)*X(224)-JVS(3795)*X(225)&
             &-JVS(3796)*X(226)-JVS(3797)*X(227)-JVS(3798)*X(228)-JVS(3799)*X(229)-JVS(3800)*X(230)-JVS(3801)*X(231)&
             &-JVS(3802)*X(232)-JVS(3803)*X(233)-JVS(3804)*X(234)-JVS(3805)*X(235)-JVS(3806)*X(236)-JVS(3807)*X(237)&
             &-JVS(3808)*X(238)-JVS(3809)*X(239)-JVS(3810)*X(240)-JVS(3811)*X(241)-JVS(3812)*X(242)-JVS(3813)*X(243)&
             &-JVS(3814)*X(244)-JVS(3815)*X(245)-JVS(3816)*X(246)-JVS(3817)*X(247)-JVS(3818)*X(248)-JVS(3819)*X(249)&
             &-JVS(3820)*X(250)-JVS(3821)*X(251)-JVS(3822)*X(252)-JVS(3823)*X(253)-JVS(3824)*X(254)-JVS(3825)*X(255)
  X(257) = X(257)-JVS(3829)*X(122)-JVS(3830)*X(124)-JVS(3831)*X(137)-JVS(3832)*X(138)-JVS(3833)*X(154)-JVS(3834)*X(157)&
             &-JVS(3835)*X(166)-JVS(3836)*X(177)-JVS(3837)*X(183)-JVS(3838)*X(188)-JVS(3839)*X(193)-JVS(3840)*X(194)&
             &-JVS(3841)*X(197)-JVS(3842)*X(200)-JVS(3843)*X(201)-JVS(3844)*X(202)-JVS(3845)*X(203)-JVS(3846)*X(211)&
             &-JVS(3847)*X(215)-JVS(3848)*X(226)-JVS(3849)*X(227)-JVS(3850)*X(229)-JVS(3851)*X(231)-JVS(3852)*X(233)&
             &-JVS(3853)*X(234)-JVS(3854)*X(236)-JVS(3855)*X(237)-JVS(3856)*X(238)-JVS(3857)*X(239)-JVS(3858)*X(240)&
             &-JVS(3859)*X(241)-JVS(3860)*X(242)-JVS(3861)*X(243)-JVS(3862)*X(244)-JVS(3863)*X(245)-JVS(3864)*X(246)&
             &-JVS(3865)*X(247)-JVS(3866)*X(248)-JVS(3867)*X(249)-JVS(3868)*X(250)-JVS(3869)*X(251)-JVS(3870)*X(252)&
             &-JVS(3871)*X(253)-JVS(3872)*X(254)-JVS(3873)*X(255)-JVS(3874)*X(256)
  X(258) = X(258)-JVS(3877)*X(39)-JVS(3878)*X(40)-JVS(3879)*X(45)-JVS(3880)*X(46)-JVS(3881)*X(47)-JVS(3882)*X(48)&
             &-JVS(3883)*X(49)-JVS(3884)*X(50)-JVS(3885)*X(51)-JVS(3886)*X(57)-JVS(3887)*X(58)-JVS(3888)*X(66)-JVS(3889)&
             &*X(69)-JVS(3890)*X(71)-JVS(3891)*X(72)-JVS(3892)*X(88)-JVS(3893)*X(89)-JVS(3894)*X(99)-JVS(3895)*X(157)&
             &-JVS(3896)*X(161)-JVS(3897)*X(166)-JVS(3898)*X(172)-JVS(3899)*X(197)-JVS(3900)*X(201)-JVS(3901)*X(202)&
             &-JVS(3902)*X(209)-JVS(3903)*X(210)-JVS(3904)*X(215)-JVS(3905)*X(229)-JVS(3906)*X(236)-JVS(3907)*X(238)&
             &-JVS(3908)*X(239)-JVS(3909)*X(240)-JVS(3910)*X(241)-JVS(3911)*X(242)-JVS(3912)*X(243)-JVS(3913)*X(244)&
             &-JVS(3914)*X(245)-JVS(3915)*X(246)-JVS(3916)*X(247)-JVS(3917)*X(248)-JVS(3918)*X(249)-JVS(3919)*X(250)&
             &-JVS(3920)*X(251)-JVS(3921)*X(252)-JVS(3922)*X(253)-JVS(3923)*X(254)-JVS(3924)*X(255)-JVS(3925)*X(256)&
             &-JVS(3926)*X(257)
  X(258) = X(258)/JVS(3927)
  X(257) = (X(257)-JVS(3876)*X(258))/(JVS(3875))
  X(256) = (X(256)-JVS(3827)*X(257)-JVS(3828)*X(258))/(JVS(3826))
  X(255) = (X(255)-JVS(3744)*X(256)-JVS(3745)*X(257)-JVS(3746)*X(258))/(JVS(3743))
  X(254) = (X(254)-JVS(3648)*X(255)-JVS(3649)*X(256)-JVS(3650)*X(257)-JVS(3651)*X(258))/(JVS(3647))
  X(253) = (X(253)-JVS(3605)*X(254)-JVS(3606)*X(255)-JVS(3607)*X(256)-JVS(3608)*X(257)-JVS(3609)*X(258))/(JVS(3604))
  X(252) = (X(252)-JVS(3562)*X(253)-JVS(3563)*X(254)-JVS(3564)*X(255)-JVS(3565)*X(256)-JVS(3566)*X(257)-JVS(3567)&
             &*X(258))/(JVS(3561))
  X(251) = (X(251)-JVS(3493)*X(252)-JVS(3494)*X(253)-JVS(3495)*X(254)-JVS(3496)*X(255)-JVS(3497)*X(256)-JVS(3498)*X(257)&
             &-JVS(3499)*X(258))/(JVS(3492))
  X(250) = (X(250)-JVS(3466)*X(251)-JVS(3467)*X(252)-JVS(3468)*X(253)-JVS(3469)*X(254)-JVS(3470)*X(255)-JVS(3471)*X(256)&
             &-JVS(3472)*X(257)-JVS(3473)*X(258))/(JVS(3465))
  X(249) = (X(249)-JVS(3276)*X(250)-JVS(3277)*X(251)-JVS(3278)*X(252)-JVS(3279)*X(253)-JVS(3280)*X(254)-JVS(3281)*X(255)&
             &-JVS(3282)*X(256)-JVS(3283)*X(257)-JVS(3284)*X(258))/(JVS(3275))
  X(248) = (X(248)-JVS(3224)*X(249)-JVS(3225)*X(250)-JVS(3226)*X(251)-JVS(3227)*X(252)-JVS(3228)*X(253)-JVS(3229)*X(254)&
             &-JVS(3230)*X(255)-JVS(3231)*X(256)-JVS(3232)*X(257)-JVS(3233)*X(258))/(JVS(3223))
  X(247) = (X(247)-JVS(3069)*X(248)-JVS(3070)*X(249)-JVS(3071)*X(250)-JVS(3072)*X(251)-JVS(3073)*X(252)-JVS(3074)*X(253)&
             &-JVS(3075)*X(254)-JVS(3076)*X(255)-JVS(3077)*X(256)-JVS(3078)*X(257)-JVS(3079)*X(258))/(JVS(3068))
  X(246) = (X(246)-JVS(2949)*X(247)-JVS(2950)*X(248)-JVS(2951)*X(249)-JVS(2952)*X(250)-JVS(2953)*X(251)-JVS(2954)*X(252)&
             &-JVS(2955)*X(253)-JVS(2956)*X(254)-JVS(2957)*X(255)-JVS(2958)*X(256)-JVS(2959)*X(257)-JVS(2960)*X(258))&
             &/(JVS(2948))
  X(245) = (X(245)-JVS(2868)*X(246)-JVS(2869)*X(247)-JVS(2870)*X(248)-JVS(2871)*X(249)-JVS(2872)*X(250)-JVS(2873)*X(251)&
             &-JVS(2874)*X(252)-JVS(2875)*X(253)-JVS(2876)*X(254)-JVS(2877)*X(255)-JVS(2878)*X(256)-JVS(2879)*X(257)&
             &-JVS(2880)*X(258))/(JVS(2867))
  X(244) = (X(244)-JVS(2838)*X(246)-JVS(2839)*X(247)-JVS(2840)*X(248)-JVS(2841)*X(249)-JVS(2842)*X(250)-JVS(2843)*X(251)&
             &-JVS(2844)*X(253)-JVS(2845)*X(254)-JVS(2846)*X(255)-JVS(2847)*X(256)-JVS(2848)*X(257)-JVS(2849)*X(258))&
             &/(JVS(2837))
  X(243) = (X(243)-JVS(2751)*X(244)-JVS(2752)*X(246)-JVS(2753)*X(247)-JVS(2754)*X(248)-JVS(2755)*X(249)-JVS(2756)*X(250)&
             &-JVS(2757)*X(253)-JVS(2758)*X(254)-JVS(2759)*X(255)-JVS(2760)*X(256)-JVS(2761)*X(257)-JVS(2762)*X(258))&
             &/(JVS(2750))
  X(242) = (X(242)-JVS(2690)*X(243)-JVS(2691)*X(244)-JVS(2692)*X(246)-JVS(2693)*X(247)-JVS(2694)*X(248)-JVS(2695)*X(249)&
             &-JVS(2696)*X(250)-JVS(2697)*X(253)-JVS(2698)*X(254)-JVS(2699)*X(255)-JVS(2700)*X(256)-JVS(2701)*X(257)&
             &-JVS(2702)*X(258))/(JVS(2689))
  X(241) = (X(241)-JVS(2589)*X(242)-JVS(2590)*X(243)-JVS(2591)*X(244)-JVS(2592)*X(246)-JVS(2593)*X(247)-JVS(2594)*X(248)&
             &-JVS(2595)*X(249)-JVS(2596)*X(250)-JVS(2597)*X(255)-JVS(2598)*X(256)-JVS(2599)*X(257)-JVS(2600)*X(258))&
             &/(JVS(2588))
  X(240) = (X(240)-JVS(2552)*X(241)-JVS(2553)*X(242)-JVS(2554)*X(243)-JVS(2555)*X(244)-JVS(2556)*X(246)-JVS(2557)*X(247)&
             &-JVS(2558)*X(248)-JVS(2559)*X(249)-JVS(2560)*X(250)-JVS(2561)*X(255)-JVS(2562)*X(256)-JVS(2563)*X(257)&
             &-JVS(2564)*X(258))/(JVS(2551))
  X(239) = (X(239)-JVS(2466)*X(241)-JVS(2467)*X(243)-JVS(2468)*X(244)-JVS(2469)*X(246)-JVS(2470)*X(247)-JVS(2471)*X(248)&
             &-JVS(2472)*X(249)-JVS(2473)*X(250)-JVS(2474)*X(255)-JVS(2475)*X(257))/(JVS(2465))
  X(238) = (X(238)-JVS(2390)*X(239)-JVS(2391)*X(240)-JVS(2392)*X(243)-JVS(2393)*X(244)-JVS(2394)*X(246)-JVS(2395)*X(247)&
             &-JVS(2396)*X(248)-JVS(2397)*X(249)-JVS(2398)*X(250)-JVS(2399)*X(255)-JVS(2400)*X(256)-JVS(2401)*X(257)&
             &-JVS(2402)*X(258))/(JVS(2389))
  X(237) = (X(237)-JVS(2373)*X(239)-JVS(2374)*X(243)-JVS(2375)*X(244)-JVS(2376)*X(246)-JVS(2377)*X(247)-JVS(2378)*X(248)&
             &-JVS(2379)*X(249)-JVS(2380)*X(250)-JVS(2381)*X(255)-JVS(2382)*X(257))/(JVS(2372))
  X(236) = (X(236)-JVS(2339)*X(239)-JVS(2340)*X(243)-JVS(2341)*X(244)-JVS(2342)*X(246)-JVS(2343)*X(248)-JVS(2344)*X(249)&
             &-JVS(2345)*X(250)-JVS(2346)*X(255)-JVS(2347)*X(257))/(JVS(2338))
  X(235) = (X(235)-JVS(2324)*X(237)-JVS(2325)*X(239)-JVS(2326)*X(243)-JVS(2327)*X(244)-JVS(2328)*X(246)-JVS(2329)*X(247)&
             &-JVS(2330)*X(248)-JVS(2331)*X(249)-JVS(2332)*X(250)-JVS(2333)*X(255)-JVS(2334)*X(257))/(JVS(2323))
  X(234) = (X(234)-JVS(2308)*X(239)-JVS(2309)*X(243)-JVS(2310)*X(244)-JVS(2311)*X(246)-JVS(2312)*X(248)-JVS(2313)*X(250)&
             &-JVS(2314)*X(255)-JVS(2315)*X(257))/(JVS(2307))
  X(233) = (X(233)-JVS(2292)*X(234)-JVS(2293)*X(239)-JVS(2294)*X(243)-JVS(2295)*X(244)-JVS(2296)*X(246)-JVS(2297)*X(248)&
             &-JVS(2298)*X(250)-JVS(2299)*X(257))/(JVS(2291))
  X(232) = (X(232)-JVS(2275)*X(233)-JVS(2276)*X(234)-JVS(2277)*X(237)-JVS(2278)*X(239)-JVS(2279)*X(243)-JVS(2280)*X(244)&
             &-JVS(2281)*X(246)-JVS(2282)*X(247)-JVS(2283)*X(248)-JVS(2284)*X(249)-JVS(2285)*X(250)-JVS(2286)*X(255)&
             &-JVS(2287)*X(257))/(JVS(2274))
  X(231) = (X(231)-JVS(2259)*X(233)-JVS(2260)*X(234)-JVS(2261)*X(239)-JVS(2262)*X(243)-JVS(2263)*X(244)-JVS(2264)*X(246)&
             &-JVS(2265)*X(248)-JVS(2266)*X(250)-JVS(2267)*X(257))/(JVS(2258))
  X(230) = (X(230)-JVS(2235)*X(231)-JVS(2236)*X(233)-JVS(2237)*X(234)-JVS(2238)*X(235)-JVS(2239)*X(239)-JVS(2240)*X(243)&
             &-JVS(2241)*X(244)-JVS(2242)*X(246)-JVS(2243)*X(247)-JVS(2244)*X(248)-JVS(2245)*X(249)-JVS(2246)*X(250)&
             &-JVS(2247)*X(255)-JVS(2248)*X(257))/(JVS(2234))
  X(229) = (X(229)-JVS(2211)*X(239)-JVS(2212)*X(243)-JVS(2213)*X(244)-JVS(2214)*X(246)-JVS(2215)*X(248)-JVS(2216)*X(250)&
             &-JVS(2217)*X(255)-JVS(2218)*X(257))/(JVS(2210))
  X(228) = (X(228)-JVS(2185)*X(230)-JVS(2186)*X(236)-JVS(2187)*X(239)-JVS(2188)*X(243)-JVS(2189)*X(244)-JVS(2190)*X(246)&
             &-JVS(2191)*X(247)-JVS(2192)*X(248)-JVS(2193)*X(249)-JVS(2194)*X(250)-JVS(2195)*X(255)-JVS(2196)*X(257))&
             &/(JVS(2184))
  X(227) = (X(227)-JVS(2131)*X(239)-JVS(2132)*X(243)-JVS(2133)*X(244)-JVS(2134)*X(246)-JVS(2135)*X(247)-JVS(2136)*X(248)&
             &-JVS(2137)*X(250)-JVS(2138)*X(255)-JVS(2139)*X(257))/(JVS(2130))
  X(226) = (X(226)-JVS(2111)*X(239)-JVS(2112)*X(243)-JVS(2113)*X(244)-JVS(2114)*X(246)-JVS(2115)*X(248)-JVS(2116)*X(250)&
             &-JVS(2117)*X(255)-JVS(2118)*X(257))/(JVS(2110))
  X(225) = (X(225)-JVS(2087)*X(239)-JVS(2088)*X(243)-JVS(2089)*X(244)-JVS(2090)*X(246)-JVS(2091)*X(248)-JVS(2092)*X(250)&
             &-JVS(2093)*X(255)-JVS(2094)*X(257))/(JVS(2086))
  X(224) = (X(224)-JVS(2071)*X(225)-JVS(2072)*X(239)-JVS(2073)*X(243)-JVS(2074)*X(244)-JVS(2075)*X(246)-JVS(2076)*X(248)&
             &-JVS(2077)*X(250)-JVS(2078)*X(255)-JVS(2079)*X(257))/(JVS(2070))
  X(223) = (X(223)-JVS(2057)*X(239)-JVS(2058)*X(243)-JVS(2059)*X(244)-JVS(2060)*X(246)-JVS(2061)*X(248)-JVS(2062)*X(250)&
             &-JVS(2063)*X(255)-JVS(2064)*X(257))/(JVS(2056))
  X(222) = (X(222)-JVS(2044)*X(223)-JVS(2045)*X(239)-JVS(2046)*X(243)-JVS(2047)*X(244)-JVS(2048)*X(246)-JVS(2049)*X(248)&
             &-JVS(2050)*X(250)-JVS(2051)*X(255)-JVS(2052)*X(257))/(JVS(2043))
  X(221) = (X(221)-JVS(2031)*X(222)-JVS(2032)*X(223)-JVS(2033)*X(224)-JVS(2034)*X(225)-JVS(2035)*X(239)-JVS(2036)*X(243)&
             &-JVS(2037)*X(244)-JVS(2038)*X(246)-JVS(2039)*X(248)-JVS(2040)*X(250))/(JVS(2030))
  X(220) = (X(220)-JVS(2008)*X(221)-JVS(2009)*X(222)-JVS(2010)*X(223)-JVS(2011)*X(224)-JVS(2012)*X(225)-JVS(2013)*X(239)&
             &-JVS(2014)*X(243)-JVS(2015)*X(244)-JVS(2016)*X(246)-JVS(2017)*X(248)-JVS(2018)*X(250))/(JVS(2007))
  X(219) = (X(219)-JVS(1977)*X(220)-JVS(1978)*X(221)-JVS(1979)*X(222)-JVS(1980)*X(223)-JVS(1981)*X(224)-JVS(1982)*X(225)&
             &-JVS(1983)*X(229)-JVS(1984)*X(239)-JVS(1985)*X(243)-JVS(1986)*X(244)-JVS(1987)*X(246)-JVS(1988)*X(247)&
             &-JVS(1989)*X(248)-JVS(1990)*X(250)-JVS(1991)*X(255)-JVS(1992)*X(257))/(JVS(1976))
  X(218) = (X(218)-JVS(1954)*X(221)-JVS(1955)*X(222)-JVS(1956)*X(223)-JVS(1957)*X(224)-JVS(1958)*X(225)-JVS(1959)*X(239)&
             &-JVS(1960)*X(243)-JVS(1961)*X(244)-JVS(1962)*X(246)-JVS(1963)*X(248)-JVS(1964)*X(250))/(JVS(1953))
  X(217) = (X(217)-JVS(1925)*X(218)-JVS(1926)*X(219)-JVS(1927)*X(220)-JVS(1928)*X(221)-JVS(1929)*X(222)-JVS(1930)*X(223)&
             &-JVS(1931)*X(224)-JVS(1932)*X(225)-JVS(1933)*X(226)-JVS(1934)*X(227)-JVS(1935)*X(228)-JVS(1936)*X(229)&
             &-JVS(1937)*X(230)-JVS(1938)*X(231)-JVS(1939)*X(236)-JVS(1940)*X(239)-JVS(1941)*X(243)-JVS(1942)*X(244)&
             &-JVS(1943)*X(246)-JVS(1944)*X(247)-JVS(1945)*X(248)-JVS(1946)*X(250)-JVS(1947)*X(255)-JVS(1948)*X(257))&
             &/(JVS(1924))
  X(216) = (X(216)-JVS(1870)*X(218)-JVS(1871)*X(219)-JVS(1872)*X(220)-JVS(1873)*X(221)-JVS(1874)*X(222)-JVS(1875)*X(223)&
             &-JVS(1876)*X(224)-JVS(1877)*X(225)-JVS(1878)*X(229)-JVS(1879)*X(239)-JVS(1880)*X(243)-JVS(1881)*X(244)&
             &-JVS(1882)*X(246)-JVS(1883)*X(247)-JVS(1884)*X(248)-JVS(1885)*X(250)-JVS(1886)*X(255)-JVS(1887)*X(257))&
             &/(JVS(1869))
  X(215) = (X(215)-JVS(1838)*X(245)-JVS(1839)*X(247)-JVS(1840)*X(248)-JVS(1841)*X(249)-JVS(1842)*X(250)-JVS(1843)*X(251)&
             &-JVS(1844)*X(252)-JVS(1845)*X(253)-JVS(1846)*X(255)-JVS(1847)*X(256)-JVS(1848)*X(257)-JVS(1849)*X(258))&
             &/(JVS(1837))
  X(214) = (X(214)-JVS(1820)*X(229)-JVS(1821)*X(231)-JVS(1822)*X(233)-JVS(1823)*X(234)-JVS(1824)*X(237)-JVS(1825)*X(239)&
             &-JVS(1826)*X(243)-JVS(1827)*X(244)-JVS(1828)*X(246)-JVS(1829)*X(247)-JVS(1830)*X(248)-JVS(1831)*X(249)&
             &-JVS(1832)*X(250)-JVS(1833)*X(255))/(JVS(1819))
  X(213) = (X(213)-JVS(1806)*X(220)-JVS(1807)*X(221)-JVS(1808)*X(222)-JVS(1809)*X(223)-JVS(1810)*X(239)-JVS(1811)*X(243)&
             &-JVS(1812)*X(244)-JVS(1813)*X(246)-JVS(1814)*X(248)-JVS(1815)*X(250))/(JVS(1805))
  X(212) = (X(212)-JVS(1766)*X(213)-JVS(1767)*X(215)-JVS(1768)*X(216)-JVS(1769)*X(217)-JVS(1770)*X(218)-JVS(1771)*X(219)&
             &-JVS(1772)*X(220)-JVS(1773)*X(221)-JVS(1774)*X(222)-JVS(1775)*X(223)-JVS(1776)*X(224)-JVS(1777)*X(225)&
             &-JVS(1778)*X(226)-JVS(1779)*X(227)-JVS(1780)*X(229)-JVS(1781)*X(231)-JVS(1782)*X(233)-JVS(1783)*X(237)&
             &-JVS(1784)*X(239)-JVS(1785)*X(241)-JVS(1786)*X(242)-JVS(1787)*X(243)-JVS(1788)*X(244)-JVS(1789)*X(245)&
             &-JVS(1790)*X(246)-JVS(1791)*X(247)-JVS(1792)*X(248)-JVS(1793)*X(249)-JVS(1794)*X(250)-JVS(1795)*X(251)&
             &-JVS(1796)*X(252)-JVS(1797)*X(253)-JVS(1798)*X(255)-JVS(1799)*X(256)-JVS(1800)*X(257)-JVS(1801)*X(258))&
             &/(JVS(1765))
  X(211) = (X(211)-JVS(1719)*X(239)-JVS(1720)*X(243)-JVS(1721)*X(244)-JVS(1722)*X(246)-JVS(1723)*X(248)-JVS(1724)*X(250)&
             &-JVS(1725)*X(257))/(JVS(1718))
  X(210) = (X(210)-JVS(1706)*X(236)-JVS(1707)*X(238)-JVS(1708)*X(240)-JVS(1709)*X(244)-JVS(1710)*X(246)-JVS(1711)*X(247)&
             &-JVS(1712)*X(250)-JVS(1713)*X(256)-JVS(1714)*X(257)-JVS(1715)*X(258))/(JVS(1705))
  X(209) = (X(209)-JVS(1689)*X(215)-JVS(1690)*X(243)-JVS(1691)*X(244)-JVS(1692)*X(245)-JVS(1693)*X(246)-JVS(1694)*X(247)&
             &-JVS(1695)*X(248)-JVS(1696)*X(250)-JVS(1697)*X(251)-JVS(1698)*X(252)-JVS(1699)*X(253)-JVS(1700)*X(254)&
             &-JVS(1701)*X(255)-JVS(1702)*X(256)-JVS(1703)*X(257))/(JVS(1688))
  X(208) = (X(208)-JVS(1667)*X(218)-JVS(1668)*X(220)-JVS(1669)*X(222)-JVS(1670)*X(223)-JVS(1671)*X(224)-JVS(1672)*X(225)&
             &-JVS(1673)*X(226)-JVS(1674)*X(243)-JVS(1675)*X(244)-JVS(1676)*X(246)-JVS(1677)*X(247)-JVS(1678)*X(248)&
             &-JVS(1679)*X(250)-JVS(1680)*X(255)-JVS(1681)*X(257))/(JVS(1666))
  X(207) = (X(207)-JVS(1633)*X(218)-JVS(1634)*X(220)-JVS(1635)*X(222)-JVS(1636)*X(223)-JVS(1637)*X(224)-JVS(1638)*X(225)&
             &-JVS(1639)*X(229)-JVS(1640)*X(243)-JVS(1641)*X(244)-JVS(1642)*X(246)-JVS(1643)*X(247)-JVS(1644)*X(248)&
             &-JVS(1645)*X(250)-JVS(1646)*X(255)-JVS(1647)*X(257))/(JVS(1632))
  X(206) = (X(206)-JVS(1607)*X(222)-JVS(1608)*X(223)-JVS(1609)*X(224)-JVS(1610)*X(225)-JVS(1611)*X(243)-JVS(1612)*X(244)&
             &-JVS(1613)*X(248)-JVS(1614)*X(250))/(JVS(1606))
  X(205) = (X(205)-JVS(1586)*X(206)-JVS(1587)*X(222)-JVS(1588)*X(223)-JVS(1589)*X(224)-JVS(1590)*X(225)-JVS(1591)*X(243)&
             &-JVS(1592)*X(244)-JVS(1593)*X(248)-JVS(1594)*X(250))/(JVS(1585))
  X(204) = (X(204)-JVS(1567)*X(231)-JVS(1568)*X(239)-JVS(1569)*X(243)-JVS(1570)*X(244)-JVS(1571)*X(246)-JVS(1572)*X(248)&
             &-JVS(1573)*X(250)-JVS(1574)*X(257))/(JVS(1566))
  X(203) = (X(203)-JVS(1556)*X(239)-JVS(1557)*X(243)-JVS(1558)*X(244)-JVS(1559)*X(246)-JVS(1560)*X(248)-JVS(1561)*X(250)&
             &-JVS(1562)*X(257))/(JVS(1555))
  X(202) = (X(202)-JVS(1543)*X(215)-JVS(1544)*X(245)-JVS(1545)*X(247)-JVS(1546)*X(248)-JVS(1547)*X(249)-JVS(1548)*X(250)&
             &-JVS(1549)*X(251)-JVS(1550)*X(252)-JVS(1551)*X(256)-JVS(1552)*X(257)-JVS(1553)*X(258))/(JVS(1542))
  X(201) = (X(201)-JVS(1534)*X(246)-JVS(1535)*X(250)-JVS(1536)*X(255)-JVS(1537)*X(257))/(JVS(1533))
  X(200) = (X(200)-JVS(1523)*X(229)-JVS(1524)*X(231)-JVS(1525)*X(237)-JVS(1526)*X(239)-JVS(1527)*X(243)-JVS(1528)*X(244)&
             &-JVS(1529)*X(246)-JVS(1530)*X(247)-JVS(1531)*X(248)-JVS(1532)*X(250))/(JVS(1522))
  X(199) = (X(199)-JVS(1514)*X(222)-JVS(1515)*X(223)-JVS(1516)*X(224)-JVS(1517)*X(243)-JVS(1518)*X(244)-JVS(1519)&
             &*X(250))/(JVS(1513))
  X(198) = (X(198)-JVS(1507)*X(222)-JVS(1508)*X(223)-JVS(1509)*X(243)-JVS(1510)*X(244)-JVS(1511)*X(248)-JVS(1512)&
             &*X(250))/(JVS(1506))
  X(197) = (X(197)-JVS(1497)*X(244)-JVS(1498)*X(246)-JVS(1499)*X(247)-JVS(1500)*X(248)-JVS(1501)*X(250)-JVS(1502)*X(251)&
             &-JVS(1503)*X(253)-JVS(1504)*X(257))/(JVS(1496))
  X(196) = (X(196)-JVS(1467)*X(203)-JVS(1468)*X(204)-JVS(1469)*X(211)-JVS(1470)*X(214)-JVS(1471)*X(216)-JVS(1472)*X(222)&
             &-JVS(1473)*X(223)-JVS(1474)*X(230)-JVS(1475)*X(232)-JVS(1476)*X(233)-JVS(1477)*X(234)-JVS(1478)*X(235)&
             &-JVS(1479)*X(236)-JVS(1480)*X(239)-JVS(1481)*X(243)-JVS(1482)*X(244)-JVS(1483)*X(246)-JVS(1484)*X(248)&
             &-JVS(1485)*X(249)-JVS(1486)*X(250)-JVS(1487)*X(255)-JVS(1488)*X(257))/(JVS(1466))
  X(195) = (X(195)-JVS(1453)*X(239)-JVS(1454)*X(243)-JVS(1455)*X(244)-JVS(1456)*X(246)-JVS(1457)*X(248)-JVS(1458)*X(249)&
             &-JVS(1459)*X(250)-JVS(1460)*X(255))/(JVS(1452))
  X(194) = (X(194)-JVS(1444)*X(239)-JVS(1445)*X(243)-JVS(1446)*X(244)-JVS(1447)*X(246)-JVS(1448)*X(248)-JVS(1449)*X(250)&
             &-JVS(1450)*X(257))/(JVS(1443))
  X(193) = (X(193)-JVS(1431)*X(194)-JVS(1432)*X(239)-JVS(1433)*X(243)-JVS(1434)*X(244)-JVS(1435)*X(246)-JVS(1436)*X(248)&
             &-JVS(1437)*X(250)-JVS(1438)*X(257))/(JVS(1430))
  X(192) = (X(192)-JVS(1416)*X(211)-JVS(1417)*X(233)-JVS(1418)*X(234)-JVS(1419)*X(235)-JVS(1420)*X(239)-JVS(1421)*X(243)&
             &-JVS(1422)*X(244)-JVS(1423)*X(248)-JVS(1424)*X(249)-JVS(1425)*X(250)-JVS(1426)*X(255))/(JVS(1415))
  X(191) = (X(191)-JVS(1401)*X(198)-JVS(1402)*X(199)-JVS(1403)*X(205)-JVS(1404)*X(206)-JVS(1405)*X(220)-JVS(1406)*X(223)&
             &-JVS(1407)*X(224)-JVS(1408)*X(225)-JVS(1409)*X(243)-JVS(1410)*X(244)-JVS(1411)*X(248)-JVS(1412)*X(250))&
             &/(JVS(1400))
  X(190) = (X(190)-JVS(1388)*X(223)-JVS(1389)*X(225)-JVS(1390)*X(243)-JVS(1391)*X(244)-JVS(1392)*X(250))/(JVS(1387))
  X(189) = (X(189)-JVS(1369)*X(190)-JVS(1370)*X(198)-JVS(1371)*X(199)-JVS(1372)*X(201)-JVS(1373)*X(205)-JVS(1374)*X(206)&
             &-JVS(1375)*X(207)-JVS(1376)*X(216)-JVS(1377)*X(218)-JVS(1378)*X(219)-JVS(1379)*X(220)-JVS(1380)*X(223)&
             &-JVS(1381)*X(224)-JVS(1382)*X(225)-JVS(1383)*X(244)-JVS(1384)*X(246)-JVS(1385)*X(248)-JVS(1386)*X(250))&
             &/(JVS(1368))
  X(188) = (X(188)-JVS(1344)*X(197)-JVS(1345)*X(244)-JVS(1346)*X(246)-JVS(1347)*X(247)-JVS(1348)*X(248)-JVS(1349)*X(250)&
             &-JVS(1350)*X(251)-JVS(1351)*X(253)-JVS(1352)*X(257))/(JVS(1343))
  X(187) = (X(187)-JVS(1309)*X(195)-JVS(1310)*X(204)-JVS(1311)*X(210)-JVS(1312)*X(214)-JVS(1313)*X(228)-JVS(1314)*X(230)&
             &-JVS(1315)*X(232)-JVS(1316)*X(233)-JVS(1317)*X(234)-JVS(1318)*X(235)-JVS(1319)*X(236)-JVS(1320)*X(239)&
             &-JVS(1321)*X(243)-JVS(1322)*X(244)-JVS(1323)*X(246)-JVS(1324)*X(248)-JVS(1325)*X(249)-JVS(1326)*X(250)&
             &-JVS(1327)*X(255)-JVS(1328)*X(256))/(JVS(1308))
  X(186) = (X(186)-JVS(1285)*X(201)-JVS(1286)*X(211)-JVS(1287)*X(216)-JVS(1288)*X(218)-JVS(1289)*X(219)-JVS(1290)*X(220)&
             &-JVS(1291)*X(224)-JVS(1292)*X(225)-JVS(1293)*X(226)-JVS(1294)*X(227)-JVS(1295)*X(228)-JVS(1296)*X(238)&
             &-JVS(1297)*X(244)-JVS(1298)*X(246)-JVS(1299)*X(247)-JVS(1300)*X(248)-JVS(1301)*X(250)-JVS(1302)*X(255)&
             &-JVS(1303)*X(256)-JVS(1304)*X(257))/(JVS(1284))
  X(185) = (X(185)-JVS(1267)*X(236)-JVS(1268)*X(239)-JVS(1269)*X(243)-JVS(1270)*X(244)-JVS(1271)*X(248)-JVS(1272)*X(249)&
             &-JVS(1273)*X(250)-JVS(1274)*X(255))/(JVS(1266))
  X(184) = (X(184)-JVS(1253)*X(190)-JVS(1254)*X(198)-JVS(1255)*X(213)-JVS(1256)*X(218)-JVS(1257)*X(219)-JVS(1258)*X(220)&
             &-JVS(1259)*X(221)-JVS(1260)*X(223)-JVS(1261)*X(244)-JVS(1262)*X(246)-JVS(1263)*X(248)-JVS(1264)*X(250))&
             &/(JVS(1252))
  X(183) = (X(183)-JVS(1241)*X(226)-JVS(1242)*X(227)-JVS(1243)*X(244)-JVS(1244)*X(246)-JVS(1245)*X(247)-JVS(1246)*X(248)&
             &-JVS(1247)*X(250))/(JVS(1240))
  X(182) = (X(182)-JVS(1229)*X(190)-JVS(1230)*X(199)-JVS(1231)*X(205)-JVS(1232)*X(206)-JVS(1233)*X(224)-JVS(1234)*X(225)&
             &-JVS(1235)*X(244)-JVS(1236)*X(248)-JVS(1237)*X(250))/(JVS(1228))
  X(181) = (X(181)-JVS(1215)*X(201)-JVS(1216)*X(218)-JVS(1217)*X(224)-JVS(1218)*X(226)-JVS(1219)*X(244)-JVS(1220)*X(247)&
             &-JVS(1221)*X(248)-JVS(1222)*X(250))/(JVS(1214))
  X(180) = (X(180)-JVS(1204)*X(201)-JVS(1205)*X(218)-JVS(1206)*X(225)-JVS(1207)*X(229)-JVS(1208)*X(244)-JVS(1209)*X(247)&
             &-JVS(1210)*X(248)-JVS(1211)*X(250))/(JVS(1203))
  X(179) = (X(179)-JVS(1194)*X(236)-JVS(1195)*X(239)-JVS(1196)*X(243)-JVS(1197)*X(244)-JVS(1198)*X(246)-JVS(1199)*X(248)&
             &-JVS(1200)*X(250))/(JVS(1193))
  X(178) = (X(178)-JVS(1186)*X(233)-JVS(1187)*X(239)-JVS(1188)*X(243)-JVS(1189)*X(244)-JVS(1190)*X(248)-JVS(1191)&
             &*X(250))/(JVS(1185))
  X(177) = (X(177)-JVS(1174)*X(193)-JVS(1175)*X(194)-JVS(1176)*X(203)-JVS(1177)*X(211)-JVS(1178)*X(239)-JVS(1179)*X(243)&
             &-JVS(1180)*X(244)-JVS(1181)*X(246)-JVS(1182)*X(248)-JVS(1183)*X(250)-JVS(1184)*X(257))/(JVS(1173))
  X(176) = (X(176)-JVS(1162)*X(181)-JVS(1163)*X(201)-JVS(1164)*X(218)-JVS(1165)*X(220)-JVS(1166)*X(224)-JVS(1167)*X(225)&
             &-JVS(1168)*X(227)-JVS(1169)*X(244)-JVS(1170)*X(247)-JVS(1171)*X(248)-JVS(1172)*X(250))/(JVS(1161))
  X(175) = (X(175)-JVS(1143)*X(179)-JVS(1144)*X(198)-JVS(1145)*X(199)-JVS(1146)*X(213)-JVS(1147)*X(218)-JVS(1148)*X(220)&
             &-JVS(1149)*X(221)-JVS(1150)*X(223)-JVS(1151)*X(226)-JVS(1152)*X(227)-JVS(1153)*X(243)-JVS(1154)*X(244)&
             &-JVS(1155)*X(246)-JVS(1156)*X(248)-JVS(1157)*X(250))/(JVS(1142))
  X(174) = (X(174)-JVS(1124)*X(198)-JVS(1125)*X(201)-JVS(1126)*X(204)-JVS(1127)*X(208)-JVS(1128)*X(220)-JVS(1129)*X(223)&
             &-JVS(1130)*X(224)-JVS(1131)*X(226)-JVS(1132)*X(230)-JVS(1133)*X(244)-JVS(1134)*X(248)-JVS(1135)*X(250))&
             &/(JVS(1123))
  X(173) = (X(173)-JVS(1113)*X(190)-JVS(1114)*X(199)-JVS(1115)*X(224)-JVS(1116)*X(225)-JVS(1117)*X(244)-JVS(1118)*X(248)&
             &-JVS(1119)*X(250))/(JVS(1112))
  X(172) = (X(172)-JVS(1097)*X(201)-JVS(1098)*X(210)-JVS(1099)*X(229)-JVS(1100)*X(238)-JVS(1101)*X(246)-JVS(1102)*X(248)&
             &-JVS(1103)*X(250)-JVS(1104)*X(255)-JVS(1105)*X(256)-JVS(1106)*X(257)-JVS(1107)*X(258))/(JVS(1096))
  X(171) = (X(171)-JVS(1085)*X(190)-JVS(1086)*X(199)-JVS(1087)*X(224)-JVS(1088)*X(225)-JVS(1089)*X(243)-JVS(1090)*X(244)&
             &-JVS(1091)*X(248)-JVS(1092)*X(250))/(JVS(1084))
  X(170) = (X(170)-JVS(1078)*X(201)-JVS(1079)*X(224)-JVS(1080)*X(248)-JVS(1081)*X(250))/(JVS(1077))
  X(169) = (X(169)-JVS(1071)*X(224)-JVS(1072)*X(225)-JVS(1073)*X(244)-JVS(1074)*X(248)-JVS(1075)*X(250))/(JVS(1070))
  X(168) = (X(168)-JVS(1064)*X(201)-JVS(1065)*X(225)-JVS(1066)*X(248)-JVS(1067)*X(250))/(JVS(1063))
  X(167) = (X(167)-JVS(1058)*X(223)-JVS(1059)*X(244)-JVS(1060)*X(248)-JVS(1061)*X(250))/(JVS(1057))
  X(166) = (X(166)-JVS(1050)*X(236)-JVS(1051)*X(241)-JVS(1052)*X(250)-JVS(1053)*X(254)-JVS(1054)*X(255)-JVS(1055)&
             &*X(257))/(JVS(1049))
  X(165) = (X(165)-JVS(1037)*X(168)-JVS(1038)*X(170)-JVS(1039)*X(182)-JVS(1040)*X(205)-JVS(1041)*X(206)-JVS(1042)*X(207)&
             &-JVS(1043)*X(218)-JVS(1044)*X(219)-JVS(1045)*X(220)-JVS(1046)*X(244)-JVS(1047)*X(248)-JVS(1048)*X(250))&
             &/(JVS(1036))
  X(164) = (X(164)-JVS(1028)*X(224)-JVS(1029)*X(244)-JVS(1030)*X(248)-JVS(1031)*X(250))/(JVS(1027))
  X(163) = (X(163)-JVS(1021)*X(225)-JVS(1022)*X(244)-JVS(1023)*X(248)-JVS(1024)*X(250))/(JVS(1020))
  X(162) = (X(162)-JVS(1013)*X(222)-JVS(1014)*X(223)-JVS(1015)*X(243)-JVS(1016)*X(248)-JVS(1017)*X(250))/(JVS(1012))
  X(161) = (X(161)-JVS(1003)*X(209)-JVS(1004)*X(215)-JVS(1005)*X(243)-JVS(1006)*X(250)-JVS(1007)*X(251)-JVS(1008)*X(252)&
             &-JVS(1009)*X(253)-JVS(1010)*X(254)-JVS(1011)*X(255))/(JVS(1002))
  X(160) = (X(160)-JVS(995)*X(188)-JVS(996)*X(197)-JVS(997)*X(244)-JVS(998)*X(246)-JVS(999)*X(247)-JVS(1000)*X(250))&
             &/(JVS(994))
  X(159) = (X(159)-JVS(982)*X(193)-JVS(983)*X(194)-JVS(984)*X(211)-JVS(985)*X(239)-JVS(986)*X(243)-JVS(987)*X(244)&
             &-JVS(988)*X(246)-JVS(989)*X(248)-JVS(990)*X(250))/(JVS(981))
  X(158) = (X(158)-JVS(976)*X(247)-JVS(977)*X(249)-JVS(978)*X(251)-JVS(979)*X(252)-JVS(980)*X(256))/(JVS(975))
  X(157) = (X(157)-JVS(965)*X(166)-JVS(966)*X(242)-JVS(967)*X(245)-JVS(968)*X(248)-JVS(969)*X(250)-JVS(970)*X(252)&
             &-JVS(971)*X(254)-JVS(972)*X(255)-JVS(973)*X(257)-JVS(974)*X(258))/(JVS(964))
  X(156) = (X(156)-JVS(954)*X(167)-JVS(955)*X(198)-JVS(956)*X(199)-JVS(957)*X(213)-JVS(958)*X(218)-JVS(959)*X(227)&
             &-JVS(960)*X(243)-JVS(961)*X(244)-JVS(962)*X(248)-JVS(963)*X(250))/(JVS(953))
  X(155) = (X(155)-JVS(940)*X(168)-JVS(941)*X(170)-JVS(942)*X(190)-JVS(943)*X(199)-JVS(944)*X(201)-JVS(945)*X(218)&
             &-JVS(946)*X(223)-JVS(947)*X(224)-JVS(948)*X(225)-JVS(949)*X(244)-JVS(950)*X(248)-JVS(951)*X(250))/(JVS(939))
  X(154) = (X(154)-JVS(924)*X(246)-JVS(925)*X(250)-JVS(926)*X(257))/(JVS(923))
  X(153) = (X(153)-JVS(914)*X(163)-JVS(915)*X(167)-JVS(916)*X(198)-JVS(917)*X(201)-JVS(918)*X(220)-JVS(919)*X(225)&
             &-JVS(920)*X(244)-JVS(921)*X(248)-JVS(922)*X(250))/(JVS(913))
  X(152) = (X(152)-JVS(909)*X(225)-JVS(910)*X(248)-JVS(911)*X(250))/(JVS(908))
  X(151) = (X(151)-JVS(899)*X(173)-JVS(900)*X(180)-JVS(901)*X(182)-JVS(902)*X(205)-JVS(903)*X(206)-JVS(904)*X(207)&
             &-JVS(905)*X(244)-JVS(906)*X(248)-JVS(907)*X(250))/(JVS(898))
  X(150) = (X(150)-JVS(892)*X(190)-JVS(893)*X(244)-JVS(894)*X(248)-JVS(895)*X(250))/(JVS(891))
  X(149) = (X(149)-JVS(887)*X(199)-JVS(888)*X(244)-JVS(889)*X(248)-JVS(890)*X(250))/(JVS(886))
  X(148) = (X(148)-JVS(882)*X(225)-JVS(883)*X(244)-JVS(884)*X(248)-JVS(885)*X(250))/(JVS(881))
  X(147) = (X(147)-JVS(877)*X(224)-JVS(878)*X(248)-JVS(879)*X(250))/(JVS(876))
  X(146) = (X(146)-JVS(871)*X(160)-JVS(872)*X(188)-JVS(873)*X(197)-JVS(874)*X(246)-JVS(875)*X(247))/(JVS(870))
  X(145) = (X(145)-JVS(865)*X(163)-JVS(866)*X(164)-JVS(867)*X(169)-JVS(868)*X(248)-JVS(869)*X(250))/(JVS(864))
  X(144) = (X(144)-JVS(858)*X(168)-JVS(859)*X(170)-JVS(860)*X(218)-JVS(861)*X(220)-JVS(862)*X(250))/(JVS(857))
  X(143) = (X(143)-JVS(854)*X(224)-JVS(855)*X(248)-JVS(856)*X(250))/(JVS(853))
  X(142) = (X(142)-JVS(849)*X(246)-JVS(850)*X(249)-JVS(851)*X(250)-JVS(852)*X(255))/(JVS(848))
  X(141) = (X(141)-JVS(836)*X(178)-JVS(837)*X(179)-JVS(838)*X(185)-JVS(839)*X(194)-JVS(840)*X(203)-JVS(841)*X(204)&
             &-JVS(842)*X(211)-JVS(843)*X(214)-JVS(844)*X(234)-JVS(845)*X(235)-JVS(846)*X(243)-JVS(847)*X(250))/(JVS(835))
  X(140) = (X(140)-JVS(832)*X(225)-JVS(833)*X(248)-JVS(834)*X(250))/(JVS(831))
  X(139) = (X(139)-JVS(825)*X(168)-JVS(826)*X(170)-JVS(827)*X(205)-JVS(828)*X(206)-JVS(829)*X(218)-JVS(830)*X(250))&
             &/(JVS(824))
  X(138) = (X(138)-JVS(819)*X(246)-JVS(820)*X(250)-JVS(821)*X(257))/(JVS(818))
  X(137) = (X(137)-JVS(815)*X(246)-JVS(816)*X(250)-JVS(817)*X(257))/(JVS(814))
  X(136) = (X(136)-JVS(810)*X(183)-JVS(811)*X(227)-JVS(812)*X(247)-JVS(813)*X(250))/(JVS(809))
  X(135) = (X(135)-JVS(805)*X(224)-JVS(806)*X(244)-JVS(807)*X(248)-JVS(808)*X(250))/(JVS(804))
  X(134) = (X(134)-JVS(800)*X(223)-JVS(801)*X(248)-JVS(802)*X(250))/(JVS(799))
  X(133) = (X(133)-JVS(794)*X(218)-JVS(795)*X(220)-JVS(796)*X(244)-JVS(797)*X(248)-JVS(798)*X(250))/(JVS(793))
  X(132) = (X(132)-JVS(789)*X(221)-JVS(790)*X(244)-JVS(791)*X(248)-JVS(792)*X(250))/(JVS(788))
  X(131) = (X(131)-JVS(784)*X(246)-JVS(785)*X(247)-JVS(786)*X(252)-JVS(787)*X(256))/(JVS(783))
  X(130) = (X(130)-JVS(778)*X(163)-JVS(779)*X(164)-JVS(780)*X(169)-JVS(781)*X(248)-JVS(782)*X(250))/(JVS(777))
  X(129) = (X(129)-JVS(772)*X(170)-JVS(773)*X(218)-JVS(774)*X(244)-JVS(775)*X(247)-JVS(776)*X(248))/(JVS(771))
  X(128) = (X(128)-JVS(766)*X(168)-JVS(767)*X(218)-JVS(768)*X(244)-JVS(769)*X(247)-JVS(770)*X(248))/(JVS(765))
  X(127) = (X(127)-JVS(762)*X(225)-JVS(763)*X(244)-JVS(764)*X(250))/(JVS(761))
  X(126) = (X(126)-JVS(756)*X(210)-JVS(757)*X(238)-JVS(758)*X(246)-JVS(759)*X(250)-JVS(760)*X(258))/(JVS(755))
  X(125) = (X(125)-JVS(749)*X(224)-JVS(750)*X(244)-JVS(751)*X(250))/(JVS(748))
  X(124) = (X(124)-JVS(744)*X(202)-JVS(745)*X(215)-JVS(746)*X(245)-JVS(747)*X(257))/(JVS(743))
  X(123) = (X(123)-JVS(739)*X(243)-JVS(740)*X(248)-JVS(741)*X(250)-JVS(742)*X(255))/(JVS(738))
  X(122) = (X(122)-JVS(734)*X(202)-JVS(735)*X(215)-JVS(736)*X(245)-JVS(737)*X(257))/(JVS(733))
  X(121) = (X(121)-JVS(730)*X(183)-JVS(731)*X(248)-JVS(732)*X(250))/(JVS(729))
  X(120) = (X(120)-JVS(724)*X(125)-JVS(725)*X(127)-JVS(726)*X(140)-JVS(727)*X(143)-JVS(728)*X(250))/(JVS(723))
  X(119) = (X(119)-JVS(718)*X(159)-JVS(719)*X(177)-JVS(720)*X(246)-JVS(721)*X(250)-JVS(722)*X(257))/(JVS(717))
  X(118) = (X(118)-JVS(712)*X(182)-JVS(713)*X(205)-JVS(714)*X(244)-JVS(715)*X(248)-JVS(716)*X(250))/(JVS(711))
  X(117) = (X(117)-JVS(706)*X(195)-JVS(707)*X(232)-JVS(708)*X(243)-JVS(709)*X(250)-JVS(710)*X(255))/(JVS(705))
  X(116) = (X(116)-JVS(700)*X(125)-JVS(701)*X(127)-JVS(702)*X(140)-JVS(703)*X(143)-JVS(704)*X(250))/(JVS(699))
  X(115) = (X(115)-JVS(696)*X(205)-JVS(697)*X(206)-JVS(698)*X(250))/(JVS(695))
  X(114) = (X(114)-JVS(687)*X(122)-JVS(688)*X(124)-JVS(689)*X(158)-JVS(690)*X(202)-JVS(691)*X(245)-JVS(692)*X(249)&
             &-JVS(693)*X(250)-JVS(694)*X(251))/(JVS(686))
  X(113) = (X(113)-JVS(682)*X(160)-JVS(683)*X(197)-JVS(684)*X(248)-JVS(685)*X(250))/(JVS(681))
  X(112) = (X(112)-JVS(677)*X(147)-JVS(678)*X(201)-JVS(679)*X(224)-JVS(680)*X(250))/(JVS(676))
  X(111) = (X(111)-JVS(672)*X(152)-JVS(673)*X(201)-JVS(674)*X(225)-JVS(675)*X(250))/(JVS(671))
  X(110) = (X(110)-JVS(663)*X(134)-JVS(664)*X(221)-JVS(665)*X(222)-JVS(666)*X(223)-JVS(667)*X(239)-JVS(668)*X(243)&
             &-JVS(669)*X(244)-JVS(670)*X(246))/(JVS(662))
  X(109) = (X(109)-JVS(659)*X(249)-JVS(660)*X(250)-JVS(661)*X(255))/(JVS(658))
  X(108) = (X(108)-JVS(654)*X(170)-JVS(655)*X(244)-JVS(656)*X(248)-JVS(657)*X(250))/(JVS(653))
  X(107) = (X(107)-JVS(649)*X(168)-JVS(650)*X(244)-JVS(651)*X(248)-JVS(652)*X(250))/(JVS(648))
  X(106) = (X(106)-JVS(638)*X(122)-JVS(639)*X(124)-JVS(640)*X(158)-JVS(641)*X(202)-JVS(642)*X(209)-JVS(643)*X(215)&
             &-JVS(644)*X(245)-JVS(645)*X(251)-JVS(646)*X(252)-JVS(647)*X(253))/(JVS(637))
  X(105) = (X(105)-JVS(633)*X(203)-JVS(634)*X(211)-JVS(635)*X(248)-JVS(636)*X(250))/(JVS(632))
  X(104) = (X(104)-JVS(627)*X(182)-JVS(628)*X(206)-JVS(629)*X(244)-JVS(630)*X(248)-JVS(631)*X(250))/(JVS(626))
  X(103) = (X(103)-JVS(621)*X(147)-JVS(622)*X(152)-JVS(623)*X(190)-JVS(624)*X(199)-JVS(625)*X(250))/(JVS(620))
  X(102) = (X(102)-JVS(617)*X(179)-JVS(618)*X(248)-JVS(619)*X(250))/(JVS(616))
  X(101) = (X(101)-JVS(613)*X(185)-JVS(614)*X(248)-JVS(615)*X(250))/(JVS(612))
  X(100) = (X(100)-JVS(609)*X(246)-JVS(610)*X(250)-JVS(611)*X(255))/(JVS(608))
  X(99) = (X(99)-JVS(604)*X(197)-JVS(605)*X(250)-JVS(606)*X(251)-JVS(607)*X(253))/(JVS(603))
  X(98) = (X(98)-JVS(599)*X(195)-JVS(600)*X(232)-JVS(601)*X(248)-JVS(602)*X(250))/(JVS(598))
  X(97) = (X(97)-JVS(594)*X(188)-JVS(595)*X(244)-JVS(596)*X(247)-JVS(597)*X(250))/(JVS(593))
  X(96) = (X(96)-JVS(586)*X(168)-JVS(587)*X(170)-JVS(588)*X(218)-JVS(589)*X(250))/(JVS(585))
  X(95) = (X(95)-JVS(580)*X(243)-JVS(581)*X(250)-JVS(582)*X(251)-JVS(583)*X(253)-JVS(584)*X(255))/(JVS(579))
  X(94) = (X(94)-JVS(573)*X(144)-JVS(574)*X(219)-JVS(575)*X(229)-JVS(576)*X(250)-JVS(577)*X(257))/(JVS(572))
  X(93) = (X(93)-JVS(569)*X(247)-JVS(570)*X(248)-JVS(571)*X(250))/(JVS(568))
  X(92) = (X(92)-JVS(566)*X(250)-JVS(567)*X(254))/(JVS(565))
  X(91) = (X(91)-JVS(563)*X(250)-JVS(564)*X(255))/(JVS(562))
  X(90) = (X(90)-JVS(549)*X(125)-JVS(550)*X(127)-JVS(551)*X(134)-JVS(552)*X(156)-JVS(553)*X(162)-JVS(554)*X(176)&
            &-JVS(555)*X(190)-JVS(556)*X(191)-JVS(557)*X(199)-JVS(558)*X(219)-JVS(559)*X(220)-JVS(560)*X(221)-JVS(561)&
            &*X(233))/(JVS(548))
  X(89) = (X(89)-JVS(546)*X(250)-JVS(547)*X(254))/(JVS(545))
  X(88) = (X(88)-JVS(543)*X(250)-JVS(544)*X(254))/(JVS(542))
  X(87) = (X(87)-JVS(539)*X(131)-JVS(540)*X(250)-JVS(541)*X(252))/(JVS(538))
  X(86) = (X(86)-JVS(536)*X(246)-JVS(537)*X(250))/(JVS(535))
  X(85) = (X(85)-JVS(532)*X(195)-JVS(533)*X(244)-JVS(534)*X(250))/(JVS(531))
  X(84) = (X(84)-JVS(528)*X(200)-JVS(529)*X(248)-JVS(530)*X(250))/(JVS(527))
  X(83) = (X(83)-JVS(524)*X(235)-JVS(525)*X(248)-JVS(526)*X(250))/(JVS(523))
  X(82) = (X(82)-JVS(520)*X(214)-JVS(521)*X(248)-JVS(522)*X(250))/(JVS(519))
  X(81) = (X(81)-JVS(516)*X(234)-JVS(517)*X(248)-JVS(518)*X(250))/(JVS(515))
  X(80) = (X(80)-JVS(512)*X(197)-JVS(513)*X(244)-JVS(514)*X(251))/(JVS(511))
  X(79) = (X(79)-JVS(505)*X(214)-JVS(506)*X(244)-JVS(507)*X(250))/(JVS(504))
  X(78) = (X(78)-JVS(501)*X(243)-JVS(502)*X(244)-JVS(503)*X(250))/(JVS(500))
  X(77) = (X(77)-JVS(497)*X(235)-JVS(498)*X(244)-JVS(499)*X(250))/(JVS(496))
  X(76) = (X(76)-JVS(494)*X(188)-JVS(495)*X(247))/(JVS(493))
  X(75) = (X(75)-JVS(491)*X(246)-JVS(492)*X(250))/(JVS(490))
  X(74) = (X(74)-JVS(487)*X(121)-JVS(488)*X(136)-JVS(489)*X(250))/(JVS(486))
  X(73) = (X(73)-JVS(483)*X(238)-JVS(484)*X(250)-JVS(485)*X(256))/(JVS(482))
  X(72) = (X(72)-JVS(480)*X(250)-JVS(481)*X(254))/(JVS(479))
  X(71) = (X(71)-JVS(477)*X(250)-JVS(478)*X(254))/(JVS(476))
  X(70) = (X(70)-JVS(474)*X(250)-JVS(475)*X(255))/(JVS(473))
  X(69) = (X(69)-JVS(471)*X(250)-JVS(472)*X(254))/(JVS(470))
  X(68) = (X(68)-JVS(468)*X(250)-JVS(469)*X(253))/(JVS(467))
  X(67) = (X(67)-JVS(465)*X(250)-JVS(466)*X(255))/(JVS(464))
  X(66) = (X(66)-JVS(462)*X(250)-JVS(463)*X(254))/(JVS(461))
  X(65) = (X(65)-JVS(459)*X(243)-JVS(460)*X(247))/(JVS(458))
  X(64) = (X(64)-JVS(453)*X(76)-JVS(454)*X(113)-JVS(455)*X(146)-JVS(456)*X(197)-JVS(457)*X(253))/(JVS(452))
  X(63) = (X(63)-JVS(449)*X(239)-JVS(450)*X(248)-JVS(451)*X(250))/(JVS(448))
  X(62) = (X(62)-JVS(445)*X(188)-JVS(446)*X(248)-JVS(447)*X(250))/(JVS(444))
  X(61) = (X(61)-JVS(440)*X(86)-JVS(441)*X(244)-JVS(442)*X(248)-JVS(443)*X(250))/(JVS(439))
  X(60) = (X(60)-JVS(435)*X(126)-JVS(436)*X(210)-JVS(437)*X(238)-JVS(438)*X(250))/(JVS(434))
  X(59) = (X(59)-JVS(432)*X(239)-JVS(433)*X(247))/(JVS(431))
  X(58) = (X(58)-JVS(429)*X(250)-JVS(430)*X(258))/(JVS(428))
  X(57) = (X(57)-JVS(426)*X(244)-JVS(427)*X(247))/(JVS(425))
  X(56) = (X(56)-JVS(422)*X(244)-JVS(423)*X(248)-JVS(424)*X(250))/(JVS(421))
  X(55) = (X(55)-JVS(417)*X(244)-JVS(418)*X(248)-JVS(419)*X(250))/(JVS(416))
  X(54) = (X(54)-JVS(412)*X(57)-JVS(413)*X(247)-JVS(414)*X(254))/(JVS(411))
  X(53) = (X(53)-JVS(409)*X(188)-JVS(410)*X(244))/(JVS(408))
  X(52) = (X(52)-JVS(405)*X(76)-JVS(406)*X(113)-JVS(407)*X(146))/(JVS(404))
  X(51) = (X(51)-JVS(403)*X(254))/(JVS(402))
  X(50) = (X(50)-JVS(401)*X(254))/(JVS(400))
  X(49) = (X(49)-JVS(399)*X(254))/(JVS(398))
  X(48) = (X(48)-JVS(397)*X(254))/(JVS(396))
  X(47) = (X(47)-JVS(395)*X(254))/(JVS(394))
  X(46) = (X(46)-JVS(393)*X(254))/(JVS(392))
  X(45) = (X(45)-JVS(391)*X(254))/(JVS(390))
  X(44) = (X(44)-JVS(388)*X(247)-JVS(389)*X(249))/(JVS(387))
  X(43) = (X(43)-JVS(386)*X(250))/(JVS(385))
  X(42) = (X(42)-JVS(383)*X(200)-JVS(384)*X(247))/(JVS(382))
  X(41) = (X(41)-JVS(380)*X(80)-JVS(381)*X(197))/(JVS(379))
  X(40) = (X(40)-JVS(378)*X(254))/(JVS(377))
  X(39) = (X(39)-JVS(376)*X(254))/(JVS(375))
  X(38) = (X(38)-JVS(374)*X(250))/(JVS(373))
  X(37) = (X(37)-JVS(372)*X(250))/(JVS(371))
  X(36) = (X(36)-JVS(368)*X(119)-JVS(369)*X(159)-JVS(370)*X(177))/(JVS(367))
  X(35) = (X(35)-JVS(366)*X(197))/(JVS(365))
  X(34) = (X(34)-JVS(364)*X(250))/(JVS(363))
  X(33) = (X(33)-JVS(362)*X(80))/(JVS(361))
  X(32) = (X(32)-JVS(350)*X(137)-JVS(351)*X(138)-JVS(352)*X(154)-JVS(353)*X(201)-JVS(354)*X(210)-JVS(355)*X(229)&
            &-JVS(356)*X(238)-JVS(357)*X(248)-JVS(358)*X(250)-JVS(359)*X(256)-JVS(360)*X(257))/(JVS(349))
  X(31) = (X(31)-JVS(345)*X(166)-JVS(346)*X(250)-JVS(347)*X(254)-JVS(348)*X(255))/(JVS(344))
  X(30) = (X(30)-JVS(340)*X(126)-JVS(341)*X(210)-JVS(342)*X(238)-JVS(343)*X(250))/(JVS(339))
  X(29) = (X(29)-JVS(335)*X(210)-JVS(336)*X(238)-JVS(337)*X(240)-JVS(338)*X(250))/(JVS(334))
  X(28) = (X(28)-JVS(269)*X(58)-JVS(270)*X(67)-JVS(271)*X(70)-JVS(272)*X(91)-JVS(273)*X(96)-JVS(274)*X(111)-JVS(275)&
            &*X(112)-JVS(276)*X(115)-JVS(277)*X(118)-JVS(278)*X(121)-JVS(279)*X(133)-JVS(280)*X(136)-JVS(281)*X(137)&
            &-JVS(282)*X(138)-JVS(283)*X(139)-JVS(284)*X(140)-JVS(285)*X(143)-JVS(286)*X(144)-JVS(287)*X(147)-JVS(288)&
            &*X(151)-JVS(289)*X(152)-JVS(290)*X(153)-JVS(291)*X(154)-JVS(292)*X(155)-JVS(293)*X(156)-JVS(294)*X(165)&
            &-JVS(295)*X(168)-JVS(296)*X(170)-JVS(297)*X(171)-JVS(298)*X(173)-JVS(299)*X(176)-JVS(300)*X(181)-JVS(301)&
            &*X(182)-JVS(302)*X(183)-JVS(303)*X(184)-JVS(304)*X(189)-JVS(305)*X(190)-JVS(306)*X(191)-JVS(307)*X(192)&
            &-JVS(308)*X(199)-JVS(309)*X(201)-JVS(310)*X(205)-JVS(311)*X(206)-JVS(312)*X(208)-JVS(313)*X(216)-JVS(314)&
            &*X(217)-JVS(315)*X(218)-JVS(316)*X(224)-JVS(317)*X(225)-JVS(318)*X(226)-JVS(319)*X(228)-JVS(320)*X(229)&
            &-JVS(321)*X(236)-JVS(322)*X(237)-JVS(323)*X(241)-JVS(324)*X(242)-JVS(325)*X(243)-JVS(326)*X(244)-JVS(327)&
            &*X(246)-JVS(328)*X(248)-JVS(329)*X(249)-JVS(330)*X(250)-JVS(331)*X(255)-JVS(332)*X(257)-JVS(333)*X(258))&
            &/(JVS(268))
  X(27) = (X(27)-JVS(189)*X(33)-JVS(190)*X(35)-JVS(191)*X(41)-JVS(192)*X(54)-JVS(193)*X(58)-JVS(194)*X(68)-JVS(195)&
            &*X(72)-JVS(196)*X(75)-JVS(197)*X(76)-JVS(198)*X(80)-JVS(199)*X(86)-JVS(200)*X(92)-JVS(201)*X(99)-JVS(202)&
            &*X(100)-JVS(203)*X(113)-JVS(204)*X(119)-JVS(205)*X(122)-JVS(206)*X(124)-JVS(207)*X(125)-JVS(208)*X(127)&
            &-JVS(209)*X(131)-JVS(210)*X(134)-JVS(211)*X(137)-JVS(212)*X(138)-JVS(213)*X(142)-JVS(214)*X(146)-JVS(215)&
            &*X(154)-JVS(216)*X(156)-JVS(217)*X(157)-JVS(218)*X(158)-JVS(219)*X(159)-JVS(220)*X(162)-JVS(221)*X(166)&
            &-JVS(222)*X(172)-JVS(223)*X(176)-JVS(224)*X(177)-JVS(225)*X(184)-JVS(226)*X(189)-JVS(227)*X(190)-JVS(228)&
            &*X(191)-JVS(229)*X(193)-JVS(230)*X(194)-JVS(231)*X(197)-JVS(232)*X(199)-JVS(233)*X(201)-JVS(234)*X(202)&
            &-JVS(235)*X(203)-JVS(236)*X(209)-JVS(237)*X(211)-JVS(238)*X(215)-JVS(239)*X(217)-JVS(240)*X(219)-JVS(241)&
            &*X(220)-JVS(242)*X(221)-JVS(243)*X(222)-JVS(244)*X(223)-JVS(245)*X(226)-JVS(246)*X(227)-JVS(247)*X(229)&
            &-JVS(248)*X(231)-JVS(249)*X(233)-JVS(250)*X(236)-JVS(251)*X(237)-JVS(252)*X(238)-JVS(253)*X(241)-JVS(254)&
            &*X(242)-JVS(255)*X(243)-JVS(256)*X(245)-JVS(257)*X(246)-JVS(258)*X(247)-JVS(259)*X(248)-JVS(260)*X(250)&
            &-JVS(261)*X(251)-JVS(262)*X(252)-JVS(263)*X(253)-JVS(264)*X(254)-JVS(265)*X(256)-JVS(266)*X(257)-JVS(267)&
            &*X(258))/(JVS(188))
  X(26) = (X(26)-JVS(112)*X(36)-JVS(113)*X(54)-JVS(114)*X(57)-JVS(115)*X(59)-JVS(116)*X(65)-JVS(117)*X(77)-JVS(118)&
            &*X(78)-JVS(119)*X(79)-JVS(120)*X(85)-JVS(121)*X(87)-JVS(122)*X(90)-JVS(123)*X(93)-JVS(124)*X(95)-JVS(125)*X(97)&
            &-JVS(126)*X(107)-JVS(127)*X(108)-JVS(128)*X(114)-JVS(129)*X(119)-JVS(130)*X(128)-JVS(131)*X(129)-JVS(132)&
            &*X(132)-JVS(133)*X(133)-JVS(134)*X(135)-JVS(135)*X(136)-JVS(136)*X(148)-JVS(137)*X(149)-JVS(138)*X(150)&
            &-JVS(139)*X(157)-JVS(140)*X(160)-JVS(141)*X(161)-JVS(142)*X(163)-JVS(143)*X(164)-JVS(144)*X(167)-JVS(145)&
            &*X(169)-JVS(146)*X(173)-JVS(147)*X(178)-JVS(148)*X(179)-JVS(149)*X(180)-JVS(150)*X(181)-JVS(151)*X(183)&
            &-JVS(152)*X(185)-JVS(153)*X(193)-JVS(154)*X(194)-JVS(155)*X(195)-JVS(156)*X(198)-JVS(157)*X(200)-JVS(158)&
            &*X(203)-JVS(159)*X(204)-JVS(160)*X(205)-JVS(161)*X(206)-JVS(162)*X(210)-JVS(163)*X(211)-JVS(164)*X(212)&
            &-JVS(165)*X(213)-JVS(166)*X(214)-JVS(167)*X(215)-JVS(168)*X(219)-JVS(169)*X(220)-JVS(170)*X(221)-JVS(171)&
            &*X(222)-JVS(172)*X(223)-JVS(173)*X(224)-JVS(174)*X(225)-JVS(175)*X(227)-JVS(176)*X(230)-JVS(177)*X(232)&
            &-JVS(178)*X(234)-JVS(179)*X(235)-JVS(180)*X(238)-JVS(181)*X(239)-JVS(182)*X(243)-JVS(183)*X(244)-JVS(184)&
            &*X(247)-JVS(185)*X(248)-JVS(186)*X(250)-JVS(187)*X(255))/(JVS(111))
  X(25) = (X(25)-JVS(104)*X(74)-JVS(105)*X(103)-JVS(106)*X(116)-JVS(107)*X(120)-JVS(108)*X(155))/(JVS(103))
  X(24) = (X(24)-JVS(100)*X(94)-JVS(101)*X(189)-JVS(102)*X(217))/(JVS(99))
  X(23) = (X(23)-JVS(98)*X(202))/(JVS(97))
  X(22) = (X(22)-JVS(96)*X(202))/(JVS(95))
  X(21) = (X(21)-JVS(93)*X(75)-JVS(94)*X(250))/(JVS(92))
  X(20) = (X(20)-JVS(90)*X(61)-JVS(91)*X(244))/(JVS(89))
  X(19) = (X(19)-JVS(87)*X(61)-JVS(88)*X(248))/(JVS(86))
  X(18) = (X(18)-JVS(81)*X(140)-JVS(82)*X(143)-JVS(83)*X(147)-JVS(84)*X(152)-JVS(85)*X(250))/(JVS(80))
  X(17) = (X(17)-JVS(79)*X(18))/(JVS(78))
  X(16) = (X(16)-JVS(76)*X(55)-JVS(77)*X(244))/(JVS(75))
  X(15) = (X(15)-JVS(73)*X(55)-JVS(74)*X(248))/(JVS(72))
  X(14) = (X(14)-JVS(70)*X(201)-JVS(71)*X(246))/(JVS(69))
  X(13) = (X(13)-JVS(67)*X(201)-JVS(68)*X(250))/(JVS(66))
  X(12) = (X(12)-JVS(64)*X(56)-JVS(65)*X(244))/(JVS(63))
  X(11) = (X(11)-JVS(61)*X(56)-JVS(62)*X(248))/(JVS(60))
  X(10) = (X(10)-JVS(53)*X(33)-JVS(54)*X(35)-JVS(55)*X(41)-JVS(56)*X(62)-JVS(57)*X(76)-JVS(58)*X(113)-JVS(59)*X(146))&
            &/(JVS(52))
  X(9) = (X(9)-JVS(45)*X(33)-JVS(46)*X(35)-JVS(47)*X(41)-JVS(48)*X(62)-JVS(49)*X(76)-JVS(50)*X(113)-JVS(51)*X(146))&
           &/(JVS(44))
  X(8) = (X(8)-JVS(42)*X(36)-JVS(43)*X(90))/(JVS(41))
  X(7) = (X(7)-JVS(12)*X(58)-JVS(13)*X(86)-JVS(14)*X(94)-JVS(15)*X(107)-JVS(16)*X(108)-JVS(17)*X(121)-JVS(18)*X(133)&
           &-JVS(19)*X(144)-JVS(20)*X(145)-JVS(21)*X(156)-JVS(22)*X(171)-JVS(23)*X(183)-JVS(24)*X(184)-JVS(25)*X(186)&
           &-JVS(26)*X(187)-JVS(27)*X(201)-JVS(28)*X(208)-JVS(29)*X(216)-JVS(30)*X(227)-JVS(31)*X(228)-JVS(32)*X(239)&
           &-JVS(33)*X(240)-JVS(34)*X(243)-JVS(35)*X(244)-JVS(36)*X(246)-JVS(37)*X(248)-JVS(38)*X(250)-JVS(39)*X(255)&
           &-JVS(40)*X(257))/(JVS(11))
  X(6) = (X(6)-JVS(7)*X(33)-JVS(8)*X(35)-JVS(9)*X(41)-JVS(10)*X(62))/(JVS(6))
  X(5) = X(5)/JVS(5)
  X(4) = X(4)/JVS(4)
  X(3) = X(3)/JVS(3)
  X(2) = X(2)/JVS(2)
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(3)
  XX(4) = X(4)/JVS(4)
  XX(5) = X(5)/JVS(5)
  XX(6) = X(6)/JVS(6)
  XX(7) = X(7)/JVS(11)
  XX(8) = X(8)/JVS(41)
  XX(9) = X(9)/JVS(44)
  XX(10) = X(10)/JVS(52)
  XX(11) = X(11)/JVS(60)
  XX(12) = X(12)/JVS(63)
  XX(13) = X(13)/JVS(66)
  XX(14) = X(14)/JVS(69)
  XX(15) = X(15)/JVS(72)
  XX(16) = X(16)/JVS(75)
  XX(17) = X(17)/JVS(78)
  XX(18) = (X(18)-JVS(79)*XX(17))/(JVS(80))
  XX(19) = X(19)/JVS(86)
  XX(20) = X(20)/JVS(89)
  XX(21) = X(21)/JVS(92)
  XX(22) = X(22)/JVS(95)
  XX(23) = X(23)/JVS(97)
  XX(24) = X(24)/JVS(99)
  XX(25) = X(25)/JVS(103)
  XX(26) = X(26)/JVS(111)
  XX(27) = X(27)/JVS(188)
  XX(28) = X(28)/JVS(268)
  XX(29) = X(29)/JVS(334)
  XX(30) = X(30)/JVS(339)
  XX(31) = X(31)/JVS(344)
  XX(32) = X(32)/JVS(349)
  XX(33) = (X(33)-JVS(7)*XX(6)-JVS(45)*XX(9)-JVS(53)*XX(10)-JVS(189)*XX(27))/(JVS(361))
  XX(34) = X(34)/JVS(363)
  XX(35) = (X(35)-JVS(8)*XX(6)-JVS(46)*XX(9)-JVS(54)*XX(10)-JVS(190)*XX(27))/(JVS(365))
  XX(36) = (X(36)-JVS(42)*XX(8)-JVS(112)*XX(26))/(JVS(367))
  XX(37) = X(37)/JVS(371)
  XX(38) = X(38)/JVS(373)
  XX(39) = X(39)/JVS(375)
  XX(40) = X(40)/JVS(377)
  XX(41) = (X(41)-JVS(9)*XX(6)-JVS(47)*XX(9)-JVS(55)*XX(10)-JVS(191)*XX(27))/(JVS(379))
  XX(42) = X(42)/JVS(382)
  XX(43) = X(43)/JVS(385)
  XX(44) = X(44)/JVS(387)
  XX(45) = X(45)/JVS(390)
  XX(46) = X(46)/JVS(392)
  XX(47) = X(47)/JVS(394)
  XX(48) = X(48)/JVS(396)
  XX(49) = X(49)/JVS(398)
  XX(50) = X(50)/JVS(400)
  XX(51) = X(51)/JVS(402)
  XX(52) = X(52)/JVS(404)
  XX(53) = X(53)/JVS(408)
  XX(54) = (X(54)-JVS(113)*XX(26)-JVS(192)*XX(27))/(JVS(411))
  XX(55) = (X(55)-JVS(73)*XX(15)-JVS(76)*XX(16))/(JVS(416))
  XX(56) = (X(56)-JVS(61)*XX(11)-JVS(64)*XX(12))/(JVS(421))
  XX(57) = (X(57)-JVS(114)*XX(26)-JVS(412)*XX(54))/(JVS(425))
  XX(58) = (X(58)-JVS(12)*XX(7)-JVS(193)*XX(27)-JVS(269)*XX(28))/(JVS(428))
  XX(59) = (X(59)-JVS(115)*XX(26))/(JVS(431))
  XX(60) = X(60)/JVS(434)
  XX(61) = (X(61)-JVS(87)*XX(19)-JVS(90)*XX(20))/(JVS(439))
  XX(62) = (X(62)-JVS(10)*XX(6)-JVS(48)*XX(9)-JVS(56)*XX(10))/(JVS(444))
  XX(63) = X(63)/JVS(448)
  XX(64) = X(64)/JVS(452)
  XX(65) = (X(65)-JVS(116)*XX(26))/(JVS(458))
  XX(66) = X(66)/JVS(461)
  XX(67) = (X(67)-JVS(270)*XX(28))/(JVS(464))
  XX(68) = (X(68)-JVS(194)*XX(27))/(JVS(467))
  XX(69) = X(69)/JVS(470)
  XX(70) = (X(70)-JVS(271)*XX(28))/(JVS(473))
  XX(71) = X(71)/JVS(476)
  XX(72) = (X(72)-JVS(195)*XX(27))/(JVS(479))
  XX(73) = X(73)/JVS(482)
  XX(74) = (X(74)-JVS(104)*XX(25))/(JVS(486))
  XX(75) = (X(75)-JVS(93)*XX(21)-JVS(196)*XX(27))/(JVS(490))
  XX(76) = (X(76)-JVS(49)*XX(9)-JVS(57)*XX(10)-JVS(197)*XX(27)-JVS(405)*XX(52)-JVS(453)*XX(64))/(JVS(493))
  XX(77) = (X(77)-JVS(117)*XX(26))/(JVS(496))
  XX(78) = (X(78)-JVS(118)*XX(26))/(JVS(500))
  XX(79) = (X(79)-JVS(119)*XX(26))/(JVS(504))
  XX(80) = (X(80)-JVS(198)*XX(27)-JVS(362)*XX(33)-JVS(380)*XX(41))/(JVS(511))
  XX(81) = X(81)/JVS(515)
  XX(82) = X(82)/JVS(519)
  XX(83) = X(83)/JVS(523)
  XX(84) = X(84)/JVS(527)
  XX(85) = (X(85)-JVS(120)*XX(26))/(JVS(531))
  XX(86) = (X(86)-JVS(13)*XX(7)-JVS(199)*XX(27)-JVS(440)*XX(61))/(JVS(535))
  XX(87) = (X(87)-JVS(121)*XX(26))/(JVS(538))
  XX(88) = X(88)/JVS(542)
  XX(89) = X(89)/JVS(545)
  XX(90) = (X(90)-JVS(43)*XX(8)-JVS(122)*XX(26))/(JVS(548))
  XX(91) = (X(91)-JVS(272)*XX(28))/(JVS(562))
  XX(92) = (X(92)-JVS(200)*XX(27))/(JVS(565))
  XX(93) = (X(93)-JVS(123)*XX(26))/(JVS(568))
  XX(94) = (X(94)-JVS(14)*XX(7)-JVS(100)*XX(24))/(JVS(572))
  XX(95) = (X(95)-JVS(124)*XX(26))/(JVS(579))
  XX(96) = (X(96)-JVS(273)*XX(28))/(JVS(585))
  XX(97) = (X(97)-JVS(125)*XX(26))/(JVS(593))
  XX(98) = X(98)/JVS(598)
  XX(99) = (X(99)-JVS(201)*XX(27))/(JVS(603))
  XX(100) = (X(100)-JVS(202)*XX(27))/(JVS(608))
  XX(101) = X(101)/JVS(612)
  XX(102) = X(102)/JVS(616)
  XX(103) = (X(103)-JVS(105)*XX(25))/(JVS(620))
  XX(104) = X(104)/JVS(626)
  XX(105) = X(105)/JVS(632)
  XX(106) = X(106)/JVS(637)
  XX(107) = (X(107)-JVS(15)*XX(7)-JVS(126)*XX(26))/(JVS(648))
  XX(108) = (X(108)-JVS(16)*XX(7)-JVS(127)*XX(26))/(JVS(653))
  XX(109) = X(109)/JVS(658)
  XX(110) = X(110)/JVS(662)
  XX(111) = (X(111)-JVS(274)*XX(28))/(JVS(671))
  XX(112) = (X(112)-JVS(275)*XX(28))/(JVS(676))
  XX(113) = (X(113)-JVS(50)*XX(9)-JVS(58)*XX(10)-JVS(203)*XX(27)-JVS(406)*XX(52)-JVS(454)*XX(64))/(JVS(681))
  XX(114) = (X(114)-JVS(128)*XX(26))/(JVS(686))
  XX(115) = (X(115)-JVS(276)*XX(28))/(JVS(695))
  XX(116) = (X(116)-JVS(106)*XX(25))/(JVS(699))
  XX(117) = X(117)/JVS(705)
  XX(118) = (X(118)-JVS(277)*XX(28))/(JVS(711))
  XX(119) = (X(119)-JVS(129)*XX(26)-JVS(204)*XX(27)-JVS(368)*XX(36))/(JVS(717))
  XX(120) = (X(120)-JVS(107)*XX(25))/(JVS(723))
  XX(121) = (X(121)-JVS(17)*XX(7)-JVS(278)*XX(28)-JVS(487)*XX(74))/(JVS(729))
  XX(122) = (X(122)-JVS(205)*XX(27)-JVS(638)*XX(106)-JVS(687)*XX(114))/(JVS(733))
  XX(123) = X(123)/JVS(738)
  XX(124) = (X(124)-JVS(206)*XX(27)-JVS(639)*XX(106)-JVS(688)*XX(114))/(JVS(743))
  XX(125) = (X(125)-JVS(207)*XX(27)-JVS(549)*XX(90)-JVS(700)*XX(116)-JVS(724)*XX(120))/(JVS(748))
  XX(126) = (X(126)-JVS(340)*XX(30)-JVS(435)*XX(60))/(JVS(755))
  XX(127) = (X(127)-JVS(208)*XX(27)-JVS(550)*XX(90)-JVS(701)*XX(116)-JVS(725)*XX(120))/(JVS(761))
  XX(128) = (X(128)-JVS(130)*XX(26))/(JVS(765))
  XX(129) = (X(129)-JVS(131)*XX(26))/(JVS(771))
  XX(130) = X(130)/JVS(777)
  XX(131) = (X(131)-JVS(209)*XX(27)-JVS(539)*XX(87))/(JVS(783))
  XX(132) = (X(132)-JVS(132)*XX(26))/(JVS(788))
  XX(133) = (X(133)-JVS(18)*XX(7)-JVS(133)*XX(26)-JVS(279)*XX(28))/(JVS(793))
  XX(134) = (X(134)-JVS(210)*XX(27)-JVS(551)*XX(90)-JVS(663)*XX(110))/(JVS(799))
  XX(135) = (X(135)-JVS(134)*XX(26))/(JVS(804))
  XX(136) = (X(136)-JVS(135)*XX(26)-JVS(280)*XX(28)-JVS(488)*XX(74))/(JVS(809))
  XX(137) = (X(137)-JVS(211)*XX(27)-JVS(281)*XX(28)-JVS(350)*XX(32))/(JVS(814))
  XX(138) = (X(138)-JVS(212)*XX(27)-JVS(282)*XX(28)-JVS(351)*XX(32))/(JVS(818))
  XX(139) = (X(139)-JVS(283)*XX(28))/(JVS(824))
  XX(140) = (X(140)-JVS(81)*XX(18)-JVS(284)*XX(28)-JVS(702)*XX(116)-JVS(726)*XX(120))/(JVS(831))
  XX(141) = X(141)/JVS(835)
  XX(142) = (X(142)-JVS(213)*XX(27))/(JVS(848))
  XX(143) = (X(143)-JVS(82)*XX(18)-JVS(285)*XX(28)-JVS(703)*XX(116)-JVS(727)*XX(120))/(JVS(853))
  XX(144) = (X(144)-JVS(19)*XX(7)-JVS(286)*XX(28)-JVS(573)*XX(94))/(JVS(857))
  XX(145) = (X(145)-JVS(20)*XX(7))/(JVS(864))
  XX(146) = (X(146)-JVS(51)*XX(9)-JVS(59)*XX(10)-JVS(214)*XX(27)-JVS(407)*XX(52)-JVS(455)*XX(64))/(JVS(870))
  XX(147) = (X(147)-JVS(83)*XX(18)-JVS(287)*XX(28)-JVS(621)*XX(103)-JVS(677)*XX(112))/(JVS(876))
  XX(148) = (X(148)-JVS(136)*XX(26))/(JVS(881))
  XX(149) = (X(149)-JVS(137)*XX(26))/(JVS(886))
  XX(150) = (X(150)-JVS(138)*XX(26))/(JVS(891))
  XX(151) = (X(151)-JVS(288)*XX(28))/(JVS(898))
  XX(152) = (X(152)-JVS(84)*XX(18)-JVS(289)*XX(28)-JVS(622)*XX(103)-JVS(672)*XX(111))/(JVS(908))
  XX(153) = (X(153)-JVS(290)*XX(28))/(JVS(913))
  XX(154) = (X(154)-JVS(215)*XX(27)-JVS(291)*XX(28)-JVS(352)*XX(32))/(JVS(923))
  XX(155) = (X(155)-JVS(108)*XX(25)-JVS(292)*XX(28))/(JVS(939))
  XX(156) = (X(156)-JVS(21)*XX(7)-JVS(216)*XX(27)-JVS(293)*XX(28)-JVS(552)*XX(90))/(JVS(953))
  XX(157) = (X(157)-JVS(139)*XX(26)-JVS(217)*XX(27))/(JVS(964))
  XX(158) = (X(158)-JVS(218)*XX(27)-JVS(640)*XX(106)-JVS(689)*XX(114))/(JVS(975))
  XX(159) = (X(159)-JVS(219)*XX(27)-JVS(369)*XX(36)-JVS(718)*XX(119))/(JVS(981))
  XX(160) = (X(160)-JVS(140)*XX(26)-JVS(682)*XX(113)-JVS(871)*XX(146))/(JVS(994))
  XX(161) = (X(161)-JVS(141)*XX(26))/(JVS(1002))
  XX(162) = (X(162)-JVS(220)*XX(27)-JVS(553)*XX(90))/(JVS(1012))
  XX(163) = (X(163)-JVS(142)*XX(26)-JVS(778)*XX(130)-JVS(865)*XX(145)-JVS(914)*XX(153))/(JVS(1020))
  XX(164) = (X(164)-JVS(143)*XX(26)-JVS(779)*XX(130)-JVS(866)*XX(145))/(JVS(1027))
  XX(165) = (X(165)-JVS(294)*XX(28))/(JVS(1036))
  XX(166) = (X(166)-JVS(221)*XX(27)-JVS(345)*XX(31)-JVS(965)*XX(157))/(JVS(1049))
  XX(167) = (X(167)-JVS(144)*XX(26)-JVS(915)*XX(153)-JVS(954)*XX(156))/(JVS(1057))
  XX(168) = (X(168)-JVS(295)*XX(28)-JVS(586)*XX(96)-JVS(649)*XX(107)-JVS(766)*XX(128)-JVS(825)*XX(139)-JVS(858)*XX(144)&
              &-JVS(940)*XX(155)-JVS(1037)*XX(165))/(JVS(1063))
  XX(169) = (X(169)-JVS(145)*XX(26)-JVS(780)*XX(130)-JVS(867)*XX(145))/(JVS(1070))
  XX(170) = (X(170)-JVS(296)*XX(28)-JVS(587)*XX(96)-JVS(654)*XX(108)-JVS(772)*XX(129)-JVS(826)*XX(139)-JVS(859)*XX(144)&
              &-JVS(941)*XX(155)-JVS(1038)*XX(165))/(JVS(1077))
  XX(171) = (X(171)-JVS(22)*XX(7)-JVS(297)*XX(28))/(JVS(1084))
  XX(172) = (X(172)-JVS(222)*XX(27))/(JVS(1096))
  XX(173) = (X(173)-JVS(146)*XX(26)-JVS(298)*XX(28)-JVS(899)*XX(151))/(JVS(1112))
  XX(174) = X(174)/JVS(1123)
  XX(175) = X(175)/JVS(1142)
  XX(176) = (X(176)-JVS(223)*XX(27)-JVS(299)*XX(28)-JVS(554)*XX(90))/(JVS(1161))
  XX(177) = (X(177)-JVS(224)*XX(27)-JVS(370)*XX(36)-JVS(719)*XX(119))/(JVS(1173))
  XX(178) = (X(178)-JVS(147)*XX(26)-JVS(836)*XX(141))/(JVS(1185))
  XX(179) = (X(179)-JVS(148)*XX(26)-JVS(617)*XX(102)-JVS(837)*XX(141)-JVS(1143)*XX(175))/(JVS(1193))
  XX(180) = (X(180)-JVS(149)*XX(26)-JVS(900)*XX(151))/(JVS(1203))
  XX(181) = (X(181)-JVS(150)*XX(26)-JVS(300)*XX(28)-JVS(1162)*XX(176))/(JVS(1214))
  XX(182) = (X(182)-JVS(301)*XX(28)-JVS(627)*XX(104)-JVS(712)*XX(118)-JVS(901)*XX(151)-JVS(1039)*XX(165))/(JVS(1228))
  XX(183) = (X(183)-JVS(23)*XX(7)-JVS(151)*XX(26)-JVS(302)*XX(28)-JVS(730)*XX(121)-JVS(810)*XX(136))/(JVS(1240))
  XX(184) = (X(184)-JVS(24)*XX(7)-JVS(225)*XX(27)-JVS(303)*XX(28))/(JVS(1252))
  XX(185) = (X(185)-JVS(152)*XX(26)-JVS(613)*XX(101)-JVS(838)*XX(141))/(JVS(1266))
  XX(186) = (X(186)-JVS(25)*XX(7))/(JVS(1284))
  XX(187) = (X(187)-JVS(26)*XX(7))/(JVS(1308))
  XX(188) = (X(188)-JVS(409)*XX(53)-JVS(445)*XX(62)-JVS(494)*XX(76)-JVS(594)*XX(97)-JVS(872)*XX(146)-JVS(995)*XX(160))&
              &/(JVS(1343))
  XX(189) = (X(189)-JVS(101)*XX(24)-JVS(226)*XX(27)-JVS(304)*XX(28))/(JVS(1368))
  XX(190) = (X(190)-JVS(227)*XX(27)-JVS(305)*XX(28)-JVS(555)*XX(90)-JVS(623)*XX(103)-JVS(892)*XX(150)-JVS(942)*XX(155)&
              &-JVS(1085)*XX(171)-JVS(1113)*XX(173)-JVS(1229)*XX(182)-JVS(1253)*XX(184)-JVS(1369)*XX(189))/(JVS(1387))
  XX(191) = (X(191)-JVS(228)*XX(27)-JVS(306)*XX(28)-JVS(556)*XX(90))/(JVS(1400))
  XX(192) = (X(192)-JVS(307)*XX(28))/(JVS(1415))
  XX(193) = (X(193)-JVS(153)*XX(26)-JVS(229)*XX(27)-JVS(982)*XX(159)-JVS(1174)*XX(177))/(JVS(1430))
  XX(194) = (X(194)-JVS(154)*XX(26)-JVS(230)*XX(27)-JVS(839)*XX(141)-JVS(983)*XX(159)-JVS(1175)*XX(177)-JVS(1431)&
              &*XX(193))/(JVS(1443))
  XX(195) = (X(195)-JVS(155)*XX(26)-JVS(532)*XX(85)-JVS(599)*XX(98)-JVS(706)*XX(117)-JVS(1309)*XX(187))/(JVS(1452))
  XX(196) = X(196)/JVS(1466)
  XX(197) = (X(197)-JVS(231)*XX(27)-JVS(366)*XX(35)-JVS(381)*XX(41)-JVS(456)*XX(64)-JVS(512)*XX(80)-JVS(604)*XX(99)&
              &-JVS(683)*XX(113)-JVS(873)*XX(146)-JVS(996)*XX(160)-JVS(1344)*XX(188))/(JVS(1496))
  XX(198) = (X(198)-JVS(156)*XX(26)-JVS(916)*XX(153)-JVS(955)*XX(156)-JVS(1124)*XX(174)-JVS(1144)*XX(175)-JVS(1254)&
              &*XX(184)-JVS(1370)*XX(189)-JVS(1401)*XX(191))/(JVS(1506))
  XX(199) = (X(199)-JVS(232)*XX(27)-JVS(308)*XX(28)-JVS(557)*XX(90)-JVS(624)*XX(103)-JVS(887)*XX(149)-JVS(943)*XX(155)&
              &-JVS(956)*XX(156)-JVS(1086)*XX(171)-JVS(1114)*XX(173)-JVS(1145)*XX(175)-JVS(1230)*XX(182)-JVS(1371)*XX(189)&
              &-JVS(1402)*XX(191))/(JVS(1513))
  XX(200) = (X(200)-JVS(157)*XX(26)-JVS(383)*XX(42)-JVS(528)*XX(84))/(JVS(1522))
  XX(201) = (X(201)-JVS(27)*XX(7)-JVS(67)*XX(13)-JVS(70)*XX(14)-JVS(233)*XX(27)-JVS(309)*XX(28)-JVS(353)*XX(32)-JVS(673)&
              &*XX(111)-JVS(678)*XX(112)-JVS(917)*XX(153)-JVS(944)*XX(155)-JVS(1064)*XX(168)-JVS(1078)*XX(170)-JVS(1097)&
              &*XX(172)-JVS(1125)*XX(174)-JVS(1163)*XX(176)-JVS(1204)*XX(180)-JVS(1215)*XX(181)-JVS(1285)*XX(186)-JVS(1372)&
              &*XX(189))/(JVS(1533))
  XX(202) = (X(202)-JVS(96)*XX(22)-JVS(98)*XX(23)-JVS(234)*XX(27)-JVS(641)*XX(106)-JVS(690)*XX(114)-JVS(734)*XX(122)&
              &-JVS(744)*XX(124))/(JVS(1542))
  XX(203) = (X(203)-JVS(158)*XX(26)-JVS(235)*XX(27)-JVS(633)*XX(105)-JVS(840)*XX(141)-JVS(1176)*XX(177)-JVS(1467)&
              &*XX(196))/(JVS(1555))
  XX(204) = (X(204)-JVS(159)*XX(26)-JVS(841)*XX(141)-JVS(1126)*XX(174)-JVS(1310)*XX(187)-JVS(1468)*XX(196))/(JVS(1566))
  XX(205) = (X(205)-JVS(160)*XX(26)-JVS(310)*XX(28)-JVS(696)*XX(115)-JVS(713)*XX(118)-JVS(827)*XX(139)-JVS(902)*XX(151)&
              &-JVS(1040)*XX(165)-JVS(1231)*XX(182)-JVS(1373)*XX(189)-JVS(1403)*XX(191))/(JVS(1585))
  XX(206) = (X(206)-JVS(161)*XX(26)-JVS(311)*XX(28)-JVS(628)*XX(104)-JVS(697)*XX(115)-JVS(828)*XX(139)-JVS(903)*XX(151)&
              &-JVS(1041)*XX(165)-JVS(1232)*XX(182)-JVS(1374)*XX(189)-JVS(1404)*XX(191)-JVS(1586)*XX(205))/(JVS(1606))
  XX(207) = (X(207)-JVS(904)*XX(151)-JVS(1042)*XX(165)-JVS(1375)*XX(189))/(JVS(1632))
  XX(208) = (X(208)-JVS(28)*XX(7)-JVS(312)*XX(28)-JVS(1127)*XX(174))/(JVS(1666))
  XX(209) = (X(209)-JVS(236)*XX(27)-JVS(642)*XX(106)-JVS(1003)*XX(161))/(JVS(1688))
  XX(210) = (X(210)-JVS(162)*XX(26)-JVS(335)*XX(29)-JVS(341)*XX(30)-JVS(354)*XX(32)-JVS(436)*XX(60)-JVS(756)*XX(126)&
              &-JVS(1098)*XX(172)-JVS(1311)*XX(187))/(JVS(1705))
  XX(211) = (X(211)-JVS(163)*XX(26)-JVS(237)*XX(27)-JVS(634)*XX(105)-JVS(842)*XX(141)-JVS(984)*XX(159)-JVS(1177)*XX(177)&
              &-JVS(1286)*XX(186)-JVS(1416)*XX(192)-JVS(1469)*XX(196))/(JVS(1718))
  XX(212) = (X(212)-JVS(164)*XX(26))/(JVS(1765))
  XX(213) = (X(213)-JVS(165)*XX(26)-JVS(957)*XX(156)-JVS(1146)*XX(175)-JVS(1255)*XX(184)-JVS(1766)*XX(212))/(JVS(1805))
  XX(214) = (X(214)-JVS(166)*XX(26)-JVS(505)*XX(79)-JVS(520)*XX(82)-JVS(843)*XX(141)-JVS(1312)*XX(187)-JVS(1470)&
              &*XX(196))/(JVS(1819))
  XX(215) = (X(215)-JVS(167)*XX(26)-JVS(238)*XX(27)-JVS(643)*XX(106)-JVS(735)*XX(122)-JVS(745)*XX(124)-JVS(1004)*XX(161)&
              &-JVS(1543)*XX(202)-JVS(1689)*XX(209)-JVS(1767)*XX(212))/(JVS(1837))
  XX(216) = (X(216)-JVS(29)*XX(7)-JVS(313)*XX(28)-JVS(1287)*XX(186)-JVS(1376)*XX(189)-JVS(1471)*XX(196)-JVS(1768)&
              &*XX(212))/(JVS(1869))
  XX(217) = (X(217)-JVS(102)*XX(24)-JVS(239)*XX(27)-JVS(314)*XX(28)-JVS(1769)*XX(212))/(JVS(1924))
  XX(218) = (X(218)-JVS(315)*XX(28)-JVS(588)*XX(96)-JVS(767)*XX(128)-JVS(773)*XX(129)-JVS(794)*XX(133)-JVS(829)*XX(139)&
              &-JVS(860)*XX(144)-JVS(945)*XX(155)-JVS(958)*XX(156)-JVS(1043)*XX(165)-JVS(1147)*XX(175)-JVS(1164)*XX(176)&
              &-JVS(1205)*XX(180)-JVS(1216)*XX(181)-JVS(1256)*XX(184)-JVS(1288)*XX(186)-JVS(1377)*XX(189)-JVS(1633)*XX(207)&
              &-JVS(1667)*XX(208)-JVS(1770)*XX(212)-JVS(1870)*XX(216)-JVS(1925)*XX(217))/(JVS(1953))
  XX(219) = (X(219)-JVS(168)*XX(26)-JVS(240)*XX(27)-JVS(558)*XX(90)-JVS(574)*XX(94)-JVS(1044)*XX(165)-JVS(1257)*XX(184)&
              &-JVS(1289)*XX(186)-JVS(1378)*XX(189)-JVS(1771)*XX(212)-JVS(1871)*XX(216)-JVS(1926)*XX(217))/(JVS(1976))
  XX(220) = (X(220)-JVS(169)*XX(26)-JVS(241)*XX(27)-JVS(559)*XX(90)-JVS(795)*XX(133)-JVS(861)*XX(144)-JVS(918)*XX(153)&
              &-JVS(1045)*XX(165)-JVS(1128)*XX(174)-JVS(1148)*XX(175)-JVS(1165)*XX(176)-JVS(1258)*XX(184)-JVS(1290)*XX(186)&
              &-JVS(1379)*XX(189)-JVS(1405)*XX(191)-JVS(1634)*XX(207)-JVS(1668)*XX(208)-JVS(1772)*XX(212)-JVS(1806)*XX(213)&
              &-JVS(1872)*XX(216)-JVS(1927)*XX(217)-JVS(1977)*XX(219))/(JVS(2007))
  XX(221) = (X(221)-JVS(170)*XX(26)-JVS(242)*XX(27)-JVS(560)*XX(90)-JVS(664)*XX(110)-JVS(789)*XX(132)-JVS(1149)*XX(175)&
              &-JVS(1259)*XX(184)-JVS(1773)*XX(212)-JVS(1807)*XX(213)-JVS(1873)*XX(216)-JVS(1928)*XX(217)-JVS(1954)*XX(218)&
              &-JVS(1978)*XX(219)-JVS(2008)*XX(220))/(JVS(2030))
  XX(222) = (X(222)-JVS(171)*XX(26)-JVS(243)*XX(27)-JVS(665)*XX(110)-JVS(1013)*XX(162)-JVS(1472)*XX(196)-JVS(1507)&
              &*XX(198)-JVS(1514)*XX(199)-JVS(1587)*XX(205)-JVS(1607)*XX(206)-JVS(1635)*XX(207)-JVS(1669)*XX(208)-JVS(1774)&
              &*XX(212)-JVS(1808)*XX(213)-JVS(1874)*XX(216)-JVS(1929)*XX(217)-JVS(1955)*XX(218)-JVS(1979)*XX(219)-JVS(2009)&
              &*XX(220)-JVS(2031)*XX(221))/(JVS(2043))
  XX(223) = (X(223)-JVS(172)*XX(26)-JVS(244)*XX(27)-JVS(666)*XX(110)-JVS(800)*XX(134)-JVS(946)*XX(155)-JVS(1014)*XX(162)&
              &-JVS(1058)*XX(167)-JVS(1129)*XX(174)-JVS(1150)*XX(175)-JVS(1260)*XX(184)-JVS(1380)*XX(189)-JVS(1388)*XX(190)&
              &-JVS(1406)*XX(191)-JVS(1473)*XX(196)-JVS(1508)*XX(198)-JVS(1515)*XX(199)-JVS(1588)*XX(205)-JVS(1608)*XX(206)&
              &-JVS(1636)*XX(207)-JVS(1670)*XX(208)-JVS(1775)*XX(212)-JVS(1809)*XX(213)-JVS(1875)*XX(216)-JVS(1930)*XX(217)&
              &-JVS(1956)*XX(218)-JVS(1980)*XX(219)-JVS(2010)*XX(220)-JVS(2032)*XX(221)-JVS(2044)*XX(222))/(JVS(2056))
  XX(224) = (X(224)-JVS(173)*XX(26)-JVS(316)*XX(28)-JVS(679)*XX(112)-JVS(749)*XX(125)-JVS(805)*XX(135)-JVS(854)*XX(143)&
              &-JVS(877)*XX(147)-JVS(947)*XX(155)-JVS(1028)*XX(164)-JVS(1071)*XX(169)-JVS(1079)*XX(170)-JVS(1087)*XX(171)&
              &-JVS(1115)*XX(173)-JVS(1130)*XX(174)-JVS(1166)*XX(176)-JVS(1217)*XX(181)-JVS(1233)*XX(182)-JVS(1291)*XX(186)&
              &-JVS(1381)*XX(189)-JVS(1407)*XX(191)-JVS(1516)*XX(199)-JVS(1589)*XX(205)-JVS(1609)*XX(206)-JVS(1637)*XX(207)&
              &-JVS(1671)*XX(208)-JVS(1776)*XX(212)-JVS(1876)*XX(216)-JVS(1931)*XX(217)-JVS(1957)*XX(218)-JVS(1981)*XX(219)&
              &-JVS(2011)*XX(220)-JVS(2033)*XX(221))/(JVS(2070))
  XX(225) = (X(225)-JVS(174)*XX(26)-JVS(317)*XX(28)-JVS(674)*XX(111)-JVS(762)*XX(127)-JVS(832)*XX(140)-JVS(882)*XX(148)&
              &-JVS(909)*XX(152)-JVS(919)*XX(153)-JVS(948)*XX(155)-JVS(1021)*XX(163)-JVS(1065)*XX(168)-JVS(1072)*XX(169)&
              &-JVS(1088)*XX(171)-JVS(1116)*XX(173)-JVS(1167)*XX(176)-JVS(1206)*XX(180)-JVS(1234)*XX(182)-JVS(1292)*XX(186)&
              &-JVS(1382)*XX(189)-JVS(1389)*XX(190)-JVS(1408)*XX(191)-JVS(1590)*XX(205)-JVS(1610)*XX(206)-JVS(1638)*XX(207)&
              &-JVS(1672)*XX(208)-JVS(1777)*XX(212)-JVS(1877)*XX(216)-JVS(1932)*XX(217)-JVS(1958)*XX(218)-JVS(1982)*XX(219)&
              &-JVS(2012)*XX(220)-JVS(2034)*XX(221)-JVS(2071)*XX(224))/(JVS(2086))
  XX(226) = (X(226)-JVS(245)*XX(27)-JVS(318)*XX(28)-JVS(1131)*XX(174)-JVS(1151)*XX(175)-JVS(1218)*XX(181)-JVS(1241)&
              &*XX(183)-JVS(1293)*XX(186)-JVS(1673)*XX(208)-JVS(1778)*XX(212)-JVS(1933)*XX(217))/(JVS(2110))
  XX(227) = (X(227)-JVS(30)*XX(7)-JVS(175)*XX(26)-JVS(246)*XX(27)-JVS(811)*XX(136)-JVS(959)*XX(156)-JVS(1152)*XX(175)&
              &-JVS(1168)*XX(176)-JVS(1242)*XX(183)-JVS(1294)*XX(186)-JVS(1779)*XX(212)-JVS(1934)*XX(217))/(JVS(2130))
  XX(228) = (X(228)-JVS(31)*XX(7)-JVS(319)*XX(28)-JVS(1295)*XX(186)-JVS(1313)*XX(187)-JVS(1935)*XX(217))/(JVS(2184))
  XX(229) = (X(229)-JVS(247)*XX(27)-JVS(320)*XX(28)-JVS(355)*XX(32)-JVS(575)*XX(94)-JVS(1099)*XX(172)-JVS(1207)*XX(180)&
              &-JVS(1523)*XX(200)-JVS(1639)*XX(207)-JVS(1780)*XX(212)-JVS(1820)*XX(214)-JVS(1878)*XX(216)-JVS(1936)*XX(217)&
              &-JVS(1983)*XX(219))/(JVS(2210))
  XX(230) = (X(230)-JVS(176)*XX(26)-JVS(1132)*XX(174)-JVS(1314)*XX(187)-JVS(1474)*XX(196)-JVS(1937)*XX(217)-JVS(2185)&
              &*XX(228))/(JVS(2234))
  XX(231) = (X(231)-JVS(248)*XX(27)-JVS(1524)*XX(200)-JVS(1567)*XX(204)-JVS(1781)*XX(212)-JVS(1821)*XX(214)-JVS(1938)&
              &*XX(217)-JVS(2235)*XX(230))/(JVS(2258))
  XX(232) = (X(232)-JVS(177)*XX(26)-JVS(600)*XX(98)-JVS(707)*XX(117)-JVS(1315)*XX(187)-JVS(1475)*XX(196))/(JVS(2274))
  XX(233) = (X(233)-JVS(249)*XX(27)-JVS(561)*XX(90)-JVS(1186)*XX(178)-JVS(1316)*XX(187)-JVS(1417)*XX(192)-JVS(1476)&
              &*XX(196)-JVS(1782)*XX(212)-JVS(1822)*XX(214)-JVS(2236)*XX(230)-JVS(2259)*XX(231)-JVS(2275)*XX(232))&
              &/(JVS(2291))
  XX(234) = (X(234)-JVS(178)*XX(26)-JVS(516)*XX(81)-JVS(844)*XX(141)-JVS(1317)*XX(187)-JVS(1418)*XX(192)-JVS(1477)&
              &*XX(196)-JVS(1823)*XX(214)-JVS(2237)*XX(230)-JVS(2260)*XX(231)-JVS(2276)*XX(232)-JVS(2292)*XX(233))&
              &/(JVS(2307))
  XX(235) = (X(235)-JVS(179)*XX(26)-JVS(497)*XX(77)-JVS(524)*XX(83)-JVS(845)*XX(141)-JVS(1318)*XX(187)-JVS(1419)*XX(192)&
              &-JVS(1478)*XX(196)-JVS(2238)*XX(230))/(JVS(2323))
  XX(236) = (X(236)-JVS(250)*XX(27)-JVS(321)*XX(28)-JVS(1050)*XX(166)-JVS(1194)*XX(179)-JVS(1267)*XX(185)-JVS(1319)&
              &*XX(187)-JVS(1479)*XX(196)-JVS(1706)*XX(210)-JVS(1939)*XX(217)-JVS(2186)*XX(228))/(JVS(2338))
  XX(237) = (X(237)-JVS(251)*XX(27)-JVS(322)*XX(28)-JVS(1525)*XX(200)-JVS(1783)*XX(212)-JVS(1824)*XX(214)-JVS(2277)&
              &*XX(232)-JVS(2324)*XX(235))/(JVS(2372))
  XX(238) = (X(238)-JVS(180)*XX(26)-JVS(252)*XX(27)-JVS(336)*XX(29)-JVS(342)*XX(30)-JVS(356)*XX(32)-JVS(437)*XX(60)&
              &-JVS(483)*XX(73)-JVS(757)*XX(126)-JVS(1100)*XX(172)-JVS(1296)*XX(186)-JVS(1707)*XX(210))/(JVS(2389))
  XX(239) = (X(239)-JVS(32)*XX(7)-JVS(181)*XX(26)-JVS(432)*XX(59)-JVS(449)*XX(63)-JVS(667)*XX(110)-JVS(985)*XX(159)&
              &-JVS(1178)*XX(177)-JVS(1187)*XX(178)-JVS(1195)*XX(179)-JVS(1268)*XX(185)-JVS(1320)*XX(187)-JVS(1420)*XX(192)&
              &-JVS(1432)*XX(193)-JVS(1444)*XX(194)-JVS(1453)*XX(195)-JVS(1480)*XX(196)-JVS(1526)*XX(200)-JVS(1556)*XX(203)&
              &-JVS(1568)*XX(204)-JVS(1719)*XX(211)-JVS(1784)*XX(212)-JVS(1810)*XX(213)-JVS(1825)*XX(214)-JVS(1879)*XX(216)&
              &-JVS(1940)*XX(217)-JVS(1959)*XX(218)-JVS(1984)*XX(219)-JVS(2013)*XX(220)-JVS(2035)*XX(221)-JVS(2045)*XX(222)&
              &-JVS(2057)*XX(223)-JVS(2072)*XX(224)-JVS(2087)*XX(225)-JVS(2111)*XX(226)-JVS(2131)*XX(227)-JVS(2187)*XX(228)&
              &-JVS(2211)*XX(229)-JVS(2239)*XX(230)-JVS(2261)*XX(231)-JVS(2278)*XX(232)-JVS(2293)*XX(233)-JVS(2308)*XX(234)&
              &-JVS(2325)*XX(235)-JVS(2339)*XX(236)-JVS(2373)*XX(237)-JVS(2390)*XX(238))/(JVS(2465))
  XX(240) = (X(240)-JVS(33)*XX(7)-JVS(337)*XX(29)-JVS(1708)*XX(210)-JVS(2391)*XX(238))/(JVS(2551))
  XX(241) = (X(241)-JVS(253)*XX(27)-JVS(323)*XX(28)-JVS(1051)*XX(166)-JVS(1785)*XX(212)-JVS(2466)*XX(239)-JVS(2552)&
              &*XX(240))/(JVS(2588))
  XX(242) = (X(242)-JVS(254)*XX(27)-JVS(324)*XX(28)-JVS(966)*XX(157)-JVS(1786)*XX(212)-JVS(2553)*XX(240)-JVS(2589)&
              &*XX(241))/(JVS(2689))
  XX(243) = (X(243)-JVS(34)*XX(7)-JVS(182)*XX(26)-JVS(255)*XX(27)-JVS(325)*XX(28)-JVS(459)*XX(65)-JVS(501)*XX(78)&
              &-JVS(580)*XX(95)-JVS(668)*XX(110)-JVS(708)*XX(117)-JVS(739)*XX(123)-JVS(846)*XX(141)-JVS(960)*XX(156)&
              &-JVS(986)*XX(159)-JVS(1005)*XX(161)-JVS(1015)*XX(162)-JVS(1089)*XX(171)-JVS(1153)*XX(175)-JVS(1179)*XX(177)&
              &-JVS(1188)*XX(178)-JVS(1196)*XX(179)-JVS(1269)*XX(185)-JVS(1321)*XX(187)-JVS(1390)*XX(190)-JVS(1409)*XX(191)&
              &-JVS(1421)*XX(192)-JVS(1433)*XX(193)-JVS(1445)*XX(194)-JVS(1454)*XX(195)-JVS(1481)*XX(196)-JVS(1509)*XX(198)&
              &-JVS(1517)*XX(199)-JVS(1527)*XX(200)-JVS(1557)*XX(203)-JVS(1569)*XX(204)-JVS(1591)*XX(205)-JVS(1611)*XX(206)&
              &-JVS(1640)*XX(207)-JVS(1674)*XX(208)-JVS(1690)*XX(209)-JVS(1720)*XX(211)-JVS(1787)*XX(212)-JVS(1811)*XX(213)&
              &-JVS(1826)*XX(214)-JVS(1880)*XX(216)-JVS(1941)*XX(217)-JVS(1960)*XX(218)-JVS(1985)*XX(219)-JVS(2014)*XX(220)&
              &-JVS(2036)*XX(221)-JVS(2046)*XX(222)-JVS(2058)*XX(223)-JVS(2073)*XX(224)-JVS(2088)*XX(225)-JVS(2112)*XX(226)&
              &-JVS(2132)*XX(227)-JVS(2188)*XX(228)-JVS(2212)*XX(229)-JVS(2240)*XX(230)-JVS(2262)*XX(231)-JVS(2279)*XX(232)&
              &-JVS(2294)*XX(233)-JVS(2309)*XX(234)-JVS(2326)*XX(235)-JVS(2340)*XX(236)-JVS(2374)*XX(237)-JVS(2392)*XX(238)&
              &-JVS(2467)*XX(239)-JVS(2554)*XX(240)-JVS(2590)*XX(241)-JVS(2690)*XX(242))/(JVS(2750))
  XX(244) = (X(244)-JVS(35)*XX(7)-JVS(65)*XX(12)-JVS(77)*XX(16)-JVS(91)*XX(20)-JVS(183)*XX(26)-JVS(326)*XX(28)-JVS(410)&
              &*XX(53)-JVS(417)*XX(55)-JVS(422)*XX(56)-JVS(426)*XX(57)-JVS(441)*XX(61)-JVS(498)*XX(77)-JVS(502)*XX(78)&
              &-JVS(506)*XX(79)-JVS(513)*XX(80)-JVS(533)*XX(85)-JVS(595)*XX(97)-JVS(629)*XX(104)-JVS(650)*XX(107)-JVS(655)&
              &*XX(108)-JVS(669)*XX(110)-JVS(714)*XX(118)-JVS(750)*XX(125)-JVS(763)*XX(127)-JVS(768)*XX(128)-JVS(774)&
              &*XX(129)-JVS(790)*XX(132)-JVS(796)*XX(133)-JVS(806)*XX(135)-JVS(883)*XX(148)-JVS(888)*XX(149)-JVS(893)&
              &*XX(150)-JVS(905)*XX(151)-JVS(920)*XX(153)-JVS(949)*XX(155)-JVS(961)*XX(156)-JVS(987)*XX(159)-JVS(997)&
              &*XX(160)-JVS(1022)*XX(163)-JVS(1029)*XX(164)-JVS(1046)*XX(165)-JVS(1059)*XX(167)-JVS(1073)*XX(169)-JVS(1090)&
              &*XX(171)-JVS(1117)*XX(173)-JVS(1133)*XX(174)-JVS(1154)*XX(175)-JVS(1169)*XX(176)-JVS(1180)*XX(177)-JVS(1189)&
              &*XX(178)-JVS(1197)*XX(179)-JVS(1208)*XX(180)-JVS(1219)*XX(181)-JVS(1235)*XX(182)-JVS(1243)*XX(183)-JVS(1261)&
              &*XX(184)-JVS(1270)*XX(185)-JVS(1297)*XX(186)-JVS(1322)*XX(187)-JVS(1345)*XX(188)-JVS(1383)*XX(189)-JVS(1391)&
              &*XX(190)-JVS(1410)*XX(191)-JVS(1422)*XX(192)-JVS(1434)*XX(193)-JVS(1446)*XX(194)-JVS(1455)*XX(195)-JVS(1482)&
              &*XX(196)-JVS(1497)*XX(197)-JVS(1510)*XX(198)-JVS(1518)*XX(199)-JVS(1528)*XX(200)-JVS(1558)*XX(203)-JVS(1570)&
              &*XX(204)-JVS(1592)*XX(205)-JVS(1612)*XX(206)-JVS(1641)*XX(207)-JVS(1675)*XX(208)-JVS(1691)*XX(209)-JVS(1709)&
              &*XX(210)-JVS(1721)*XX(211)-JVS(1788)*XX(212)-JVS(1812)*XX(213)-JVS(1827)*XX(214)-JVS(1881)*XX(216)-JVS(1942)&
              &*XX(217)-JVS(1961)*XX(218)-JVS(1986)*XX(219)-JVS(2015)*XX(220)-JVS(2037)*XX(221)-JVS(2047)*XX(222)-JVS(2059)&
              &*XX(223)-JVS(2074)*XX(224)-JVS(2089)*XX(225)-JVS(2113)*XX(226)-JVS(2133)*XX(227)-JVS(2189)*XX(228)-JVS(2213)&
              &*XX(229)-JVS(2241)*XX(230)-JVS(2263)*XX(231)-JVS(2280)*XX(232)-JVS(2295)*XX(233)-JVS(2310)*XX(234)-JVS(2327)&
              &*XX(235)-JVS(2341)*XX(236)-JVS(2375)*XX(237)-JVS(2393)*XX(238)-JVS(2468)*XX(239)-JVS(2555)*XX(240)-JVS(2591)&
              &*XX(241)-JVS(2691)*XX(242)-JVS(2751)*XX(243))/(JVS(2837))
  XX(245) = (X(245)-JVS(256)*XX(27)-JVS(644)*XX(106)-JVS(691)*XX(114)-JVS(736)*XX(122)-JVS(746)*XX(124)-JVS(967)*XX(157)&
              &-JVS(1544)*XX(202)-JVS(1692)*XX(209)-JVS(1789)*XX(212)-JVS(1838)*XX(215))/(JVS(2867))
  XX(246) = (X(246)-JVS(36)*XX(7)-JVS(71)*XX(14)-JVS(257)*XX(27)-JVS(327)*XX(28)-JVS(491)*XX(75)-JVS(536)*XX(86)&
              &-JVS(609)*XX(100)-JVS(670)*XX(110)-JVS(720)*XX(119)-JVS(758)*XX(126)-JVS(784)*XX(131)-JVS(815)*XX(137)&
              &-JVS(819)*XX(138)-JVS(849)*XX(142)-JVS(874)*XX(146)-JVS(924)*XX(154)-JVS(988)*XX(159)-JVS(998)*XX(160)&
              &-JVS(1101)*XX(172)-JVS(1155)*XX(175)-JVS(1181)*XX(177)-JVS(1198)*XX(179)-JVS(1244)*XX(183)-JVS(1262)*XX(184)&
              &-JVS(1298)*XX(186)-JVS(1323)*XX(187)-JVS(1346)*XX(188)-JVS(1384)*XX(189)-JVS(1435)*XX(193)-JVS(1447)*XX(194)&
              &-JVS(1456)*XX(195)-JVS(1483)*XX(196)-JVS(1498)*XX(197)-JVS(1529)*XX(200)-JVS(1534)*XX(201)-JVS(1559)*XX(203)&
              &-JVS(1571)*XX(204)-JVS(1642)*XX(207)-JVS(1676)*XX(208)-JVS(1693)*XX(209)-JVS(1710)*XX(210)-JVS(1722)*XX(211)&
              &-JVS(1790)*XX(212)-JVS(1813)*XX(213)-JVS(1828)*XX(214)-JVS(1882)*XX(216)-JVS(1943)*XX(217)-JVS(1962)*XX(218)&
              &-JVS(1987)*XX(219)-JVS(2016)*XX(220)-JVS(2038)*XX(221)-JVS(2048)*XX(222)-JVS(2060)*XX(223)-JVS(2075)*XX(224)&
              &-JVS(2090)*XX(225)-JVS(2114)*XX(226)-JVS(2134)*XX(227)-JVS(2190)*XX(228)-JVS(2214)*XX(229)-JVS(2242)*XX(230)&
              &-JVS(2264)*XX(231)-JVS(2281)*XX(232)-JVS(2296)*XX(233)-JVS(2311)*XX(234)-JVS(2328)*XX(235)-JVS(2342)*XX(236)&
              &-JVS(2376)*XX(237)-JVS(2394)*XX(238)-JVS(2469)*XX(239)-JVS(2556)*XX(240)-JVS(2592)*XX(241)-JVS(2692)*XX(242)&
              &-JVS(2752)*XX(243)-JVS(2838)*XX(244)-JVS(2868)*XX(245))/(JVS(2948))
  XX(247) = (X(247)-JVS(184)*XX(26)-JVS(258)*XX(27)-JVS(384)*XX(42)-JVS(388)*XX(44)-JVS(413)*XX(54)-JVS(427)*XX(57)&
              &-JVS(433)*XX(59)-JVS(460)*XX(65)-JVS(495)*XX(76)-JVS(569)*XX(93)-JVS(596)*XX(97)-JVS(769)*XX(128)-JVS(775)&
              &*XX(129)-JVS(785)*XX(131)-JVS(812)*XX(136)-JVS(875)*XX(146)-JVS(976)*XX(158)-JVS(999)*XX(160)-JVS(1170)&
              &*XX(176)-JVS(1209)*XX(180)-JVS(1220)*XX(181)-JVS(1245)*XX(183)-JVS(1299)*XX(186)-JVS(1347)*XX(188)-JVS(1499)&
              &*XX(197)-JVS(1530)*XX(200)-JVS(1545)*XX(202)-JVS(1643)*XX(207)-JVS(1677)*XX(208)-JVS(1694)*XX(209)-JVS(1711)&
              &*XX(210)-JVS(1791)*XX(212)-JVS(1829)*XX(214)-JVS(1839)*XX(215)-JVS(1883)*XX(216)-JVS(1944)*XX(217)-JVS(1988)&
              &*XX(219)-JVS(2135)*XX(227)-JVS(2191)*XX(228)-JVS(2243)*XX(230)-JVS(2282)*XX(232)-JVS(2329)*XX(235)-JVS(2377)&
              &*XX(237)-JVS(2395)*XX(238)-JVS(2470)*XX(239)-JVS(2557)*XX(240)-JVS(2593)*XX(241)-JVS(2693)*XX(242)-JVS(2753)&
              &*XX(243)-JVS(2839)*XX(244)-JVS(2869)*XX(245)-JVS(2949)*XX(246))/(JVS(3068))
  XX(248) = (X(248)-JVS(37)*XX(7)-JVS(62)*XX(11)-JVS(74)*XX(15)-JVS(88)*XX(19)-JVS(185)*XX(26)-JVS(259)*XX(27)-JVS(328)&
              &*XX(28)-JVS(357)*XX(32)-JVS(418)*XX(55)-JVS(423)*XX(56)-JVS(442)*XX(61)-JVS(446)*XX(62)-JVS(450)*XX(63)&
              &-JVS(517)*XX(81)-JVS(521)*XX(82)-JVS(525)*XX(83)-JVS(529)*XX(84)-JVS(570)*XX(93)-JVS(601)*XX(98)-JVS(614)&
              &*XX(101)-JVS(618)*XX(102)-JVS(630)*XX(104)-JVS(635)*XX(105)-JVS(651)*XX(107)-JVS(656)*XX(108)-JVS(684)&
              &*XX(113)-JVS(715)*XX(118)-JVS(731)*XX(121)-JVS(740)*XX(123)-JVS(770)*XX(128)-JVS(776)*XX(129)-JVS(781)&
              &*XX(130)-JVS(791)*XX(132)-JVS(797)*XX(133)-JVS(801)*XX(134)-JVS(807)*XX(135)-JVS(833)*XX(140)-JVS(855)&
              &*XX(143)-JVS(868)*XX(145)-JVS(878)*XX(147)-JVS(884)*XX(148)-JVS(889)*XX(149)-JVS(894)*XX(150)-JVS(906)&
              &*XX(151)-JVS(910)*XX(152)-JVS(921)*XX(153)-JVS(950)*XX(155)-JVS(962)*XX(156)-JVS(968)*XX(157)-JVS(989)&
              &*XX(159)-JVS(1016)*XX(162)-JVS(1023)*XX(163)-JVS(1030)*XX(164)-JVS(1047)*XX(165)-JVS(1060)*XX(167)-JVS(1066)&
              &*XX(168)-JVS(1074)*XX(169)-JVS(1080)*XX(170)-JVS(1091)*XX(171)-JVS(1102)*XX(172)-JVS(1118)*XX(173)-JVS(1134)&
              &*XX(174)-JVS(1156)*XX(175)-JVS(1171)*XX(176)-JVS(1182)*XX(177)-JVS(1190)*XX(178)-JVS(1199)*XX(179)-JVS(1210)&
              &*XX(180)-JVS(1221)*XX(181)-JVS(1236)*XX(182)-JVS(1246)*XX(183)-JVS(1263)*XX(184)-JVS(1271)*XX(185)-JVS(1300)&
              &*XX(186)-JVS(1324)*XX(187)-JVS(1348)*XX(188)-JVS(1385)*XX(189)-JVS(1411)*XX(191)-JVS(1423)*XX(192)-JVS(1436)&
              &*XX(193)-JVS(1448)*XX(194)-JVS(1457)*XX(195)-JVS(1484)*XX(196)-JVS(1500)*XX(197)-JVS(1511)*XX(198)-JVS(1531)&
              &*XX(200)-JVS(1546)*XX(202)-JVS(1560)*XX(203)-JVS(1572)*XX(204)-JVS(1593)*XX(205)-JVS(1613)*XX(206)-JVS(1644)&
              &*XX(207)-JVS(1678)*XX(208)-JVS(1695)*XX(209)-JVS(1723)*XX(211)-JVS(1792)*XX(212)-JVS(1814)*XX(213)-JVS(1830)&
              &*XX(214)-JVS(1840)*XX(215)-JVS(1884)*XX(216)-JVS(1945)*XX(217)-JVS(1963)*XX(218)-JVS(1989)*XX(219)-JVS(2017)&
              &*XX(220)-JVS(2039)*XX(221)-JVS(2049)*XX(222)-JVS(2061)*XX(223)-JVS(2076)*XX(224)-JVS(2091)*XX(225)-JVS(2115)&
              &*XX(226)-JVS(2136)*XX(227)-JVS(2192)*XX(228)-JVS(2215)*XX(229)-JVS(2244)*XX(230)-JVS(2265)*XX(231)-JVS(2283)&
              &*XX(232)-JVS(2297)*XX(233)-JVS(2312)*XX(234)-JVS(2330)*XX(235)-JVS(2343)*XX(236)-JVS(2378)*XX(237)-JVS(2396)&
              &*XX(238)-JVS(2471)*XX(239)-JVS(2558)*XX(240)-JVS(2594)*XX(241)-JVS(2694)*XX(242)-JVS(2754)*XX(243)-JVS(2840)&
              &*XX(244)-JVS(2870)*XX(245)-JVS(2950)*XX(246)-JVS(3069)*XX(247))/(JVS(3223))
  XX(249) = (X(249)-JVS(329)*XX(28)-JVS(389)*XX(44)-JVS(659)*XX(109)-JVS(692)*XX(114)-JVS(850)*XX(142)-JVS(977)*XX(158)&
              &-JVS(1272)*XX(185)-JVS(1325)*XX(187)-JVS(1424)*XX(192)-JVS(1458)*XX(195)-JVS(1485)*XX(196)-JVS(1547)*XX(202)&
              &-JVS(1793)*XX(212)-JVS(1831)*XX(214)-JVS(1841)*XX(215)-JVS(2193)*XX(228)-JVS(2245)*XX(230)-JVS(2284)*XX(232)&
              &-JVS(2331)*XX(235)-JVS(2344)*XX(236)-JVS(2379)*XX(237)-JVS(2397)*XX(238)-JVS(2472)*XX(239)-JVS(2559)*XX(240)&
              &-JVS(2595)*XX(241)-JVS(2695)*XX(242)-JVS(2755)*XX(243)-JVS(2841)*XX(244)-JVS(2871)*XX(245)-JVS(2951)*XX(246)&
              &-JVS(3070)*XX(247)-JVS(3224)*XX(248))/(JVS(3275))
  XX(250) = (X(250)-JVS(38)*XX(7)-JVS(68)*XX(13)-JVS(85)*XX(18)-JVS(94)*XX(21)-JVS(186)*XX(26)-JVS(260)*XX(27)-JVS(330)&
              &*XX(28)-JVS(338)*XX(29)-JVS(343)*XX(30)-JVS(346)*XX(31)-JVS(358)*XX(32)-JVS(364)*XX(34)-JVS(372)*XX(37)&
              &-JVS(374)*XX(38)-JVS(386)*XX(43)-JVS(419)*XX(55)-JVS(424)*XX(56)-JVS(429)*XX(58)-JVS(438)*XX(60)-JVS(443)&
              &*XX(61)-JVS(447)*XX(62)-JVS(451)*XX(63)-JVS(462)*XX(66)-JVS(465)*XX(67)-JVS(468)*XX(68)-JVS(471)*XX(69)&
              &-JVS(474)*XX(70)-JVS(477)*XX(71)-JVS(480)*XX(72)-JVS(484)*XX(73)-JVS(489)*XX(74)-JVS(492)*XX(75)-JVS(499)&
              &*XX(77)-JVS(503)*XX(78)-JVS(507)*XX(79)-JVS(518)*XX(81)-JVS(522)*XX(82)-JVS(526)*XX(83)-JVS(530)*XX(84)&
              &-JVS(534)*XX(85)-JVS(537)*XX(86)-JVS(540)*XX(87)-JVS(543)*XX(88)-JVS(546)*XX(89)-JVS(563)*XX(91)-JVS(566)&
              &*XX(92)-JVS(571)*XX(93)-JVS(576)*XX(94)-JVS(581)*XX(95)-JVS(589)*XX(96)-JVS(597)*XX(97)-JVS(602)*XX(98)&
              &-JVS(605)*XX(99)-JVS(610)*XX(100)-JVS(615)*XX(101)-JVS(619)*XX(102)-JVS(625)*XX(103)-JVS(631)*XX(104)&
              &-JVS(636)*XX(105)-JVS(652)*XX(107)-JVS(657)*XX(108)-JVS(660)*XX(109)-JVS(675)*XX(111)-JVS(680)*XX(112)&
              &-JVS(685)*XX(113)-JVS(693)*XX(114)-JVS(698)*XX(115)-JVS(704)*XX(116)-JVS(709)*XX(117)-JVS(716)*XX(118)&
              &-JVS(721)*XX(119)-JVS(728)*XX(120)-JVS(732)*XX(121)-JVS(741)*XX(123)-JVS(751)*XX(125)-JVS(759)*XX(126)&
              &-JVS(764)*XX(127)-JVS(782)*XX(130)-JVS(792)*XX(132)-JVS(798)*XX(133)-JVS(802)*XX(134)-JVS(808)*XX(135)&
              &-JVS(813)*XX(136)-JVS(816)*XX(137)-JVS(820)*XX(138)-JVS(830)*XX(139)-JVS(834)*XX(140)-JVS(847)*XX(141)&
              &-JVS(851)*XX(142)-JVS(856)*XX(143)-JVS(862)*XX(144)-JVS(869)*XX(145)-JVS(879)*XX(147)-JVS(885)*XX(148)&
              &-JVS(890)*XX(149)-JVS(895)*XX(150)-JVS(907)*XX(151)-JVS(911)*XX(152)-JVS(922)*XX(153)-JVS(925)*XX(154)&
              &-JVS(951)*XX(155)-JVS(963)*XX(156)-JVS(969)*XX(157)-JVS(990)*XX(159)-JVS(1000)*XX(160)-JVS(1006)*XX(161)&
              &-JVS(1017)*XX(162)-JVS(1024)*XX(163)-JVS(1031)*XX(164)-JVS(1048)*XX(165)-JVS(1052)*XX(166)-JVS(1061)*XX(167)&
              &-JVS(1067)*XX(168)-JVS(1075)*XX(169)-JVS(1081)*XX(170)-JVS(1092)*XX(171)-JVS(1103)*XX(172)-JVS(1119)*XX(173)&
              &-JVS(1135)*XX(174)-JVS(1157)*XX(175)-JVS(1172)*XX(176)-JVS(1183)*XX(177)-JVS(1191)*XX(178)-JVS(1200)*XX(179)&
              &-JVS(1211)*XX(180)-JVS(1222)*XX(181)-JVS(1237)*XX(182)-JVS(1247)*XX(183)-JVS(1264)*XX(184)-JVS(1273)*XX(185)&
              &-JVS(1301)*XX(186)-JVS(1326)*XX(187)-JVS(1349)*XX(188)-JVS(1386)*XX(189)-JVS(1392)*XX(190)-JVS(1412)*XX(191)&
              &-JVS(1425)*XX(192)-JVS(1437)*XX(193)-JVS(1449)*XX(194)-JVS(1459)*XX(195)-JVS(1486)*XX(196)-JVS(1501)*XX(197)&
              &-JVS(1512)*XX(198)-JVS(1519)*XX(199)-JVS(1532)*XX(200)-JVS(1535)*XX(201)-JVS(1548)*XX(202)-JVS(1561)*XX(203)&
              &-JVS(1573)*XX(204)-JVS(1594)*XX(205)-JVS(1614)*XX(206)-JVS(1645)*XX(207)-JVS(1679)*XX(208)-JVS(1696)*XX(209)&
              &-JVS(1712)*XX(210)-JVS(1724)*XX(211)-JVS(1794)*XX(212)-JVS(1815)*XX(213)-JVS(1832)*XX(214)-JVS(1842)*XX(215)&
              &-JVS(1885)*XX(216)-JVS(1946)*XX(217)-JVS(1964)*XX(218)-JVS(1990)*XX(219)-JVS(2018)*XX(220)-JVS(2040)*XX(221)&
              &-JVS(2050)*XX(222)-JVS(2062)*XX(223)-JVS(2077)*XX(224)-JVS(2092)*XX(225)-JVS(2116)*XX(226)-JVS(2137)*XX(227)&
              &-JVS(2194)*XX(228)-JVS(2216)*XX(229)-JVS(2246)*XX(230)-JVS(2266)*XX(231)-JVS(2285)*XX(232)-JVS(2298)*XX(233)&
              &-JVS(2313)*XX(234)-JVS(2332)*XX(235)-JVS(2345)*XX(236)-JVS(2380)*XX(237)-JVS(2398)*XX(238)-JVS(2473)*XX(239)&
              &-JVS(2560)*XX(240)-JVS(2596)*XX(241)-JVS(2696)*XX(242)-JVS(2756)*XX(243)-JVS(2842)*XX(244)-JVS(2872)*XX(245)&
              &-JVS(2952)*XX(246)-JVS(3071)*XX(247)-JVS(3225)*XX(248)-JVS(3276)*XX(249))/(JVS(3465))
  XX(251) = (X(251)-JVS(261)*XX(27)-JVS(514)*XX(80)-JVS(582)*XX(95)-JVS(606)*XX(99)-JVS(645)*XX(106)-JVS(694)*XX(114)&
              &-JVS(978)*XX(158)-JVS(1007)*XX(161)-JVS(1350)*XX(188)-JVS(1502)*XX(197)-JVS(1549)*XX(202)-JVS(1697)*XX(209)&
              &-JVS(1795)*XX(212)-JVS(1843)*XX(215)-JVS(2843)*XX(244)-JVS(2873)*XX(245)-JVS(2953)*XX(246)-JVS(3072)*XX(247)&
              &-JVS(3226)*XX(248)-JVS(3277)*XX(249)-JVS(3466)*XX(250))/(JVS(3492))
  XX(252) = (X(252)-JVS(262)*XX(27)-JVS(541)*XX(87)-JVS(646)*XX(106)-JVS(786)*XX(131)-JVS(970)*XX(157)-JVS(979)*XX(158)&
              &-JVS(1008)*XX(161)-JVS(1550)*XX(202)-JVS(1698)*XX(209)-JVS(1796)*XX(212)-JVS(1844)*XX(215)-JVS(2874)*XX(245)&
              &-JVS(2954)*XX(246)-JVS(3073)*XX(247)-JVS(3227)*XX(248)-JVS(3278)*XX(249)-JVS(3467)*XX(250)-JVS(3493)*XX(251))&
              &/(JVS(3561))
  XX(253) = (X(253)-JVS(263)*XX(27)-JVS(457)*XX(64)-JVS(469)*XX(68)-JVS(583)*XX(95)-JVS(607)*XX(99)-JVS(647)*XX(106)&
              &-JVS(1009)*XX(161)-JVS(1351)*XX(188)-JVS(1503)*XX(197)-JVS(1699)*XX(209)-JVS(1797)*XX(212)-JVS(1845)*XX(215)&
              &-JVS(2697)*XX(242)-JVS(2757)*XX(243)-JVS(2844)*XX(244)-JVS(2875)*XX(245)-JVS(2955)*XX(246)-JVS(3074)*XX(247)&
              &-JVS(3228)*XX(248)-JVS(3279)*XX(249)-JVS(3468)*XX(250)-JVS(3494)*XX(251)-JVS(3562)*XX(252))/(JVS(3604))
  XX(254) = (X(254)-JVS(264)*XX(27)-JVS(347)*XX(31)-JVS(376)*XX(39)-JVS(378)*XX(40)-JVS(391)*XX(45)-JVS(393)*XX(46)&
              &-JVS(395)*XX(47)-JVS(397)*XX(48)-JVS(399)*XX(49)-JVS(401)*XX(50)-JVS(403)*XX(51)-JVS(414)*XX(54)-JVS(463)&
              &*XX(66)-JVS(472)*XX(69)-JVS(478)*XX(71)-JVS(481)*XX(72)-JVS(544)*XX(88)-JVS(547)*XX(89)-JVS(567)*XX(92)&
              &-JVS(971)*XX(157)-JVS(1010)*XX(161)-JVS(1053)*XX(166)-JVS(1700)*XX(209)-JVS(2698)*XX(242)-JVS(2758)*XX(243)&
              &-JVS(2845)*XX(244)-JVS(2876)*XX(245)-JVS(2956)*XX(246)-JVS(3075)*XX(247)-JVS(3229)*XX(248)-JVS(3280)*XX(249)&
              &-JVS(3469)*XX(250)-JVS(3495)*XX(251)-JVS(3563)*XX(252)-JVS(3605)*XX(253))/(JVS(3647))
  XX(255) = (X(255)-JVS(39)*XX(7)-JVS(187)*XX(26)-JVS(331)*XX(28)-JVS(348)*XX(31)-JVS(466)*XX(67)-JVS(475)*XX(70)&
              &-JVS(564)*XX(91)-JVS(584)*XX(95)-JVS(611)*XX(100)-JVS(661)*XX(109)-JVS(710)*XX(117)-JVS(742)*XX(123)-JVS(852)&
              &*XX(142)-JVS(972)*XX(157)-JVS(1011)*XX(161)-JVS(1054)*XX(166)-JVS(1104)*XX(172)-JVS(1274)*XX(185)-JVS(1302)&
              &*XX(186)-JVS(1327)*XX(187)-JVS(1426)*XX(192)-JVS(1460)*XX(195)-JVS(1487)*XX(196)-JVS(1536)*XX(201)-JVS(1646)&
              &*XX(207)-JVS(1680)*XX(208)-JVS(1701)*XX(209)-JVS(1798)*XX(212)-JVS(1833)*XX(214)-JVS(1846)*XX(215)-JVS(1886)&
              &*XX(216)-JVS(1947)*XX(217)-JVS(1991)*XX(219)-JVS(2051)*XX(222)-JVS(2063)*XX(223)-JVS(2078)*XX(224)-JVS(2093)&
              &*XX(225)-JVS(2117)*XX(226)-JVS(2138)*XX(227)-JVS(2195)*XX(228)-JVS(2217)*XX(229)-JVS(2247)*XX(230)-JVS(2286)&
              &*XX(232)-JVS(2314)*XX(234)-JVS(2333)*XX(235)-JVS(2346)*XX(236)-JVS(2381)*XX(237)-JVS(2399)*XX(238)-JVS(2474)&
              &*XX(239)-JVS(2561)*XX(240)-JVS(2597)*XX(241)-JVS(2699)*XX(242)-JVS(2759)*XX(243)-JVS(2846)*XX(244)-JVS(2877)&
              &*XX(245)-JVS(2957)*XX(246)-JVS(3076)*XX(247)-JVS(3230)*XX(248)-JVS(3281)*XX(249)-JVS(3470)*XX(250)-JVS(3496)&
              &*XX(251)-JVS(3564)*XX(252)-JVS(3606)*XX(253)-JVS(3648)*XX(254))/(JVS(3743))
  XX(256) = (X(256)-JVS(265)*XX(27)-JVS(359)*XX(32)-JVS(485)*XX(73)-JVS(787)*XX(131)-JVS(980)*XX(158)-JVS(1105)*XX(172)&
              &-JVS(1303)*XX(186)-JVS(1328)*XX(187)-JVS(1551)*XX(202)-JVS(1702)*XX(209)-JVS(1713)*XX(210)-JVS(1799)*XX(212)&
              &-JVS(1847)*XX(215)-JVS(2400)*XX(238)-JVS(2562)*XX(240)-JVS(2598)*XX(241)-JVS(2700)*XX(242)-JVS(2760)*XX(243)&
              &-JVS(2847)*XX(244)-JVS(2878)*XX(245)-JVS(2958)*XX(246)-JVS(3077)*XX(247)-JVS(3231)*XX(248)-JVS(3282)*XX(249)&
              &-JVS(3471)*XX(250)-JVS(3497)*XX(251)-JVS(3565)*XX(252)-JVS(3607)*XX(253)-JVS(3649)*XX(254)-JVS(3744)*XX(255))&
              &/(JVS(3826))
  XX(257) = (X(257)-JVS(40)*XX(7)-JVS(266)*XX(27)-JVS(332)*XX(28)-JVS(360)*XX(32)-JVS(577)*XX(94)-JVS(722)*XX(119)&
              &-JVS(737)*XX(122)-JVS(747)*XX(124)-JVS(817)*XX(137)-JVS(821)*XX(138)-JVS(926)*XX(154)-JVS(973)*XX(157)&
              &-JVS(1055)*XX(166)-JVS(1106)*XX(172)-JVS(1184)*XX(177)-JVS(1304)*XX(186)-JVS(1352)*XX(188)-JVS(1438)*XX(193)&
              &-JVS(1450)*XX(194)-JVS(1488)*XX(196)-JVS(1504)*XX(197)-JVS(1537)*XX(201)-JVS(1552)*XX(202)-JVS(1562)*XX(203)&
              &-JVS(1574)*XX(204)-JVS(1647)*XX(207)-JVS(1681)*XX(208)-JVS(1703)*XX(209)-JVS(1714)*XX(210)-JVS(1725)*XX(211)&
              &-JVS(1800)*XX(212)-JVS(1848)*XX(215)-JVS(1887)*XX(216)-JVS(1948)*XX(217)-JVS(1992)*XX(219)-JVS(2052)*XX(222)&
              &-JVS(2064)*XX(223)-JVS(2079)*XX(224)-JVS(2094)*XX(225)-JVS(2118)*XX(226)-JVS(2139)*XX(227)-JVS(2196)*XX(228)&
              &-JVS(2218)*XX(229)-JVS(2248)*XX(230)-JVS(2267)*XX(231)-JVS(2287)*XX(232)-JVS(2299)*XX(233)-JVS(2315)*XX(234)&
              &-JVS(2334)*XX(235)-JVS(2347)*XX(236)-JVS(2382)*XX(237)-JVS(2401)*XX(238)-JVS(2475)*XX(239)-JVS(2563)*XX(240)&
              &-JVS(2599)*XX(241)-JVS(2701)*XX(242)-JVS(2761)*XX(243)-JVS(2848)*XX(244)-JVS(2879)*XX(245)-JVS(2959)*XX(246)&
              &-JVS(3078)*XX(247)-JVS(3232)*XX(248)-JVS(3283)*XX(249)-JVS(3472)*XX(250)-JVS(3498)*XX(251)-JVS(3566)*XX(252)&
              &-JVS(3608)*XX(253)-JVS(3650)*XX(254)-JVS(3745)*XX(255)-JVS(3827)*XX(256))/(JVS(3875))
  XX(258) = (X(258)-JVS(267)*XX(27)-JVS(333)*XX(28)-JVS(430)*XX(58)-JVS(760)*XX(126)-JVS(974)*XX(157)-JVS(1107)*XX(172)&
              &-JVS(1553)*XX(202)-JVS(1715)*XX(210)-JVS(1801)*XX(212)-JVS(1849)*XX(215)-JVS(2402)*XX(238)-JVS(2564)*XX(240)&
              &-JVS(2600)*XX(241)-JVS(2702)*XX(242)-JVS(2762)*XX(243)-JVS(2849)*XX(244)-JVS(2880)*XX(245)-JVS(2960)*XX(246)&
              &-JVS(3079)*XX(247)-JVS(3233)*XX(248)-JVS(3284)*XX(249)-JVS(3473)*XX(250)-JVS(3499)*XX(251)-JVS(3567)*XX(252)&
              &-JVS(3609)*XX(253)-JVS(3651)*XX(254)-JVS(3746)*XX(255)-JVS(3828)*XX(256)-JVS(3876)*XX(257))/(JVS(3927))
  XX(258) = XX(258)
  XX(257) = XX(257)-JVS(3926)*XX(258)
  XX(256) = XX(256)-JVS(3874)*XX(257)-JVS(3925)*XX(258)
  XX(255) = XX(255)-JVS(3825)*XX(256)-JVS(3873)*XX(257)-JVS(3924)*XX(258)
  XX(254) = XX(254)-JVS(3742)*XX(255)-JVS(3824)*XX(256)-JVS(3872)*XX(257)-JVS(3923)*XX(258)
  XX(253) = XX(253)-JVS(3646)*XX(254)-JVS(3741)*XX(255)-JVS(3823)*XX(256)-JVS(3871)*XX(257)-JVS(3922)*XX(258)
  XX(252) = XX(252)-JVS(3603)*XX(253)-JVS(3645)*XX(254)-JVS(3740)*XX(255)-JVS(3822)*XX(256)-JVS(3870)*XX(257)-JVS(3921)&
              &*XX(258)
  XX(251) = XX(251)-JVS(3560)*XX(252)-JVS(3602)*XX(253)-JVS(3644)*XX(254)-JVS(3739)*XX(255)-JVS(3821)*XX(256)-JVS(3869)&
              &*XX(257)-JVS(3920)*XX(258)
  XX(250) = XX(250)-JVS(3491)*XX(251)-JVS(3559)*XX(252)-JVS(3601)*XX(253)-JVS(3643)*XX(254)-JVS(3738)*XX(255)-JVS(3820)&
              &*XX(256)-JVS(3868)*XX(257)-JVS(3919)*XX(258)
  XX(249) = XX(249)-JVS(3464)*XX(250)-JVS(3490)*XX(251)-JVS(3558)*XX(252)-JVS(3600)*XX(253)-JVS(3642)*XX(254)-JVS(3737)&
              &*XX(255)-JVS(3819)*XX(256)-JVS(3867)*XX(257)-JVS(3918)*XX(258)
  XX(248) = XX(248)-JVS(3274)*XX(249)-JVS(3463)*XX(250)-JVS(3489)*XX(251)-JVS(3557)*XX(252)-JVS(3599)*XX(253)-JVS(3641)&
              &*XX(254)-JVS(3736)*XX(255)-JVS(3818)*XX(256)-JVS(3866)*XX(257)-JVS(3917)*XX(258)
  XX(247) = XX(247)-JVS(3222)*XX(248)-JVS(3273)*XX(249)-JVS(3462)*XX(250)-JVS(3488)*XX(251)-JVS(3556)*XX(252)-JVS(3598)&
              &*XX(253)-JVS(3640)*XX(254)-JVS(3735)*XX(255)-JVS(3817)*XX(256)-JVS(3865)*XX(257)-JVS(3916)*XX(258)
  XX(246) = XX(246)-JVS(3067)*XX(247)-JVS(3221)*XX(248)-JVS(3272)*XX(249)-JVS(3461)*XX(250)-JVS(3487)*XX(251)-JVS(3555)&
              &*XX(252)-JVS(3597)*XX(253)-JVS(3639)*XX(254)-JVS(3734)*XX(255)-JVS(3816)*XX(256)-JVS(3864)*XX(257)-JVS(3915)&
              &*XX(258)
  XX(245) = XX(245)-JVS(2947)*XX(246)-JVS(3066)*XX(247)-JVS(3220)*XX(248)-JVS(3271)*XX(249)-JVS(3460)*XX(250)-JVS(3486)&
              &*XX(251)-JVS(3554)*XX(252)-JVS(3596)*XX(253)-JVS(3638)*XX(254)-JVS(3733)*XX(255)-JVS(3815)*XX(256)-JVS(3863)&
              &*XX(257)-JVS(3914)*XX(258)
  XX(244) = XX(244)-JVS(2866)*XX(245)-JVS(2946)*XX(246)-JVS(3065)*XX(247)-JVS(3219)*XX(248)-JVS(3270)*XX(249)-JVS(3459)&
              &*XX(250)-JVS(3485)*XX(251)-JVS(3553)*XX(252)-JVS(3595)*XX(253)-JVS(3637)*XX(254)-JVS(3732)*XX(255)-JVS(3814)&
              &*XX(256)-JVS(3862)*XX(257)-JVS(3913)*XX(258)
  XX(243) = XX(243)-JVS(2836)*XX(244)-JVS(2865)*XX(245)-JVS(2945)*XX(246)-JVS(3064)*XX(247)-JVS(3218)*XX(248)-JVS(3269)&
              &*XX(249)-JVS(3458)*XX(250)-JVS(3552)*XX(252)-JVS(3594)*XX(253)-JVS(3636)*XX(254)-JVS(3731)*XX(255)-JVS(3813)&
              &*XX(256)-JVS(3861)*XX(257)-JVS(3912)*XX(258)
  XX(242) = XX(242)-JVS(2749)*XX(243)-JVS(2835)*XX(244)-JVS(2864)*XX(245)-JVS(2944)*XX(246)-JVS(3063)*XX(247)-JVS(3217)&
              &*XX(248)-JVS(3268)*XX(249)-JVS(3457)*XX(250)-JVS(3551)*XX(252)-JVS(3593)*XX(253)-JVS(3635)*XX(254)-JVS(3730)&
              &*XX(255)-JVS(3812)*XX(256)-JVS(3860)*XX(257)-JVS(3911)*XX(258)
  XX(241) = XX(241)-JVS(2688)*XX(242)-JVS(2748)*XX(243)-JVS(2834)*XX(244)-JVS(2863)*XX(245)-JVS(2943)*XX(246)-JVS(3062)&
              &*XX(247)-JVS(3216)*XX(248)-JVS(3267)*XX(249)-JVS(3456)*XX(250)-JVS(3550)*XX(252)-JVS(3592)*XX(253)-JVS(3634)&
              &*XX(254)-JVS(3729)*XX(255)-JVS(3811)*XX(256)-JVS(3859)*XX(257)-JVS(3910)*XX(258)
  XX(240) = XX(240)-JVS(2587)*XX(241)-JVS(2687)*XX(242)-JVS(2747)*XX(243)-JVS(2833)*XX(244)-JVS(2942)*XX(246)-JVS(3061)&
              &*XX(247)-JVS(3215)*XX(248)-JVS(3455)*XX(250)-JVS(3549)*XX(252)-JVS(3728)*XX(255)-JVS(3810)*XX(256)-JVS(3858)&
              &*XX(257)-JVS(3909)*XX(258)
  XX(239) = XX(239)-JVS(2550)*XX(240)-JVS(2586)*XX(241)-JVS(2686)*XX(242)-JVS(2746)*XX(243)-JVS(2832)*XX(244)-JVS(2862)&
              &*XX(245)-JVS(2941)*XX(246)-JVS(3060)*XX(247)-JVS(3214)*XX(248)-JVS(3266)*XX(249)-JVS(3454)*XX(250)-JVS(3548)&
              &*XX(252)-JVS(3591)*XX(253)-JVS(3633)*XX(254)-JVS(3727)*XX(255)-JVS(3809)*XX(256)-JVS(3857)*XX(257)-JVS(3908)&
              &*XX(258)
  XX(238) = XX(238)-JVS(2549)*XX(240)-JVS(2585)*XX(241)-JVS(2685)*XX(242)-JVS(2745)*XX(243)-JVS(2831)*XX(244)-JVS(2940)&
              &*XX(246)-JVS(3059)*XX(247)-JVS(3213)*XX(248)-JVS(3453)*XX(250)-JVS(3547)*XX(252)-JVS(3726)*XX(255)-JVS(3808)&
              &*XX(256)-JVS(3856)*XX(257)-JVS(3907)*XX(258)
  XX(237) = XX(237)-JVS(2464)*XX(239)-JVS(2548)*XX(240)-JVS(2584)*XX(241)-JVS(2684)*XX(242)-JVS(2744)*XX(243)-JVS(2830)&
              &*XX(244)-JVS(2861)*XX(245)-JVS(2939)*XX(246)-JVS(3058)*XX(247)-JVS(3212)*XX(248)-JVS(3265)*XX(249)-JVS(3452)&
              &*XX(250)-JVS(3546)*XX(252)-JVS(3590)*XX(253)-JVS(3725)*XX(255)-JVS(3807)*XX(256)-JVS(3855)*XX(257)
  XX(236) = XX(236)-JVS(2371)*XX(237)-JVS(2388)*XX(238)-JVS(2463)*XX(239)-JVS(2547)*XX(240)-JVS(2583)*XX(241)-JVS(2683)&
              &*XX(242)-JVS(2743)*XX(243)-JVS(2829)*XX(244)-JVS(2860)*XX(245)-JVS(2938)*XX(246)-JVS(3057)*XX(247)-JVS(3211)&
              &*XX(248)-JVS(3264)*XX(249)-JVS(3451)*XX(250)-JVS(3545)*XX(252)-JVS(3632)*XX(254)-JVS(3724)*XX(255)-JVS(3806)&
              &*XX(256)-JVS(3854)*XX(257)-JVS(3906)*XX(258)
  XX(235) = XX(235)-JVS(2370)*XX(237)-JVS(2462)*XX(239)-JVS(2546)*XX(240)-JVS(2682)*XX(242)-JVS(2742)*XX(243)-JVS(2828)&
              &*XX(244)-JVS(2859)*XX(245)-JVS(2937)*XX(246)-JVS(3056)*XX(247)-JVS(3210)*XX(248)-JVS(3263)*XX(249)-JVS(3450)&
              &*XX(250)-JVS(3544)*XX(252)-JVS(3723)*XX(255)-JVS(3805)*XX(256)
  XX(234) = XX(234)-JVS(2322)*XX(235)-JVS(2369)*XX(237)-JVS(2461)*XX(239)-JVS(2545)*XX(240)-JVS(2582)*XX(241)-JVS(2681)&
              &*XX(242)-JVS(2741)*XX(243)-JVS(2827)*XX(244)-JVS(2858)*XX(245)-JVS(2936)*XX(246)-JVS(3055)*XX(247)-JVS(3209)&
              &*XX(248)-JVS(3262)*XX(249)-JVS(3449)*XX(250)-JVS(3543)*XX(252)-JVS(3589)*XX(253)-JVS(3722)*XX(255)-JVS(3804)&
              &*XX(256)-JVS(3853)*XX(257)
  XX(233) = XX(233)-JVS(2306)*XX(234)-JVS(2321)*XX(235)-JVS(2368)*XX(237)-JVS(2460)*XX(239)-JVS(2544)*XX(240)-JVS(2581)&
              &*XX(241)-JVS(2680)*XX(242)-JVS(2740)*XX(243)-JVS(2826)*XX(244)-JVS(2857)*XX(245)-JVS(2935)*XX(246)-JVS(3054)&
              &*XX(247)-JVS(3208)*XX(248)-JVS(3261)*XX(249)-JVS(3448)*XX(250)-JVS(3542)*XX(252)-JVS(3588)*XX(253)-JVS(3721)&
              &*XX(255)-JVS(3803)*XX(256)-JVS(3852)*XX(257)
  XX(232) = XX(232)-JVS(2459)*XX(239)-JVS(2580)*XX(241)-JVS(2679)*XX(242)-JVS(2739)*XX(243)-JVS(2825)*XX(244)-JVS(3053)&
              &*XX(247)-JVS(3207)*XX(248)-JVS(3447)*XX(250)-JVS(3541)*XX(252)-JVS(3587)*XX(253)-JVS(3720)*XX(255)-JVS(3802)&
              &*XX(256)
  XX(231) = XX(231)-JVS(2273)*XX(232)-JVS(2290)*XX(233)-JVS(2320)*XX(235)-JVS(2367)*XX(237)-JVS(2458)*XX(239)-JVS(2543)&
              &*XX(240)-JVS(2579)*XX(241)-JVS(2678)*XX(242)-JVS(2738)*XX(243)-JVS(2824)*XX(244)-JVS(2934)*XX(246)-JVS(3052)&
              &*XX(247)-JVS(3206)*XX(248)-JVS(3446)*XX(250)-JVS(3540)*XX(252)-JVS(3719)*XX(255)-JVS(3801)*XX(256)-JVS(3851)&
              &*XX(257)
  XX(230) = XX(230)-JVS(2457)*XX(239)-JVS(2542)*XX(240)-JVS(2677)*XX(242)-JVS(2737)*XX(243)-JVS(2823)*XX(244)-JVS(2933)&
              &*XX(246)-JVS(3051)*XX(247)-JVS(3205)*XX(248)-JVS(3445)*XX(250)-JVS(3539)*XX(252)-JVS(3718)*XX(255)-JVS(3800)&
              &*XX(256)
  XX(229) = XX(229)-JVS(2272)*XX(232)-JVS(2319)*XX(235)-JVS(2337)*XX(236)-JVS(2366)*XX(237)-JVS(2387)*XX(238)-JVS(2456)&
              &*XX(239)-JVS(2541)*XX(240)-JVS(2578)*XX(241)-JVS(2676)*XX(242)-JVS(2736)*XX(243)-JVS(2822)*XX(244)-JVS(2932)&
              &*XX(246)-JVS(3050)*XX(247)-JVS(3204)*XX(248)-JVS(3444)*XX(250)-JVS(3538)*XX(252)-JVS(3717)*XX(255)-JVS(3799)&
              &*XX(256)-JVS(3850)*XX(257)-JVS(3905)*XX(258)
  XX(228) = XX(228)-JVS(2455)*XX(239)-JVS(2540)*XX(240)-JVS(2675)*XX(242)-JVS(2735)*XX(243)-JVS(2931)*XX(246)-JVS(3049)&
              &*XX(247)-JVS(3203)*XX(248)-JVS(3443)*XX(250)-JVS(3537)*XX(252)-JVS(3716)*XX(255)-JVS(3798)*XX(256)
  XX(227) = XX(227)-JVS(2183)*XX(228)-JVS(2454)*XX(239)-JVS(2539)*XX(240)-JVS(2674)*XX(242)-JVS(2734)*XX(243)-JVS(2821)&
              &*XX(244)-JVS(2930)*XX(246)-JVS(3048)*XX(247)-JVS(3202)*XX(248)-JVS(3442)*XX(250)-JVS(3536)*XX(252)-JVS(3715)&
              &*XX(255)-JVS(3797)*XX(256)-JVS(3849)*XX(257)
  XX(226) = XX(226)-JVS(2129)*XX(227)-JVS(2182)*XX(228)-JVS(2233)*XX(230)-JVS(2386)*XX(238)-JVS(2453)*XX(239)-JVS(2538)&
              &*XX(240)-JVS(2673)*XX(242)-JVS(2733)*XX(243)-JVS(2820)*XX(244)-JVS(2929)*XX(246)-JVS(3047)*XX(247)-JVS(3201)&
              &*XX(248)-JVS(3441)*XX(250)-JVS(3535)*XX(252)-JVS(3714)*XX(255)-JVS(3796)*XX(256)-JVS(3848)*XX(257)
  XX(225) = XX(225)-JVS(2109)*XX(226)-JVS(2128)*XX(227)-JVS(2181)*XX(228)-JVS(2209)*XX(229)-JVS(2232)*XX(230)-JVS(2452)&
              &*XX(239)-JVS(2537)*XX(240)-JVS(2672)*XX(242)-JVS(2732)*XX(243)-JVS(2819)*XX(244)-JVS(2928)*XX(246)-JVS(3046)&
              &*XX(247)-JVS(3200)*XX(248)-JVS(3440)*XX(250)-JVS(3534)*XX(252)-JVS(3713)*XX(255)-JVS(3795)*XX(256)
  XX(224) = XX(224)-JVS(2085)*XX(225)-JVS(2108)*XX(226)-JVS(2127)*XX(227)-JVS(2180)*XX(228)-JVS(2208)*XX(229)-JVS(2231)&
              &*XX(230)-JVS(2451)*XX(239)-JVS(2536)*XX(240)-JVS(2671)*XX(242)-JVS(2731)*XX(243)-JVS(2818)*XX(244)-JVS(2927)&
              &*XX(246)-JVS(3045)*XX(247)-JVS(3199)*XX(248)-JVS(3439)*XX(250)-JVS(3533)*XX(252)-JVS(3712)*XX(255)-JVS(3794)&
              &*XX(256)
  XX(223) = XX(223)-JVS(2069)*XX(224)-JVS(2084)*XX(225)-JVS(2107)*XX(226)-JVS(2126)*XX(227)-JVS(2179)*XX(228)-JVS(2207)&
              &*XX(229)-JVS(2230)*XX(230)-JVS(2450)*XX(239)-JVS(2535)*XX(240)-JVS(2670)*XX(242)-JVS(2730)*XX(243)-JVS(2817)&
              &*XX(244)-JVS(2926)*XX(246)-JVS(3044)*XX(247)-JVS(3198)*XX(248)-JVS(3438)*XX(250)-JVS(3532)*XX(252)-JVS(3711)&
              &*XX(255)-JVS(3793)*XX(256)
  XX(222) = XX(222)-JVS(2055)*XX(223)-JVS(2106)*XX(226)-JVS(2125)*XX(227)-JVS(2178)*XX(228)-JVS(2206)*XX(229)-JVS(2229)&
              &*XX(230)-JVS(2449)*XX(239)-JVS(2534)*XX(240)-JVS(2669)*XX(242)-JVS(2729)*XX(243)-JVS(2816)*XX(244)-JVS(2925)&
              &*XX(246)-JVS(3043)*XX(247)-JVS(3197)*XX(248)-JVS(3437)*XX(250)-JVS(3531)*XX(252)-JVS(3710)*XX(255)-JVS(3792)&
              &*XX(256)
  XX(221) = XX(221)-JVS(2105)*XX(226)-JVS(2124)*XX(227)-JVS(2177)*XX(228)-JVS(2205)*XX(229)-JVS(2228)*XX(230)-JVS(2448)&
              &*XX(239)-JVS(2533)*XX(240)-JVS(2668)*XX(242)-JVS(2815)*XX(244)-JVS(2924)*XX(246)-JVS(3042)*XX(247)-JVS(3196)&
              &*XX(248)-JVS(3436)*XX(250)-JVS(3530)*XX(252)-JVS(3709)*XX(255)-JVS(3791)*XX(256)
  XX(220) = XX(220)-JVS(2029)*XX(221)-JVS(2123)*XX(227)-JVS(2176)*XX(228)-JVS(2227)*XX(230)-JVS(2447)*XX(239)-JVS(2532)&
              &*XX(240)-JVS(2667)*XX(242)-JVS(2814)*XX(244)-JVS(2923)*XX(246)-JVS(3041)*XX(247)-JVS(3195)*XX(248)-JVS(3435)&
              &*XX(250)-JVS(3529)*XX(252)-JVS(3708)*XX(255)-JVS(3790)*XX(256)
  XX(219) = XX(219)-JVS(2446)*XX(239)-JVS(2531)*XX(240)-JVS(2666)*XX(242)-JVS(2922)*XX(246)-JVS(3040)*XX(247)-JVS(3194)&
              &*XX(248)-JVS(3434)*XX(250)-JVS(3528)*XX(252)-JVS(3707)*XX(255)-JVS(3789)*XX(256)
  XX(218) = XX(218)-JVS(1975)*XX(219)-JVS(2122)*XX(227)-JVS(2175)*XX(228)-JVS(2226)*XX(230)-JVS(2445)*XX(239)-JVS(2530)&
              &*XX(240)-JVS(2665)*XX(242)-JVS(2813)*XX(244)-JVS(2921)*XX(246)-JVS(3039)*XX(247)-JVS(3193)*XX(248)-JVS(3433)&
              &*XX(250)-JVS(3527)*XX(252)-JVS(3706)*XX(255)-JVS(3788)*XX(256)
  XX(217) = XX(217)-JVS(2444)*XX(239)-JVS(2529)*XX(240)-JVS(2920)*XX(246)-JVS(3038)*XX(247)-JVS(3192)*XX(248)-JVS(3432)&
              &*XX(250)-JVS(3787)*XX(256)
  XX(216) = XX(216)-JVS(2528)*XX(240)-JVS(2664)*XX(242)-JVS(2919)*XX(246)-JVS(3037)*XX(247)-JVS(3191)*XX(248)-JVS(3431)&
              &*XX(250)-JVS(3526)*XX(252)-JVS(3705)*XX(255)-JVS(3786)*XX(256)
  XX(215) = XX(215)-JVS(2856)*XX(245)-JVS(2918)*XX(246)-JVS(3036)*XX(247)-JVS(3260)*XX(249)-JVS(3430)*XX(250)-JVS(3484)&
              &*XX(251)-JVS(3525)*XX(252)-JVS(3586)*XX(253)-JVS(3631)*XX(254)-JVS(3704)*XX(255)-JVS(3785)*XX(256)-JVS(3847)&
              &*XX(257)-JVS(3904)*XX(258)
  XX(214) = XX(214)-JVS(2365)*XX(237)-JVS(2443)*XX(239)-JVS(2663)*XX(242)-JVS(2728)*XX(243)-JVS(2812)*XX(244)-JVS(3035)&
              &*XX(247)-JVS(3190)*XX(248)-JVS(3429)*XX(250)-JVS(3524)*XX(252)-JVS(3703)*XX(255)-JVS(3784)*XX(256)
  XX(213) = XX(213)-JVS(1868)*XX(216)-JVS(1923)*XX(217)-JVS(1974)*XX(219)-JVS(2006)*XX(220)-JVS(2028)*XX(221)-JVS(2174)&
              &*XX(228)-JVS(2442)*XX(239)-JVS(2527)*XX(240)-JVS(2662)*XX(242)-JVS(2811)*XX(244)-JVS(2917)*XX(246)-JVS(3034)&
              &*XX(247)-JVS(3189)*XX(248)-JVS(3428)*XX(250)-JVS(3783)*XX(256)
  XX(212) = XX(212)-JVS(2916)*XX(246)-JVS(3033)*XX(247)-JVS(3427)*XX(250)-JVS(3782)*XX(256)
  XX(211) = XX(211)-JVS(1764)*XX(212)-JVS(2173)*XX(228)-JVS(2225)*XX(230)-JVS(2257)*XX(231)-JVS(2305)*XX(234)-JVS(2364)&
              &*XX(237)-JVS(2441)*XX(239)-JVS(2526)*XX(240)-JVS(2661)*XX(242)-JVS(2727)*XX(243)-JVS(2810)*XX(244)-JVS(2855)&
              &*XX(245)-JVS(2915)*XX(246)-JVS(3032)*XX(247)-JVS(3188)*XX(248)-JVS(3259)*XX(249)-JVS(3426)*XX(250)-JVS(3523)&
              &*XX(252)-JVS(3702)*XX(255)-JVS(3781)*XX(256)-JVS(3846)*XX(257)
  XX(210) = XX(210)-JVS(2385)*XX(238)-JVS(2525)*XX(240)-JVS(2577)*XX(241)-JVS(2660)*XX(242)-JVS(2726)*XX(243)-JVS(2809)&
              &*XX(244)-JVS(2914)*XX(246)-JVS(3031)*XX(247)-JVS(3187)*XX(248)-JVS(3425)*XX(250)-JVS(3522)*XX(252)-JVS(3701)&
              &*XX(255)-JVS(3780)*XX(256)-JVS(3903)*XX(258)
  XX(209) = XX(209)-JVS(2854)*XX(245)-JVS(3258)*XX(249)-JVS(3424)*XX(250)-JVS(3521)*XX(252)-JVS(3585)*XX(253)-JVS(3630)&
              &*XX(254)-JVS(3700)*XX(255)-JVS(3779)*XX(256)-JVS(3902)*XX(258)
  XX(208) = XX(208)-JVS(1922)*XX(217)-JVS(2172)*XX(228)-JVS(2224)*XX(230)-JVS(2440)*XX(239)-JVS(2524)*XX(240)-JVS(2659)&
              &*XX(242)-JVS(3186)*XX(248)-JVS(3423)*XX(250)-JVS(3778)*XX(256)
  XX(207) = XX(207)-JVS(1763)*XX(212)-JVS(1867)*XX(216)-JVS(1921)*XX(217)-JVS(2439)*XX(239)-JVS(2523)*XX(240)-JVS(2658)&
              &*XX(242)-JVS(2913)*XX(246)-JVS(3185)*XX(248)-JVS(3422)*XX(250)
  XX(206) = XX(206)-JVS(1631)*XX(207)-JVS(1665)*XX(208)-JVS(1762)*XX(212)-JVS(1866)*XX(216)-JVS(1920)*XX(217)-JVS(2171)&
              &*XX(228)-JVS(2438)*XX(239)-JVS(2522)*XX(240)-JVS(2657)*XX(242)-JVS(2808)*XX(244)-JVS(2912)*XX(246)-JVS(3030)&
              &*XX(247)-JVS(3184)*XX(248)-JVS(3421)*XX(250)
  XX(205) = XX(205)-JVS(1605)*XX(206)-JVS(1630)*XX(207)-JVS(1664)*XX(208)-JVS(1761)*XX(212)-JVS(1865)*XX(216)-JVS(1919)&
              &*XX(217)-JVS(2170)*XX(228)-JVS(2437)*XX(239)-JVS(2521)*XX(240)-JVS(2656)*XX(242)-JVS(2807)*XX(244)-JVS(2911)&
              &*XX(246)-JVS(3029)*XX(247)-JVS(3183)*XX(248)-JVS(3420)*XX(250)
  XX(204) = XX(204)-JVS(1918)*XX(217)-JVS(2223)*XX(230)-JVS(2256)*XX(231)-JVS(2289)*XX(233)-JVS(2363)*XX(237)-JVS(2436)&
              &*XX(239)-JVS(2576)*XX(241)-JVS(2655)*XX(242)-JVS(2725)*XX(243)-JVS(2806)*XX(244)-JVS(3028)*XX(247)-JVS(3182)&
              &*XX(248)-JVS(3419)*XX(250)-JVS(3520)*XX(252)-JVS(3699)*XX(255)-JVS(3777)*XX(256)
  XX(203) = XX(203)-JVS(1760)*XX(212)-JVS(2104)*XX(226)-JVS(2169)*XX(228)-JVS(2255)*XX(231)-JVS(2304)*XX(234)-JVS(2336)&
              &*XX(236)-JVS(2362)*XX(237)-JVS(2435)*XX(239)-JVS(2654)*XX(242)-JVS(2724)*XX(243)-JVS(2805)*XX(244)-JVS(2910)&
              &*XX(246)-JVS(3027)*XX(247)-JVS(3181)*XX(248)-JVS(3418)*XX(250)-JVS(3519)*XX(252)-JVS(3698)*XX(255)-JVS(3845)&
              &*XX(257)
  XX(202) = XX(202)-JVS(1759)*XX(212)-JVS(1836)*XX(215)-JVS(2853)*XX(245)-JVS(3257)*XX(249)-JVS(3417)*XX(250)-JVS(3483)&
              &*XX(251)-JVS(3518)*XX(252)-JVS(3697)*XX(255)-JVS(3776)*XX(256)-JVS(3844)*XX(257)-JVS(3901)*XX(258)
  XX(201) = XX(201)-JVS(1629)*XX(207)-JVS(1663)*XX(208)-JVS(1758)*XX(212)-JVS(1864)*XX(216)-JVS(1917)*XX(217)-JVS(1973)&
              &*XX(219)-JVS(2042)*XX(222)-JVS(2054)*XX(223)-JVS(2068)*XX(224)-JVS(2083)*XX(225)-JVS(2103)*XX(226)-JVS(2121)&
              &*XX(227)-JVS(2168)*XX(228)-JVS(2204)*XX(229)-JVS(2222)*XX(230)-JVS(2384)*XX(238)-JVS(2434)*XX(239)-JVS(2520)&
              &*XX(240)-JVS(2653)*XX(242)-JVS(2723)*XX(243)-JVS(2804)*XX(244)-JVS(2909)*XX(246)-JVS(3026)*XX(247)-JVS(3180)&
              &*XX(248)-JVS(3416)*XX(250)-JVS(3517)*XX(252)-JVS(3696)*XX(255)-JVS(3775)*XX(256)-JVS(3843)*XX(257)-JVS(3900)&
              &*XX(258)
  XX(200) = XX(200)-JVS(1818)*XX(214)-JVS(2271)*XX(232)-JVS(2318)*XX(235)-JVS(2433)*XX(239)-JVS(2575)*XX(241)-JVS(2652)&
              &*XX(242)-JVS(2722)*XX(243)-JVS(2803)*XX(244)-JVS(3025)*XX(247)-JVS(3179)*XX(248)-JVS(3415)*XX(250)-JVS(3842)&
              &*XX(257)
  XX(199) = XX(199)-JVS(1584)*XX(205)-JVS(1604)*XX(206)-JVS(1628)*XX(207)-JVS(1662)*XX(208)-JVS(1757)*XX(212)-JVS(1863)&
              &*XX(216)-JVS(1916)*XX(217)-JVS(1952)*XX(218)-JVS(2005)*XX(220)-JVS(2027)*XX(221)-JVS(2167)*XX(228)-JVS(2432)&
              &*XX(239)-JVS(2519)*XX(240)-JVS(2651)*XX(242)-JVS(2802)*XX(244)-JVS(2908)*XX(246)-JVS(3024)*XX(247)-JVS(3178)&
              &*XX(248)-JVS(3414)*XX(250)
  XX(198) = XX(198)-JVS(1627)*XX(207)-JVS(1661)*XX(208)-JVS(1756)*XX(212)-JVS(1862)*XX(216)-JVS(1915)*XX(217)-JVS(1972)&
              &*XX(219)-JVS(2004)*XX(220)-JVS(2026)*XX(221)-JVS(2166)*XX(228)-JVS(2221)*XX(230)-JVS(2431)*XX(239)-JVS(2518)&
              &*XX(240)-JVS(2650)*XX(242)-JVS(2801)*XX(244)-JVS(2907)*XX(246)-JVS(3023)*XX(247)-JVS(3177)*XX(248)-JVS(3413)&
              &*XX(250)-JVS(3774)*XX(256)
  XX(197) = XX(197)-JVS(1687)*XX(209)-JVS(1755)*XX(212)-JVS(2800)*XX(244)-JVS(2906)*XX(246)-JVS(3022)*XX(247)-JVS(3176)&
              &*XX(248)-JVS(3256)*XX(249)-JVS(3412)*XX(250)-JVS(3482)*XX(251)-JVS(3584)*XX(253)-JVS(3695)*XX(255)-JVS(3773)&
              &*XX(256)-JVS(3841)*XX(257)-JVS(3899)*XX(258)
  XX(196) = XX(196)-JVS(2649)*XX(242)-JVS(3175)*XX(248)-JVS(3411)*XX(250)-JVS(3516)*XX(252)-JVS(3694)*XX(255)
  XX(195) = XX(195)-JVS(1465)*XX(196)-JVS(2270)*XX(232)-JVS(2430)*XX(239)-JVS(2574)*XX(241)-JVS(2648)*XX(242)-JVS(2721)&
              &*XX(243)-JVS(2799)*XX(244)-JVS(3021)*XX(247)-JVS(3174)*XX(248)-JVS(3410)*XX(250)-JVS(3515)*XX(252)-JVS(3583)&
              &*XX(253)-JVS(3693)*XX(255)-JVS(3772)*XX(256)
  XX(194) = XX(194)-JVS(1464)*XX(196)-JVS(1754)*XX(212)-JVS(2165)*XX(228)-JVS(2254)*XX(231)-JVS(2361)*XX(237)-JVS(2429)&
              &*XX(239)-JVS(2647)*XX(242)-JVS(2720)*XX(243)-JVS(2798)*XX(244)-JVS(2905)*XX(246)-JVS(3020)*XX(247)-JVS(3173)&
              &*XX(248)-JVS(3409)*XX(250)-JVS(3840)*XX(257)
  XX(193) = XX(193)-JVS(1442)*XX(194)-JVS(1753)*XX(212)-JVS(2164)*XX(228)-JVS(2253)*XX(231)-JVS(2360)*XX(237)-JVS(2428)&
              &*XX(239)-JVS(2646)*XX(242)-JVS(2719)*XX(243)-JVS(2797)*XX(244)-JVS(2904)*XX(246)-JVS(3019)*XX(247)-JVS(3172)&
              &*XX(248)-JVS(3408)*XX(250)-JVS(3839)*XX(257)
  XX(192) = XX(192)-JVS(2220)*XX(230)-JVS(2427)*XX(239)-JVS(2517)*XX(240)-JVS(2718)*XX(243)-JVS(2852)*XX(245)-JVS(3255)&
              &*XX(249)-JVS(3407)*XX(250)-JVS(3514)*XX(252)-JVS(3692)*XX(255)-JVS(3771)*XX(256)
  XX(191) = XX(191)-JVS(1626)*XX(207)-JVS(1660)*XX(208)-JVS(1752)*XX(212)-JVS(1861)*XX(216)-JVS(1914)*XX(217)-JVS(2516)&
              &*XX(240)-JVS(3018)*XX(247)-JVS(3171)*XX(248)-JVS(3406)*XX(250)
  XX(190) = XX(190)-JVS(1399)*XX(191)-JVS(1583)*XX(205)-JVS(1603)*XX(206)-JVS(1625)*XX(207)-JVS(1659)*XX(208)-JVS(1751)&
              &*XX(212)-JVS(1860)*XX(216)-JVS(1913)*XX(217)-JVS(1951)*XX(218)-JVS(1971)*XX(219)-JVS(2003)*XX(220)-JVS(2025)&
              &*XX(221)-JVS(2163)*XX(228)-JVS(2426)*XX(239)-JVS(2515)*XX(240)-JVS(2645)*XX(242)-JVS(2796)*XX(244)-JVS(2903)&
              &*XX(246)-JVS(3017)*XX(247)-JVS(3170)*XX(248)-JVS(3405)*XX(250)
  XX(189) = XX(189)-JVS(1750)*XX(212)-JVS(2514)*XX(240)-JVS(2644)*XX(242)-JVS(2902)*XX(246)-JVS(3169)*XX(248)-JVS(3404)&
              &*XX(250)
  XX(188) = XX(188)-JVS(1495)*XX(197)-JVS(1749)*XX(212)-JVS(2795)*XX(244)-JVS(2901)*XX(246)-JVS(3016)*XX(247)-JVS(3168)&
              &*XX(248)-JVS(3254)*XX(249)-JVS(3403)*XX(250)-JVS(3481)*XX(251)-JVS(3691)*XX(255)-JVS(3770)*XX(256)-JVS(3838)&
              &*XX(257)
  XX(187) = XX(187)-JVS(2717)*XX(243)-JVS(3402)*XX(250)-JVS(3513)*XX(252)-JVS(3690)*XX(255)-JVS(3769)*XX(256)
  XX(186) = XX(186)-JVS(3167)*XX(248)-JVS(3401)*XX(250)-JVS(3512)*XX(252)-JVS(3689)*XX(255)-JVS(3768)*XX(256)
  XX(185) = XX(185)-JVS(1307)*XX(187)-JVS(1463)*XX(196)-JVS(2162)*XX(228)-JVS(2359)*XX(237)-JVS(2425)*XX(239)-JVS(2573)&
              &*XX(241)-JVS(2643)*XX(242)-JVS(2716)*XX(243)-JVS(2794)*XX(244)-JVS(3015)*XX(247)-JVS(3166)*XX(248)-JVS(3400)&
              &*XX(250)
  XX(184) = XX(184)-JVS(1748)*XX(212)-JVS(2424)*XX(239)-JVS(2513)*XX(240)-JVS(2642)*XX(242)-JVS(2900)*XX(246)-JVS(3014)&
              &*XX(247)-JVS(3165)*XX(248)-JVS(3399)*XX(250)
  XX(183) = XX(183)-JVS(1283)*XX(186)-JVS(1912)*XX(217)-JVS(2161)*XX(228)-JVS(2423)*XX(239)-JVS(2512)*XX(240)-JVS(2641)&
              &*XX(242)-JVS(2715)*XX(243)-JVS(2793)*XX(244)-JVS(2899)*XX(246)-JVS(3013)*XX(247)-JVS(3164)*XX(248)-JVS(3398)&
              &*XX(250)-JVS(3837)*XX(257)
  XX(182) = XX(182)-JVS(1367)*XX(189)-JVS(1658)*XX(208)-JVS(1859)*XX(216)-JVS(1911)*XX(217)-JVS(2160)*XX(228)-JVS(2422)&
              &*XX(239)-JVS(2511)*XX(240)-JVS(2640)*XX(242)-JVS(3163)*XX(248)-JVS(3397)*XX(250)
  XX(181) = XX(181)-JVS(1657)*XX(208)-JVS(1747)*XX(212)-JVS(1910)*XX(217)-JVS(2120)*XX(227)-JVS(2159)*XX(228)-JVS(2510)&
              &*XX(240)-JVS(2639)*XX(242)-JVS(2792)*XX(244)-JVS(3012)*XX(247)-JVS(3162)*XX(248)-JVS(3396)*XX(250)
  XX(180) = XX(180)-JVS(1624)*XX(207)-JVS(1858)*XX(216)-JVS(1909)*XX(217)-JVS(1970)*XX(219)-JVS(2421)*XX(239)-JVS(2509)&
              &*XX(240)-JVS(2638)*XX(242)-JVS(2791)*XX(244)-JVS(3011)*XX(247)-JVS(3161)*XX(248)-JVS(3395)*XX(250)
  XX(179) = XX(179)-JVS(1306)*XX(187)-JVS(1462)*XX(196)-JVS(1908)*XX(217)-JVS(2358)*XX(237)-JVS(2420)*XX(239)-JVS(2572)&
              &*XX(241)-JVS(2637)*XX(242)-JVS(2714)*XX(243)-JVS(2790)*XX(244)-JVS(3010)*XX(247)-JVS(3160)*XX(248)-JVS(3394)&
              &*XX(250)
  XX(178) = XX(178)-JVS(1305)*XX(187)-JVS(1461)*XX(196)-JVS(2288)*XX(233)-JVS(2303)*XX(234)-JVS(2357)*XX(237)-JVS(2419)&
              &*XX(239)-JVS(2571)*XX(241)-JVS(2636)*XX(242)-JVS(2713)*XX(243)-JVS(2789)*XX(244)-JVS(3009)*XX(247)-JVS(3159)&
              &*XX(248)-JVS(3393)*XX(250)
  XX(177) = XX(177)-JVS(1746)*XX(212)-JVS(2158)*XX(228)-JVS(2356)*XX(237)-JVS(2898)*XX(246)-JVS(3008)*XX(247)-JVS(3392)&
              &*XX(250)-JVS(3836)*XX(257)
  XX(176) = XX(176)-JVS(1745)*XX(212)-JVS(2119)*XX(227)-JVS(2157)*XX(228)-JVS(2508)*XX(240)-JVS(3007)*XX(247)-JVS(3158)&
              &*XX(248)-JVS(3391)*XX(250)
  XX(175) = XX(175)-JVS(1907)*XX(217)-JVS(2418)*XX(239)-JVS(2635)*XX(242)-JVS(3006)*XX(247)-JVS(3390)*XX(250)
  XX(174) = XX(174)-JVS(1906)*XX(217)-JVS(2219)*XX(230)-JVS(2417)*XX(239)-JVS(2634)*XX(242)-JVS(3389)*XX(250)-JVS(3767)&
              &*XX(256)
  XX(173) = XX(173)-JVS(1227)*XX(182)-JVS(1398)*XX(191)-JVS(2156)*XX(228)-JVS(2416)*XX(239)-JVS(2507)*XX(240)-JVS(2633)&
              &*XX(242)-JVS(2788)*XX(244)-JVS(3005)*XX(247)-JVS(3157)*XX(248)-JVS(3388)*XX(250)
  XX(172) = XX(172)-JVS(3156)*XX(248)-JVS(3387)*XX(250)-JVS(3511)*XX(252)-JVS(3688)*XX(255)-JVS(3766)*XX(256)-JVS(3898)&
              &*XX(258)
  XX(171) = XX(171)-JVS(1582)*XX(205)-JVS(1602)*XX(206)-JVS(1623)*XX(207)-JVS(1656)*XX(208)-JVS(1905)*XX(217)-JVS(2506)&
              &*XX(240)-JVS(3155)*XX(248)-JVS(3386)*XX(250)
  XX(170) = XX(170)-JVS(1160)*XX(176)-JVS(1213)*XX(181)-JVS(1282)*XX(186)-JVS(1366)*XX(189)-JVS(1655)*XX(208)-JVS(1904)&
              &*XX(217)-JVS(2102)*XX(226)-JVS(2155)*XX(228)-JVS(2415)*XX(239)-JVS(2505)*XX(240)-JVS(2632)*XX(242)-JVS(2787)&
              &*XX(244)-JVS(3004)*XX(247)-JVS(3154)*XX(248)-JVS(3385)*XX(250)
  XX(169) = XX(169)-JVS(1226)*XX(182)-JVS(1365)*XX(189)-JVS(1622)*XX(207)-JVS(1654)*XX(208)-JVS(1857)*XX(216)-JVS(1903)&
              &*XX(217)-JVS(2002)*XX(220)-JVS(2154)*XX(228)-JVS(2786)*XX(244)-JVS(3003)*XX(247)-JVS(3153)*XX(248)-JVS(3384)&
              &*XX(250)
  XX(168) = XX(168)-JVS(1202)*XX(180)-JVS(1281)*XX(186)-JVS(1364)*XX(189)-JVS(1621)*XX(207)-JVS(1902)*XX(217)-JVS(1969)&
              &*XX(219)-JVS(2153)*XX(228)-JVS(2203)*XX(229)-JVS(2414)*XX(239)-JVS(2504)*XX(240)-JVS(2631)*XX(242)-JVS(2785)&
              &*XX(244)-JVS(3002)*XX(247)-JVS(3152)*XX(248)-JVS(3383)*XX(250)
  XX(167) = XX(167)-JVS(1122)*XX(174)-JVS(1141)*XX(175)-JVS(1251)*XX(184)-JVS(1363)*XX(189)-JVS(1397)*XX(191)-JVS(1744)&
              &*XX(212)-JVS(1968)*XX(219)-JVS(2001)*XX(220)-JVS(2024)*XX(221)-JVS(2503)*XX(240)-JVS(2630)*XX(242)-JVS(2784)&
              &*XX(244)-JVS(3001)*XX(247)-JVS(3151)*XX(248)-JVS(3382)*XX(250)
  XX(166) = XX(166)-JVS(2629)*XX(242)-JVS(2712)*XX(243)-JVS(3150)*XX(248)-JVS(3381)*XX(250)-JVS(3510)*XX(252)-JVS(3629)&
              &*XX(254)-JVS(3687)*XX(255)-JVS(3765)*XX(256)-JVS(3835)*XX(257)-JVS(3897)*XX(258)
  XX(165) = XX(165)-JVS(1362)*XX(189)-JVS(1901)*XX(217)-JVS(2413)*XX(239)-JVS(2502)*XX(240)-JVS(3149)*XX(248)
  XX(164) = XX(164)-JVS(1121)*XX(174)-JVS(1225)*XX(182)-JVS(1361)*XX(189)-JVS(1620)*XX(207)-JVS(1653)*XX(208)-JVS(1856)&
              &*XX(216)-JVS(1900)*XX(217)-JVS(2000)*XX(220)-JVS(2152)*XX(228)-JVS(2628)*XX(242)-JVS(2783)*XX(244)-JVS(3000)&
              &*XX(247)-JVS(3148)*XX(248)-JVS(3380)*XX(250)
  XX(163) = XX(163)-JVS(1224)*XX(182)-JVS(1360)*XX(189)-JVS(1619)*XX(207)-JVS(1652)*XX(208)-JVS(1855)*XX(216)-JVS(1899)&
              &*XX(217)-JVS(1999)*XX(220)-JVS(2151)*XX(228)-JVS(2501)*XX(240)-JVS(2627)*XX(242)-JVS(2782)*XX(244)-JVS(2999)&
              &*XX(247)-JVS(3147)*XX(248)-JVS(3379)*XX(250)
  XX(162) = XX(162)-JVS(1505)*XX(198)-JVS(1743)*XX(212)-JVS(1804)*XX(213)-JVS(1998)*XX(220)-JVS(2041)*XX(222)-JVS(2101)&
              &*XX(226)-JVS(2202)*XX(229)-JVS(2626)*XX(242)-JVS(2998)*XX(247)-JVS(3146)*XX(248)-JVS(3378)*XX(250)
  XX(161) = XX(161)-JVS(1686)*XX(209)-JVS(3377)*XX(250)-JVS(3582)*XX(253)-JVS(3628)*XX(254)-JVS(3686)*XX(255)-JVS(3896)&
              &*XX(258)
  XX(160) = XX(160)-JVS(1342)*XX(188)-JVS(1494)*XX(197)-JVS(1742)*XX(212)-JVS(2897)*XX(246)-JVS(2997)*XX(247)-JVS(3253)&
              &*XX(249)-JVS(3376)*XX(250)-JVS(3685)*XX(255)-JVS(3764)*XX(256)
  XX(159) = XX(159)-JVS(1741)*XX(212)-JVS(2150)*XX(228)-JVS(2252)*XX(231)-JVS(2896)*XX(246)-JVS(2996)*XX(247)-JVS(3375)&
              &*XX(250)
  XX(158) = XX(158)-JVS(1541)*XX(202)-JVS(1740)*XX(212)-JVS(2895)*XX(246)-JVS(2995)*XX(247)-JVS(3252)*XX(249)-JVS(3374)&
              &*XX(250)-JVS(3480)*XX(251)-JVS(3509)*XX(252)-JVS(3684)*XX(255)-JVS(3763)*XX(256)
  XX(157) = XX(157)-JVS(3145)*XX(248)-JVS(3373)*XX(250)-JVS(3762)*XX(256)-JVS(3834)*XX(257)-JVS(3895)*XX(258)
  XX(156) = XX(156)-JVS(1140)*XX(175)-JVS(1739)*XX(212)-JVS(2500)*XX(240)-JVS(3144)*XX(248)-JVS(3372)*XX(250)
  XX(155) = XX(155)-JVS(1898)*XX(217)-JVS(2149)*XX(228)-JVS(2499)*XX(240)-JVS(2625)*XX(242)
  XX(154) = XX(154)-JVS(1095)*XX(172)-JVS(1280)*XX(186)-JVS(1429)*XX(193)-JVS(1441)*XX(194)-JVS(1554)*XX(203)-JVS(1565)&
              &*XX(204)-JVS(2100)*XX(226)-JVS(2269)*XX(232)-JVS(2335)*XX(236)-JVS(2498)*XX(240)-JVS(2624)*XX(242)-JVS(2894)&
              &*XX(246)-JVS(3143)*XX(248)-JVS(3371)*XX(250)-JVS(3833)*XX(257)
  XX(153) = XX(153)-JVS(1359)*XX(189)-JVS(2497)*XX(240)-JVS(2623)*XX(242)-JVS(3142)*XX(248)-JVS(3370)*XX(250)
  XX(152) = XX(152)-JVS(912)*XX(153)-JVS(938)*XX(155)-JVS(1019)*XX(163)-JVS(1062)*XX(168)-JVS(1083)*XX(171)-JVS(1111)&
              &*XX(173)-JVS(1618)*XX(207)-JVS(1897)*XX(217)-JVS(2082)*XX(225)-JVS(2201)*XX(229)-JVS(2412)*XX(239)-JVS(2496)&
              &*XX(240)-JVS(2622)*XX(242)-JVS(3141)*XX(248)-JVS(3369)*XX(250)
  XX(151) = XX(151)-JVS(2411)*XX(239)-JVS(2495)*XX(240)-JVS(2621)*XX(242)-JVS(3140)*XX(248)-JVS(3368)*XX(250)
  XX(150) = XX(150)-JVS(1250)*XX(184)-JVS(1396)*XX(191)-JVS(1967)*XX(219)-JVS(1997)*XX(220)-JVS(2023)*XX(221)-JVS(2148)&
              &*XX(228)-JVS(2620)*XX(242)-JVS(2781)*XX(244)-JVS(2994)*XX(247)-JVS(3139)*XX(248)-JVS(3367)*XX(250)
  XX(149) = XX(149)-JVS(952)*XX(156)-JVS(1139)*XX(175)-JVS(1395)*XX(191)-JVS(1854)*XX(216)-JVS(1996)*XX(220)-JVS(2022)&
              &*XX(221)-JVS(2619)*XX(242)-JVS(2780)*XX(244)-JVS(2993)*XX(247)-JVS(3138)*XX(248)-JVS(3366)*XX(250)
  XX(148) = XX(148)-JVS(1159)*XX(176)-JVS(1394)*XX(191)-JVS(1853)*XX(216)-JVS(1995)*XX(220)-JVS(2021)*XX(221)-JVS(2147)&
              &*XX(228)-JVS(2618)*XX(242)-JVS(2779)*XX(244)-JVS(2992)*XX(247)-JVS(3137)*XX(248)-JVS(3365)*XX(250)
  XX(147) = XX(147)-JVS(937)*XX(155)-JVS(1026)*XX(164)-JVS(1076)*XX(170)-JVS(1082)*XX(171)-JVS(1110)*XX(173)-JVS(1120)&
              &*XX(174)-JVS(1651)*XX(208)-JVS(1896)*XX(217)-JVS(2067)*XX(224)-JVS(2099)*XX(226)-JVS(2494)*XX(240)-JVS(2617)&
              &*XX(242)-JVS(3136)*XX(248)-JVS(3364)*XX(250)
  XX(146) = XX(146)-JVS(993)*XX(160)-JVS(1341)*XX(188)-JVS(1493)*XX(197)-JVS(1738)*XX(212)-JVS(2893)*XX(246)-JVS(2991)&
              &*XX(247)-JVS(3251)*XX(249)-JVS(3683)*XX(255)
  XX(145) = XX(145)-JVS(1358)*XX(189)-JVS(1617)*XX(207)-JVS(1650)*XX(208)-JVS(1852)*XX(216)-JVS(1895)*XX(217)-JVS(2146)&
              &*XX(228)-JVS(3135)*XX(248)-JVS(3363)*XX(250)
  XX(144) = XX(144)-JVS(1035)*XX(165)-JVS(1279)*XX(186)-JVS(1357)*XX(189)-JVS(1894)*XX(217)-JVS(2410)*XX(239)-JVS(2493)&
              &*XX(240)-JVS(3134)*XX(248)-JVS(3362)*XX(250)
  XX(143) = XX(143)-JVS(936)*XX(155)-JVS(1025)*XX(164)-JVS(1069)*XX(169)-JVS(1109)*XX(173)-JVS(1581)*XX(205)-JVS(1601)&
              &*XX(206)-JVS(1649)*XX(208)-JVS(2066)*XX(224)-JVS(2098)*XX(226)-JVS(2492)*XX(240)-JVS(2616)*XX(242)-JVS(3133)&
              &*XX(248)-JVS(3361)*XX(250)
  XX(142) = XX(142)-JVS(1451)*XX(195)-JVS(1737)*XX(212)-JVS(2851)*XX(245)-JVS(2892)*XX(246)-JVS(3250)*XX(249)-JVS(3360)&
              &*XX(250)-JVS(3508)*XX(252)-JVS(3682)*XX(255)-JVS(3761)*XX(256)
  XX(141) = XX(141)-JVS(2355)*XX(237)-JVS(3132)*XX(248)-JVS(3359)*XX(250)
  XX(140) = XX(140)-JVS(935)*XX(155)-JVS(1018)*XX(163)-JVS(1068)*XX(169)-JVS(1580)*XX(205)-JVS(1600)*XX(206)-JVS(1616)&
              &*XX(207)-JVS(2081)*XX(225)-JVS(2200)*XX(229)-JVS(2491)*XX(240)-JVS(2615)*XX(242)-JVS(3131)*XX(248)-JVS(3358)&
              &*XX(250)
  XX(139) = XX(139)-JVS(1356)*XX(189)-JVS(1893)*XX(217)-JVS(2409)*XX(239)-JVS(2490)*XX(240)-JVS(3130)*XX(248)-JVS(3357)&
              &*XX(250)
  XX(138) = XX(138)-JVS(1094)*XX(172)-JVS(1428)*XX(193)-JVS(1440)*XX(194)-JVS(1564)*XX(204)-JVS(1717)*XX(211)-JVS(2251)&
              &*XX(231)-JVS(2354)*XX(237)-JVS(2489)*XX(240)-JVS(2891)*XX(246)-JVS(3129)*XX(248)-JVS(3356)*XX(250)-JVS(3832)&
              &*XX(257)
  XX(137) = XX(137)-JVS(1093)*XX(172)-JVS(1427)*XX(193)-JVS(1439)*XX(194)-JVS(1563)*XX(204)-JVS(1716)*XX(211)-JVS(2250)&
              &*XX(231)-JVS(2353)*XX(237)-JVS(2488)*XX(240)-JVS(2890)*XX(246)-JVS(3128)*XX(248)-JVS(3355)*XX(250)-JVS(3831)&
              &*XX(257)
  XX(136) = XX(136)-JVS(1239)*XX(183)-JVS(1278)*XX(186)-JVS(1892)*XX(217)-JVS(2145)*XX(228)-JVS(2408)*XX(239)-JVS(2487)&
              &*XX(240)-JVS(2889)*XX(246)-JVS(2990)*XX(247)-JVS(3354)*XX(250)
  XX(135) = XX(135)-JVS(1393)*XX(191)-JVS(1966)*XX(219)-JVS(1994)*XX(220)-JVS(2020)*XX(221)-JVS(2614)*XX(242)-JVS(2778)&
              &*XX(244)-JVS(2989)*XX(247)-JVS(3127)*XX(248)-JVS(3353)*XX(250)
  XX(134) = XX(134)-JVS(934)*XX(155)-JVS(1056)*XX(167)-JVS(1736)*XX(212)-JVS(1803)*XX(213)-JVS(1950)*XX(218)-JVS(1993)&
              &*XX(220)-JVS(2053)*XX(223)-JVS(2065)*XX(224)-JVS(2080)*XX(225)-JVS(2988)*XX(247)-JVS(3126)*XX(248)-JVS(3352)&
              &*XX(250)
  XX(133) = XX(133)-JVS(1138)*XX(175)-JVS(1249)*XX(184)-JVS(2486)*XX(240)-JVS(2777)*XX(244)-JVS(2987)*XX(247)-JVS(3125)&
              &*XX(248)-JVS(3351)*XX(250)
  XX(132) = XX(132)-JVS(1137)*XX(175)-JVS(1248)*XX(184)-JVS(1851)*XX(216)-JVS(2019)*XX(221)-JVS(2776)*XX(244)-JVS(2986)&
              &*XX(247)-JVS(3124)*XX(248)-JVS(3350)*XX(250)
  XX(131) = XX(131)-JVS(1685)*XX(209)-JVS(1735)*XX(212)-JVS(2888)*XX(246)-JVS(2985)*XX(247)-JVS(3349)*XX(250)-JVS(3507)&
              &*XX(252)-JVS(3681)*XX(255)-JVS(3760)*XX(256)
  XX(130) = XX(130)-JVS(863)*XX(145)-JVS(1223)*XX(182)-JVS(1850)*XX(216)-JVS(2144)*XX(228)-JVS(3123)*XX(248)-JVS(3348)&
              &*XX(250)
  XX(129) = XX(129)-JVS(1158)*XX(176)-JVS(1212)*XX(181)-JVS(2775)*XX(244)-JVS(2984)*XX(247)-JVS(3122)*XX(248)-JVS(3347)&
              &*XX(250)
  XX(128) = XX(128)-JVS(1201)*XX(180)-JVS(1965)*XX(219)-JVS(2774)*XX(244)-JVS(2983)*XX(247)-JVS(3121)*XX(248)-JVS(3346)&
              &*XX(250)
  XX(127) = XX(127)-JVS(880)*XX(148)-JVS(933)*XX(155)-JVS(1579)*XX(205)-JVS(1599)*XX(206)-JVS(1734)*XX(212)-JVS(2199)&
              &*XX(229)-JVS(2613)*XX(242)-JVS(2982)*XX(247)-JVS(3120)*XX(248)-JVS(3345)*XX(250)
  XX(126) = XX(126)-JVS(1704)*XX(210)-JVS(2383)*XX(238)-JVS(2570)*XX(241)-JVS(2612)*XX(242)-JVS(3119)*XX(248)-JVS(3344)&
              &*XX(250)
  XX(125) = XX(125)-JVS(803)*XX(135)-JVS(932)*XX(155)-JVS(1578)*XX(205)-JVS(1598)*XX(206)-JVS(1733)*XX(212)-JVS(2097)&
              &*XX(226)-JVS(2611)*XX(242)-JVS(2981)*XX(247)-JVS(3118)*XX(248)-JVS(3343)*XX(250)
  XX(124) = XX(124)-JVS(1540)*XX(202)-JVS(1732)*XX(212)-JVS(1835)*XX(215)-JVS(3249)*XX(249)-JVS(3342)*XX(250)-JVS(3680)&
              &*XX(255)-JVS(3830)*XX(257)
  XX(123) = XX(123)-JVS(2610)*XX(242)-JVS(2711)*XX(243)-JVS(3117)*XX(248)-JVS(3341)*XX(250)-JVS(3506)*XX(252)-JVS(3679)&
              &*XX(255)-JVS(3759)*XX(256)
  XX(122) = XX(122)-JVS(1539)*XX(202)-JVS(1731)*XX(212)-JVS(1834)*XX(215)-JVS(3248)*XX(249)-JVS(3340)*XX(250)-JVS(3678)&
              &*XX(255)-JVS(3829)*XX(257)
  XX(121) = XX(121)-JVS(1238)*XX(183)-JVS(1277)*XX(186)-JVS(1891)*XX(217)-JVS(2143)*XX(228)-JVS(2407)*XX(239)-JVS(2485)&
              &*XX(240)-JVS(2609)*XX(242)-JVS(2710)*XX(243)-JVS(3339)*XX(250)
  XX(120) = XX(120)-JVS(931)*XX(155)-JVS(1577)*XX(205)-JVS(1597)*XX(206)-JVS(3116)*XX(248)-JVS(3338)*XX(250)
  XX(119) = XX(119)-JVS(1730)*XX(212)-JVS(2142)*XX(228)-JVS(2887)*XX(246)-JVS(2980)*XX(247)-JVS(3337)*XX(250)
  XX(118) = XX(118)-JVS(1034)*XX(165)-JVS(2141)*XX(228)-JVS(2484)*XX(240)-JVS(3115)*XX(248)-JVS(3336)*XX(250)
  XX(117) = XX(117)-JVS(2569)*XX(241)-JVS(3114)*XX(248)-JVS(3335)*XX(250)-JVS(3505)*XX(252)-JVS(3677)*XX(255)
  XX(116) = XX(116)-JVS(930)*XX(155)-JVS(1576)*XX(205)-JVS(1596)*XX(206)-JVS(3113)*XX(248)-JVS(3334)*XX(250)
  XX(115) = XX(115)-JVS(823)*XX(139)-JVS(897)*XX(151)-JVS(1033)*XX(165)-JVS(1575)*XX(205)-JVS(1595)*XX(206)-JVS(2483)&
              &*XX(240)-JVS(3112)*XX(248)-JVS(3333)*XX(250)
  XX(114) = XX(114)-JVS(1538)*XX(202)-JVS(3247)*XX(249)-JVS(3332)*XX(250)
  XX(113) = XX(113)-JVS(1340)*XX(188)-JVS(1492)*XX(197)-JVS(3246)*XX(249)-JVS(3331)*XX(250)-JVS(3676)*XX(255)-JVS(3758)&
              &*XX(256)
  XX(112) = XX(112)-JVS(929)*XX(155)-JVS(1648)*XX(208)-JVS(2096)*XX(226)-JVS(2482)*XX(240)-JVS(3111)*XX(248)-JVS(3330)&
              &*XX(250)
  XX(111) = XX(111)-JVS(928)*XX(155)-JVS(1615)*XX(207)-JVS(2198)*XX(229)-JVS(2481)*XX(240)-JVS(3110)*XX(248)-JVS(3329)&
              &*XX(250)
  XX(110) = XX(110)-JVS(1802)*XX(213)-JVS(1949)*XX(218)-JVS(3109)*XX(248)
  XX(109) = XX(109)-JVS(1817)*XX(214)-JVS(2317)*XX(235)-JVS(2850)*XX(245)-JVS(3245)*XX(249)-JVS(3328)*XX(250)-JVS(3504)&
              &*XX(252)-JVS(3675)*XX(255)
  XX(108) = XX(108)-JVS(2095)*XX(226)-JVS(2773)*XX(244)-JVS(2979)*XX(247)-JVS(3108)*XX(248)-JVS(3327)*XX(250)
  XX(107) = XX(107)-JVS(2197)*XX(229)-JVS(2772)*XX(244)-JVS(2978)*XX(247)-JVS(3107)*XX(248)-JVS(3326)*XX(250)
  XX(106) = XX(106)-JVS(3244)*XX(249)-JVS(3674)*XX(255)
  XX(105) = XX(105)-JVS(2249)*XX(231)-JVS(2302)*XX(234)-JVS(2352)*XX(237)-JVS(3106)*XX(248)-JVS(3325)*XX(250)
  XX(104) = XX(104)-JVS(896)*XX(151)-JVS(1032)*XX(165)-JVS(3105)*XX(248)-JVS(3324)*XX(250)
  XX(103) = XX(103)-JVS(927)*XX(155)-JVS(1108)*XX(173)-JVS(3104)*XX(248)-JVS(3323)*XX(250)
  XX(102) = XX(102)-JVS(1136)*XX(175)-JVS(1192)*XX(179)-JVS(2351)*XX(237)-JVS(2977)*XX(247)-JVS(3103)*XX(248)-JVS(3322)&
              &*XX(250)
  XX(101) = XX(101)-JVS(1265)*XX(185)-JVS(2140)*XX(228)-JVS(2568)*XX(241)-JVS(2608)*XX(242)-JVS(3102)*XX(248)-JVS(3321)&
              &*XX(250)
  XX(100) = XX(100)-JVS(1729)*XX(212)-JVS(2301)*XX(234)-JVS(2886)*XX(246)-JVS(3320)*XX(250)-JVS(3503)*XX(252)-JVS(3673)&
              &*XX(255)
  XX(99) = XX(99)-JVS(1684)*XX(209)-JVS(3319)*XX(250)-JVS(3581)*XX(253)-JVS(3894)*XX(258)
  XX(98) = XX(98)-JVS(2268)*XX(232)-JVS(2567)*XX(241)-JVS(3101)*XX(248)-JVS(3318)*XX(250)
  XX(97) = XX(97)-JVS(2771)*XX(244)-JVS(2976)*XX(247)-JVS(3317)*XX(250)-JVS(3757)*XX(256)
  XX(96) = XX(96)-JVS(822)*XX(139)-JVS(2480)*XX(240)-JVS(3100)*XX(248)-JVS(3316)*XX(250)
  XX(95) = XX(95)-JVS(1001)*XX(161)-JVS(3580)*XX(253)-JVS(3672)*XX(255)
  XX(94) = XX(94)-JVS(2406)*XX(239)-JVS(3099)*XX(248)-JVS(3315)*XX(250)
  XX(93) = XX(93)-JVS(2885)*XX(246)-JVS(2975)*XX(247)-JVS(3098)*XX(248)-JVS(3314)*XX(250)-JVS(3756)*XX(256)
  XX(92) = XX(92)-JVS(2709)*XX(243)-JVS(3097)*XX(248)-JVS(3243)*XX(249)-JVS(3313)*XX(250)-JVS(3479)*XX(251)-JVS(3627)&
             &*XX(254)-JVS(3755)*XX(256)
  XX(91) = XX(91)-JVS(2479)*XX(240)-JVS(2708)*XX(243)-JVS(3096)*XX(248)-JVS(3312)*XX(250)-JVS(3502)*XX(252)-JVS(3671)&
             &*XX(255)-JVS(3754)*XX(256)
  XX(90) = XX(90)-JVS(1728)*XX(212)
  XX(89) = XX(89)-JVS(3311)*XX(250)-JVS(3579)*XX(253)-JVS(3626)*XX(254)-JVS(3670)*XX(255)-JVS(3753)*XX(256)-JVS(3893)&
             &*XX(258)
  XX(88) = XX(88)-JVS(3310)*XX(250)-JVS(3578)*XX(253)-JVS(3625)*XX(254)-JVS(3669)*XX(255)-JVS(3752)*XX(256)-JVS(3892)&
             &*XX(258)
  XX(87) = XX(87)-JVS(1683)*XX(209)-JVS(2974)*XX(247)-JVS(3309)*XX(250)-JVS(3668)*XX(255)
  XX(86) = XX(86)-JVS(1355)*XX(189)-JVS(1890)*XX(217)-JVS(2607)*XX(242)-JVS(2770)*XX(244)-JVS(2884)*XX(246)-JVS(3095)&
             &*XX(248)
  XX(85) = XX(85)-JVS(2566)*XX(241)-JVS(2973)*XX(247)-JVS(3094)*XX(248)-JVS(3308)*XX(250)
  XX(84) = XX(84)-JVS(1521)*XX(200)-JVS(2565)*XX(241)-JVS(3093)*XX(248)-JVS(3307)*XX(250)
  XX(83) = XX(83)-JVS(1414)*XX(192)-JVS(2316)*XX(235)-JVS(3092)*XX(248)-JVS(3306)*XX(250)
  XX(82) = XX(82)-JVS(1816)*XX(214)-JVS(2350)*XX(237)-JVS(3091)*XX(248)-JVS(3305)*XX(250)
  XX(81) = XX(81)-JVS(2300)*XX(234)-JVS(2349)*XX(237)-JVS(3090)*XX(248)-JVS(3304)*XX(250)
  XX(80) = XX(80)-JVS(1339)*XX(188)-JVS(1491)*XX(197)-JVS(2769)*XX(244)-JVS(2972)*XX(247)
  XX(79) = XX(79)-JVS(2348)*XX(237)-JVS(2971)*XX(247)-JVS(3089)*XX(248)-JVS(3303)*XX(250)
  XX(78) = XX(78)-JVS(2606)*XX(242)-JVS(2970)*XX(247)-JVS(3088)*XX(248)-JVS(3302)*XX(250)
  XX(77) = XX(77)-JVS(1413)*XX(192)-JVS(2969)*XX(247)-JVS(3087)*XX(248)-JVS(3301)*XX(250)
  XX(76) = XX(76)-JVS(592)*XX(97)-JVS(992)*XX(160)-JVS(1338)*XX(188)-JVS(2968)*XX(247)-JVS(3242)*XX(249)-JVS(3667)&
             &*XX(255)
  XX(75) = XX(75)-JVS(754)*XX(126)-JVS(1727)*XX(212)-JVS(2605)*XX(242)-JVS(2707)*XX(243)-JVS(2883)*XX(246)-JVS(3300)&
             &*XX(250)
  XX(74) = XX(74)-JVS(1276)*XX(186)-JVS(1889)*XX(217)-JVS(2405)*XX(239)-JVS(3299)*XX(250)
  XX(73) = XX(73)-JVS(1275)*XX(186)-JVS(2604)*XX(242)-JVS(3086)*XX(248)-JVS(3298)*XX(250)
  XX(72) = XX(72)-JVS(3297)*XX(250)-JVS(3577)*XX(253)-JVS(3624)*XX(254)-JVS(3666)*XX(255)-JVS(3751)*XX(256)-JVS(3891)&
             &*XX(258)
  XX(71) = XX(71)-JVS(3296)*XX(250)-JVS(3576)*XX(253)-JVS(3623)*XX(254)-JVS(3665)*XX(255)-JVS(3750)*XX(256)-JVS(3890)&
             &*XX(258)
  XX(70) = XX(70)-JVS(2478)*XX(240)-JVS(3085)*XX(248)-JVS(3295)*XX(250)-JVS(3501)*XX(252)-JVS(3664)*XX(255)
  XX(69) = XX(69)-JVS(3241)*XX(249)-JVS(3294)*XX(250)-JVS(3478)*XX(251)-JVS(3622)*XX(254)-JVS(3889)*XX(258)
  XX(68) = XX(68)-JVS(578)*XX(95)-JVS(1682)*XX(209)-JVS(3293)*XX(250)-JVS(3575)*XX(253)-JVS(3663)*XX(255)
  XX(67) = XX(67)-JVS(2477)*XX(240)-JVS(3084)*XX(248)-JVS(3292)*XX(250)-JVS(3500)*XX(252)-JVS(3662)*XX(255)
  XX(66) = XX(66)-JVS(3240)*XX(249)-JVS(3291)*XX(250)-JVS(3477)*XX(251)-JVS(3621)*XX(254)-JVS(3888)*XX(258)
  XX(65) = XX(65)-JVS(2603)*XX(242)-JVS(2706)*XX(243)-JVS(2882)*XX(246)-JVS(2967)*XX(247)-JVS(3083)*XX(248)
  XX(64) = XX(64)-JVS(1337)*XX(188)-JVS(3661)*XX(255)
  XX(63) = XX(63)-JVS(2404)*XX(239)-JVS(2705)*XX(243)-JVS(3290)*XX(250)
  XX(62) = XX(62)-JVS(1336)*XX(188)-JVS(3289)*XX(250)-JVS(3749)*XX(256)
  XX(61) = XX(61)-JVS(2768)*XX(244)-JVS(3082)*XX(248)
  XX(60) = XX(60)-JVS(753)*XX(126)-JVS(3288)*XX(250)
  XX(59) = XX(59)-JVS(2403)*XX(239)-JVS(2704)*XX(243)-JVS(2881)*XX(246)-JVS(2966)*XX(247)
  XX(58) = XX(58)-JVS(752)*XX(126)-JVS(2476)*XX(240)-JVS(3287)*XX(250)-JVS(3887)*XX(258)
  XX(57) = XX(57)-JVS(2767)*XX(244)-JVS(2965)*XX(247)-JVS(3620)*XX(254)-JVS(3886)*XX(258)
  XX(56) = XX(56)-JVS(2766)*XX(244)-JVS(3081)*XX(248)
  XX(55) = XX(55)-JVS(2765)*XX(244)-JVS(3080)*XX(248)
  XX(54) = XX(54)-JVS(2764)*XX(244)-JVS(3619)*XX(254)
  XX(53) = XX(53)-JVS(991)*XX(160)-JVS(1335)*XX(188)-JVS(2763)*XX(244)
  XX(52) = XX(52)-JVS(1334)*XX(188)-JVS(3239)*XX(249)
  XX(51) = XX(51)-JVS(3238)*XX(249)-JVS(3476)*XX(251)-JVS(3574)*XX(253)-JVS(3618)*XX(254)-JVS(3660)*XX(255)-JVS(3885)&
             &*XX(258)
  XX(50) = XX(50)-JVS(3573)*XX(253)-JVS(3617)*XX(254)-JVS(3659)*XX(255)-JVS(3884)*XX(258)
  XX(49) = XX(49)-JVS(3572)*XX(253)-JVS(3616)*XX(254)-JVS(3658)*XX(255)-JVS(3883)*XX(258)
  XX(48) = XX(48)-JVS(3571)*XX(253)-JVS(3615)*XX(254)-JVS(3657)*XX(255)-JVS(3882)*XX(258)
  XX(47) = XX(47)-JVS(3570)*XX(253)-JVS(3614)*XX(254)-JVS(3656)*XX(255)-JVS(3881)*XX(258)
  XX(46) = XX(46)-JVS(3569)*XX(253)-JVS(3613)*XX(254)-JVS(3655)*XX(255)-JVS(3880)*XX(258)
  XX(45) = XX(45)-JVS(3568)*XX(253)-JVS(3612)*XX(254)-JVS(3654)*XX(255)-JVS(3879)*XX(258)
  XX(44) = XX(44)-JVS(2964)*XX(247)-JVS(3237)*XX(249)
  XX(43) = XX(43)-JVS(415)*XX(55)-JVS(1354)*XX(189)-JVS(1888)*XX(217)-JVS(2602)*XX(242)
  XX(42) = XX(42)-JVS(1520)*XX(200)-JVS(2963)*XX(247)
  XX(41) = XX(41)-JVS(510)*XX(80)-JVS(1490)*XX(197)
  XX(40) = XX(40)-JVS(3236)*XX(249)-JVS(3475)*XX(251)-JVS(3611)*XX(254)-JVS(3878)*XX(258)
  XX(39) = XX(39)-JVS(3235)*XX(249)-JVS(3474)*XX(251)-JVS(3610)*XX(254)-JVS(3877)*XX(258)
  XX(38) = XX(38)-JVS(1333)*XX(188)-JVS(2703)*XX(243)-JVS(3286)*XX(250)-JVS(3748)*XX(256)
  XX(37) = XX(37)-JVS(420)*XX(56)-JVS(1353)*XX(189)-JVS(2601)*XX(242)
  XX(36) = XX(36)-JVS(1726)*XX(212)
  XX(35) = XX(35)-JVS(509)*XX(80)-JVS(1332)*XX(188)-JVS(1489)*XX(197)
  XX(34) = XX(34)-JVS(3285)*XX(250)-JVS(3653)*XX(255)-JVS(3747)*XX(256)
  XX(33) = XX(33)-JVS(508)*XX(80)
  XX(32) = XX(32)
  XX(31) = XX(31)
  XX(30) = XX(30)
  XX(29) = XX(29)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)-JVS(110)*XX(26)-JVS(591)*XX(97)-JVS(2962)*XX(247)
  XX(4) = XX(4)-JVS(109)*XX(26)-JVS(590)*XX(97)-JVS(2961)*XX(247)
  XX(3) = XX(3)-JVS(1331)*XX(188)-JVS(3652)*XX(255)
  XX(2) = XX(2)-JVS(1330)*XX(188)-JVS(3234)*XX(249)
  XX(1) = XX(1)-JVS(1329)*XX(188)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

