! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! Linear Algebra Data and Routines File
! 
! Generated by KPP-2.2.4_gc symbolic chemistry Kinetics PreProcessor
!       (http://www.cs.vt.edu/~asandu/Software/KPP)
! KPP is distributed under GPL, the general public licence
!       (http://www.gnu.org/copyleft/gpl.html)
! (C) 1995-1997, V. Damian & A. Sandu, CGRER, Univ. Iowa
! (C) 1997-2005, A. Sandu, Michigan Tech, Virginia Tech
!     With important contributions from:
!        M. Damian, Villanova University, USA
!        R. Sander, Max-Planck Institute for Chemistry, Mainz, Germany
! 
! File                 : gckpp_LinearAlgebra.f90
! Time                 : Fri Mar 13 14:32:03 2020
! Working directory    : /n/home05/msulprizio/GC/Code.GCHP/KPP/Tropchem
! Equation file        : gckpp.kpp
! Output root filename : gckpp
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



MODULE gckpp_LinearAlgebra

  USE gckpp_Parameters
  USE gckpp_JacobianSP

  IMPLICIT NONE

CONTAINS


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! SPARSE_UTIL - SPARSE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecomp( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: IER
      REAL(kind=dp) :: JVS(LU_NONZERO), W(NVAR), a
      INTEGER  :: k, kk, j, jj

      a = 0. ! mz_rs_20050606
      IER = 0
      DO k=1,NVAR
        ! mz_rs_20050606: don't check if real value == 0
        ! IF ( JVS( LU_DIAG(k) ) .EQ. 0. ) THEN
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(a) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecomp


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplx( JVS, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse LU factorization, complex
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: IER
      DOUBLE COMPLEX :: JVS(LU_NONZERO), W(NVAR), a
      REAL(kind=dp)  :: b = 0.0
      INTEGER        :: k, kk, j, jj

      IER = 0
      DO k=1,NVAR
        IF ( ABS(JVS(LU_DIAG(k))) < TINY(b) ) THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              W( LU_ICOL(kk) ) = JVS(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            a = -W(j) / JVS( LU_DIAG(j) )
            W(j) = -a
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               W( LU_ICOL(jj) ) = W( LU_ICOL(jj) ) + a*JVS(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVS(kk) = W( LU_ICOL(kk) )
         END DO
      END DO
      
END SUBROUTINE KppDecompCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppDecompCmplxR( JVSR, JVSI, IER )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!    Sparse LU factorization, complex
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: IER
      REAL(kind=dp) :: JVSR(LU_NONZERO), JVSI(LU_NONZERO) 
      REAL(kind=dp) :: WR(NVAR), WI(NVAR), ar, ai, den
      INTEGER       :: k, kk, j, jj

      IER = 0
      ar  = 0.0
      DO k=1,NVAR
        IF (  ( ABS(JVSR(LU_DIAG(k))) < TINY(ar) ) .AND. &
              ( ABS(JVSI(LU_DIAG(k))) < TINY(ar) ) )  THEN
            IER = k
            RETURN
        END IF
        DO kk = LU_CROW(k), LU_CROW(k+1)-1
              WR( LU_ICOL(kk) ) = JVSR(kk)
              WI( LU_ICOL(kk) ) = JVSI(kk)
        END DO
        DO kk = LU_CROW(k), LU_DIAG(k)-1
            j = LU_ICOL(kk)
            den = JVSR(LU_DIAG(j))**2 + JVSI(LU_DIAG(j))**2
            ar = -(WR(j)*JVSR(LU_DIAG(j)) + WI(j)*JVSI(LU_DIAG(j)))/den
            ai = -(WI(j)*JVSR(LU_DIAG(j)) - WR(j)*JVSI(LU_DIAG(j)))/den
            WR(j) = -ar
            WI(j) = -ai
            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
               WR( LU_ICOL(jj) ) = WR( LU_ICOL(jj) ) + ar*JVSR(jj) - ai*JVSI(jj)
               WI( LU_ICOL(jj) ) = WI( LU_ICOL(jj) ) + ar*JVSI(jj) + ai*JVSR(jj)
            END DO
         END DO
         DO kk = LU_CROW(k), LU_CROW(k+1)-1
            JVSR(kk) = WR( LU_ICOL(kk) )
            JVSI(kk) = WI( LU_ICOL(kk) )
         END DO
      END DO

END SUBROUTINE KppDecompCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER  :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRIndirect( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       :: i, j
      REAL(kind=dp) :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRIndirect


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR), sum

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             X(i) = X(i) - JVS(j)*X(LU_ICOL(j));
         END DO  
      END DO

      DO i=NVAR,1,-1
        sum = X(i);
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
          sum = sum - JVS(j)*X(LU_ICOL(j));
        END DO
        X(i) = sum/JVS(LU_DIAG(i));
      END DO
      
END SUBROUTINE KppSolveCmplx

! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), sumr, sumi, den

      DO i=1,NVAR
         DO j = LU_CROW(i), LU_DIAG(i)-1 
             XR(i) = XR(i) - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
             XI(i) = XI(i) - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
         END DO  
      END DO

      DO i=NVAR,1,-1
        sumr = XR(i); sumi = XI(i)
        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
            sumr = sumr - (JVSR(j)*XR(LU_ICOL(j)) - JVSI(j)*XI(LU_ICOL(j)))
            sumi = sumi - (JVSR(j)*XI(LU_ICOL(j)) + JVSI(j)*XR(LU_ICOL(j)))
        END DO
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (sumr*JVSR(LU_DIAG(i)) + sumi*JVSI(LU_DIAG(i)))/den
        XI(i) = (sumi*JVSR(LU_DIAG(i)) - sumr*JVSI(LU_DIAG(i)))/den
      END DO
      
END SUBROUTINE KppSolveCmplxR


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplx( JVS, X )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!        Complex sparse solve transpose subroutine using indirect addressing
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER        :: i, j
      DOUBLE COMPLEX :: JVS(LU_NONZERO), X(NVAR)

      DO i=1,NVAR
        X(i) = X(i)/JVS(LU_DIAG(i))
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  X(LU_ICOL(j)) = X(LU_ICOL(j))-JVS(j)*X(i)
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplx


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
SUBROUTINE KppSolveTRCmplxR( JVSR, JVSI, XR, XI )
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!   Complex sparse solve transpose subroutine using indirect addressing
!   (Real and Imaginary parts are used instead of complex data type)     
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

  USE gckpp_Parameters
  USE gckpp_JacobianSP

      INTEGER       ::  i, j
      REAL(kind=dp) ::  JVSR(LU_NONZERO), JVSI(LU_NONZERO), XR(NVAR), XI(NVAR), den

      DO i=1,NVAR
        den   = JVSR(LU_DIAG(i))**2 + JVSI(LU_DIAG(i))**2
        XR(i) = (XR(i)*JVSR(LU_DIAG(i)) + XI(i)*JVSI(LU_DIAG(i)))/den
        XI(i) = (XI(i)*JVSR(LU_DIAG(i)) - XR(i)*JVSI(LU_DIAG(i)))/den
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO

      DO i=NVAR, 1, -1
	! subtract all nonzero elements in row i of JVS from X
        DO j=LU_CROW(i),LU_DIAG(i)-1
	  XR(LU_ICOL(j)) = XR(LU_ICOL(j))-(JVSR(j)*XR(i) - JVSI(j)*XI(i))
	  XI(LU_ICOL(j)) = XI(LU_ICOL(j))-(JVSI(j)*XR(i) + JVSR(j)*XI(i))
	END DO
      END DO
      
END SUBROUTINE KppSolveTRCmplxR


!
! Next few commented subroutines perform sparse big linear algebra
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppDecompBig( JVS, IP, IER )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse LU factorization
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: IP3(3), IER, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), W(3,3,NVAR), a(3,3), E(3,3)
!      INTEGER  :: k, kk, j, jj
!
!      a = 0.0d0
!      IER = 0
!      DO k=1,NVAR
!        DO kk = LU_CROW(k), LU_CROW(k+1)-1
!              W( 1:3,1:3,LU_ICOL(kk) ) = JVS(1:3,1:3,kk)
!        END DO
!        DO kk = LU_CROW(k), LU_DIAG(k)-1
!            j = LU_ICOL(kk)
!            E(1:3,1:3) = JVS( 1:3,1:3,LU_DIAG(j) )
!            ! CALL DGETRF(3,3,E,3,IP3,IER) 
!            CALL FAC3(E,IP3,IER)
!            IF ( IER /= 0 )  RETURN
!            ! a = W(j) / JVS( LU_DIAG(j) )
!            a(1:3,1:3) = W( 1:3,1:3,j )
!            ! CALL DGETRS ('N',3,3,E,3,IP3,a,3,IER) 
!            CALL SOL3('N',E,IP3,a(1,1))
!            CALL SOL3('N',E,IP3,a(1,2))
!            CALL SOL3('N',E,IP3,a(1,3))
!            W(1:3,1:3,j) = a(1:3,1:3)
!            DO jj = LU_DIAG(j)+1, LU_CROW(j+1)-1
!               W( 1:3,1:3,LU_ICOL(jj) ) = W( 1:3,1:3,LU_ICOL(jj) ) &
!                        - MATMUL( a(1:3,1:3) , JVS(1:3,1:3,jj) )
!            END DO
!         END DO
!         DO kk = LU_CROW(k), LU_CROW(k+1)-1
!            JVS(1:3,1:3,kk) = W( 1:3,1:3,LU_ICOL(kk) )
!         END DO
!      END DO
!
!      DO k=1,NVAR
!         ! CALL WGEFA(JVS(1,1,LU_DIAG(k)),3,3,IP(1,k),IER)
!         ! CALL DGETRF(3,3,JVS(1,1,LU_DIAG(k)),3,IP(1,k),IER)
!         CALL FAC3(JVS(1,1,LU_DIAG(k)),IP(1,k),IER)
!         IF ( IER /= 0 )  RETURN
!      END DO 
!      
!END SUBROUTINE KppDecompBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBig( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Sparse solve subroutine using indirect addressing
!!        for the Runge Kutta (3n)x(3n) linear system
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER  :: i, j, k, m, IP3(3), IP(3,NVAR), IER
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR), sum(3)
!
!      DO i=1,NVAR
!        DO j = LU_CROW(i), LU_DIAG(i)-1 
!          !X(1:3,i) = X(1:3,i) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       X(k,i) = X(k,i) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO  
!      END DO
!
!      DO i=NVAR,1,-1
!        sum(1:3) = X(1:3,i);
!        DO j = LU_DIAG(i)+1, LU_CROW(i+1)-1
!          !sum(1:3) = sum(1:3) - MATMUL(JVS(1:3,1:3,j),X(1:3,LU_ICOL(j)));
!          DO k=1,3
!            DO m=1,3
!	       sum(k) = sum(k) - JVS(k,m,j)*X(m,LU_ICOL(j))
!            END DO
!          END DO
!        END DO
!        ! X(i) = sum/JVS(LU_DIAG(i));
!        ! CALL DGETRS ('N',3,1,JVS(1:3,1:3,LU_DIAG(i)),3,IP(1,i),sum,3,0) 
!        ! CALL WGESL('N',JVS(1,1,LU_DIAG(i)),3,3,IP(1,i),sum)
!        CALL SOL3('N',JVS(1,1,LU_DIAG(i)),IP(1,i),sum)
!        X(1:3,i) = sum(1:3)
!      END DO
!      
!END SUBROUTINE KppSolveBig
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE KppSolveBigTR( JVS, IP, X )
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!        Big sparse transpose solve using indirect addressing
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!  USE gckpp_Parameters
!  USE gckpp_JacobianSP
!
!      INTEGER       :: i, j, k, m, IP(3,NVAR)
!      REAL(kind=dp) :: JVS(3,3,LU_NONZERO), X(3,NVAR)
!
!      DO i=1,NVAR
!        ! X(i) = X(i)/JVS(LU_DIAG(i))
!        CALL SOL3('T',JVS(1,1,LU_DIAG(i)),IP(1,i),X(1,i))
!        DO j=LU_DIAG(i)+1,LU_CROW(i+1)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !    - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!
!      DO i=NVAR, 1, -1
!        DO j=LU_CROW(i),LU_DIAG(i)-1
!	  !X(1:3,LU_ICOL(j)) = X(1:3,LU_ICOL(j)) &
!          !   - MATMUL( TRANSPOSE(JVS(1:3,1:3,j)), X(1:3,i) )
!          DO k=1,3
!            DO m=1,3
!	       X(k,LU_ICOL(j)) = X(k,LU_ICOL(j)) - JVS(m,k,j)*X(m,i)
!            END DO
!          END DO
!	END DO
!      END DO
!      
!END SUBROUTINE KppSolveBigTR
!
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE FAC3(A,IPVT,INFO)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     FAC3 FACTORS THE MATRIX A (3,3) BY
!!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!!     LINPACK - LIKE 
!!
!!     Remove comments to perform pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!
!      REAL(kind=dp) :: A(3,3)
!      INTEGER       :: IPVT(3),INFO
!!      INTEGER       :: L
!!      REAL(kind=dp) :: t, dmax, da, TMP(3)
!      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0
!
!      info = 0
!!      t = TINY(da)
!!      
!!      da = ABS(A(1,1)); L = 1
!!      IF ( ABS(A(2,1))>da ) THEN
!!        da = ABS(A(2,1)); L = 2
!!        IF ( ABS(A(3,1))>da ) THEN
!!          L = 3
!!        END IF  
!!      END IF  
!!      IPVT(1)  = L
!!      IF (L /=1 ) THEN
!!         TMP(1:3) = A(L,1:3)
!!         A(L,1:3) = A(1,1:3)
!!         A(1,1:3) = TMP(1:3)
!!      END IF
!!      IF (ABS(A(1,1)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!
!      A(2,1) = A(2,1)/A(1,1)
!      A(2,2) = A(2,2) - A(2,1)*A(1,2)
!      A(2,3) = A(2,3) - A(2,1)*A(1,3)
!      A(3,1) = A(3,1)/A(1,1)
!      A(3,2) = A(3,2) - A(3,1)*A(1,2)
!      A(3,3) = A(3,3) - A(3,1)*A(1,3)
!      
!!      IPVT(2)  = 2
!!      IF (ABS(A(3,2))>ABS(A(2,2))) THEN
!!         IPVT(2)  = 3
!!         TMP(2:3) = A(3,2:3)
!!         A(3,2:3) = A(2,2:3)
!!         A(2,2:3) = TMP(2:3)
!!      END IF
!!      IF (ABS(A(2,2)) < t) THEN
!!         info = 1
!!         return
!!      END IF   
!!      
!      A(3,2)   = A(3,2)/A(2,2)
!      A(3,3)   = A(3,3) - A(3,2)*A(2,3)
!      IPVT(3)  = 3
!      
!END SUBROUTINE FAC3
!
!
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!SUBROUTINE SOL3(Trans,A,IPVT,b)
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!!     SOL3 solves the system 3x3
!!     A * x = b  or  trans(a) * x = b
!!     using the factors computed by WGEFA.
!!
!!     Trans      = 'N'   to solve  A*x = b ,
!!                = 'T'   to solve  transpose(A)*x = b
!!     LINPACK - LIKE 
!!
!!     Remove comments to use pivoting
!! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
!
!      CHARACTER     :: Trans
!      REAL(kind=dp) :: a(3,3),b(3)
!      INTEGER       :: IPVT(3)
!!      INTEGER       :: L
!!      REAL(kind=dp) :: TMP
!      
!      SELECT CASE (Trans)
!
!      CASE ('n','N')  !  Solve  A * x = b
!
!!     Solve  L*y = b
!!         L = IPVT(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!         b(2) = b(2)-A(2,1)*b(1)
!         b(3) = b(3)-A(3,1)*b(1)
!         
!!         L = IPVT(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(3) = b(3)-A(3,2)*b(2)
!
!!     Solve  U*x = y
!         b(3) = b(3)/A(3,3)
!         b(2) = (b(2)-A(2,3)*b(3))/A(2,2)
!         b(1) = (b(1)-A(1,3)*b(3)-A(1,2)*b(2))/A(1,1)
!      
!      
!      CASE ('t','T')  !  Solve transpose(A) * x = b
!
!!      Solve transpose(U)*y = b
!         b(1) = b(1)/A(1,1)
!         b(2) = (b(2)-A(1,2)*b(1))/A(2,2)
!         b(3) = (b(3)-A(1,3)*b(1)-A(2,3)*b(2))/A(3,3)
!
!!      Solve transpose(L)*x = y
!         b(2) = b(2)-A(3,2)*b(3)
!!         L = ipvt(2)
!!         IF (L /= 2) THEN
!!            TMP = B(2); B(2) = B(L); B(L) = TMP
!!         END IF
!         b(1) = b(1)-A(3,1)*b(3)-A(2,1)*b(2)
!!         L = ipvt(1)
!!         IF (L /= 1) THEN
!!            TMP = B(1); B(1) = B(L); B(L) = TMP
!!         END IF
!   
!      END SELECT
!
!END SUBROUTINE SOL3

! End of SPARSE_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolve - sparse back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolve ( JVS, X )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)

  X(27) = X(27)-JVS(113)*X(4)-JVS(114)*X(5)
  X(49) = X(49)-JVS(388)*X(43)
  X(50) = X(50)-JVS(393)*X(39)
  X(61) = X(61)-JVS(435)*X(4)-JVS(436)*X(5)
  X(67) = X(67)-JVS(462)*X(34)-JVS(463)*X(37)-JVS(464)*X(41)
  X(78) = X(78)-JVS(515)*X(57)
  X(98) = X(98)-JVS(624)*X(78)
  X(99) = X(99)-JVS(634)*X(74)
  X(119) = X(119)-JVS(745)*X(112)
  X(123) = X(123)-JVS(764)*X(80)-JVS(765)*X(97)
  X(131) = X(131)-JVS(815)*X(121)-JVS(816)*X(122)
  X(132) = X(132)-JVS(828)*X(113)
  X(135) = X(135)-JVS(844)*X(111)
  X(137) = X(137)-JVS(855)*X(87)-JVS(856)*X(97)
  X(139) = X(139)-JVS(871)*X(138)
  X(140) = X(140)-JVS(882)*X(48)-JVS(883)*X(77)-JVS(884)*X(130)
  X(142) = X(142)-JVS(896)*X(86)-JVS(897)*X(100)-JVS(898)*X(102)-JVS(899)*X(104)-JVS(900)*X(106)-JVS(901)*X(111)&
             &-JVS(902)*X(112)-JVS(903)*X(124)-JVS(904)*X(126)-JVS(905)*X(128)-JVS(906)*X(133)-JVS(907)*X(138)
  X(143) = X(143)-JVS(921)*X(136)
  X(146) = X(146)-JVS(949)*X(124)-JVS(950)*X(138)
  X(147) = X(147)-JVS(956)*X(128)-JVS(957)*X(133)
  X(148) = X(148)-JVS(963)*X(87)-JVS(964)*X(97)-JVS(965)*X(103)-JVS(966)*X(129)
  X(149) = X(149)-JVS(980)*X(124)-JVS(981)*X(128)
  X(150) = X(150)-JVS(988)*X(138)
  X(151) = X(151)-JVS(994)*X(133)
  X(152) = X(152)-JVS(1000)*X(133)-JVS(1001)*X(147)
  X(153) = X(153)-JVS(1015)*X(133)-JVS(1016)*X(138)
  X(154) = X(154)-JVS(1026)*X(126)
  X(156) = X(156)-JVS(1050)*X(86)-JVS(1051)*X(128)-JVS(1052)*X(133)-JVS(1053)*X(138)
  X(157) = X(157)-JVS(1062)*X(57)-JVS(1063)*X(73)-JVS(1064)*X(81)-JVS(1065)*X(93)-JVS(1066)*X(98)
  X(158) = X(158)-JVS(1080)*X(101)-JVS(1081)*X(109)-JVS(1082)*X(110)-JVS(1083)*X(127)
  X(159) = X(159)-JVS(1094)*X(85)-JVS(1095)*X(116)-JVS(1096)*X(118)-JVS(1097)*X(136)-JVS(1098)*X(143)-JVS(1099)*X(154)
  X(160) = X(160)-JVS(1116)*X(51)-JVS(1117)*X(60)-JVS(1118)*X(108)-JVS(1119)*X(120)-JVS(1120)*X(129)-JVS(1121)*X(141)&
             &-JVS(1122)*X(150)-JVS(1123)*X(151)
  X(161) = X(161)-JVS(1144)*X(115)-JVS(1145)*X(135)-JVS(1146)*X(151)
  X(164) = X(164)-JVS(1178)*X(114)-JVS(1179)*X(150)
  X(165) = X(165)-JVS(1189)*X(115)-JVS(1190)*X(151)
  X(166) = X(166)-JVS(1200)*X(113)-JVS(1201)*X(146)-JVS(1202)*X(147)-JVS(1203)*X(149)-JVS(1204)*X(156)
  X(167) = X(167)-JVS(1215)*X(85)
  X(168) = X(168)-JVS(1224)*X(116)-JVS(1225)*X(118)-JVS(1226)*X(134)-JVS(1227)*X(154)
  X(169) = X(169)-JVS(1241)*X(99)
  X(170) = X(170)-JVS(1251)*X(108)-JVS(1252)*X(120)
  X(171) = X(171)-JVS(1261)*X(1)-JVS(1262)*X(2)-JVS(1263)*X(3)-JVS(1264)*X(37)-JVS(1265)*X(40)-JVS(1266)*X(46)-JVS(1267)&
             &*X(47)-JVS(1268)*X(48)-JVS(1269)*X(56)-JVS(1270)*X(67)-JVS(1271)*X(77)-JVS(1272)*X(88)-JVS(1273)*X(130)&
             &-JVS(1274)*X(140)
  X(172) = X(172)-JVS(1285)*X(109)-JVS(1286)*X(110)-JVS(1287)*X(158)
  X(173) = X(173)-JVS(1299)*X(84)
  X(174) = X(174)-JVS(1309)*X(37)-JVS(1310)*X(41)-JVS(1311)*X(67)-JVS(1312)*X(88)-JVS(1313)*X(130)-JVS(1314)*X(140)&
             &-JVS(1315)*X(171)
  X(175) = X(175)-JVS(1325)*X(117)
  X(176) = X(176)-JVS(1335)*X(119)-JVS(1336)*X(134)-JVS(1337)*X(135)-JVS(1338)*X(136)-JVS(1339)*X(154)-JVS(1340)*X(156)
  X(178) = X(178)-JVS(1360)*X(127)-JVS(1361)*X(171)-JVS(1362)*X(174)
  X(179) = X(179)-JVS(1373)*X(39)-JVS(1374)*X(43)-JVS(1375)*X(72)-JVS(1376)*X(123)-JVS(1377)*X(129)-JVS(1378)*X(132)&
             &-JVS(1379)*X(139)-JVS(1380)*X(146)-JVS(1381)*X(147)-JVS(1382)*X(148)-JVS(1383)*X(149)-JVS(1384)*X(150)&
             &-JVS(1385)*X(151)-JVS(1386)*X(154)-JVS(1387)*X(166)-JVS(1388)*X(177)
  X(180) = X(180)-JVS(1408)*X(145)
  X(181) = X(181)-JVS(1416)*X(64)-JVS(1417)*X(70)-JVS(1418)*X(163)
  X(182) = X(182)-JVS(1432)*X(167)-JVS(1433)*X(173)-JVS(1434)*X(175)
  X(184) = X(184)-JVS(1463)*X(121)-JVS(1464)*X(122)-JVS(1465)*X(141)
  X(185) = X(185)-JVS(1475)*X(121)-JVS(1476)*X(122)-JVS(1477)*X(141)-JVS(1478)*X(184)
  X(187) = X(187)-JVS(1494)*X(38)-JVS(1495)*X(74)-JVS(1496)*X(76)-JVS(1497)*X(83)-JVS(1498)*X(93)-JVS(1499)*X(105)&
             &-JVS(1500)*X(109)-JVS(1501)*X(110)-JVS(1502)*X(111)-JVS(1503)*X(112)-JVS(1504)*X(117)-JVS(1505)*X(126)&
             &-JVS(1506)*X(127)-JVS(1507)*X(130)-JVS(1508)*X(140)-JVS(1509)*X(143)-JVS(1510)*X(144)-JVS(1511)*X(145)&
             &-JVS(1512)*X(154)-JVS(1513)*X(158)-JVS(1514)*X(161)-JVS(1515)*X(162)-JVS(1516)*X(163)-JVS(1517)*X(165)&
             &-JVS(1518)*X(168)-JVS(1519)*X(171)-JVS(1520)*X(172)-JVS(1521)*X(174)-JVS(1522)*X(176)-JVS(1523)*X(177)&
             &-JVS(1524)*X(178)-JVS(1525)*X(179)-JVS(1526)*X(180)-JVS(1527)*X(183)-JVS(1528)*X(184)-JVS(1529)*X(185)&
             &-JVS(1530)*X(186)
  X(188) = X(188)-JVS(1570)*X(141)
  X(189) = X(189)-JVS(1579)*X(89)-JVS(1580)*X(121)-JVS(1581)*X(122)-JVS(1582)*X(144)-JVS(1583)*X(163)-JVS(1584)*X(184)&
             &-JVS(1585)*X(185)-JVS(1586)*X(188)
  X(190) = X(190)-JVS(1599)*X(99)-JVS(1600)*X(169)-JVS(1601)*X(183)
  X(191) = X(191)-JVS(1613)*X(97)-JVS(1614)*X(104)-JVS(1615)*X(106)-JVS(1616)*X(111)-JVS(1617)*X(112)-JVS(1618)*X(124)&
             &-JVS(1619)*X(128)-JVS(1620)*X(153)-JVS(1621)*X(177)-JVS(1622)*X(186)
  X(192) = X(192)-JVS(1633)*X(97)-JVS(1634)*X(104)-JVS(1635)*X(106)-JVS(1636)*X(111)-JVS(1637)*X(112)-JVS(1638)*X(124)&
             &-JVS(1639)*X(128)-JVS(1640)*X(153)-JVS(1641)*X(177)-JVS(1642)*X(186)-JVS(1643)*X(191)
  X(193) = X(193)-JVS(1653)*X(102)-JVS(1654)*X(128)-JVS(1655)*X(132)-JVS(1656)*X(133)-JVS(1657)*X(146)-JVS(1658)*X(147)&
             &-JVS(1659)*X(149)-JVS(1660)*X(151)-JVS(1661)*X(153)-JVS(1662)*X(165)-JVS(1663)*X(166)-JVS(1664)*X(176)&
             &-JVS(1665)*X(177)-JVS(1666)*X(180)-JVS(1667)*X(183)-JVS(1668)*X(186)-JVS(1669)*X(191)-JVS(1670)*X(192)
  X(194) = X(194)-JVS(1687)*X(100)-JVS(1688)*X(124)-JVS(1689)*X(132)-JVS(1690)*X(138)-JVS(1691)*X(146)-JVS(1692)*X(147)&
             &-JVS(1693)*X(149)-JVS(1694)*X(150)-JVS(1695)*X(153)-JVS(1696)*X(164)-JVS(1697)*X(176)-JVS(1698)*X(177)&
             &-JVS(1699)*X(180)-JVS(1700)*X(183)-JVS(1701)*X(186)-JVS(1702)*X(191)-JVS(1703)*X(192)
  X(195) = X(195)-JVS(1720)*X(95)-JVS(1721)*X(126)-JVS(1722)*X(145)
  X(196) = X(196)-JVS(1734)*X(66)-JVS(1735)*X(68)-JVS(1736)*X(69)-JVS(1737)*X(85)-JVS(1738)*X(89)-JVS(1739)*X(121)&
             &-JVS(1740)*X(122)-JVS(1741)*X(125)-JVS(1742)*X(162)-JVS(1743)*X(163)-JVS(1744)*X(167)-JVS(1745)*X(173)&
             &-JVS(1746)*X(184)-JVS(1747)*X(185)-JVS(1748)*X(188)
  X(197) = X(197)-JVS(1766)*X(113)-JVS(1767)*X(116)-JVS(1768)*X(132)-JVS(1769)*X(135)-JVS(1770)*X(136)-JVS(1771)*X(146)&
             &-JVS(1772)*X(147)-JVS(1773)*X(149)-JVS(1774)*X(164)-JVS(1775)*X(166)-JVS(1776)*X(176)-JVS(1777)*X(177)&
             &-JVS(1778)*X(180)-JVS(1779)*X(183)-JVS(1780)*X(186)-JVS(1781)*X(191)-JVS(1782)*X(192)-JVS(1783)*X(194)&
             &-JVS(1784)*X(195)
  X(198) = X(198)-JVS(1804)*X(43)-JVS(1805)*X(60)-JVS(1806)*X(72)-JVS(1807)*X(108)-JVS(1808)*X(120)-JVS(1809)*X(123)&
             &-JVS(1810)*X(129)-JVS(1811)*X(132)-JVS(1812)*X(133)-JVS(1813)*X(138)-JVS(1814)*X(142)-JVS(1815)*X(146)&
             &-JVS(1816)*X(147)-JVS(1817)*X(148)-JVS(1818)*X(149)-JVS(1819)*X(150)-JVS(1820)*X(151)-JVS(1821)*X(152)&
             &-JVS(1822)*X(153)-JVS(1823)*X(154)-JVS(1824)*X(159)-JVS(1825)*X(164)-JVS(1826)*X(165)-JVS(1827)*X(166)&
             &-JVS(1828)*X(167)-JVS(1829)*X(170)-JVS(1830)*X(176)-JVS(1831)*X(177)-JVS(1832)*X(180)-JVS(1833)*X(183)&
             &-JVS(1834)*X(186)-JVS(1835)*X(191)-JVS(1836)*X(192)-JVS(1837)*X(193)-JVS(1838)*X(194)-JVS(1839)*X(195)
  X(199) = X(199)-JVS(1865)*X(163)
  X(200) = X(200)-JVS(1874)*X(94)-JVS(1875)*X(117)-JVS(1876)*X(157)-JVS(1877)*X(158)-JVS(1878)*X(172)-JVS(1879)*X(174)&
             &-JVS(1880)*X(178)-JVS(1881)*X(181)-JVS(1882)*X(199)
  X(201) = X(201)-JVS(1903)*X(114)-JVS(1904)*X(119)-JVS(1905)*X(134)-JVS(1906)*X(150)-JVS(1907)*X(154)-JVS(1908)*X(164)&
             &-JVS(1909)*X(177)-JVS(1910)*X(180)-JVS(1911)*X(183)-JVS(1912)*X(195)
  X(202) = X(202)-JVS(1931)*X(95)-JVS(1932)*X(126)-JVS(1933)*X(177)-JVS(1934)*X(186)
  X(203) = X(203)-JVS(1947)*X(119)-JVS(1948)*X(126)-JVS(1949)*X(134)-JVS(1950)*X(135)-JVS(1951)*X(136)-JVS(1952)*X(145)&
             &-JVS(1953)*X(146)-JVS(1954)*X(147)-JVS(1955)*X(149)-JVS(1956)*X(154)-JVS(1957)*X(177)-JVS(1958)*X(180)&
             &-JVS(1959)*X(186)-JVS(1960)*X(195)
  X(204) = X(204)-JVS(1973)*X(116)-JVS(1974)*X(119)-JVS(1975)*X(134)-JVS(1976)*X(135)-JVS(1977)*X(136)-JVS(1978)*X(154)&
             &-JVS(1979)*X(177)-JVS(1980)*X(180)-JVS(1981)*X(186)-JVS(1982)*X(195)-JVS(1983)*X(203)
  X(205) = X(205)-JVS(1995)*X(124)-JVS(1996)*X(126)-JVS(1997)*X(138)-JVS(1998)*X(183)
  X(206) = X(206)-JVS(2009)*X(126)-JVS(2010)*X(128)-JVS(2011)*X(133)-JVS(2012)*X(183)-JVS(2013)*X(205)
  X(207) = X(207)-JVS(2023)*X(90)-JVS(2024)*X(100)-JVS(2025)*X(111)-JVS(2026)*X(124)-JVS(2027)*X(138)-JVS(2028)*X(145)&
             &-JVS(2029)*X(150)-JVS(2030)*X(183)-JVS(2031)*X(204)-JVS(2032)*X(205)-JVS(2033)*X(206)
  X(208) = X(208)-JVS(2045)*X(121)-JVS(2046)*X(122)
  X(209) = X(209)-JVS(2055)*X(161)-JVS(2056)*X(165)-JVS(2057)*X(183)-JVS(2058)*X(202)-JVS(2059)*X(203)-JVS(2060)*X(204)&
             &-JVS(2061)*X(205)-JVS(2062)*X(206)
  X(210) = X(210)-JVS(2076)*X(84)-JVS(2077)*X(103)-JVS(2078)*X(105)-JVS(2079)*X(108)-JVS(2080)*X(113)-JVS(2081)*X(120)&
             &-JVS(2082)*X(132)-JVS(2083)*X(134)-JVS(2084)*X(135)-JVS(2085)*X(142)-JVS(2086)*X(144)-JVS(2087)*X(146)&
             &-JVS(2088)*X(147)-JVS(2089)*X(149)-JVS(2090)*X(150)-JVS(2091)*X(151)-JVS(2092)*X(156)-JVS(2093)*X(161)&
             &-JVS(2094)*X(162)-JVS(2095)*X(165)-JVS(2096)*X(166)-JVS(2097)*X(170)-JVS(2098)*X(173)-JVS(2099)*X(177)&
             &-JVS(2100)*X(180)-JVS(2101)*X(183)-JVS(2102)*X(184)-JVS(2103)*X(185)-JVS(2104)*X(186)-JVS(2105)*X(188)&
             &-JVS(2106)*X(191)-JVS(2107)*X(192)-JVS(2108)*X(193)-JVS(2109)*X(195)-JVS(2110)*X(202)-JVS(2111)*X(203)&
             &-JVS(2112)*X(204)-JVS(2113)*X(205)-JVS(2114)*X(206)-JVS(2115)*X(208)-JVS(2116)*X(209)
  X(211) = X(211)-JVS(2133)*X(91)-JVS(2134)*X(102)-JVS(2135)*X(112)-JVS(2136)*X(128)-JVS(2137)*X(133)-JVS(2138)*X(141)&
             &-JVS(2139)*X(145)-JVS(2140)*X(151)-JVS(2141)*X(183)-JVS(2142)*X(188)-JVS(2143)*X(204)-JVS(2144)*X(205)&
             &-JVS(2145)*X(206)
  X(212) = X(212)-JVS(2157)*X(126)-JVS(2158)*X(183)
  X(213) = X(213)-JVS(2169)*X(145)-JVS(2170)*X(183)-JVS(2171)*X(212)
  X(214) = X(214)-JVS(2181)*X(152)-JVS(2182)*X(154)-JVS(2183)*X(180)-JVS(2184)*X(181)-JVS(2185)*X(183)-JVS(2186)*X(193)&
             &-JVS(2187)*X(199)-JVS(2188)*X(202)-JVS(2189)*X(203)-JVS(2190)*X(204)-JVS(2191)*X(205)-JVS(2192)*X(206)&
             &-JVS(2193)*X(208)-JVS(2194)*X(211)-JVS(2195)*X(212)-JVS(2196)*X(213)
  X(215) = X(215)-JVS(2211)*X(121)-JVS(2212)*X(122)-JVS(2213)*X(141)-JVS(2214)*X(189)-JVS(2215)*X(199)-JVS(2216)*X(208)
  X(216) = X(216)-JVS(2226)*X(68)-JVS(2227)*X(83)-JVS(2228)*X(89)-JVS(2229)*X(188)-JVS(2230)*X(199)-JVS(2231)*X(208)&
             &-JVS(2232)*X(215)
  X(217) = X(217)-JVS(2242)*X(82)-JVS(2243)*X(141)-JVS(2244)*X(163)-JVS(2245)*X(175)-JVS(2246)*X(189)-JVS(2247)*X(196)&
             &-JVS(2248)*X(199)-JVS(2249)*X(208)-JVS(2250)*X(215)-JVS(2251)*X(216)
  X(218) = X(218)-JVS(2266)*X(55)-JVS(2267)*X(59)-JVS(2268)*X(75)-JVS(2269)*X(83)-JVS(2270)*X(93)-JVS(2271)*X(94)&
             &-JVS(2272)*X(96)-JVS(2273)*X(107)-JVS(2274)*X(117)-JVS(2275)*X(127)-JVS(2276)*X(131)-JVS(2277)*X(141)&
             &-JVS(2278)*X(155)-JVS(2279)*X(157)-JVS(2280)*X(158)-JVS(2281)*X(160)-JVS(2282)*X(167)-JVS(2283)*X(169)&
             &-JVS(2284)*X(170)-JVS(2285)*X(172)-JVS(2286)*X(173)-JVS(2287)*X(174)-JVS(2288)*X(175)-JVS(2289)*X(178)&
             &-JVS(2290)*X(181)-JVS(2291)*X(182)-JVS(2292)*X(183)-JVS(2293)*X(185)-JVS(2294)*X(188)-JVS(2295)*X(190)&
             &-JVS(2296)*X(197)-JVS(2297)*X(199)-JVS(2298)*X(200)-JVS(2299)*X(201)-JVS(2300)*X(202)-JVS(2301)*X(203)&
             &-JVS(2302)*X(204)-JVS(2303)*X(205)-JVS(2304)*X(206)-JVS(2305)*X(207)-JVS(2306)*X(208)-JVS(2307)*X(209)&
             &-JVS(2308)*X(210)-JVS(2309)*X(211)-JVS(2310)*X(212)-JVS(2311)*X(213)-JVS(2312)*X(214)-JVS(2313)*X(215)&
             &-JVS(2314)*X(216)-JVS(2315)*X(217)
  X(219) = X(219)-JVS(2335)*X(141)-JVS(2336)*X(188)-JVS(2337)*X(207)-JVS(2338)*X(212)-JVS(2339)*X(213)
  X(220) = X(220)-JVS(2350)*X(39)-JVS(2351)*X(43)-JVS(2352)*X(51)-JVS(2353)*X(58)-JVS(2354)*X(65)-JVS(2355)*X(72)&
             &-JVS(2356)*X(74)-JVS(2357)*X(84)-JVS(2358)*X(96)-JVS(2359)*X(99)-JVS(2360)*X(108)-JVS(2361)*X(111)-JVS(2362)&
             &*X(112)-JVS(2363)*X(119)-JVS(2364)*X(124)-JVS(2365)*X(128)-JVS(2366)*X(133)-JVS(2367)*X(134)-JVS(2368)*X(135)&
             &-JVS(2369)*X(136)-JVS(2370)*X(137)-JVS(2371)*X(138)-JVS(2372)*X(139)-JVS(2373)*X(141)-JVS(2374)*X(142)&
             &-JVS(2375)*X(145)-JVS(2376)*X(146)-JVS(2377)*X(147)-JVS(2378)*X(150)-JVS(2379)*X(151)-JVS(2380)*X(152)&
             &-JVS(2381)*X(154)-JVS(2382)*X(156)-JVS(2383)*X(159)-JVS(2384)*X(164)-JVS(2385)*X(165)-JVS(2386)*X(166)&
             &-JVS(2387)*X(167)-JVS(2388)*X(168)-JVS(2389)*X(169)-JVS(2390)*X(170)-JVS(2391)*X(173)-JVS(2392)*X(175)&
             &-JVS(2393)*X(177)-JVS(2394)*X(179)-JVS(2395)*X(180)-JVS(2396)*X(182)-JVS(2397)*X(183)-JVS(2398)*X(184)&
             &-JVS(2399)*X(185)-JVS(2400)*X(186)-JVS(2401)*X(188)-JVS(2402)*X(190)-JVS(2403)*X(191)-JVS(2404)*X(192)&
             &-JVS(2405)*X(193)-JVS(2406)*X(194)-JVS(2407)*X(195)-JVS(2408)*X(197)-JVS(2409)*X(199)-JVS(2410)*X(201)&
             &-JVS(2411)*X(202)-JVS(2412)*X(203)-JVS(2413)*X(204)-JVS(2414)*X(205)-JVS(2415)*X(206)-JVS(2416)*X(207)&
             &-JVS(2417)*X(208)-JVS(2418)*X(209)-JVS(2419)*X(210)-JVS(2420)*X(211)-JVS(2421)*X(212)-JVS(2422)*X(213)&
             &-JVS(2423)*X(214)-JVS(2424)*X(215)-JVS(2425)*X(216)-JVS(2426)*X(217)-JVS(2427)*X(219)
  X(221) = X(221)-JVS(2445)*X(57)-JVS(2446)*X(78)-JVS(2447)*X(81)-JVS(2448)*X(157)-JVS(2449)*X(172)-JVS(2450)*X(174)&
             &-JVS(2451)*X(175)-JVS(2452)*X(178)-JVS(2453)*X(200)-JVS(2454)*X(208)-JVS(2455)*X(215)-JVS(2456)*X(216)&
             &-JVS(2457)*X(217)-JVS(2458)*X(218)-JVS(2459)*X(219)-JVS(2460)*X(220)
  X(222) = X(222)-JVS(2477)*X(55)-JVS(2478)*X(59)-JVS(2479)*X(75)-JVS(2480)*X(80)-JVS(2481)*X(97)-JVS(2482)*X(100)&
             &-JVS(2483)*X(102)-JVS(2484)*X(103)-JVS(2485)*X(108)-JVS(2486)*X(118)-JVS(2487)*X(120)-JVS(2488)*X(121)&
             &-JVS(2489)*X(122)-JVS(2490)*X(123)-JVS(2491)*X(124)-JVS(2492)*X(128)-JVS(2493)*X(129)-JVS(2494)*X(133)&
             &-JVS(2495)*X(137)-JVS(2496)*X(138)-JVS(2497)*X(139)-JVS(2498)*X(141)-JVS(2499)*X(142)-JVS(2500)*X(143)&
             &-JVS(2501)*X(146)-JVS(2502)*X(148)-JVS(2503)*X(150)-JVS(2504)*X(151)-JVS(2505)*X(153)-JVS(2506)*X(154)&
             &-JVS(2507)*X(156)-JVS(2508)*X(161)-JVS(2509)*X(164)-JVS(2510)*X(165)-JVS(2511)*X(166)-JVS(2512)*X(168)&
             &-JVS(2513)*X(169)-JVS(2514)*X(170)-JVS(2515)*X(176)-JVS(2516)*X(177)-JVS(2517)*X(179)-JVS(2518)*X(180)&
             &-JVS(2519)*X(181)-JVS(2520)*X(183)-JVS(2521)*X(186)-JVS(2522)*X(190)-JVS(2523)*X(191)-JVS(2524)*X(192)&
             &-JVS(2525)*X(193)-JVS(2526)*X(194)-JVS(2527)*X(195)-JVS(2528)*X(196)-JVS(2529)*X(197)-JVS(2530)*X(198)&
             &-JVS(2531)*X(199)-JVS(2532)*X(201)-JVS(2533)*X(202)-JVS(2534)*X(203)-JVS(2535)*X(204)-JVS(2536)*X(205)&
             &-JVS(2537)*X(206)-JVS(2538)*X(207)-JVS(2539)*X(208)-JVS(2540)*X(209)-JVS(2541)*X(210)-JVS(2542)*X(211)&
             &-JVS(2543)*X(212)-JVS(2544)*X(213)-JVS(2545)*X(214)-JVS(2546)*X(215)-JVS(2547)*X(216)-JVS(2548)*X(219)&
             &-JVS(2549)*X(220)-JVS(2550)*X(221)
  X(223) = X(223)-JVS(2566)*X(63)-JVS(2567)*X(71)-JVS(2568)*X(82)-JVS(2569)*X(84)-JVS(2570)*X(99)-JVS(2571)*X(107)&
             &-JVS(2572)*X(163)-JVS(2573)*X(167)-JVS(2574)*X(169)-JVS(2575)*X(173)-JVS(2576)*X(175)-JVS(2577)*X(190)&
             &-JVS(2578)*X(199)-JVS(2579)*X(207)-JVS(2580)*X(211)-JVS(2581)*X(212)-JVS(2582)*X(213)-JVS(2583)*X(215)&
             &-JVS(2584)*X(216)-JVS(2585)*X(217)-JVS(2586)*X(219)-JVS(2587)*X(222)
  X(224) = X(224)-JVS(2602)*X(4)-JVS(2603)*X(5)-JVS(2604)*X(42)-JVS(2605)*X(44)-JVS(2606)*X(52)-JVS(2607)*X(58)&
             &-JVS(2608)*X(61)-JVS(2609)*X(62)-JVS(2610)*X(63)-JVS(2611)*X(64)-JVS(2612)*X(65)-JVS(2613)*X(66)-JVS(2614)&
             &*X(67)-JVS(2615)*X(73)-JVS(2616)*X(77)-JVS(2617)*X(85)-JVS(2618)*X(90)-JVS(2619)*X(91)-JVS(2620)*X(93)&
             &-JVS(2621)*X(105)-JVS(2622)*X(111)-JVS(2623)*X(112)-JVS(2624)*X(114)-JVS(2625)*X(115)-JVS(2626)*X(116)&
             &-JVS(2627)*X(118)-JVS(2628)*X(119)-JVS(2629)*X(120)-JVS(2630)*X(126)-JVS(2631)*X(127)-JVS(2632)*X(130)&
             &-JVS(2633)*X(134)-JVS(2634)*X(135)-JVS(2635)*X(136)-JVS(2636)*X(140)-JVS(2637)*X(144)-JVS(2638)*X(145)&
             &-JVS(2639)*X(146)-JVS(2640)*X(147)-JVS(2641)*X(149)-JVS(2642)*X(150)-JVS(2643)*X(151)-JVS(2644)*X(154)&
             &-JVS(2645)*X(156)-JVS(2646)*X(159)-JVS(2647)*X(161)-JVS(2648)*X(162)-JVS(2649)*X(163)-JVS(2650)*X(164)&
             &-JVS(2651)*X(165)-JVS(2652)*X(167)-JVS(2653)*X(168)-JVS(2654)*X(169)-JVS(2655)*X(170)-JVS(2656)*X(171)&
             &-JVS(2657)*X(172)-JVS(2658)*X(173)-JVS(2659)*X(174)-JVS(2660)*X(175)-JVS(2661)*X(176)-JVS(2662)*X(177)&
             &-JVS(2663)*X(178)-JVS(2664)*X(180)-JVS(2665)*X(183)-JVS(2666)*X(184)-JVS(2667)*X(185)-JVS(2668)*X(186)&
             &-JVS(2669)*X(187)-JVS(2670)*X(188)-JVS(2671)*X(189)-JVS(2672)*X(190)-JVS(2673)*X(191)-JVS(2674)*X(192)&
             &-JVS(2675)*X(194)-JVS(2676)*X(195)-JVS(2677)*X(196)-JVS(2678)*X(197)-JVS(2679)*X(198)-JVS(2680)*X(199)&
             &-JVS(2681)*X(200)-JVS(2682)*X(201)-JVS(2683)*X(202)-JVS(2684)*X(203)-JVS(2685)*X(204)-JVS(2686)*X(205)&
             &-JVS(2687)*X(206)-JVS(2688)*X(207)-JVS(2689)*X(208)-JVS(2690)*X(209)-JVS(2691)*X(210)-JVS(2692)*X(211)&
             &-JVS(2693)*X(212)-JVS(2694)*X(213)-JVS(2695)*X(214)-JVS(2696)*X(215)-JVS(2697)*X(216)-JVS(2698)*X(217)&
             &-JVS(2699)*X(218)-JVS(2700)*X(219)-JVS(2701)*X(220)-JVS(2702)*X(221)-JVS(2703)*X(222)-JVS(2704)*X(223)
  X(225) = X(225)-JVS(2718)*X(52)-JVS(2719)*X(54)-JVS(2720)*X(60)-JVS(2721)*X(79)-JVS(2722)*X(108)-JVS(2723)*X(120)&
             &-JVS(2724)*X(123)-JVS(2725)*X(129)-JVS(2726)*X(137)-JVS(2727)*X(138)-JVS(2728)*X(148)-JVS(2729)*X(150)&
             &-JVS(2730)*X(151)-JVS(2731)*X(152)-JVS(2732)*X(154)-JVS(2733)*X(156)-JVS(2734)*X(159)-JVS(2735)*X(164)&
             &-JVS(2736)*X(166)-JVS(2737)*X(167)-JVS(2738)*X(168)-JVS(2739)*X(170)-JVS(2740)*X(173)-JVS(2741)*X(175)&
             &-JVS(2742)*X(177)-JVS(2743)*X(180)-JVS(2744)*X(181)-JVS(2745)*X(183)-JVS(2746)*X(184)-JVS(2747)*X(185)&
             &-JVS(2748)*X(186)-JVS(2749)*X(188)-JVS(2750)*X(189)-JVS(2751)*X(191)-JVS(2752)*X(192)-JVS(2753)*X(193)&
             &-JVS(2754)*X(194)-JVS(2755)*X(195)-JVS(2756)*X(198)-JVS(2757)*X(199)-JVS(2758)*X(201)-JVS(2759)*X(202)&
             &-JVS(2760)*X(203)-JVS(2761)*X(204)-JVS(2762)*X(205)-JVS(2763)*X(206)-JVS(2764)*X(207)-JVS(2765)*X(208)&
             &-JVS(2766)*X(209)-JVS(2767)*X(210)-JVS(2768)*X(211)-JVS(2769)*X(212)-JVS(2770)*X(213)-JVS(2771)*X(214)&
             &-JVS(2772)*X(215)-JVS(2773)*X(216)-JVS(2774)*X(217)-JVS(2775)*X(219)-JVS(2776)*X(223)-JVS(2777)*X(224)
  X(226) = X(226)-JVS(2790)*X(3)-JVS(2791)*X(55)-JVS(2792)*X(56)-JVS(2793)*X(57)-JVS(2794)*X(59)-JVS(2795)*X(73)&
             &-JVS(2796)*X(75)-JVS(2797)*X(77)-JVS(2798)*X(78)-JVS(2799)*X(83)-JVS(2800)*X(88)-JVS(2801)*X(92)-JVS(2802)&
             &*X(93)-JVS(2803)*X(94)-JVS(2804)*X(96)-JVS(2805)*X(98)-JVS(2806)*X(107)-JVS(2807)*X(109)-JVS(2808)*X(110)&
             &-JVS(2809)*X(117)-JVS(2810)*X(127)-JVS(2811)*X(130)-JVS(2812)*X(131)-JVS(2813)*X(140)-JVS(2814)*X(141)&
             &-JVS(2815)*X(155)-JVS(2816)*X(157)-JVS(2817)*X(158)-JVS(2818)*X(160)-JVS(2819)*X(167)-JVS(2820)*X(169)&
             &-JVS(2821)*X(170)-JVS(2822)*X(171)-JVS(2823)*X(172)-JVS(2824)*X(173)-JVS(2825)*X(174)-JVS(2826)*X(175)&
             &-JVS(2827)*X(178)-JVS(2828)*X(181)-JVS(2829)*X(182)-JVS(2830)*X(183)-JVS(2831)*X(185)-JVS(2832)*X(188)&
             &-JVS(2833)*X(190)-JVS(2834)*X(197)-JVS(2835)*X(199)-JVS(2836)*X(200)-JVS(2837)*X(201)-JVS(2838)*X(202)&
             &-JVS(2839)*X(203)-JVS(2840)*X(204)-JVS(2841)*X(205)-JVS(2842)*X(206)-JVS(2843)*X(207)-JVS(2844)*X(208)&
             &-JVS(2845)*X(209)-JVS(2846)*X(210)-JVS(2847)*X(211)-JVS(2848)*X(212)-JVS(2849)*X(213)-JVS(2850)*X(214)&
             &-JVS(2851)*X(215)-JVS(2852)*X(216)-JVS(2853)*X(217)-JVS(2854)*X(218)-JVS(2855)*X(219)-JVS(2856)*X(220)&
             &-JVS(2857)*X(221)-JVS(2858)*X(222)-JVS(2859)*X(223)-JVS(2860)*X(224)-JVS(2861)*X(225)
  X(227) = X(227)-JVS(2873)*X(52)-JVS(2874)*X(58)-JVS(2875)*X(62)-JVS(2876)*X(72)-JVS(2877)*X(74)-JVS(2878)*X(83)&
             &-JVS(2879)*X(93)-JVS(2880)*X(105)-JVS(2881)*X(117)-JVS(2882)*X(120)-JVS(2883)*X(121)-JVS(2884)*X(122)&
             &-JVS(2885)*X(127)-JVS(2886)*X(130)-JVS(2887)*X(140)-JVS(2888)*X(141)-JVS(2889)*X(144)-JVS(2890)*X(162)&
             &-JVS(2891)*X(168)-JVS(2892)*X(169)-JVS(2893)*X(170)-JVS(2894)*X(171)-JVS(2895)*X(172)-JVS(2896)*X(174)&
             &-JVS(2897)*X(177)-JVS(2898)*X(178)-JVS(2899)*X(179)-JVS(2900)*X(180)-JVS(2901)*X(183)-JVS(2902)*X(184)&
             &-JVS(2903)*X(185)-JVS(2904)*X(186)-JVS(2905)*X(187)-JVS(2906)*X(188)-JVS(2907)*X(189)-JVS(2908)*X(190)&
             &-JVS(2909)*X(191)-JVS(2910)*X(192)-JVS(2911)*X(194)-JVS(2912)*X(195)-JVS(2913)*X(196)-JVS(2914)*X(197)&
             &-JVS(2915)*X(198)-JVS(2916)*X(199)-JVS(2917)*X(200)-JVS(2918)*X(201)-JVS(2919)*X(202)-JVS(2920)*X(203)&
             &-JVS(2921)*X(204)-JVS(2922)*X(205)-JVS(2923)*X(206)-JVS(2924)*X(207)-JVS(2925)*X(208)-JVS(2926)*X(209)&
             &-JVS(2927)*X(210)-JVS(2928)*X(211)-JVS(2929)*X(212)-JVS(2930)*X(213)-JVS(2931)*X(214)-JVS(2932)*X(215)&
             &-JVS(2933)*X(216)-JVS(2934)*X(218)-JVS(2935)*X(219)-JVS(2936)*X(220)-JVS(2937)*X(221)-JVS(2938)*X(222)&
             &-JVS(2939)*X(223)-JVS(2940)*X(224)-JVS(2941)*X(225)-JVS(2942)*X(226)
  X(228) = X(228)-JVS(2953)*X(69)-JVS(2954)*X(94)-JVS(2955)*X(163)-JVS(2956)*X(189)-JVS(2957)*X(196)-JVS(2958)*X(199)&
             &-JVS(2959)*X(208)-JVS(2960)*X(215)-JVS(2961)*X(216)-JVS(2962)*X(219)-JVS(2963)*X(225)-JVS(2964)*X(226)&
             &-JVS(2965)*X(227)
  X(229) = X(229)-JVS(2975)*X(70)-JVS(2976)*X(94)-JVS(2977)*X(163)-JVS(2978)*X(189)-JVS(2979)*X(196)-JVS(2980)*X(199)&
             &-JVS(2981)*X(208)-JVS(2982)*X(215)-JVS(2983)*X(216)-JVS(2984)*X(219)-JVS(2985)*X(225)-JVS(2986)*X(226)&
             &-JVS(2987)*X(227)-JVS(2988)*X(228)
  X(230) = X(230)-JVS(2997)*X(35)-JVS(2998)*X(36)-JVS(2999)*X(40)-JVS(3000)*X(45)-JVS(3001)*X(46)-JVS(3002)*X(51)&
             &-JVS(3003)*X(54)-JVS(3004)*X(55)-JVS(3005)*X(57)-JVS(3006)*X(59)-JVS(3007)*X(60)-JVS(3008)*X(61)-JVS(3009)&
             &*X(62)-JVS(3010)*X(63)-JVS(3011)*X(64)-JVS(3012)*X(65)-JVS(3013)*X(66)-JVS(3014)*X(68)-JVS(3015)*X(69)&
             &-JVS(3016)*X(70)-JVS(3017)*X(71)-JVS(3018)*X(73)-JVS(3019)*X(74)-JVS(3020)*X(75)-JVS(3021)*X(77)-JVS(3022)&
             &*X(79)-JVS(3023)*X(80)-JVS(3024)*X(81)-JVS(3025)*X(82)-JVS(3026)*X(83)-JVS(3027)*X(84)-JVS(3028)*X(85)&
             &-JVS(3029)*X(86)-JVS(3030)*X(87)-JVS(3031)*X(88)-JVS(3032)*X(89)-JVS(3033)*X(90)-JVS(3034)*X(91)-JVS(3035)&
             &*X(93)-JVS(3036)*X(94)-JVS(3037)*X(96)-JVS(3038)*X(97)-JVS(3039)*X(98)-JVS(3040)*X(99)-JVS(3041)*X(100)&
             &-JVS(3042)*X(101)-JVS(3043)*X(102)-JVS(3044)*X(103)-JVS(3045)*X(104)-JVS(3046)*X(105)-JVS(3047)*X(106)&
             &-JVS(3048)*X(107)-JVS(3049)*X(108)-JVS(3050)*X(109)-JVS(3051)*X(110)-JVS(3052)*X(111)-JVS(3053)*X(112)&
             &-JVS(3054)*X(113)-JVS(3055)*X(114)-JVS(3056)*X(115)-JVS(3057)*X(116)-JVS(3058)*X(117)-JVS(3059)*X(118)&
             &-JVS(3060)*X(119)-JVS(3061)*X(120)-JVS(3062)*X(121)-JVS(3063)*X(122)-JVS(3064)*X(123)-JVS(3065)*X(124)&
             &-JVS(3066)*X(125)-JVS(3067)*X(126)-JVS(3068)*X(127)-JVS(3069)*X(128)-JVS(3070)*X(129)-JVS(3071)*X(131)&
             &-JVS(3072)*X(132)-JVS(3073)*X(133)-JVS(3074)*X(134)-JVS(3075)*X(135)-JVS(3076)*X(136)-JVS(3077)*X(137)&
             &-JVS(3078)*X(138)-JVS(3079)*X(139)-JVS(3080)*X(140)-JVS(3081)*X(141)-JVS(3082)*X(143)-JVS(3083)*X(144)&
             &-JVS(3084)*X(145)-JVS(3085)*X(146)-JVS(3086)*X(147)-JVS(3087)*X(149)-JVS(3088)*X(150)-JVS(3089)*X(151)&
             &-JVS(3090)*X(152)-JVS(3091)*X(153)-JVS(3092)*X(154)-JVS(3093)*X(155)-JVS(3094)*X(156)-JVS(3095)*X(157)&
             &-JVS(3096)*X(158)-JVS(3097)*X(159)-JVS(3098)*X(160)-JVS(3099)*X(161)-JVS(3100)*X(162)-JVS(3101)*X(163)&
             &-JVS(3102)*X(164)-JVS(3103)*X(165)-JVS(3104)*X(166)-JVS(3105)*X(167)-JVS(3106)*X(168)-JVS(3107)*X(169)&
             &-JVS(3108)*X(170)-JVS(3109)*X(171)-JVS(3110)*X(172)-JVS(3111)*X(173)-JVS(3112)*X(174)-JVS(3113)*X(175)&
             &-JVS(3114)*X(176)-JVS(3115)*X(177)-JVS(3116)*X(178)-JVS(3117)*X(179)-JVS(3118)*X(180)-JVS(3119)*X(181)&
             &-JVS(3120)*X(182)-JVS(3121)*X(183)-JVS(3122)*X(184)-JVS(3123)*X(185)-JVS(3124)*X(186)-JVS(3125)*X(187)&
             &-JVS(3126)*X(188)-JVS(3127)*X(189)-JVS(3128)*X(190)-JVS(3129)*X(191)-JVS(3130)*X(192)-JVS(3131)*X(193)&
             &-JVS(3132)*X(194)-JVS(3133)*X(195)-JVS(3134)*X(196)-JVS(3135)*X(197)-JVS(3136)*X(198)-JVS(3137)*X(199)&
             &-JVS(3138)*X(200)-JVS(3139)*X(201)-JVS(3140)*X(202)-JVS(3141)*X(203)-JVS(3142)*X(204)-JVS(3143)*X(205)&
             &-JVS(3144)*X(206)-JVS(3145)*X(207)-JVS(3146)*X(208)-JVS(3147)*X(209)-JVS(3148)*X(210)-JVS(3149)*X(211)&
             &-JVS(3150)*X(212)-JVS(3151)*X(213)-JVS(3152)*X(214)-JVS(3153)*X(215)-JVS(3154)*X(216)-JVS(3155)*X(217)&
             &-JVS(3156)*X(218)-JVS(3157)*X(219)-JVS(3158)*X(220)-JVS(3159)*X(221)-JVS(3160)*X(222)-JVS(3161)*X(223)&
             &-JVS(3162)*X(224)-JVS(3163)*X(225)-JVS(3164)*X(226)-JVS(3165)*X(227)-JVS(3166)*X(228)-JVS(3167)*X(229)
  X(231) = X(231)-JVS(3175)*X(45)-JVS(3176)*X(49)-JVS(3177)*X(50)-JVS(3178)*X(51)-JVS(3179)*X(53)-JVS(3180)*X(55)&
             &-JVS(3181)*X(58)-JVS(3182)*X(59)-JVS(3183)*X(62)-JVS(3184)*X(63)-JVS(3185)*X(64)-JVS(3186)*X(65)-JVS(3187)&
             &*X(66)-JVS(3188)*X(68)-JVS(3189)*X(69)-JVS(3190)*X(70)-JVS(3191)*X(71)-JVS(3192)*X(72)-JVS(3193)*X(75)&
             &-JVS(3194)*X(79)-JVS(3195)*X(80)-JVS(3196)*X(82)-JVS(3197)*X(84)-JVS(3198)*X(85)-JVS(3199)*X(86)-JVS(3200)&
             &*X(87)-JVS(3201)*X(89)-JVS(3202)*X(90)-JVS(3203)*X(91)-JVS(3204)*X(95)-JVS(3205)*X(96)-JVS(3206)*X(97)&
             &-JVS(3207)*X(99)-JVS(3208)*X(100)-JVS(3209)*X(102)-JVS(3210)*X(103)-JVS(3211)*X(104)-JVS(3212)*X(106)&
             &-JVS(3213)*X(107)-JVS(3214)*X(111)-JVS(3215)*X(112)-JVS(3216)*X(113)-JVS(3217)*X(114)-JVS(3218)*X(115)&
             &-JVS(3219)*X(116)-JVS(3220)*X(118)-JVS(3221)*X(119)-JVS(3222)*X(121)-JVS(3223)*X(122)-JVS(3224)*X(123)&
             &-JVS(3225)*X(124)-JVS(3226)*X(125)-JVS(3227)*X(126)-JVS(3228)*X(128)-JVS(3229)*X(129)-JVS(3230)*X(131)&
             &-JVS(3231)*X(132)-JVS(3232)*X(133)-JVS(3233)*X(134)-JVS(3234)*X(135)-JVS(3235)*X(136)-JVS(3236)*X(137)&
             &-JVS(3237)*X(138)-JVS(3238)*X(139)-JVS(3239)*X(141)-JVS(3240)*X(143)-JVS(3241)*X(145)-JVS(3242)*X(146)&
             &-JVS(3243)*X(147)-JVS(3244)*X(148)-JVS(3245)*X(149)-JVS(3246)*X(150)-JVS(3247)*X(151)-JVS(3248)*X(153)&
             &-JVS(3249)*X(154)-JVS(3250)*X(156)-JVS(3251)*X(160)-JVS(3252)*X(161)-JVS(3253)*X(163)-JVS(3254)*X(164)&
             &-JVS(3255)*X(165)-JVS(3256)*X(166)-JVS(3257)*X(167)-JVS(3258)*X(168)-JVS(3259)*X(169)-JVS(3260)*X(170)&
             &-JVS(3261)*X(171)-JVS(3262)*X(173)-JVS(3263)*X(174)-JVS(3264)*X(175)-JVS(3265)*X(176)-JVS(3266)*X(177)&
             &-JVS(3267)*X(178)-JVS(3268)*X(179)-JVS(3269)*X(180)-JVS(3270)*X(182)-JVS(3271)*X(183)-JVS(3272)*X(184)&
             &-JVS(3273)*X(185)-JVS(3274)*X(186)-JVS(3275)*X(188)-JVS(3276)*X(190)-JVS(3277)*X(191)-JVS(3278)*X(192)&
             &-JVS(3279)*X(193)-JVS(3280)*X(194)-JVS(3281)*X(195)-JVS(3282)*X(196)-JVS(3283)*X(197)-JVS(3284)*X(198)&
             &-JVS(3285)*X(199)-JVS(3286)*X(201)-JVS(3287)*X(202)-JVS(3288)*X(203)-JVS(3289)*X(204)-JVS(3290)*X(205)&
             &-JVS(3291)*X(206)-JVS(3292)*X(207)-JVS(3293)*X(208)-JVS(3294)*X(209)-JVS(3295)*X(210)-JVS(3296)*X(211)&
             &-JVS(3297)*X(212)-JVS(3298)*X(213)-JVS(3299)*X(214)-JVS(3300)*X(215)-JVS(3301)*X(216)-JVS(3302)*X(217)&
             &-JVS(3303)*X(218)-JVS(3304)*X(219)-JVS(3305)*X(220)-JVS(3306)*X(221)-JVS(3307)*X(222)-JVS(3308)*X(223)&
             &-JVS(3309)*X(224)-JVS(3310)*X(225)-JVS(3311)*X(226)-JVS(3312)*X(227)-JVS(3313)*X(228)-JVS(3314)*X(229)&
             &-JVS(3315)*X(230)
  X(232) = X(232)-JVS(3322)*X(2)-JVS(3323)*X(35)-JVS(3324)*X(36)-JVS(3325)*X(44)-JVS(3326)*X(45)-JVS(3327)*X(47)&
             &-JVS(3328)*X(77)-JVS(3329)*X(88)-JVS(3330)*X(92)-JVS(3331)*X(94)-JVS(3332)*X(101)-JVS(3333)*X(109)-JVS(3334)&
             &*X(110)-JVS(3335)*X(117)-JVS(3336)*X(127)-JVS(3337)*X(130)-JVS(3338)*X(140)-JVS(3339)*X(157)-JVS(3340)*X(158)&
             &-JVS(3341)*X(171)-JVS(3342)*X(172)-JVS(3343)*X(174)-JVS(3344)*X(178)-JVS(3345)*X(181)-JVS(3346)*X(199)&
             &-JVS(3347)*X(200)-JVS(3348)*X(208)-JVS(3349)*X(215)-JVS(3350)*X(216)-JVS(3351)*X(218)-JVS(3352)*X(219)&
             &-JVS(3353)*X(220)-JVS(3354)*X(221)-JVS(3355)*X(222)-JVS(3356)*X(223)-JVS(3357)*X(224)-JVS(3358)*X(225)&
             &-JVS(3359)*X(226)-JVS(3360)*X(227)-JVS(3361)*X(228)-JVS(3362)*X(229)-JVS(3363)*X(230)-JVS(3364)*X(231)
  X(233) = X(233)-JVS(3370)*X(81)-JVS(3371)*X(109)-JVS(3372)*X(110)-JVS(3373)*X(121)-JVS(3374)*X(122)-JVS(3375)*X(141)&
             &-JVS(3376)*X(158)-JVS(3377)*X(162)-JVS(3378)*X(170)-JVS(3379)*X(171)-JVS(3380)*X(172)-JVS(3381)*X(174)&
             &-JVS(3382)*X(178)-JVS(3383)*X(183)-JVS(3384)*X(184)-JVS(3385)*X(185)-JVS(3386)*X(188)-JVS(3387)*X(190)&
             &-JVS(3388)*X(200)-JVS(3389)*X(207)-JVS(3390)*X(208)-JVS(3391)*X(209)-JVS(3392)*X(211)-JVS(3393)*X(212)&
             &-JVS(3394)*X(213)-JVS(3395)*X(215)-JVS(3396)*X(216)-JVS(3397)*X(218)-JVS(3398)*X(219)-JVS(3399)*X(220)&
             &-JVS(3400)*X(221)-JVS(3401)*X(222)-JVS(3402)*X(223)-JVS(3403)*X(224)-JVS(3404)*X(225)-JVS(3405)*X(226)&
             &-JVS(3406)*X(227)-JVS(3407)*X(228)-JVS(3408)*X(229)-JVS(3409)*X(230)-JVS(3410)*X(231)-JVS(3411)*X(232)
  X(234) = X(234)-JVS(3416)*X(48)-JVS(3417)*X(49)-JVS(3418)*X(50)-JVS(3419)*X(53)-JVS(3420)*X(61)-JVS(3421)*X(67)&
             &-JVS(3422)*X(72)-JVS(3423)*X(77)-JVS(3424)*X(90)-JVS(3425)*X(91)-JVS(3426)*X(114)-JVS(3427)*X(115)-JVS(3428)&
             &*X(116)-JVS(3429)*X(118)-JVS(3430)*X(119)-JVS(3431)*X(134)-JVS(3432)*X(135)-JVS(3433)*X(136)-JVS(3434)*X(146)&
             &-JVS(3435)*X(147)-JVS(3436)*X(149)-JVS(3437)*X(150)-JVS(3438)*X(151)-JVS(3439)*X(154)-JVS(3440)*X(156)&
             &-JVS(3441)*X(164)-JVS(3442)*X(165)-JVS(3443)*X(167)-JVS(3444)*X(169)-JVS(3445)*X(170)-JVS(3446)*X(171)&
             &-JVS(3447)*X(173)-JVS(3448)*X(174)-JVS(3449)*X(175)-JVS(3450)*X(177)-JVS(3451)*X(178)-JVS(3452)*X(180)&
             &-JVS(3453)*X(183)-JVS(3454)*X(184)-JVS(3455)*X(185)-JVS(3456)*X(186)-JVS(3457)*X(188)-JVS(3458)*X(190)&
             &-JVS(3459)*X(191)-JVS(3460)*X(192)-JVS(3461)*X(195)-JVS(3462)*X(199)-JVS(3463)*X(202)-JVS(3464)*X(203)&
             &-JVS(3465)*X(204)-JVS(3466)*X(205)-JVS(3467)*X(206)-JVS(3468)*X(207)-JVS(3469)*X(208)-JVS(3470)*X(209)&
             &-JVS(3471)*X(211)-JVS(3472)*X(212)-JVS(3473)*X(213)-JVS(3474)*X(214)-JVS(3475)*X(215)-JVS(3476)*X(216)&
             &-JVS(3477)*X(217)-JVS(3478)*X(218)-JVS(3479)*X(219)-JVS(3480)*X(220)-JVS(3481)*X(221)-JVS(3482)*X(222)&
             &-JVS(3483)*X(223)-JVS(3484)*X(224)-JVS(3485)*X(225)-JVS(3486)*X(226)-JVS(3487)*X(227)-JVS(3488)*X(228)&
             &-JVS(3489)*X(229)-JVS(3490)*X(230)-JVS(3491)*X(231)-JVS(3492)*X(232)-JVS(3493)*X(233)
  X(235) = X(235)-JVS(3497)*X(42)-JVS(3498)*X(71)-JVS(3499)*X(189)-JVS(3500)*X(196)-JVS(3501)*X(199)-JVS(3502)*X(207)&
             &-JVS(3503)*X(208)-JVS(3504)*X(212)-JVS(3505)*X(213)-JVS(3506)*X(215)-JVS(3507)*X(216)-JVS(3508)*X(219)&
             &-JVS(3509)*X(224)-JVS(3510)*X(225)-JVS(3511)*X(226)-JVS(3512)*X(227)-JVS(3513)*X(228)-JVS(3514)*X(229)&
             &-JVS(3515)*X(230)-JVS(3516)*X(231)-JVS(3517)*X(232)-JVS(3518)*X(233)-JVS(3519)*X(234)
  X(236) = X(236)-JVS(3522)*X(40)-JVS(3523)*X(45)-JVS(3524)*X(52)-JVS(3525)*X(54)-JVS(3526)*X(58)-JVS(3527)*X(74)&
             &-JVS(3528)*X(75)-JVS(3529)*X(96)-JVS(3530)*X(108)-JVS(3531)*X(155)-JVS(3532)*X(163)-JVS(3533)*X(167)-JVS(3534)&
             &*X(169)-JVS(3535)*X(170)-JVS(3536)*X(173)-JVS(3537)*X(175)-JVS(3538)*X(181)-JVS(3539)*X(183)-JVS(3540)*X(184)&
             &-JVS(3541)*X(185)-JVS(3542)*X(188)-JVS(3543)*X(189)-JVS(3544)*X(190)-JVS(3545)*X(199)-JVS(3546)*X(205)&
             &-JVS(3547)*X(206)-JVS(3548)*X(207)-JVS(3549)*X(208)-JVS(3550)*X(209)-JVS(3551)*X(210)-JVS(3552)*X(211)&
             &-JVS(3553)*X(212)-JVS(3554)*X(213)-JVS(3555)*X(214)-JVS(3556)*X(215)-JVS(3557)*X(216)-JVS(3558)*X(217)&
             &-JVS(3559)*X(219)-JVS(3560)*X(221)-JVS(3561)*X(222)-JVS(3562)*X(223)-JVS(3563)*X(224)-JVS(3564)*X(225)&
             &-JVS(3565)*X(226)-JVS(3566)*X(227)-JVS(3567)*X(228)-JVS(3568)*X(229)-JVS(3569)*X(230)-JVS(3570)*X(231)&
             &-JVS(3571)*X(232)-JVS(3572)*X(233)-JVS(3573)*X(234)-JVS(3574)*X(235)
  X(236) = X(236)/JVS(3575)
  X(235) = (X(235)-JVS(3521)*X(236))/(JVS(3520))
  X(234) = (X(234)-JVS(3495)*X(235)-JVS(3496)*X(236))/(JVS(3494))
  X(233) = (X(233)-JVS(3413)*X(234)-JVS(3414)*X(235)-JVS(3415)*X(236))/(JVS(3412))
  X(232) = (X(232)-JVS(3366)*X(233)-JVS(3367)*X(234)-JVS(3368)*X(235)-JVS(3369)*X(236))/(JVS(3365))
  X(231) = (X(231)-JVS(3317)*X(232)-JVS(3318)*X(233)-JVS(3319)*X(234)-JVS(3320)*X(235)-JVS(3321)*X(236))/(JVS(3316))
  X(230) = (X(230)-JVS(3169)*X(231)-JVS(3170)*X(232)-JVS(3171)*X(233)-JVS(3172)*X(234)-JVS(3173)*X(235)-JVS(3174)&
             &*X(236))/(JVS(3168))
  X(229) = (X(229)-JVS(2990)*X(230)-JVS(2991)*X(231)-JVS(2992)*X(232)-JVS(2993)*X(233)-JVS(2994)*X(234)-JVS(2995)*X(235)&
             &-JVS(2996)*X(236))/(JVS(2989))
  X(228) = (X(228)-JVS(2967)*X(229)-JVS(2968)*X(230)-JVS(2969)*X(231)-JVS(2970)*X(232)-JVS(2971)*X(233)-JVS(2972)*X(234)&
             &-JVS(2973)*X(235)-JVS(2974)*X(236))/(JVS(2966))
  X(227) = (X(227)-JVS(2944)*X(228)-JVS(2945)*X(229)-JVS(2946)*X(230)-JVS(2947)*X(231)-JVS(2948)*X(232)-JVS(2949)*X(233)&
             &-JVS(2950)*X(234)-JVS(2951)*X(235)-JVS(2952)*X(236))/(JVS(2943))
  X(226) = (X(226)-JVS(2863)*X(227)-JVS(2864)*X(228)-JVS(2865)*X(229)-JVS(2866)*X(230)-JVS(2867)*X(231)-JVS(2868)*X(232)&
             &-JVS(2869)*X(233)-JVS(2870)*X(234)-JVS(2871)*X(235)-JVS(2872)*X(236))/(JVS(2862))
  X(225) = (X(225)-JVS(2779)*X(226)-JVS(2780)*X(227)-JVS(2781)*X(228)-JVS(2782)*X(229)-JVS(2783)*X(230)-JVS(2784)*X(231)&
             &-JVS(2785)*X(232)-JVS(2786)*X(233)-JVS(2787)*X(234)-JVS(2788)*X(235)-JVS(2789)*X(236))/(JVS(2778))
  X(224) = (X(224)-JVS(2706)*X(225)-JVS(2707)*X(226)-JVS(2708)*X(227)-JVS(2709)*X(228)-JVS(2710)*X(229)-JVS(2711)*X(230)&
             &-JVS(2712)*X(231)-JVS(2713)*X(232)-JVS(2714)*X(233)-JVS(2715)*X(234)-JVS(2716)*X(235)-JVS(2717)*X(236))&
             &/(JVS(2705))
  X(223) = (X(223)-JVS(2589)*X(224)-JVS(2590)*X(225)-JVS(2591)*X(226)-JVS(2592)*X(227)-JVS(2593)*X(228)-JVS(2594)*X(229)&
             &-JVS(2595)*X(230)-JVS(2596)*X(231)-JVS(2597)*X(232)-JVS(2598)*X(233)-JVS(2599)*X(234)-JVS(2600)*X(235)&
             &-JVS(2601)*X(236))/(JVS(2588))
  X(222) = (X(222)-JVS(2552)*X(223)-JVS(2553)*X(224)-JVS(2554)*X(225)-JVS(2555)*X(226)-JVS(2556)*X(227)-JVS(2557)*X(228)&
             &-JVS(2558)*X(229)-JVS(2559)*X(230)-JVS(2560)*X(231)-JVS(2561)*X(232)-JVS(2562)*X(233)-JVS(2563)*X(234)&
             &-JVS(2564)*X(235)-JVS(2565)*X(236))/(JVS(2551))
  X(221) = (X(221)-JVS(2462)*X(222)-JVS(2463)*X(223)-JVS(2464)*X(224)-JVS(2465)*X(225)-JVS(2466)*X(226)-JVS(2467)*X(227)&
             &-JVS(2468)*X(228)-JVS(2469)*X(229)-JVS(2470)*X(230)-JVS(2471)*X(231)-JVS(2472)*X(232)-JVS(2473)*X(233)&
             &-JVS(2474)*X(234)-JVS(2475)*X(235)-JVS(2476)*X(236))/(JVS(2461))
  X(220) = (X(220)-JVS(2429)*X(221)-JVS(2430)*X(222)-JVS(2431)*X(223)-JVS(2432)*X(224)-JVS(2433)*X(225)-JVS(2434)*X(226)&
             &-JVS(2435)*X(227)-JVS(2436)*X(228)-JVS(2437)*X(229)-JVS(2438)*X(230)-JVS(2439)*X(231)-JVS(2440)*X(232)&
             &-JVS(2441)*X(233)-JVS(2442)*X(234)-JVS(2443)*X(235)-JVS(2444)*X(236))/(JVS(2428))
  X(219) = (X(219)-JVS(2341)*X(225)-JVS(2342)*X(226)-JVS(2343)*X(227)-JVS(2344)*X(230)-JVS(2345)*X(231)-JVS(2346)*X(232)&
             &-JVS(2347)*X(233)-JVS(2348)*X(234)-JVS(2349)*X(236))/(JVS(2340))
  X(218) = (X(218)-JVS(2317)*X(219)-JVS(2318)*X(220)-JVS(2319)*X(221)-JVS(2320)*X(222)-JVS(2321)*X(223)-JVS(2322)*X(224)&
             &-JVS(2323)*X(225)-JVS(2324)*X(226)-JVS(2325)*X(227)-JVS(2326)*X(228)-JVS(2327)*X(229)-JVS(2328)*X(230)&
             &-JVS(2329)*X(231)-JVS(2330)*X(232)-JVS(2331)*X(233)-JVS(2332)*X(234)-JVS(2333)*X(235)-JVS(2334)*X(236))&
             &/(JVS(2316))
  X(217) = (X(217)-JVS(2253)*X(219)-JVS(2254)*X(225)-JVS(2255)*X(226)-JVS(2256)*X(227)-JVS(2257)*X(228)-JVS(2258)*X(229)&
             &-JVS(2259)*X(230)-JVS(2260)*X(231)-JVS(2261)*X(232)-JVS(2262)*X(233)-JVS(2263)*X(234)-JVS(2264)*X(235)&
             &-JVS(2265)*X(236))/(JVS(2252))
  X(216) = (X(216)-JVS(2234)*X(225)-JVS(2235)*X(226)-JVS(2236)*X(227)-JVS(2237)*X(230)-JVS(2238)*X(231)-JVS(2239)*X(233)&
             &-JVS(2240)*X(234)-JVS(2241)*X(236))/(JVS(2233))
  X(215) = (X(215)-JVS(2218)*X(216)-JVS(2219)*X(225)-JVS(2220)*X(227)-JVS(2221)*X(230)-JVS(2222)*X(231)-JVS(2223)*X(233)&
             &-JVS(2224)*X(234)-JVS(2225)*X(236))/(JVS(2217))
  X(214) = (X(214)-JVS(2198)*X(215)-JVS(2199)*X(216)-JVS(2200)*X(224)-JVS(2201)*X(225)-JVS(2202)*X(226)-JVS(2203)*X(227)&
             &-JVS(2204)*X(229)-JVS(2205)*X(230)-JVS(2206)*X(231)-JVS(2207)*X(232)-JVS(2208)*X(233)-JVS(2209)*X(234)&
             &-JVS(2210)*X(236))/(JVS(2197))
  X(213) = (X(213)-JVS(2173)*X(225)-JVS(2174)*X(226)-JVS(2175)*X(227)-JVS(2176)*X(230)-JVS(2177)*X(231)-JVS(2178)*X(233)&
             &-JVS(2179)*X(234)-JVS(2180)*X(236))/(JVS(2172))
  X(212) = (X(212)-JVS(2160)*X(213)-JVS(2161)*X(225)-JVS(2162)*X(226)-JVS(2163)*X(227)-JVS(2164)*X(230)-JVS(2165)*X(231)&
             &-JVS(2166)*X(233)-JVS(2167)*X(234)-JVS(2168)*X(236))/(JVS(2159))
  X(211) = (X(211)-JVS(2147)*X(212)-JVS(2148)*X(213)-JVS(2149)*X(225)-JVS(2150)*X(226)-JVS(2151)*X(227)-JVS(2152)*X(230)&
             &-JVS(2153)*X(231)-JVS(2154)*X(233)-JVS(2155)*X(234)-JVS(2156)*X(236))/(JVS(2146))
  X(210) = (X(210)-JVS(2118)*X(211)-JVS(2119)*X(212)-JVS(2120)*X(213)-JVS(2121)*X(214)-JVS(2122)*X(219)-JVS(2123)*X(224)&
             &-JVS(2124)*X(225)-JVS(2125)*X(226)-JVS(2126)*X(227)-JVS(2127)*X(230)-JVS(2128)*X(231)-JVS(2129)*X(232)&
             &-JVS(2130)*X(233)-JVS(2131)*X(234)-JVS(2132)*X(236))/(JVS(2117))
  X(209) = (X(209)-JVS(2064)*X(211)-JVS(2065)*X(212)-JVS(2066)*X(213)-JVS(2067)*X(224)-JVS(2068)*X(225)-JVS(2069)*X(226)&
             &-JVS(2070)*X(227)-JVS(2071)*X(230)-JVS(2072)*X(231)-JVS(2073)*X(233)-JVS(2074)*X(234)-JVS(2075)*X(236))&
             &/(JVS(2063))
  X(208) = (X(208)-JVS(2048)*X(225)-JVS(2049)*X(227)-JVS(2050)*X(230)-JVS(2051)*X(231)-JVS(2052)*X(233)-JVS(2053)*X(234)&
             &-JVS(2054)*X(236))/(JVS(2047))
  X(207) = (X(207)-JVS(2035)*X(212)-JVS(2036)*X(213)-JVS(2037)*X(225)-JVS(2038)*X(226)-JVS(2039)*X(227)-JVS(2040)*X(230)&
             &-JVS(2041)*X(231)-JVS(2042)*X(233)-JVS(2043)*X(234)-JVS(2044)*X(236))/(JVS(2034))
  X(206) = (X(206)-JVS(2015)*X(212)-JVS(2016)*X(226)-JVS(2017)*X(227)-JVS(2018)*X(230)-JVS(2019)*X(231)-JVS(2020)*X(233)&
             &-JVS(2021)*X(234)-JVS(2022)*X(236))/(JVS(2014))
  X(205) = (X(205)-JVS(2000)*X(206)-JVS(2001)*X(212)-JVS(2002)*X(226)-JVS(2003)*X(227)-JVS(2004)*X(230)-JVS(2005)*X(231)&
             &-JVS(2006)*X(233)-JVS(2007)*X(234)-JVS(2008)*X(236))/(JVS(1999))
  X(204) = (X(204)-JVS(1985)*X(205)-JVS(1986)*X(206)-JVS(1987)*X(212)-JVS(1988)*X(213)-JVS(1989)*X(225)-JVS(1990)*X(227)&
             &-JVS(1991)*X(230)-JVS(1992)*X(231)-JVS(1993)*X(234)-JVS(1994)*X(236))/(JVS(1984))
  X(203) = (X(203)-JVS(1962)*X(204)-JVS(1963)*X(205)-JVS(1964)*X(206)-JVS(1965)*X(212)-JVS(1966)*X(213)-JVS(1967)*X(225)&
             &-JVS(1968)*X(227)-JVS(1969)*X(230)-JVS(1970)*X(231)-JVS(1971)*X(234)-JVS(1972)*X(236))/(JVS(1961))
  X(202) = (X(202)-JVS(1936)*X(204)-JVS(1937)*X(205)-JVS(1938)*X(206)-JVS(1939)*X(212)-JVS(1940)*X(213)-JVS(1941)*X(225)&
             &-JVS(1942)*X(227)-JVS(1943)*X(230)-JVS(1944)*X(231)-JVS(1945)*X(234)-JVS(1946)*X(236))/(JVS(1935))
  X(201) = (X(201)-JVS(1914)*X(202)-JVS(1915)*X(203)-JVS(1916)*X(204)-JVS(1917)*X(205)-JVS(1918)*X(206)-JVS(1919)*X(207)&
             &-JVS(1920)*X(212)-JVS(1921)*X(213)-JVS(1922)*X(224)-JVS(1923)*X(225)-JVS(1924)*X(226)-JVS(1925)*X(227)&
             &-JVS(1926)*X(230)-JVS(1927)*X(231)-JVS(1928)*X(233)-JVS(1929)*X(234)-JVS(1930)*X(236))/(JVS(1913))
  X(200) = (X(200)-JVS(1884)*X(208)-JVS(1885)*X(215)-JVS(1886)*X(216)-JVS(1887)*X(218)-JVS(1888)*X(219)-JVS(1889)*X(220)&
             &-JVS(1890)*X(221)-JVS(1891)*X(223)-JVS(1892)*X(224)-JVS(1893)*X(225)-JVS(1894)*X(226)-JVS(1895)*X(227)&
             &-JVS(1896)*X(229)-JVS(1897)*X(230)-JVS(1898)*X(231)-JVS(1899)*X(232)-JVS(1900)*X(233)-JVS(1901)*X(234)&
             &-JVS(1902)*X(236))/(JVS(1883))
  X(199) = (X(199)-JVS(1867)*X(215)-JVS(1868)*X(216)-JVS(1869)*X(225)-JVS(1870)*X(230)-JVS(1871)*X(231)-JVS(1872)*X(234)&
             &-JVS(1873)*X(236))/(JVS(1866))
  X(198) = (X(198)-JVS(1841)*X(201)-JVS(1842)*X(202)-JVS(1843)*X(203)-JVS(1844)*X(204)-JVS(1845)*X(205)-JVS(1846)*X(206)&
             &-JVS(1847)*X(207)-JVS(1848)*X(209)-JVS(1849)*X(210)-JVS(1850)*X(211)-JVS(1851)*X(212)-JVS(1852)*X(213)&
             &-JVS(1853)*X(214)-JVS(1854)*X(215)-JVS(1855)*X(219)-JVS(1856)*X(224)-JVS(1857)*X(225)-JVS(1858)*X(226)&
             &-JVS(1859)*X(227)-JVS(1860)*X(230)-JVS(1861)*X(231)-JVS(1862)*X(233)-JVS(1863)*X(234)-JVS(1864)*X(236))&
             &/(JVS(1840))
  X(197) = (X(197)-JVS(1786)*X(201)-JVS(1787)*X(202)-JVS(1788)*X(203)-JVS(1789)*X(204)-JVS(1790)*X(205)-JVS(1791)*X(206)&
             &-JVS(1792)*X(207)-JVS(1793)*X(212)-JVS(1794)*X(213)-JVS(1795)*X(224)-JVS(1796)*X(225)-JVS(1797)*X(226)&
             &-JVS(1798)*X(227)-JVS(1799)*X(230)-JVS(1800)*X(231)-JVS(1801)*X(233)-JVS(1802)*X(234)-JVS(1803)*X(236))&
             &/(JVS(1785))
  X(196) = (X(196)-JVS(1750)*X(199)-JVS(1751)*X(208)-JVS(1752)*X(215)-JVS(1753)*X(216)-JVS(1754)*X(219)-JVS(1755)*X(225)&
             &-JVS(1756)*X(226)-JVS(1757)*X(227)-JVS(1758)*X(228)-JVS(1759)*X(229)-JVS(1760)*X(230)-JVS(1761)*X(231)&
             &-JVS(1762)*X(232)-JVS(1763)*X(233)-JVS(1764)*X(234)-JVS(1765)*X(236))/(JVS(1749))
  X(195) = (X(195)-JVS(1724)*X(203)-JVS(1725)*X(204)-JVS(1726)*X(212)-JVS(1727)*X(213)-JVS(1728)*X(225)-JVS(1729)*X(227)&
             &-JVS(1730)*X(230)-JVS(1731)*X(231)-JVS(1732)*X(234)-JVS(1733)*X(236))/(JVS(1723))
  X(194) = (X(194)-JVS(1705)*X(202)-JVS(1706)*X(203)-JVS(1707)*X(205)-JVS(1708)*X(206)-JVS(1709)*X(207)-JVS(1710)*X(212)&
             &-JVS(1711)*X(213)-JVS(1712)*X(224)-JVS(1713)*X(226)-JVS(1714)*X(227)-JVS(1715)*X(230)-JVS(1716)*X(231)&
             &-JVS(1717)*X(233)-JVS(1718)*X(234)-JVS(1719)*X(236))/(JVS(1704))
  X(193) = (X(193)-JVS(1672)*X(202)-JVS(1673)*X(203)-JVS(1674)*X(205)-JVS(1675)*X(206)-JVS(1676)*X(211)-JVS(1677)*X(212)&
             &-JVS(1678)*X(213)-JVS(1679)*X(224)-JVS(1680)*X(226)-JVS(1681)*X(227)-JVS(1682)*X(230)-JVS(1683)*X(231)&
             &-JVS(1684)*X(233)-JVS(1685)*X(234)-JVS(1686)*X(236))/(JVS(1671))
  X(192) = (X(192)-JVS(1645)*X(205)-JVS(1646)*X(206)-JVS(1647)*X(212)-JVS(1648)*X(213)-JVS(1649)*X(230)-JVS(1650)*X(231)&
             &-JVS(1651)*X(234)-JVS(1652)*X(236))/(JVS(1644))
  X(191) = (X(191)-JVS(1624)*X(192)-JVS(1625)*X(205)-JVS(1626)*X(206)-JVS(1627)*X(212)-JVS(1628)*X(213)-JVS(1629)*X(230)&
             &-JVS(1630)*X(231)-JVS(1631)*X(234)-JVS(1632)*X(236))/(JVS(1623))
  X(190) = (X(190)-JVS(1603)*X(207)-JVS(1604)*X(211)-JVS(1605)*X(219)-JVS(1606)*X(222)-JVS(1607)*X(224)-JVS(1608)*X(226)&
             &-JVS(1609)*X(227)-JVS(1610)*X(230)-JVS(1611)*X(233)-JVS(1612)*X(234))/(JVS(1602))
  X(189) = (X(189)-JVS(1588)*X(199)-JVS(1589)*X(208)-JVS(1590)*X(215)-JVS(1591)*X(216)-JVS(1592)*X(225)-JVS(1593)*X(227)&
             &-JVS(1594)*X(230)-JVS(1595)*X(231)-JVS(1596)*X(233)-JVS(1597)*X(234)-JVS(1598)*X(236))/(JVS(1587))
  X(188) = (X(188)-JVS(1572)*X(225)-JVS(1573)*X(227)-JVS(1574)*X(230)-JVS(1575)*X(231)-JVS(1576)*X(233)-JVS(1577)*X(234)&
             &-JVS(1578)*X(236))/(JVS(1571))
  X(187) = (X(187)-JVS(1532)*X(188)-JVS(1533)*X(189)-JVS(1534)*X(191)-JVS(1535)*X(192)-JVS(1536)*X(194)-JVS(1537)*X(195)&
             &-JVS(1538)*X(196)-JVS(1539)*X(197)-JVS(1540)*X(198)-JVS(1541)*X(199)-JVS(1542)*X(200)-JVS(1543)*X(201)&
             &-JVS(1544)*X(202)-JVS(1545)*X(203)-JVS(1546)*X(204)-JVS(1547)*X(205)-JVS(1548)*X(206)-JVS(1549)*X(208)&
             &-JVS(1550)*X(209)-JVS(1551)*X(211)-JVS(1552)*X(212)-JVS(1553)*X(213)-JVS(1554)*X(215)-JVS(1555)*X(216)&
             &-JVS(1556)*X(218)-JVS(1557)*X(220)-JVS(1558)*X(221)-JVS(1559)*X(223)-JVS(1560)*X(224)-JVS(1561)*X(225)&
             &-JVS(1562)*X(226)-JVS(1563)*X(227)-JVS(1564)*X(230)-JVS(1565)*X(231)-JVS(1566)*X(232)-JVS(1567)*X(233)&
             &-JVS(1568)*X(234)-JVS(1569)*X(236))/(JVS(1531))
  X(186) = (X(186)-JVS(1488)*X(206)-JVS(1489)*X(212)-JVS(1490)*X(213)-JVS(1491)*X(230)-JVS(1492)*X(234)-JVS(1493)&
             &*X(236))/(JVS(1487))
  X(185) = (X(185)-JVS(1480)*X(225)-JVS(1481)*X(227)-JVS(1482)*X(230)-JVS(1483)*X(231)-JVS(1484)*X(233)-JVS(1485)*X(234)&
             &-JVS(1486)*X(236))/(JVS(1479))
  X(184) = (X(184)-JVS(1467)*X(185)-JVS(1468)*X(225)-JVS(1469)*X(227)-JVS(1470)*X(230)-JVS(1471)*X(231)-JVS(1472)*X(233)&
             &-JVS(1473)*X(234)-JVS(1474)*X(236))/(JVS(1466))
  X(183) = (X(183)-JVS(1459)*X(226)-JVS(1460)*X(227)-JVS(1461)*X(230)-JVS(1462)*X(233))/(JVS(1458))
  X(182) = (X(182)-JVS(1436)*X(185)-JVS(1437)*X(188)-JVS(1438)*X(197)-JVS(1439)*X(199)-JVS(1440)*X(208)-JVS(1441)*X(212)&
             &-JVS(1442)*X(213)-JVS(1443)*X(214)-JVS(1444)*X(215)-JVS(1445)*X(216)-JVS(1446)*X(217)-JVS(1447)*X(219)&
             &-JVS(1448)*X(225)-JVS(1449)*X(226)-JVS(1450)*X(227)-JVS(1451)*X(228)-JVS(1452)*X(229)-JVS(1453)*X(230)&
             &-JVS(1454)*X(231)-JVS(1455)*X(232)-JVS(1456)*X(234)-JVS(1457)*X(236))/(JVS(1435))
  X(181) = (X(181)-JVS(1420)*X(199)-JVS(1421)*X(208)-JVS(1422)*X(215)-JVS(1423)*X(216)-JVS(1424)*X(225)-JVS(1425)*X(226)&
             &-JVS(1426)*X(229)-JVS(1427)*X(230)-JVS(1428)*X(231)-JVS(1429)*X(232)-JVS(1430)*X(234)-JVS(1431)*X(236))&
             &/(JVS(1419))
  X(180) = (X(180)-JVS(1410)*X(212)-JVS(1411)*X(213)-JVS(1412)*X(230)-JVS(1413)*X(231)-JVS(1414)*X(234)-JVS(1415)&
             &*X(236))/(JVS(1409))
  X(179) = (X(179)-JVS(1390)*X(180)-JVS(1391)*X(183)-JVS(1392)*X(186)-JVS(1393)*X(191)-JVS(1394)*X(192)-JVS(1395)*X(194)&
             &-JVS(1396)*X(197)-JVS(1397)*X(201)-JVS(1398)*X(202)-JVS(1399)*X(203)-JVS(1400)*X(205)-JVS(1401)*X(206)&
             &-JVS(1402)*X(212)-JVS(1403)*X(227)-JVS(1404)*X(230)-JVS(1405)*X(231)-JVS(1406)*X(234)-JVS(1407)*X(236))&
             &/(JVS(1389))
  X(178) = (X(178)-JVS(1364)*X(218)-JVS(1365)*X(221)-JVS(1366)*X(224)-JVS(1367)*X(227)-JVS(1368)*X(230)-JVS(1369)*X(231)&
             &-JVS(1370)*X(232)-JVS(1371)*X(233)-JVS(1372)*X(234))/(JVS(1363))
  X(177) = (X(177)-JVS(1355)*X(205)-JVS(1356)*X(212)-JVS(1357)*X(230)-JVS(1358)*X(234)-JVS(1359)*X(236))/(JVS(1354))
  X(176) = (X(176)-JVS(1342)*X(177)-JVS(1343)*X(180)-JVS(1344)*X(186)-JVS(1345)*X(191)-JVS(1346)*X(192)-JVS(1347)*X(203)&
             &-JVS(1348)*X(205)-JVS(1349)*X(206)-JVS(1350)*X(212)-JVS(1351)*X(230)-JVS(1352)*X(231)-JVS(1353)*X(234))&
             &/(JVS(1341))
  X(175) = (X(175)-JVS(1327)*X(225)-JVS(1328)*X(226)-JVS(1329)*X(227)-JVS(1330)*X(230)-JVS(1331)*X(231)-JVS(1332)*X(232)&
             &-JVS(1333)*X(234)-JVS(1334)*X(236))/(JVS(1326))
  X(174) = (X(174)-JVS(1317)*X(178)-JVS(1318)*X(221)-JVS(1319)*X(224)-JVS(1320)*X(227)-JVS(1321)*X(230)-JVS(1322)*X(231)&
             &-JVS(1323)*X(233)-JVS(1324)*X(234))/(JVS(1316))
  X(173) = (X(173)-JVS(1301)*X(219)-JVS(1302)*X(225)-JVS(1303)*X(226)-JVS(1304)*X(230)-JVS(1305)*X(231)-JVS(1306)*X(232)&
             &-JVS(1307)*X(234)-JVS(1308)*X(236))/(JVS(1300))
  X(172) = (X(172)-JVS(1289)*X(178)-JVS(1290)*X(200)-JVS(1291)*X(218)-JVS(1292)*X(221)-JVS(1293)*X(224)-JVS(1294)*X(226)&
             &-JVS(1295)*X(230)-JVS(1296)*X(231)-JVS(1297)*X(232)-JVS(1298)*X(233))/(JVS(1288))
  X(171) = (X(171)-JVS(1276)*X(174)-JVS(1277)*X(178)-JVS(1278)*X(221)-JVS(1279)*X(224)-JVS(1280)*X(227)-JVS(1281)*X(230)&
             &-JVS(1282)*X(231)-JVS(1283)*X(233)-JVS(1284)*X(234))/(JVS(1275))
  X(170) = (X(170)-JVS(1254)*X(209)-JVS(1255)*X(211)-JVS(1256)*X(224)-JVS(1257)*X(227)-JVS(1258)*X(230)-JVS(1259)*X(231)&
             &-JVS(1260)*X(234))/(JVS(1253))
  X(169) = (X(169)-JVS(1243)*X(190)-JVS(1244)*X(219)-JVS(1245)*X(222)-JVS(1246)*X(224)-JVS(1247)*X(227)-JVS(1248)*X(230)&
             &-JVS(1249)*X(233)-JVS(1250)*X(234))/(JVS(1242))
  X(168) = (X(168)-JVS(1229)*X(177)-JVS(1230)*X(180)-JVS(1231)*X(195)-JVS(1232)*X(201)-JVS(1233)*X(202)-JVS(1234)*X(203)&
             &-JVS(1235)*X(204)-JVS(1236)*X(212)-JVS(1237)*X(227)-JVS(1238)*X(230)-JVS(1239)*X(231)-JVS(1240)*X(234))&
             &/(JVS(1228))
  X(167) = (X(167)-JVS(1217)*X(219)-JVS(1218)*X(225)-JVS(1219)*X(227)-JVS(1220)*X(230)-JVS(1221)*X(231)-JVS(1222)*X(234)&
             &-JVS(1223)*X(236))/(JVS(1216))
  X(166) = (X(166)-JVS(1206)*X(177)-JVS(1207)*X(186)-JVS(1208)*X(191)-JVS(1209)*X(192)-JVS(1210)*X(205)-JVS(1211)*X(206)&
             &-JVS(1212)*X(230)-JVS(1213)*X(231)-JVS(1214)*X(234))/(JVS(1205))
  X(165) = (X(165)-JVS(1192)*X(183)-JVS(1193)*X(202)-JVS(1194)*X(206)-JVS(1195)*X(211)-JVS(1196)*X(224)-JVS(1197)*X(230)&
             &-JVS(1198)*X(231)-JVS(1199)*X(234))/(JVS(1191))
  X(164) = (X(164)-JVS(1181)*X(183)-JVS(1182)*X(202)-JVS(1183)*X(205)-JVS(1184)*X(207)-JVS(1185)*X(224)-JVS(1186)*X(230)&
             &-JVS(1187)*X(231)-JVS(1188)*X(234))/(JVS(1180))
  X(163) = (X(163)-JVS(1172)*X(199)-JVS(1173)*X(215)-JVS(1174)*X(216)-JVS(1175)*X(230)-JVS(1176)*X(231)-JVS(1177)&
             &*X(234))/(JVS(1171))
  X(162) = (X(162)-JVS(1160)*X(184)-JVS(1161)*X(185)-JVS(1162)*X(188)-JVS(1163)*X(208)-JVS(1164)*X(225)-JVS(1165)*X(227)&
             &-JVS(1166)*X(230)-JVS(1167)*X(231)-JVS(1168)*X(233)-JVS(1169)*X(234)-JVS(1170)*X(236))/(JVS(1159))
  X(161) = (X(161)-JVS(1148)*X(165)-JVS(1149)*X(183)-JVS(1150)*X(202)-JVS(1151)*X(203)-JVS(1152)*X(205)-JVS(1153)*X(206)&
             &-JVS(1154)*X(209)-JVS(1155)*X(224)-JVS(1156)*X(230)-JVS(1157)*X(231)-JVS(1158)*X(234))/(JVS(1147))
  X(160) = (X(160)-JVS(1125)*X(170)-JVS(1126)*X(183)-JVS(1127)*X(190)-JVS(1128)*X(197)-JVS(1129)*X(201)-JVS(1130)*X(202)&
             &-JVS(1131)*X(203)-JVS(1132)*X(205)-JVS(1133)*X(206)-JVS(1134)*X(208)-JVS(1135)*X(209)-JVS(1136)*X(210)&
             &-JVS(1137)*X(224)-JVS(1138)*X(226)-JVS(1139)*X(227)-JVS(1140)*X(230)-JVS(1141)*X(231)-JVS(1142)*X(233)&
             &-JVS(1143)*X(234))/(JVS(1124))
  X(159) = (X(159)-JVS(1101)*X(167)-JVS(1102)*X(180)-JVS(1103)*X(186)-JVS(1104)*X(195)-JVS(1105)*X(202)-JVS(1106)*X(203)&
             &-JVS(1107)*X(204)-JVS(1108)*X(209)-JVS(1109)*X(211)-JVS(1110)*X(212)-JVS(1111)*X(227)-JVS(1112)*X(230)&
             &-JVS(1113)*X(231)-JVS(1114)*X(234)-JVS(1115)*X(236))/(JVS(1100))
  X(158) = (X(158)-JVS(1085)*X(172)-JVS(1086)*X(178)-JVS(1087)*X(200)-JVS(1088)*X(218)-JVS(1089)*X(224)-JVS(1090)*X(230)&
             &-JVS(1091)*X(231)-JVS(1092)*X(232)-JVS(1093)*X(233))/(JVS(1084))
  X(157) = (X(157)-JVS(1068)*X(172)-JVS(1069)*X(174)-JVS(1070)*X(178)-JVS(1071)*X(200)-JVS(1072)*X(218)-JVS(1073)*X(221)&
             &-JVS(1074)*X(224)-JVS(1075)*X(226)-JVS(1076)*X(227)-JVS(1077)*X(230)-JVS(1078)*X(231)-JVS(1079)*X(236))&
             &/(JVS(1067))
  X(156) = (X(156)-JVS(1055)*X(177)-JVS(1056)*X(186)-JVS(1057)*X(205)-JVS(1058)*X(206)-JVS(1059)*X(230)-JVS(1060)*X(231)&
             &-JVS(1061)*X(234))/(JVS(1054))
  X(155) = (X(155)-JVS(1033)*X(167)-JVS(1034)*X(169)-JVS(1035)*X(173)-JVS(1036)*X(175)-JVS(1037)*X(199)-JVS(1038)*X(210)&
             &-JVS(1039)*X(214)-JVS(1040)*X(215)-JVS(1041)*X(216)-JVS(1042)*X(217)-JVS(1043)*X(225)-JVS(1044)*X(226)&
             &-JVS(1045)*X(228)-JVS(1046)*X(229)-JVS(1047)*X(230)-JVS(1048)*X(231)-JVS(1049)*X(236))/(JVS(1032))
  X(154) = (X(154)-JVS(1028)*X(212)-JVS(1029)*X(230)-JVS(1030)*X(231)-JVS(1031)*X(234))/(JVS(1027))
  X(153) = (X(153)-JVS(1018)*X(177)-JVS(1019)*X(186)-JVS(1020)*X(205)-JVS(1021)*X(206)-JVS(1022)*X(230)-JVS(1023)*X(231)&
             &-JVS(1024)*X(234)-JVS(1025)*X(236))/(JVS(1017))
  X(152) = (X(152)-JVS(1003)*X(154)-JVS(1004)*X(180)-JVS(1005)*X(183)-JVS(1006)*X(193)-JVS(1007)*X(203)-JVS(1008)*X(206)&
             &-JVS(1009)*X(211)-JVS(1010)*X(214)-JVS(1011)*X(215)-JVS(1012)*X(230)-JVS(1013)*X(231)-JVS(1014)*X(234))&
             &/(JVS(1002))
  X(151) = (X(151)-JVS(996)*X(183)-JVS(997)*X(206)-JVS(998)*X(230)-JVS(999)*X(231))/(JVS(995))
  X(150) = (X(150)-JVS(990)*X(183)-JVS(991)*X(205)-JVS(992)*X(230)-JVS(993)*X(231))/(JVS(989))
  X(149) = (X(149)-JVS(983)*X(205)-JVS(984)*X(206)-JVS(985)*X(230)-JVS(986)*X(231)-JVS(987)*X(234))/(JVS(982))
  X(148) = (X(148)-JVS(968)*X(150)-JVS(969)*X(151)-JVS(970)*X(166)-JVS(971)*X(191)-JVS(972)*X(192)-JVS(973)*X(194)&
             &-JVS(974)*X(201)-JVS(975)*X(202)-JVS(976)*X(203)-JVS(977)*X(230)-JVS(978)*X(231)-JVS(979)*X(234))/(JVS(967))
  X(147) = (X(147)-JVS(959)*X(206)-JVS(960)*X(230)-JVS(961)*X(231)-JVS(962)*X(234))/(JVS(958))
  X(146) = (X(146)-JVS(952)*X(205)-JVS(953)*X(230)-JVS(954)*X(231)-JVS(955)*X(234))/(JVS(951))
  X(145) = (X(145)-JVS(944)*X(212)-JVS(945)*X(213)-JVS(946)*X(230)-JVS(947)*X(231)-JVS(948)*X(236))/(JVS(943))
  X(144) = (X(144)-JVS(934)*X(184)-JVS(935)*X(185)-JVS(936)*X(208)-JVS(937)*X(225)-JVS(938)*X(227)-JVS(939)*X(230)&
             &-JVS(940)*X(231)-JVS(941)*X(234)-JVS(942)*X(236))/(JVS(933))
  X(143) = (X(143)-JVS(923)*X(154)-JVS(924)*X(180)-JVS(925)*X(186)-JVS(926)*X(195)-JVS(927)*X(202)-JVS(928)*X(209)&
             &-JVS(929)*X(230)-JVS(930)*X(231)-JVS(931)*X(234)-JVS(932)*X(236))/(JVS(922))
  X(142) = (X(142)-JVS(909)*X(150)-JVS(910)*X(151)-JVS(911)*X(177)-JVS(912)*X(183)-JVS(913)*X(186)-JVS(914)*X(202)&
             &-JVS(915)*X(205)-JVS(916)*X(206)-JVS(917)*X(212)-JVS(918)*X(230)-JVS(919)*X(231)-JVS(920)*X(234))/(JVS(908))
  X(141) = (X(141)-JVS(893)*X(227)-JVS(894)*X(230)-JVS(895)*X(233))/(JVS(892))
  X(140) = (X(140)-JVS(886)*X(171)-JVS(887)*X(174)-JVS(888)*X(224)-JVS(889)*X(227)-JVS(890)*X(230)-JVS(891)*X(234))&
             &/(JVS(885))
  X(139) = (X(139)-JVS(873)*X(146)-JVS(874)*X(154)-JVS(875)*X(180)-JVS(876)*X(183)-JVS(877)*X(203)-JVS(878)*X(205)&
             &-JVS(879)*X(230)-JVS(880)*X(231)-JVS(881)*X(234))/(JVS(872))
  X(138) = (X(138)-JVS(868)*X(205)-JVS(869)*X(230)-JVS(870)*X(231))/(JVS(867))
  X(137) = (X(137)-JVS(858)*X(156)-JVS(859)*X(164)-JVS(860)*X(166)-JVS(861)*X(191)-JVS(862)*X(192)-JVS(863)*X(194)&
             &-JVS(864)*X(230)-JVS(865)*X(231)-JVS(866)*X(234))/(JVS(857))
  X(136) = (X(136)-JVS(851)*X(186)-JVS(852)*X(230)-JVS(853)*X(231)-JVS(854)*X(234))/(JVS(850))
  X(135) = (X(135)-JVS(846)*X(205)-JVS(847)*X(230)-JVS(848)*X(231)-JVS(849)*X(234))/(JVS(845))
  X(134) = (X(134)-JVS(840)*X(177)-JVS(841)*X(230)-JVS(842)*X(231)-JVS(843)*X(234))/(JVS(839))
  X(133) = (X(133)-JVS(836)*X(206)-JVS(837)*X(230)-JVS(838)*X(231))/(JVS(835))
  X(132) = (X(132)-JVS(830)*X(146)-JVS(831)*X(147)-JVS(832)*X(149)-JVS(833)*X(230)-JVS(834)*X(231))/(JVS(829))
  X(131) = (X(131)-JVS(818)*X(141)-JVS(819)*X(169)-JVS(820)*X(183)-JVS(821)*X(190)-JVS(822)*X(207)-JVS(823)*X(226)&
             &-JVS(824)*X(227)-JVS(825)*X(230)-JVS(826)*X(231)-JVS(827)*X(233))/(JVS(817))
  X(130) = (X(130)-JVS(810)*X(140)-JVS(811)*X(171)-JVS(812)*X(174)-JVS(813)*X(224)-JVS(814)*X(227))/(JVS(809))
  X(129) = (X(129)-JVS(804)*X(150)-JVS(805)*X(151)-JVS(806)*X(202)-JVS(807)*X(203)-JVS(808)*X(230))/(JVS(803))
  X(128) = (X(128)-JVS(800)*X(206)-JVS(801)*X(230)-JVS(802)*X(231))/(JVS(799))
  X(127) = (X(127)-JVS(795)*X(178)-JVS(796)*X(218)-JVS(797)*X(224)-JVS(798)*X(232))/(JVS(794))
  X(126) = (X(126)-JVS(791)*X(212)-JVS(792)*X(230)-JVS(793)*X(231))/(JVS(790))
  X(125) = (X(125)-JVS(778)*X(167)-JVS(779)*X(173)-JVS(780)*X(185)-JVS(781)*X(188)-JVS(782)*X(199)-JVS(783)*X(208)&
             &-JVS(784)*X(215)-JVS(785)*X(216)-JVS(786)*X(228)-JVS(787)*X(229)-JVS(788)*X(230)-JVS(789)*X(236))/(JVS(777))
  X(124) = (X(124)-JVS(774)*X(205)-JVS(775)*X(230)-JVS(776)*X(231))/(JVS(773))
  X(123) = (X(123)-JVS(767)*X(150)-JVS(768)*X(151)-JVS(769)*X(191)-JVS(770)*X(192)-JVS(771)*X(202)-JVS(772)*X(230))&
             &/(JVS(766))
  X(122) = (X(122)-JVS(761)*X(227)-JVS(762)*X(230)-JVS(763)*X(233))/(JVS(760))
  X(121) = (X(121)-JVS(757)*X(227)-JVS(758)*X(230)-JVS(759)*X(233))/(JVS(756))
  X(120) = (X(120)-JVS(752)*X(170)-JVS(753)*X(209)-JVS(754)*X(224)-JVS(755)*X(230))/(JVS(751))
  X(119) = (X(119)-JVS(747)*X(206)-JVS(748)*X(230)-JVS(749)*X(231)-JVS(750)*X(234))/(JVS(746))
  X(118) = (X(118)-JVS(740)*X(202)-JVS(741)*X(203)-JVS(742)*X(230)-JVS(743)*X(231)-JVS(744)*X(234))/(JVS(739))
  X(117) = (X(117)-JVS(735)*X(226)-JVS(736)*X(227)-JVS(737)*X(230)-JVS(738)*X(232))/(JVS(734))
  X(116) = (X(116)-JVS(730)*X(204)-JVS(731)*X(230)-JVS(732)*X(231)-JVS(733)*X(234))/(JVS(729))
  X(115) = (X(115)-JVS(724)*X(151)-JVS(725)*X(202)-JVS(726)*X(224)-JVS(727)*X(231)-JVS(728)*X(234))/(JVS(723))
  X(114) = (X(114)-JVS(718)*X(150)-JVS(719)*X(202)-JVS(720)*X(224)-JVS(721)*X(231)-JVS(722)*X(234))/(JVS(717))
  X(113) = (X(113)-JVS(712)*X(146)-JVS(713)*X(147)-JVS(714)*X(149)-JVS(715)*X(230)-JVS(716)*X(231))/(JVS(711))
  X(112) = (X(112)-JVS(708)*X(206)-JVS(709)*X(230)-JVS(710)*X(234))/(JVS(707))
  X(111) = (X(111)-JVS(704)*X(205)-JVS(705)*X(230)-JVS(706)*X(234))/(JVS(703))
  X(110) = (X(110)-JVS(699)*X(158)-JVS(700)*X(172)-JVS(701)*X(200)-JVS(702)*X(233))/(JVS(698))
  X(109) = (X(109)-JVS(694)*X(158)-JVS(695)*X(172)-JVS(696)*X(200)-JVS(697)*X(233))/(JVS(693))
  X(108) = (X(108)-JVS(690)*X(170)-JVS(691)*X(230)-JVS(692)*X(231))/(JVS(689))
  X(107) = (X(107)-JVS(684)*X(175)-JVS(685)*X(217)-JVS(686)*X(226)-JVS(687)*X(230)-JVS(688)*X(236))/(JVS(683))
  X(106) = (X(106)-JVS(678)*X(111)-JVS(679)*X(112)-JVS(680)*X(124)-JVS(681)*X(128)-JVS(682)*X(230))/(JVS(677))
  X(105) = (X(105)-JVS(672)*X(144)-JVS(673)*X(162)-JVS(674)*X(227)-JVS(675)*X(230)-JVS(676)*X(233))/(JVS(671))
  X(104) = (X(104)-JVS(666)*X(111)-JVS(667)*X(112)-JVS(668)*X(124)-JVS(669)*X(128)-JVS(670)*X(230))/(JVS(665))
  X(103) = (X(103)-JVS(660)*X(166)-JVS(661)*X(192)-JVS(662)*X(230)-JVS(663)*X(231)-JVS(664)*X(234))/(JVS(659))
  X(102) = (X(102)-JVS(655)*X(133)-JVS(656)*X(183)-JVS(657)*X(206)-JVS(658)*X(230))/(JVS(654))
  X(101) = (X(101)-JVS(646)*X(109)-JVS(647)*X(110)-JVS(648)*X(127)-JVS(649)*X(158)-JVS(650)*X(178)-JVS(651)*X(200)&
             &-JVS(652)*X(230)-JVS(653)*X(232))/(JVS(645))
  X(100) = (X(100)-JVS(641)*X(138)-JVS(642)*X(183)-JVS(643)*X(205)-JVS(644)*X(230))/(JVS(640))
  X(99) = (X(99)-JVS(636)*X(169)-JVS(637)*X(190)-JVS(638)*X(227)-JVS(639)*X(230))/(JVS(635))
  X(98) = (X(98)-JVS(626)*X(157)-JVS(627)*X(172)-JVS(628)*X(178)-JVS(629)*X(218)-JVS(630)*X(221)-JVS(631)*X(226)&
            &-JVS(632)*X(230)-JVS(633)*X(236))/(JVS(625))
  X(97) = (X(97)-JVS(621)*X(191)-JVS(622)*X(192)-JVS(623)*X(230))/(JVS(620))
  X(96) = (X(96)-JVS(616)*X(226)-JVS(617)*X(230)-JVS(618)*X(231)-JVS(619)*X(236))/(JVS(615))
  X(95) = (X(95)-JVS(607)*X(126)-JVS(608)*X(204)-JVS(609)*X(212)-JVS(610)*X(213)-JVS(611)*X(225)-JVS(612)*X(227)&
            &-JVS(613)*X(234)-JVS(614)*X(236))/(JVS(606))
  X(94) = (X(94)-JVS(603)*X(226)-JVS(604)*X(230)-JVS(605)*X(232))/(JVS(602))
  X(93) = (X(93)-JVS(599)*X(218)-JVS(600)*X(224)-JVS(601)*X(227))/(JVS(598))
  X(92) = (X(92)-JVS(588)*X(109)-JVS(589)*X(110)-JVS(590)*X(127)-JVS(591)*X(157)-JVS(592)*X(158)-JVS(593)*X(172)&
            &-JVS(594)*X(178)-JVS(595)*X(200)-JVS(596)*X(218)-JVS(597)*X(221))/(JVS(587))
  X(91) = (X(91)-JVS(583)*X(151)-JVS(584)*X(230)-JVS(585)*X(231)-JVS(586)*X(234))/(JVS(582))
  X(90) = (X(90)-JVS(578)*X(150)-JVS(579)*X(230)-JVS(580)*X(231)-JVS(581)*X(234))/(JVS(577))
  X(89) = (X(89)-JVS(573)*X(188)-JVS(574)*X(208)-JVS(575)*X(230)-JVS(576)*X(231))/(JVS(572))
  X(88) = (X(88)-JVS(568)*X(140)-JVS(569)*X(174)-JVS(570)*X(230)-JVS(571)*X(231))/(JVS(567))
  X(87) = (X(87)-JVS(562)*X(166)-JVS(563)*X(191)-JVS(564)*X(230)-JVS(565)*X(231)-JVS(566)*X(234))/(JVS(561))
  X(86) = (X(86)-JVS(556)*X(133)-JVS(557)*X(138)-JVS(558)*X(177)-JVS(559)*X(186)-JVS(560)*X(230))/(JVS(555))
  X(85) = (X(85)-JVS(552)*X(167)-JVS(553)*X(230)-JVS(554)*X(231))/(JVS(551))
  X(84) = (X(84)-JVS(548)*X(173)-JVS(549)*X(230)-JVS(550)*X(231))/(JVS(547))
  X(83) = (X(83)-JVS(544)*X(226)-JVS(545)*X(227)-JVS(546)*X(230))/(JVS(543))
  X(82) = (X(82)-JVS(539)*X(175)-JVS(540)*X(217)-JVS(541)*X(230)-JVS(542)*X(231))/(JVS(538))
  X(81) = (X(81)-JVS(534)*X(174)-JVS(535)*X(178)-JVS(536)*X(221)-JVS(537)*X(230))/(JVS(533))
  X(80) = (X(80)-JVS(529)*X(150)-JVS(530)*X(151)-JVS(531)*X(202)-JVS(532)*X(230))/(JVS(528))
  X(79) = (X(79)-JVS(523)*X(129)-JVS(524)*X(201)-JVS(525)*X(207)-JVS(526)*X(230)-JVS(527)*X(233))/(JVS(522))
  X(78) = (X(78)-JVS(517)*X(178)-JVS(518)*X(221)-JVS(519)*X(226)-JVS(520)*X(230)-JVS(521)*X(236))/(JVS(516))
  X(77) = (X(77)-JVS(513)*X(171)-JVS(514)*X(224))/(JVS(512))
  X(76) = (X(76)-JVS(499)*X(111)-JVS(500)*X(112)-JVS(501)*X(126)-JVS(502)*X(143)-JVS(503)*X(145)-JVS(504)*X(161)&
            &-JVS(505)*X(163)-JVS(506)*X(176)-JVS(507)*X(177)-JVS(508)*X(186)-JVS(509)*X(201)-JVS(510)*X(203)-JVS(511)&
            &*X(204))/(JVS(498))
  X(75) = (X(75)-JVS(496)*X(226)-JVS(497)*X(230))/(JVS(495))
  X(74) = (X(74)-JVS(493)*X(227)-JVS(494)*X(230))/(JVS(492))
  X(73) = (X(73)-JVS(489)*X(93)-JVS(490)*X(218)-JVS(491)*X(230))/(JVS(488))
  X(72) = (X(72)-JVS(486)*X(227)-JVS(487)*X(230))/(JVS(485))
  X(71) = (X(71)-JVS(482)*X(230)-JVS(483)*X(231)-JVS(484)*X(235))/(JVS(481))
  X(70) = (X(70)-JVS(478)*X(229)-JVS(479)*X(230)-JVS(480)*X(231))/(JVS(477))
  X(69) = (X(69)-JVS(474)*X(228)-JVS(475)*X(230)-JVS(476)*X(231))/(JVS(473))
  X(68) = (X(68)-JVS(470)*X(216)-JVS(471)*X(230)-JVS(472)*X(231))/(JVS(469))
  X(67) = (X(67)-JVS(466)*X(174)-JVS(467)*X(178)-JVS(468)*X(234))/(JVS(465))
  X(66) = (X(66)-JVS(459)*X(228)-JVS(460)*X(230)-JVS(461)*X(234))/(JVS(458))
  X(65) = (X(65)-JVS(455)*X(230)-JVS(456)*X(234)-JVS(457)*X(236))/(JVS(454))
  X(64) = (X(64)-JVS(451)*X(229)-JVS(452)*X(230)-JVS(453)*X(234))/(JVS(450))
  X(63) = (X(63)-JVS(447)*X(175)-JVS(448)*X(230)-JVS(449)*X(234))/(JVS(446))
  X(62) = (X(62)-JVS(443)*X(224)-JVS(444)*X(230)-JVS(445)*X(231))/(JVS(442))
  X(61) = (X(61)-JVS(438)*X(77)-JVS(439)*X(224)-JVS(440)*X(230)-JVS(441)*X(234))/(JVS(437))
  X(60) = (X(60)-JVS(432)*X(108)-JVS(433)*X(120)-JVS(434)*X(230))/(JVS(431))
  X(59) = (X(59)-JVS(429)*X(226)-JVS(430)*X(230))/(JVS(428))
  X(58) = (X(58)-JVS(426)*X(224)-JVS(427)*X(236))/(JVS(425))
  X(57) = (X(57)-JVS(423)*X(221)-JVS(424)*X(230))/(JVS(422))
  X(56) = (X(56)-JVS(417)*X(77)-JVS(418)*X(88)-JVS(419)*X(130)-JVS(420)*X(174)-JVS(421)*X(221))/(JVS(416))
  X(55) = (X(55)-JVS(414)*X(226)-JVS(415)*X(230))/(JVS(413))
  X(54) = (X(54)-JVS(410)*X(225)-JVS(411)*X(230)-JVS(412)*X(231))/(JVS(409))
  X(53) = (X(53)-JVS(405)*X(72)-JVS(406)*X(230)-JVS(407)*X(231)-JVS(408)*X(234))/(JVS(404))
  X(52) = (X(52)-JVS(402)*X(224)-JVS(403)*X(225))/(JVS(401))
  X(51) = (X(51)-JVS(399)*X(190)-JVS(400)*X(230))/(JVS(398))
  X(50) = (X(50)-JVS(395)*X(230)-JVS(396)*X(231)-JVS(397)*X(234))/(JVS(394))
  X(49) = (X(49)-JVS(390)*X(230)-JVS(391)*X(231)-JVS(392)*X(234))/(JVS(389))
  X(48) = (X(48)-JVS(386)*X(171)-JVS(387)*X(234))/(JVS(385))
  X(47) = (X(47)-JVS(382)*X(77)-JVS(383)*X(88)-JVS(384)*X(130))/(JVS(381))
  X(46) = (X(46)-JVS(378)*X(171)-JVS(379)*X(230)-JVS(380)*X(231))/(JVS(377))
  X(45) = (X(45)-JVS(376)*X(230))/(JVS(375))
  X(44) = (X(44)-JVS(373)*X(224)-JVS(374)*X(232))/(JVS(372))
  X(43) = (X(43)-JVS(371)*X(230))/(JVS(370))
  X(42) = (X(42)-JVS(368)*X(224)-JVS(369)*X(235))/(JVS(367))
  X(41) = (X(41)-JVS(365)*X(67)-JVS(366)*X(174))/(JVS(364))
  X(40) = (X(40)-JVS(363)*X(230))/(JVS(362))
  X(39) = (X(39)-JVS(361)*X(230))/(JVS(360))
  X(38) = (X(38)-JVS(357)*X(105)-JVS(358)*X(144)-JVS(359)*X(162))/(JVS(356))
  X(37) = (X(37)-JVS(355)*X(174))/(JVS(354))
  X(36) = (X(36)-JVS(353)*X(230))/(JVS(352))
  X(35) = (X(35)-JVS(351)*X(230))/(JVS(350))
  X(34) = (X(34)-JVS(349)*X(67))/(JVS(348))
  X(33) = (X(33)-JVS(338)*X(121)-JVS(339)*X(122)-JVS(340)*X(141)-JVS(341)*X(169)-JVS(342)*X(183)-JVS(343)*X(190)&
            &-JVS(344)*X(207)-JVS(345)*X(230)-JVS(346)*X(231)-JVS(347)*X(233))/(JVS(337))
  X(32) = (X(32)-JVS(335)*X(226)-JVS(336)*X(230))/(JVS(334))
  X(31) = (X(31)-JVS(330)*X(99)-JVS(331)*X(169)-JVS(332)*X(190)-JVS(333)*X(230))/(JVS(329))
  X(30) = (X(30)-JVS(325)*X(169)-JVS(326)*X(190)-JVS(327)*X(222)-JVS(328)*X(230))/(JVS(324))
  X(29) = (X(29)-JVS(261)*X(55)-JVS(262)*X(59)-JVS(263)*X(75)-JVS(264)*X(80)-JVS(265)*X(97)-JVS(266)*X(100)-JVS(267)&
            &*X(102)-JVS(268)*X(103)-JVS(269)*X(108)-JVS(270)*X(118)-JVS(271)*X(120)-JVS(272)*X(121)-JVS(273)*X(122)&
            &-JVS(274)*X(123)-JVS(275)*X(124)-JVS(276)*X(128)-JVS(277)*X(129)-JVS(278)*X(133)-JVS(279)*X(137)-JVS(280)&
            &*X(138)-JVS(281)*X(139)-JVS(282)*X(141)-JVS(283)*X(142)-JVS(284)*X(143)-JVS(285)*X(148)-JVS(286)*X(150)&
            &-JVS(287)*X(151)-JVS(288)*X(153)-JVS(289)*X(156)-JVS(290)*X(161)-JVS(291)*X(165)-JVS(292)*X(166)-JVS(293)&
            &*X(168)-JVS(294)*X(170)-JVS(295)*X(176)-JVS(296)*X(177)-JVS(297)*X(179)-JVS(298)*X(181)-JVS(299)*X(183)&
            &-JVS(300)*X(186)-JVS(301)*X(191)-JVS(302)*X(192)-JVS(303)*X(193)-JVS(304)*X(196)-JVS(305)*X(197)-JVS(306)&
            &*X(198)-JVS(307)*X(202)-JVS(308)*X(205)-JVS(309)*X(206)-JVS(310)*X(207)-JVS(311)*X(210)-JVS(312)*X(211)&
            &-JVS(313)*X(219)-JVS(314)*X(220)-JVS(315)*X(223)-JVS(316)*X(226)-JVS(317)*X(227)-JVS(318)*X(230)-JVS(319)&
            &*X(231)-JVS(320)*X(232)-JVS(321)*X(233)-JVS(322)*X(234)-JVS(323)*X(236))/(JVS(260))
  X(28) = (X(28)-JVS(190)*X(34)-JVS(191)*X(37)-JVS(192)*X(41)-JVS(193)*X(57)-JVS(194)*X(67)-JVS(195)*X(72)-JVS(196)&
            &*X(74)-JVS(197)*X(77)-JVS(198)*X(81)-JVS(199)*X(83)-JVS(200)*X(88)-JVS(201)*X(93)-JVS(202)*X(105)-JVS(203)&
            &*X(109)-JVS(204)*X(110)-JVS(205)*X(111)-JVS(206)*X(112)-JVS(207)*X(117)-JVS(208)*X(121)-JVS(209)*X(122)&
            &-JVS(210)*X(126)-JVS(211)*X(127)-JVS(212)*X(130)-JVS(213)*X(141)-JVS(214)*X(143)-JVS(215)*X(144)-JVS(216)&
            &*X(145)-JVS(217)*X(157)-JVS(218)*X(158)-JVS(219)*X(161)-JVS(220)*X(162)-JVS(221)*X(163)-JVS(222)*X(168)&
            &-JVS(223)*X(170)-JVS(224)*X(172)-JVS(225)*X(174)-JVS(226)*X(176)-JVS(227)*X(177)-JVS(228)*X(178)-JVS(229)&
            &*X(179)-JVS(230)*X(183)-JVS(231)*X(184)-JVS(232)*X(185)-JVS(233)*X(186)-JVS(234)*X(188)-JVS(235)*X(189)&
            &-JVS(236)*X(190)-JVS(237)*X(196)-JVS(238)*X(198)-JVS(239)*X(200)-JVS(240)*X(201)-JVS(241)*X(203)-JVS(242)&
            &*X(204)-JVS(243)*X(207)-JVS(244)*X(208)-JVS(245)*X(209)-JVS(246)*X(211)-JVS(247)*X(212)-JVS(248)*X(213)&
            &-JVS(249)*X(218)-JVS(250)*X(219)-JVS(251)*X(220)-JVS(252)*X(221)-JVS(253)*X(223)-JVS(254)*X(224)-JVS(255)&
            &*X(227)-JVS(256)*X(230)-JVS(257)*X(231)-JVS(258)*X(233)-JVS(259)*X(236))/(JVS(189))
  X(27) = (X(27)-JVS(116)*X(38)-JVS(117)*X(52)-JVS(118)*X(58)-JVS(119)*X(61)-JVS(120)*X(62)-JVS(121)*X(63)-JVS(122)&
            &*X(64)-JVS(123)*X(65)-JVS(124)*X(66)-JVS(125)*X(73)-JVS(126)*X(76)-JVS(127)*X(78)-JVS(128)*X(90)-JVS(129)*X(91)&
            &-JVS(130)*X(98)-JVS(131)*X(101)-JVS(132)*X(105)-JVS(133)*X(114)-JVS(134)*X(115)-JVS(135)*X(116)-JVS(136)*X(118)&
            &-JVS(137)*X(119)-JVS(138)*X(120)-JVS(139)*X(134)-JVS(140)*X(135)-JVS(141)*X(136)-JVS(142)*X(140)-JVS(143)&
            &*X(146)-JVS(144)*X(147)-JVS(145)*X(149)-JVS(146)*X(154)-JVS(147)*X(156)-JVS(148)*X(164)-JVS(149)*X(165)&
            &-JVS(150)*X(167)-JVS(151)*X(169)-JVS(152)*X(170)-JVS(153)*X(172)-JVS(154)*X(173)-JVS(155)*X(175)-JVS(156)&
            &*X(180)-JVS(157)*X(184)-JVS(158)*X(185)-JVS(159)*X(187)-JVS(160)*X(188)-JVS(161)*X(190)-JVS(162)*X(191)&
            &-JVS(163)*X(192)-JVS(164)*X(195)-JVS(165)*X(199)-JVS(166)*X(201)-JVS(167)*X(203)-JVS(168)*X(204)-JVS(169)&
            &*X(205)-JVS(170)*X(206)-JVS(171)*X(208)-JVS(172)*X(209)-JVS(173)*X(212)-JVS(174)*X(213)-JVS(175)*X(214)&
            &-JVS(176)*X(215)-JVS(177)*X(216)-JVS(178)*X(217)-JVS(179)*X(224)-JVS(180)*X(225)-JVS(181)*X(226)-JVS(182)&
            &*X(228)-JVS(183)*X(229)-JVS(184)*X(230)-JVS(185)*X(231)-JVS(186)*X(234)-JVS(187)*X(235)-JVS(188)*X(236))&
            &/(JVS(115))
  X(26) = (X(26)-JVS(108)*X(60)-JVS(109)*X(86)-JVS(110)*X(104)-JVS(111)*X(106)-JVS(112)*X(142))/(JVS(107))
  X(25) = (X(25)-JVS(104)*X(79)-JVS(105)*X(179)-JVS(106)*X(198))/(JVS(103))
  X(24) = (X(24)-JVS(102)*X(158))/(JVS(101))
  X(23) = (X(23)-JVS(100)*X(158))/(JVS(99))
  X(22) = (X(22)-JVS(95)*X(99)-JVS(96)*X(169)-JVS(97)*X(190)-JVS(98)*X(230))/(JVS(94))
  X(21) = (X(21)-JVS(92)*X(74)-JVS(93)*X(230))/(JVS(91))
  X(20) = (X(20)-JVS(89)*X(53)-JVS(90)*X(234))/(JVS(88))
  X(19) = (X(19)-JVS(86)*X(53)-JVS(87)*X(231))/(JVS(85))
  X(18) = (X(18)-JVS(80)*X(124)-JVS(81)*X(128)-JVS(82)*X(133)-JVS(83)*X(138)-JVS(84)*X(230))/(JVS(79))
  X(17) = (X(17)-JVS(78)*X(18))/(JVS(77))
  X(16) = (X(16)-JVS(75)*X(49)-JVS(76)*X(234))/(JVS(74))
  X(15) = (X(15)-JVS(72)*X(49)-JVS(73)*X(231))/(JVS(71))
  X(14) = (X(14)-JVS(69)*X(183)-JVS(70)*X(227))/(JVS(68))
  X(13) = (X(13)-JVS(66)*X(183)-JVS(67)*X(230))/(JVS(65))
  X(12) = (X(12)-JVS(63)*X(50)-JVS(64)*X(234))/(JVS(62))
  X(11) = (X(11)-JVS(60)*X(50)-JVS(61)*X(231))/(JVS(59))
  X(10) = (X(10)-JVS(52)*X(34)-JVS(53)*X(37)-JVS(54)*X(41)-JVS(55)*X(46)-JVS(56)*X(77)-JVS(57)*X(88)-JVS(58)*X(130))&
            &/(JVS(51))
  X(9) = (X(9)-JVS(44)*X(34)-JVS(45)*X(37)-JVS(46)*X(41)-JVS(47)*X(46)-JVS(48)*X(77)-JVS(49)*X(88)-JVS(50)*X(130))&
           &/(JVS(43))
  X(8) = (X(8)-JVS(41)*X(38)-JVS(42)*X(76))/(JVS(40))
  X(7) = (X(7)-JVS(12)*X(72)-JVS(13)*X(79)-JVS(14)*X(90)-JVS(15)*X(91)-JVS(16)*X(108)-JVS(17)*X(118)-JVS(18)*X(129)&
           &-JVS(19)*X(132)-JVS(20)*X(143)-JVS(21)*X(153)-JVS(22)*X(155)-JVS(23)*X(160)-JVS(24)*X(168)-JVS(25)*X(170)&
           &-JVS(26)*X(183)-JVS(27)*X(193)-JVS(28)*X(197)-JVS(29)*X(209)-JVS(30)*X(210)-JVS(31)*X(222)-JVS(32)*X(225)&
           &-JVS(33)*X(226)-JVS(34)*X(227)-JVS(35)*X(230)-JVS(36)*X(231)-JVS(37)*X(233)-JVS(38)*X(234)-JVS(39)*X(236))&
           &/(JVS(11))
  X(6) = (X(6)-JVS(7)*X(34)-JVS(8)*X(37)-JVS(9)*X(41)-JVS(10)*X(46))/(JVS(6))
  X(5) = X(5)/JVS(5)
  X(4) = X(4)/JVS(4)
  X(3) = X(3)/JVS(3)
  X(2) = X(2)/JVS(2)
  X(1) = X(1)/JVS(1)
      
END SUBROUTINE KppSolve

! End of KppSolve function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! KppSolveTR - sparse, transposed back substitution
!   Arguments :
!      JVS       - sparse Jacobian of variables
!      X         - Vector for variables
!      XX        - Vector for output variables
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

SUBROUTINE KppSolveTR ( JVS, X, XX )

! JVS - sparse Jacobian of variables
  REAL(kind=dp) :: JVS(LU_NONZERO)
! X - Vector for variables
  REAL(kind=dp) :: X(NVAR)
! XX - Vector for output variables
  REAL(kind=dp) :: XX(NVAR)

  XX(1) = X(1)/JVS(1)
  XX(2) = X(2)/JVS(2)
  XX(3) = X(3)/JVS(3)
  XX(4) = X(4)/JVS(4)
  XX(5) = X(5)/JVS(5)
  XX(6) = X(6)/JVS(6)
  XX(7) = X(7)/JVS(11)
  XX(8) = X(8)/JVS(40)
  XX(9) = X(9)/JVS(43)
  XX(10) = X(10)/JVS(51)
  XX(11) = X(11)/JVS(59)
  XX(12) = X(12)/JVS(62)
  XX(13) = X(13)/JVS(65)
  XX(14) = X(14)/JVS(68)
  XX(15) = X(15)/JVS(71)
  XX(16) = X(16)/JVS(74)
  XX(17) = X(17)/JVS(77)
  XX(18) = (X(18)-JVS(78)*XX(17))/(JVS(79))
  XX(19) = X(19)/JVS(85)
  XX(20) = X(20)/JVS(88)
  XX(21) = X(21)/JVS(91)
  XX(22) = X(22)/JVS(94)
  XX(23) = X(23)/JVS(99)
  XX(24) = X(24)/JVS(101)
  XX(25) = X(25)/JVS(103)
  XX(26) = X(26)/JVS(107)
  XX(27) = X(27)/JVS(115)
  XX(28) = X(28)/JVS(189)
  XX(29) = X(29)/JVS(260)
  XX(30) = X(30)/JVS(324)
  XX(31) = X(31)/JVS(329)
  XX(32) = X(32)/JVS(334)
  XX(33) = X(33)/JVS(337)
  XX(34) = (X(34)-JVS(7)*XX(6)-JVS(44)*XX(9)-JVS(52)*XX(10)-JVS(190)*XX(28))/(JVS(348))
  XX(35) = X(35)/JVS(350)
  XX(36) = X(36)/JVS(352)
  XX(37) = (X(37)-JVS(8)*XX(6)-JVS(45)*XX(9)-JVS(53)*XX(10)-JVS(191)*XX(28))/(JVS(354))
  XX(38) = (X(38)-JVS(41)*XX(8)-JVS(116)*XX(27))/(JVS(356))
  XX(39) = X(39)/JVS(360)
  XX(40) = X(40)/JVS(362)
  XX(41) = (X(41)-JVS(9)*XX(6)-JVS(46)*XX(9)-JVS(54)*XX(10)-JVS(192)*XX(28))/(JVS(364))
  XX(42) = X(42)/JVS(367)
  XX(43) = X(43)/JVS(370)
  XX(44) = X(44)/JVS(372)
  XX(45) = X(45)/JVS(375)
  XX(46) = (X(46)-JVS(10)*XX(6)-JVS(47)*XX(9)-JVS(55)*XX(10))/(JVS(377))
  XX(47) = X(47)/JVS(381)
  XX(48) = X(48)/JVS(385)
  XX(49) = (X(49)-JVS(72)*XX(15)-JVS(75)*XX(16))/(JVS(389))
  XX(50) = (X(50)-JVS(60)*XX(11)-JVS(63)*XX(12))/(JVS(394))
  XX(51) = X(51)/JVS(398)
  XX(52) = (X(52)-JVS(117)*XX(27))/(JVS(401))
  XX(53) = (X(53)-JVS(86)*XX(19)-JVS(89)*XX(20))/(JVS(404))
  XX(54) = X(54)/JVS(409)
  XX(55) = (X(55)-JVS(261)*XX(29))/(JVS(413))
  XX(56) = X(56)/JVS(416)
  XX(57) = (X(57)-JVS(193)*XX(28))/(JVS(422))
  XX(58) = (X(58)-JVS(118)*XX(27))/(JVS(425))
  XX(59) = (X(59)-JVS(262)*XX(29))/(JVS(428))
  XX(60) = (X(60)-JVS(108)*XX(26))/(JVS(431))
  XX(61) = (X(61)-JVS(119)*XX(27))/(JVS(437))
  XX(62) = (X(62)-JVS(120)*XX(27))/(JVS(442))
  XX(63) = (X(63)-JVS(121)*XX(27))/(JVS(446))
  XX(64) = (X(64)-JVS(122)*XX(27))/(JVS(450))
  XX(65) = (X(65)-JVS(123)*XX(27))/(JVS(454))
  XX(66) = (X(66)-JVS(124)*XX(27))/(JVS(458))
  XX(67) = (X(67)-JVS(194)*XX(28)-JVS(349)*XX(34)-JVS(365)*XX(41))/(JVS(465))
  XX(68) = X(68)/JVS(469)
  XX(69) = X(69)/JVS(473)
  XX(70) = X(70)/JVS(477)
  XX(71) = X(71)/JVS(481)
  XX(72) = (X(72)-JVS(12)*XX(7)-JVS(195)*XX(28)-JVS(405)*XX(53))/(JVS(485))
  XX(73) = (X(73)-JVS(125)*XX(27))/(JVS(488))
  XX(74) = (X(74)-JVS(92)*XX(21)-JVS(196)*XX(28))/(JVS(492))
  XX(75) = (X(75)-JVS(263)*XX(29))/(JVS(495))
  XX(76) = (X(76)-JVS(42)*XX(8)-JVS(126)*XX(27))/(JVS(498))
  XX(77) = (X(77)-JVS(48)*XX(9)-JVS(56)*XX(10)-JVS(197)*XX(28)-JVS(382)*XX(47)-JVS(417)*XX(56)-JVS(438)*XX(61))&
             &/(JVS(512))
  XX(78) = (X(78)-JVS(127)*XX(27))/(JVS(516))
  XX(79) = (X(79)-JVS(13)*XX(7)-JVS(104)*XX(25))/(JVS(522))
  XX(80) = (X(80)-JVS(264)*XX(29))/(JVS(528))
  XX(81) = (X(81)-JVS(198)*XX(28))/(JVS(533))
  XX(82) = X(82)/JVS(538)
  XX(83) = (X(83)-JVS(199)*XX(28))/(JVS(543))
  XX(84) = X(84)/JVS(547)
  XX(85) = X(85)/JVS(551)
  XX(86) = (X(86)-JVS(109)*XX(26))/(JVS(555))
  XX(87) = X(87)/JVS(561)
  XX(88) = (X(88)-JVS(49)*XX(9)-JVS(57)*XX(10)-JVS(200)*XX(28)-JVS(383)*XX(47)-JVS(418)*XX(56))/(JVS(567))
  XX(89) = X(89)/JVS(572)
  XX(90) = (X(90)-JVS(14)*XX(7)-JVS(128)*XX(27))/(JVS(577))
  XX(91) = (X(91)-JVS(15)*XX(7)-JVS(129)*XX(27))/(JVS(582))
  XX(92) = X(92)/JVS(587)
  XX(93) = (X(93)-JVS(201)*XX(28)-JVS(489)*XX(73))/(JVS(598))
  XX(94) = X(94)/JVS(602)
  XX(95) = X(95)/JVS(606)
  XX(96) = X(96)/JVS(615)
  XX(97) = (X(97)-JVS(265)*XX(29))/(JVS(620))
  XX(98) = (X(98)-JVS(130)*XX(27))/(JVS(625))
  XX(99) = (X(99)-JVS(95)*XX(22)-JVS(330)*XX(31))/(JVS(635))
  XX(100) = (X(100)-JVS(266)*XX(29))/(JVS(640))
  XX(101) = (X(101)-JVS(131)*XX(27))/(JVS(645))
  XX(102) = (X(102)-JVS(267)*XX(29))/(JVS(654))
  XX(103) = (X(103)-JVS(268)*XX(29))/(JVS(659))
  XX(104) = (X(104)-JVS(110)*XX(26))/(JVS(665))
  XX(105) = (X(105)-JVS(132)*XX(27)-JVS(202)*XX(28)-JVS(357)*XX(38))/(JVS(671))
  XX(106) = (X(106)-JVS(111)*XX(26))/(JVS(677))
  XX(107) = X(107)/JVS(683)
  XX(108) = (X(108)-JVS(16)*XX(7)-JVS(269)*XX(29)-JVS(432)*XX(60))/(JVS(689))
  XX(109) = (X(109)-JVS(203)*XX(28)-JVS(588)*XX(92)-JVS(646)*XX(101))/(JVS(693))
  XX(110) = (X(110)-JVS(204)*XX(28)-JVS(589)*XX(92)-JVS(647)*XX(101))/(JVS(698))
  XX(111) = (X(111)-JVS(205)*XX(28)-JVS(499)*XX(76)-JVS(666)*XX(104)-JVS(678)*XX(106))/(JVS(703))
  XX(112) = (X(112)-JVS(206)*XX(28)-JVS(500)*XX(76)-JVS(667)*XX(104)-JVS(679)*XX(106))/(JVS(707))
  XX(113) = X(113)/JVS(711)
  XX(114) = (X(114)-JVS(133)*XX(27))/(JVS(717))
  XX(115) = (X(115)-JVS(134)*XX(27))/(JVS(723))
  XX(116) = (X(116)-JVS(135)*XX(27))/(JVS(729))
  XX(117) = (X(117)-JVS(207)*XX(28))/(JVS(734))
  XX(118) = (X(118)-JVS(17)*XX(7)-JVS(136)*XX(27)-JVS(270)*XX(29))/(JVS(739))
  XX(119) = (X(119)-JVS(137)*XX(27))/(JVS(746))
  XX(120) = (X(120)-JVS(138)*XX(27)-JVS(271)*XX(29)-JVS(433)*XX(60))/(JVS(751))
  XX(121) = (X(121)-JVS(208)*XX(28)-JVS(272)*XX(29)-JVS(338)*XX(33))/(JVS(756))
  XX(122) = (X(122)-JVS(209)*XX(28)-JVS(273)*XX(29)-JVS(339)*XX(33))/(JVS(760))
  XX(123) = (X(123)-JVS(274)*XX(29))/(JVS(766))
  XX(124) = (X(124)-JVS(80)*XX(18)-JVS(275)*XX(29)-JVS(668)*XX(104)-JVS(680)*XX(106))/(JVS(773))
  XX(125) = X(125)/JVS(777)
  XX(126) = (X(126)-JVS(210)*XX(28)-JVS(501)*XX(76)-JVS(607)*XX(95))/(JVS(790))
  XX(127) = (X(127)-JVS(211)*XX(28)-JVS(590)*XX(92)-JVS(648)*XX(101))/(JVS(794))
  XX(128) = (X(128)-JVS(81)*XX(18)-JVS(276)*XX(29)-JVS(669)*XX(104)-JVS(681)*XX(106))/(JVS(799))
  XX(129) = (X(129)-JVS(18)*XX(7)-JVS(277)*XX(29)-JVS(523)*XX(79))/(JVS(803))
  XX(130) = (X(130)-JVS(50)*XX(9)-JVS(58)*XX(10)-JVS(212)*XX(28)-JVS(384)*XX(47)-JVS(419)*XX(56))/(JVS(809))
  XX(131) = X(131)/JVS(817)
  XX(132) = (X(132)-JVS(19)*XX(7))/(JVS(829))
  XX(133) = (X(133)-JVS(82)*XX(18)-JVS(278)*XX(29)-JVS(556)*XX(86)-JVS(655)*XX(102))/(JVS(835))
  XX(134) = (X(134)-JVS(139)*XX(27))/(JVS(839))
  XX(135) = (X(135)-JVS(140)*XX(27))/(JVS(845))
  XX(136) = (X(136)-JVS(141)*XX(27))/(JVS(850))
  XX(137) = (X(137)-JVS(279)*XX(29))/(JVS(857))
  XX(138) = (X(138)-JVS(83)*XX(18)-JVS(280)*XX(29)-JVS(557)*XX(86)-JVS(641)*XX(100))/(JVS(867))
  XX(139) = (X(139)-JVS(281)*XX(29))/(JVS(872))
  XX(140) = (X(140)-JVS(142)*XX(27)-JVS(568)*XX(88)-JVS(810)*XX(130))/(JVS(885))
  XX(141) = (X(141)-JVS(213)*XX(28)-JVS(282)*XX(29)-JVS(340)*XX(33)-JVS(818)*XX(131))/(JVS(892))
  XX(142) = (X(142)-JVS(112)*XX(26)-JVS(283)*XX(29))/(JVS(908))
  XX(143) = (X(143)-JVS(20)*XX(7)-JVS(214)*XX(28)-JVS(284)*XX(29)-JVS(502)*XX(76))/(JVS(922))
  XX(144) = (X(144)-JVS(215)*XX(28)-JVS(358)*XX(38)-JVS(672)*XX(105))/(JVS(933))
  XX(145) = (X(145)-JVS(216)*XX(28)-JVS(503)*XX(76))/(JVS(943))
  XX(146) = (X(146)-JVS(143)*XX(27)-JVS(712)*XX(113)-JVS(830)*XX(132)-JVS(873)*XX(139))/(JVS(951))
  XX(147) = (X(147)-JVS(144)*XX(27)-JVS(713)*XX(113)-JVS(831)*XX(132))/(JVS(958))
  XX(148) = (X(148)-JVS(285)*XX(29))/(JVS(967))
  XX(149) = (X(149)-JVS(145)*XX(27)-JVS(714)*XX(113)-JVS(832)*XX(132))/(JVS(982))
  XX(150) = (X(150)-JVS(286)*XX(29)-JVS(529)*XX(80)-JVS(578)*XX(90)-JVS(718)*XX(114)-JVS(767)*XX(123)-JVS(804)*XX(129)&
              &-JVS(909)*XX(142)-JVS(968)*XX(148))/(JVS(989))
  XX(151) = (X(151)-JVS(287)*XX(29)-JVS(530)*XX(80)-JVS(583)*XX(91)-JVS(724)*XX(115)-JVS(768)*XX(123)-JVS(805)*XX(129)&
              &-JVS(910)*XX(142)-JVS(969)*XX(148))/(JVS(995))
  XX(152) = X(152)/JVS(1002)
  XX(153) = (X(153)-JVS(21)*XX(7)-JVS(288)*XX(29))/(JVS(1017))
  XX(154) = (X(154)-JVS(146)*XX(27)-JVS(874)*XX(139)-JVS(923)*XX(143)-JVS(1003)*XX(152))/(JVS(1027))
  XX(155) = (X(155)-JVS(22)*XX(7))/(JVS(1032))
  XX(156) = (X(156)-JVS(147)*XX(27)-JVS(289)*XX(29)-JVS(858)*XX(137))/(JVS(1054))
  XX(157) = (X(157)-JVS(217)*XX(28)-JVS(591)*XX(92)-JVS(626)*XX(98))/(JVS(1067))
  XX(158) = (X(158)-JVS(100)*XX(23)-JVS(102)*XX(24)-JVS(218)*XX(28)-JVS(592)*XX(92)-JVS(649)*XX(101)-JVS(694)*XX(109)&
              &-JVS(699)*XX(110))/(JVS(1084))
  XX(159) = X(159)/JVS(1100)
  XX(160) = (X(160)-JVS(23)*XX(7))/(JVS(1124))
  XX(161) = (X(161)-JVS(219)*XX(28)-JVS(290)*XX(29)-JVS(504)*XX(76))/(JVS(1147))
  XX(162) = (X(162)-JVS(220)*XX(28)-JVS(359)*XX(38)-JVS(673)*XX(105))/(JVS(1159))
  XX(163) = (X(163)-JVS(221)*XX(28)-JVS(505)*XX(76))/(JVS(1171))
  XX(164) = (X(164)-JVS(148)*XX(27)-JVS(859)*XX(137))/(JVS(1180))
  XX(165) = (X(165)-JVS(149)*XX(27)-JVS(291)*XX(29)-JVS(1148)*XX(161))/(JVS(1191))
  XX(166) = (X(166)-JVS(292)*XX(29)-JVS(562)*XX(87)-JVS(660)*XX(103)-JVS(860)*XX(137)-JVS(970)*XX(148))/(JVS(1205))
  XX(167) = (X(167)-JVS(150)*XX(27)-JVS(552)*XX(85)-JVS(778)*XX(125)-JVS(1033)*XX(155)-JVS(1101)*XX(159))/(JVS(1216))
  XX(168) = (X(168)-JVS(24)*XX(7)-JVS(222)*XX(28)-JVS(293)*XX(29))/(JVS(1228))
  XX(169) = (X(169)-JVS(96)*XX(22)-JVS(151)*XX(27)-JVS(325)*XX(30)-JVS(331)*XX(31)-JVS(341)*XX(33)-JVS(636)*XX(99)&
              &-JVS(819)*XX(131)-JVS(1034)*XX(155))/(JVS(1242))
  XX(170) = (X(170)-JVS(25)*XX(7)-JVS(152)*XX(27)-JVS(223)*XX(28)-JVS(294)*XX(29)-JVS(690)*XX(108)-JVS(752)*XX(120)&
              &-JVS(1125)*XX(160))/(JVS(1253))
  XX(171) = (X(171)-JVS(378)*XX(46)-JVS(386)*XX(48)-JVS(513)*XX(77)-JVS(811)*XX(130)-JVS(886)*XX(140))/(JVS(1275))
  XX(172) = (X(172)-JVS(153)*XX(27)-JVS(224)*XX(28)-JVS(593)*XX(92)-JVS(627)*XX(98)-JVS(695)*XX(109)-JVS(700)*XX(110)&
              &-JVS(1068)*XX(157)-JVS(1085)*XX(158))/(JVS(1288))
  XX(173) = (X(173)-JVS(154)*XX(27)-JVS(548)*XX(84)-JVS(779)*XX(125)-JVS(1035)*XX(155))/(JVS(1300))
  XX(174) = (X(174)-JVS(225)*XX(28)-JVS(355)*XX(37)-JVS(366)*XX(41)-JVS(420)*XX(56)-JVS(466)*XX(67)-JVS(534)*XX(81)&
              &-JVS(569)*XX(88)-JVS(812)*XX(130)-JVS(887)*XX(140)-JVS(1069)*XX(157)-JVS(1276)*XX(171))/(JVS(1316))
  XX(175) = (X(175)-JVS(155)*XX(27)-JVS(447)*XX(63)-JVS(539)*XX(82)-JVS(684)*XX(107)-JVS(1036)*XX(155))/(JVS(1326))
  XX(176) = (X(176)-JVS(226)*XX(28)-JVS(295)*XX(29)-JVS(506)*XX(76))/(JVS(1341))
  XX(177) = (X(177)-JVS(227)*XX(28)-JVS(296)*XX(29)-JVS(507)*XX(76)-JVS(558)*XX(86)-JVS(840)*XX(134)-JVS(911)*XX(142)&
              &-JVS(1018)*XX(153)-JVS(1055)*XX(156)-JVS(1206)*XX(166)-JVS(1229)*XX(168)-JVS(1342)*XX(176))/(JVS(1354))
  XX(178) = (X(178)-JVS(228)*XX(28)-JVS(467)*XX(67)-JVS(517)*XX(78)-JVS(535)*XX(81)-JVS(594)*XX(92)-JVS(628)*XX(98)&
              &-JVS(650)*XX(101)-JVS(795)*XX(127)-JVS(1070)*XX(157)-JVS(1086)*XX(158)-JVS(1277)*XX(171)-JVS(1289)*XX(172)&
              &-JVS(1317)*XX(174))/(JVS(1363))
  XX(179) = (X(179)-JVS(105)*XX(25)-JVS(229)*XX(28)-JVS(297)*XX(29))/(JVS(1389))
  XX(180) = (X(180)-JVS(156)*XX(27)-JVS(875)*XX(139)-JVS(924)*XX(143)-JVS(1004)*XX(152)-JVS(1102)*XX(159)-JVS(1230)&
              &*XX(168)-JVS(1343)*XX(176)-JVS(1390)*XX(179))/(JVS(1409))
  XX(181) = (X(181)-JVS(298)*XX(29))/(JVS(1419))
  XX(182) = X(182)/JVS(1435)
  XX(183) = (X(183)-JVS(26)*XX(7)-JVS(66)*XX(13)-JVS(69)*XX(14)-JVS(230)*XX(28)-JVS(299)*XX(29)-JVS(342)*XX(33)-JVS(642)&
              &*XX(100)-JVS(656)*XX(102)-JVS(820)*XX(131)-JVS(876)*XX(139)-JVS(912)*XX(142)-JVS(990)*XX(150)-JVS(996)&
              &*XX(151)-JVS(1005)*XX(152)-JVS(1126)*XX(160)-JVS(1149)*XX(161)-JVS(1181)*XX(164)-JVS(1192)*XX(165)-JVS(1391)&
              &*XX(179))/(JVS(1458))
  XX(184) = (X(184)-JVS(157)*XX(27)-JVS(231)*XX(28)-JVS(934)*XX(144)-JVS(1160)*XX(162))/(JVS(1466))
  XX(185) = (X(185)-JVS(158)*XX(27)-JVS(232)*XX(28)-JVS(780)*XX(125)-JVS(935)*XX(144)-JVS(1161)*XX(162)-JVS(1436)&
              &*XX(182)-JVS(1467)*XX(184))/(JVS(1479))
  XX(186) = (X(186)-JVS(233)*XX(28)-JVS(300)*XX(29)-JVS(508)*XX(76)-JVS(559)*XX(86)-JVS(851)*XX(136)-JVS(913)*XX(142)&
              &-JVS(925)*XX(143)-JVS(1019)*XX(153)-JVS(1056)*XX(156)-JVS(1103)*XX(159)-JVS(1207)*XX(166)-JVS(1344)*XX(176)&
              &-JVS(1392)*XX(179))/(JVS(1487))
  XX(187) = (X(187)-JVS(159)*XX(27))/(JVS(1531))
  XX(188) = (X(188)-JVS(160)*XX(27)-JVS(234)*XX(28)-JVS(573)*XX(89)-JVS(781)*XX(125)-JVS(1162)*XX(162)-JVS(1437)*XX(182)&
              &-JVS(1532)*XX(187))/(JVS(1571))
  XX(189) = (X(189)-JVS(235)*XX(28)-JVS(1533)*XX(187))/(JVS(1587))
  XX(190) = (X(190)-JVS(97)*XX(22)-JVS(161)*XX(27)-JVS(236)*XX(28)-JVS(326)*XX(30)-JVS(332)*XX(31)-JVS(343)*XX(33)&
              &-JVS(399)*XX(51)-JVS(637)*XX(99)-JVS(821)*XX(131)-JVS(1127)*XX(160)-JVS(1243)*XX(169))/(JVS(1602))
  XX(191) = (X(191)-JVS(162)*XX(27)-JVS(301)*XX(29)-JVS(563)*XX(87)-JVS(621)*XX(97)-JVS(769)*XX(123)-JVS(861)*XX(137)&
              &-JVS(971)*XX(148)-JVS(1208)*XX(166)-JVS(1345)*XX(176)-JVS(1393)*XX(179)-JVS(1534)*XX(187))/(JVS(1623))
  XX(192) = (X(192)-JVS(163)*XX(27)-JVS(302)*XX(29)-JVS(622)*XX(97)-JVS(661)*XX(103)-JVS(770)*XX(123)-JVS(862)*XX(137)&
              &-JVS(972)*XX(148)-JVS(1209)*XX(166)-JVS(1346)*XX(176)-JVS(1394)*XX(179)-JVS(1535)*XX(187)-JVS(1624)*XX(191))&
              &/(JVS(1644))
  XX(193) = (X(193)-JVS(27)*XX(7)-JVS(303)*XX(29)-JVS(1006)*XX(152))/(JVS(1671))
  XX(194) = (X(194)-JVS(863)*XX(137)-JVS(973)*XX(148)-JVS(1395)*XX(179)-JVS(1536)*XX(187))/(JVS(1704))
  XX(195) = (X(195)-JVS(164)*XX(27)-JVS(926)*XX(143)-JVS(1104)*XX(159)-JVS(1231)*XX(168)-JVS(1537)*XX(187))/(JVS(1723))
  XX(196) = (X(196)-JVS(237)*XX(28)-JVS(304)*XX(29)-JVS(1538)*XX(187))/(JVS(1749))
  XX(197) = (X(197)-JVS(28)*XX(7)-JVS(305)*XX(29)-JVS(1128)*XX(160)-JVS(1396)*XX(179)-JVS(1438)*XX(182)-JVS(1539)&
              &*XX(187))/(JVS(1785))
  XX(198) = (X(198)-JVS(106)*XX(25)-JVS(238)*XX(28)-JVS(306)*XX(29)-JVS(1540)*XX(187))/(JVS(1840))
  XX(199) = (X(199)-JVS(165)*XX(27)-JVS(782)*XX(125)-JVS(1037)*XX(155)-JVS(1172)*XX(163)-JVS(1420)*XX(181)-JVS(1439)&
              &*XX(182)-JVS(1541)*XX(187)-JVS(1588)*XX(189)-JVS(1750)*XX(196))/(JVS(1866))
  XX(200) = (X(200)-JVS(239)*XX(28)-JVS(595)*XX(92)-JVS(651)*XX(101)-JVS(696)*XX(109)-JVS(701)*XX(110)-JVS(1071)*XX(157)&
              &-JVS(1087)*XX(158)-JVS(1290)*XX(172)-JVS(1542)*XX(187))/(JVS(1883))
  XX(201) = (X(201)-JVS(166)*XX(27)-JVS(240)*XX(28)-JVS(509)*XX(76)-JVS(524)*XX(79)-JVS(974)*XX(148)-JVS(1129)*XX(160)&
              &-JVS(1232)*XX(168)-JVS(1397)*XX(179)-JVS(1543)*XX(187)-JVS(1786)*XX(197)-JVS(1841)*XX(198))/(JVS(1913))
  XX(202) = (X(202)-JVS(307)*XX(29)-JVS(531)*XX(80)-JVS(719)*XX(114)-JVS(725)*XX(115)-JVS(740)*XX(118)-JVS(771)*XX(123)&
              &-JVS(806)*XX(129)-JVS(914)*XX(142)-JVS(927)*XX(143)-JVS(975)*XX(148)-JVS(1105)*XX(159)-JVS(1130)*XX(160)&
              &-JVS(1150)*XX(161)-JVS(1182)*XX(164)-JVS(1193)*XX(165)-JVS(1233)*XX(168)-JVS(1398)*XX(179)-JVS(1544)*XX(187)&
              &-JVS(1672)*XX(193)-JVS(1705)*XX(194)-JVS(1787)*XX(197)-JVS(1842)*XX(198)-JVS(1914)*XX(201))/(JVS(1935))
  XX(203) = (X(203)-JVS(167)*XX(27)-JVS(241)*XX(28)-JVS(510)*XX(76)-JVS(741)*XX(118)-JVS(807)*XX(129)-JVS(877)*XX(139)&
              &-JVS(976)*XX(148)-JVS(1007)*XX(152)-JVS(1106)*XX(159)-JVS(1131)*XX(160)-JVS(1151)*XX(161)-JVS(1234)*XX(168)&
              &-JVS(1347)*XX(176)-JVS(1399)*XX(179)-JVS(1545)*XX(187)-JVS(1673)*XX(193)-JVS(1706)*XX(194)-JVS(1724)*XX(195)&
              &-JVS(1788)*XX(197)-JVS(1843)*XX(198)-JVS(1915)*XX(201))/(JVS(1961))
  XX(204) = (X(204)-JVS(168)*XX(27)-JVS(242)*XX(28)-JVS(511)*XX(76)-JVS(608)*XX(95)-JVS(730)*XX(116)-JVS(1107)*XX(159)&
              &-JVS(1235)*XX(168)-JVS(1546)*XX(187)-JVS(1725)*XX(195)-JVS(1789)*XX(197)-JVS(1844)*XX(198)-JVS(1916)*XX(201)&
              &-JVS(1936)*XX(202)-JVS(1962)*XX(203))/(JVS(1984))
  XX(205) = (X(205)-JVS(169)*XX(27)-JVS(308)*XX(29)-JVS(643)*XX(100)-JVS(704)*XX(111)-JVS(774)*XX(124)-JVS(846)*XX(135)&
              &-JVS(868)*XX(138)-JVS(878)*XX(139)-JVS(915)*XX(142)-JVS(952)*XX(146)-JVS(983)*XX(149)-JVS(991)*XX(150)&
              &-JVS(1020)*XX(153)-JVS(1057)*XX(156)-JVS(1132)*XX(160)-JVS(1152)*XX(161)-JVS(1183)*XX(164)-JVS(1210)*XX(166)&
              &-JVS(1348)*XX(176)-JVS(1355)*XX(177)-JVS(1400)*XX(179)-JVS(1547)*XX(187)-JVS(1625)*XX(191)-JVS(1645)*XX(192)&
              &-JVS(1674)*XX(193)-JVS(1707)*XX(194)-JVS(1790)*XX(197)-JVS(1845)*XX(198)-JVS(1917)*XX(201)-JVS(1937)*XX(202)&
              &-JVS(1963)*XX(203)-JVS(1985)*XX(204))/(JVS(1999))
  XX(206) = (X(206)-JVS(170)*XX(27)-JVS(309)*XX(29)-JVS(657)*XX(102)-JVS(708)*XX(112)-JVS(747)*XX(119)-JVS(800)*XX(128)&
              &-JVS(836)*XX(133)-JVS(916)*XX(142)-JVS(959)*XX(147)-JVS(984)*XX(149)-JVS(997)*XX(151)-JVS(1008)*XX(152)&
              &-JVS(1021)*XX(153)-JVS(1058)*XX(156)-JVS(1133)*XX(160)-JVS(1153)*XX(161)-JVS(1194)*XX(165)-JVS(1211)*XX(166)&
              &-JVS(1349)*XX(176)-JVS(1401)*XX(179)-JVS(1488)*XX(186)-JVS(1548)*XX(187)-JVS(1626)*XX(191)-JVS(1646)*XX(192)&
              &-JVS(1675)*XX(193)-JVS(1708)*XX(194)-JVS(1791)*XX(197)-JVS(1846)*XX(198)-JVS(1918)*XX(201)-JVS(1938)*XX(202)&
              &-JVS(1964)*XX(203)-JVS(1986)*XX(204)-JVS(2000)*XX(205))/(JVS(2014))
  XX(207) = (X(207)-JVS(243)*XX(28)-JVS(310)*XX(29)-JVS(344)*XX(33)-JVS(525)*XX(79)-JVS(822)*XX(131)-JVS(1184)*XX(164)&
              &-JVS(1603)*XX(190)-JVS(1709)*XX(194)-JVS(1792)*XX(197)-JVS(1847)*XX(198)-JVS(1919)*XX(201))/(JVS(2034))
  XX(208) = (X(208)-JVS(171)*XX(27)-JVS(244)*XX(28)-JVS(574)*XX(89)-JVS(783)*XX(125)-JVS(936)*XX(144)-JVS(1134)*XX(160)&
              &-JVS(1163)*XX(162)-JVS(1421)*XX(181)-JVS(1440)*XX(182)-JVS(1549)*XX(187)-JVS(1589)*XX(189)-JVS(1751)*XX(196)&
              &-JVS(1884)*XX(200))/(JVS(2047))
  XX(209) = (X(209)-JVS(29)*XX(7)-JVS(172)*XX(27)-JVS(245)*XX(28)-JVS(753)*XX(120)-JVS(928)*XX(143)-JVS(1108)*XX(159)&
              &-JVS(1135)*XX(160)-JVS(1154)*XX(161)-JVS(1254)*XX(170)-JVS(1550)*XX(187)-JVS(1848)*XX(198))/(JVS(2063))
  XX(210) = (X(210)-JVS(30)*XX(7)-JVS(311)*XX(29)-JVS(1038)*XX(155)-JVS(1136)*XX(160)-JVS(1849)*XX(198))/(JVS(2117))
  XX(211) = (X(211)-JVS(246)*XX(28)-JVS(312)*XX(29)-JVS(1009)*XX(152)-JVS(1109)*XX(159)-JVS(1195)*XX(165)-JVS(1255)&
              &*XX(170)-JVS(1551)*XX(187)-JVS(1604)*XX(190)-JVS(1676)*XX(193)-JVS(1850)*XX(198)-JVS(2064)*XX(209)-JVS(2118)&
              &*XX(210))/(JVS(2146))
  XX(212) = (X(212)-JVS(173)*XX(27)-JVS(247)*XX(28)-JVS(609)*XX(95)-JVS(791)*XX(126)-JVS(917)*XX(142)-JVS(944)*XX(145)&
              &-JVS(1028)*XX(154)-JVS(1110)*XX(159)-JVS(1236)*XX(168)-JVS(1350)*XX(176)-JVS(1356)*XX(177)-JVS(1402)*XX(179)&
              &-JVS(1410)*XX(180)-JVS(1441)*XX(182)-JVS(1489)*XX(186)-JVS(1552)*XX(187)-JVS(1627)*XX(191)-JVS(1647)*XX(192)&
              &-JVS(1677)*XX(193)-JVS(1710)*XX(194)-JVS(1726)*XX(195)-JVS(1793)*XX(197)-JVS(1851)*XX(198)-JVS(1920)*XX(201)&
              &-JVS(1939)*XX(202)-JVS(1965)*XX(203)-JVS(1987)*XX(204)-JVS(2001)*XX(205)-JVS(2015)*XX(206)-JVS(2035)*XX(207)&
              &-JVS(2065)*XX(209)-JVS(2119)*XX(210)-JVS(2147)*XX(211))/(JVS(2159))
  XX(213) = (X(213)-JVS(174)*XX(27)-JVS(248)*XX(28)-JVS(610)*XX(95)-JVS(945)*XX(145)-JVS(1411)*XX(180)-JVS(1442)*XX(182)&
              &-JVS(1490)*XX(186)-JVS(1553)*XX(187)-JVS(1628)*XX(191)-JVS(1648)*XX(192)-JVS(1678)*XX(193)-JVS(1711)*XX(194)&
              &-JVS(1727)*XX(195)-JVS(1794)*XX(197)-JVS(1852)*XX(198)-JVS(1921)*XX(201)-JVS(1940)*XX(202)-JVS(1966)*XX(203)&
              &-JVS(1988)*XX(204)-JVS(2036)*XX(207)-JVS(2066)*XX(209)-JVS(2120)*XX(210)-JVS(2148)*XX(211)-JVS(2160)*XX(212))&
              &/(JVS(2172))
  XX(214) = (X(214)-JVS(175)*XX(27)-JVS(1010)*XX(152)-JVS(1039)*XX(155)-JVS(1443)*XX(182)-JVS(1853)*XX(198)-JVS(2121)&
              &*XX(210))/(JVS(2197))
  XX(215) = (X(215)-JVS(176)*XX(27)-JVS(784)*XX(125)-JVS(1011)*XX(152)-JVS(1040)*XX(155)-JVS(1173)*XX(163)-JVS(1422)&
              &*XX(181)-JVS(1444)*XX(182)-JVS(1554)*XX(187)-JVS(1590)*XX(189)-JVS(1752)*XX(196)-JVS(1854)*XX(198)-JVS(1867)&
              &*XX(199)-JVS(1885)*XX(200)-JVS(2198)*XX(214))/(JVS(2217))
  XX(216) = (X(216)-JVS(177)*XX(27)-JVS(470)*XX(68)-JVS(785)*XX(125)-JVS(1041)*XX(155)-JVS(1174)*XX(163)-JVS(1423)&
              &*XX(181)-JVS(1445)*XX(182)-JVS(1555)*XX(187)-JVS(1591)*XX(189)-JVS(1753)*XX(196)-JVS(1868)*XX(199)-JVS(1886)&
              &*XX(200)-JVS(2199)*XX(214)-JVS(2218)*XX(215))/(JVS(2233))
  XX(217) = (X(217)-JVS(178)*XX(27)-JVS(540)*XX(82)-JVS(685)*XX(107)-JVS(1042)*XX(155)-JVS(1446)*XX(182))/(JVS(2252))
  XX(218) = (X(218)-JVS(249)*XX(28)-JVS(490)*XX(73)-JVS(596)*XX(92)-JVS(599)*XX(93)-JVS(629)*XX(98)-JVS(796)*XX(127)&
              &-JVS(1072)*XX(157)-JVS(1088)*XX(158)-JVS(1291)*XX(172)-JVS(1364)*XX(178)-JVS(1556)*XX(187)-JVS(1887)*XX(200))&
              &/(JVS(2316))
  XX(219) = (X(219)-JVS(250)*XX(28)-JVS(313)*XX(29)-JVS(1217)*XX(167)-JVS(1244)*XX(169)-JVS(1301)*XX(173)-JVS(1447)&
              &*XX(182)-JVS(1605)*XX(190)-JVS(1754)*XX(196)-JVS(1855)*XX(198)-JVS(1888)*XX(200)-JVS(2122)*XX(210)-JVS(2253)&
              &*XX(217)-JVS(2317)*XX(218))/(JVS(2340))
  XX(220) = (X(220)-JVS(251)*XX(28)-JVS(314)*XX(29)-JVS(1557)*XX(187)-JVS(1889)*XX(200)-JVS(2318)*XX(218))/(JVS(2428))
  XX(221) = (X(221)-JVS(252)*XX(28)-JVS(421)*XX(56)-JVS(423)*XX(57)-JVS(518)*XX(78)-JVS(536)*XX(81)-JVS(597)*XX(92)&
              &-JVS(630)*XX(98)-JVS(1073)*XX(157)-JVS(1278)*XX(171)-JVS(1292)*XX(172)-JVS(1318)*XX(174)-JVS(1365)*XX(178)&
              &-JVS(1558)*XX(187)-JVS(1890)*XX(200)-JVS(2319)*XX(218)-JVS(2429)*XX(220))/(JVS(2461))
  XX(222) = (X(222)-JVS(31)*XX(7)-JVS(327)*XX(30)-JVS(1245)*XX(169)-JVS(1606)*XX(190)-JVS(2320)*XX(218)-JVS(2430)&
              &*XX(220)-JVS(2462)*XX(221))/(JVS(2551))
  XX(223) = (X(223)-JVS(253)*XX(28)-JVS(315)*XX(29)-JVS(1559)*XX(187)-JVS(1891)*XX(200)-JVS(2321)*XX(218)-JVS(2431)&
              &*XX(220)-JVS(2463)*XX(221)-JVS(2552)*XX(222))/(JVS(2588))
  XX(224) = (X(224)-JVS(179)*XX(27)-JVS(254)*XX(28)-JVS(368)*XX(42)-JVS(373)*XX(44)-JVS(402)*XX(52)-JVS(426)*XX(58)&
              &-JVS(439)*XX(61)-JVS(443)*XX(62)-JVS(514)*XX(77)-JVS(600)*XX(93)-JVS(720)*XX(114)-JVS(726)*XX(115)-JVS(754)&
              &*XX(120)-JVS(797)*XX(127)-JVS(813)*XX(130)-JVS(888)*XX(140)-JVS(1074)*XX(157)-JVS(1089)*XX(158)-JVS(1137)&
              &*XX(160)-JVS(1155)*XX(161)-JVS(1185)*XX(164)-JVS(1196)*XX(165)-JVS(1246)*XX(169)-JVS(1256)*XX(170)-JVS(1279)&
              &*XX(171)-JVS(1293)*XX(172)-JVS(1319)*XX(174)-JVS(1366)*XX(178)-JVS(1560)*XX(187)-JVS(1607)*XX(190)-JVS(1679)&
              &*XX(193)-JVS(1712)*XX(194)-JVS(1795)*XX(197)-JVS(1856)*XX(198)-JVS(1892)*XX(200)-JVS(1922)*XX(201)-JVS(2067)&
              &*XX(209)-JVS(2123)*XX(210)-JVS(2200)*XX(214)-JVS(2322)*XX(218)-JVS(2432)*XX(220)-JVS(2464)*XX(221)-JVS(2553)&
              &*XX(222)-JVS(2589)*XX(223))/(JVS(2705))
  XX(225) = (X(225)-JVS(32)*XX(7)-JVS(180)*XX(27)-JVS(403)*XX(52)-JVS(410)*XX(54)-JVS(611)*XX(95)-JVS(937)*XX(144)&
              &-JVS(1043)*XX(155)-JVS(1164)*XX(162)-JVS(1218)*XX(167)-JVS(1302)*XX(173)-JVS(1327)*XX(175)-JVS(1424)*XX(181)&
              &-JVS(1448)*XX(182)-JVS(1468)*XX(184)-JVS(1480)*XX(185)-JVS(1561)*XX(187)-JVS(1572)*XX(188)-JVS(1592)*XX(189)&
              &-JVS(1728)*XX(195)-JVS(1755)*XX(196)-JVS(1796)*XX(197)-JVS(1857)*XX(198)-JVS(1869)*XX(199)-JVS(1893)*XX(200)&
              &-JVS(1923)*XX(201)-JVS(1941)*XX(202)-JVS(1967)*XX(203)-JVS(1989)*XX(204)-JVS(2037)*XX(207)-JVS(2048)*XX(208)&
              &-JVS(2068)*XX(209)-JVS(2124)*XX(210)-JVS(2149)*XX(211)-JVS(2161)*XX(212)-JVS(2173)*XX(213)-JVS(2201)*XX(214)&
              &-JVS(2219)*XX(215)-JVS(2234)*XX(216)-JVS(2254)*XX(217)-JVS(2323)*XX(218)-JVS(2341)*XX(219)-JVS(2433)*XX(220)&
              &-JVS(2465)*XX(221)-JVS(2554)*XX(222)-JVS(2590)*XX(223)-JVS(2706)*XX(224))/(JVS(2778))
  XX(226) = (X(226)-JVS(33)*XX(7)-JVS(181)*XX(27)-JVS(316)*XX(29)-JVS(335)*XX(32)-JVS(414)*XX(55)-JVS(429)*XX(59)&
              &-JVS(496)*XX(75)-JVS(519)*XX(78)-JVS(544)*XX(83)-JVS(603)*XX(94)-JVS(616)*XX(96)-JVS(631)*XX(98)-JVS(686)&
              &*XX(107)-JVS(735)*XX(117)-JVS(823)*XX(131)-JVS(1044)*XX(155)-JVS(1075)*XX(157)-JVS(1138)*XX(160)-JVS(1294)&
              &*XX(172)-JVS(1303)*XX(173)-JVS(1328)*XX(175)-JVS(1425)*XX(181)-JVS(1449)*XX(182)-JVS(1459)*XX(183)-JVS(1562)&
              &*XX(187)-JVS(1608)*XX(190)-JVS(1680)*XX(193)-JVS(1713)*XX(194)-JVS(1756)*XX(196)-JVS(1797)*XX(197)-JVS(1858)&
              &*XX(198)-JVS(1894)*XX(200)-JVS(1924)*XX(201)-JVS(2002)*XX(205)-JVS(2016)*XX(206)-JVS(2038)*XX(207)-JVS(2069)&
              &*XX(209)-JVS(2125)*XX(210)-JVS(2150)*XX(211)-JVS(2162)*XX(212)-JVS(2174)*XX(213)-JVS(2202)*XX(214)-JVS(2235)&
              &*XX(216)-JVS(2255)*XX(217)-JVS(2324)*XX(218)-JVS(2342)*XX(219)-JVS(2434)*XX(220)-JVS(2466)*XX(221)-JVS(2555)&
              &*XX(222)-JVS(2591)*XX(223)-JVS(2707)*XX(224)-JVS(2779)*XX(225))/(JVS(2862))
  XX(227) = (X(227)-JVS(34)*XX(7)-JVS(70)*XX(14)-JVS(255)*XX(28)-JVS(317)*XX(29)-JVS(486)*XX(72)-JVS(493)*XX(74)&
              &-JVS(545)*XX(83)-JVS(601)*XX(93)-JVS(612)*XX(95)-JVS(638)*XX(99)-JVS(674)*XX(105)-JVS(736)*XX(117)-JVS(757)&
              &*XX(121)-JVS(761)*XX(122)-JVS(814)*XX(130)-JVS(824)*XX(131)-JVS(889)*XX(140)-JVS(893)*XX(141)-JVS(938)&
              &*XX(144)-JVS(1076)*XX(157)-JVS(1111)*XX(159)-JVS(1139)*XX(160)-JVS(1165)*XX(162)-JVS(1219)*XX(167)-JVS(1237)&
              &*XX(168)-JVS(1247)*XX(169)-JVS(1257)*XX(170)-JVS(1280)*XX(171)-JVS(1320)*XX(174)-JVS(1329)*XX(175)-JVS(1367)&
              &*XX(178)-JVS(1403)*XX(179)-JVS(1450)*XX(182)-JVS(1460)*XX(183)-JVS(1469)*XX(184)-JVS(1481)*XX(185)-JVS(1563)&
              &*XX(187)-JVS(1573)*XX(188)-JVS(1593)*XX(189)-JVS(1609)*XX(190)-JVS(1681)*XX(193)-JVS(1714)*XX(194)-JVS(1729)&
              &*XX(195)-JVS(1757)*XX(196)-JVS(1798)*XX(197)-JVS(1859)*XX(198)-JVS(1895)*XX(200)-JVS(1925)*XX(201)-JVS(1942)&
              &*XX(202)-JVS(1968)*XX(203)-JVS(1990)*XX(204)-JVS(2003)*XX(205)-JVS(2017)*XX(206)-JVS(2039)*XX(207)-JVS(2049)&
              &*XX(208)-JVS(2070)*XX(209)-JVS(2126)*XX(210)-JVS(2151)*XX(211)-JVS(2163)*XX(212)-JVS(2175)*XX(213)-JVS(2203)&
              &*XX(214)-JVS(2220)*XX(215)-JVS(2236)*XX(216)-JVS(2256)*XX(217)-JVS(2325)*XX(218)-JVS(2343)*XX(219)-JVS(2435)&
              &*XX(220)-JVS(2467)*XX(221)-JVS(2556)*XX(222)-JVS(2592)*XX(223)-JVS(2708)*XX(224)-JVS(2780)*XX(225)-JVS(2863)&
              &*XX(226))/(JVS(2943))
  XX(228) = (X(228)-JVS(182)*XX(27)-JVS(459)*XX(66)-JVS(474)*XX(69)-JVS(786)*XX(125)-JVS(1045)*XX(155)-JVS(1451)*XX(182)&
              &-JVS(1758)*XX(196)-JVS(2257)*XX(217)-JVS(2326)*XX(218)-JVS(2436)*XX(220)-JVS(2468)*XX(221)-JVS(2557)*XX(222)&
              &-JVS(2593)*XX(223)-JVS(2709)*XX(224)-JVS(2781)*XX(225)-JVS(2864)*XX(226)-JVS(2944)*XX(227))/(JVS(2966))
  XX(229) = (X(229)-JVS(183)*XX(27)-JVS(451)*XX(64)-JVS(478)*XX(70)-JVS(787)*XX(125)-JVS(1046)*XX(155)-JVS(1426)*XX(181)&
              &-JVS(1452)*XX(182)-JVS(1759)*XX(196)-JVS(1896)*XX(200)-JVS(2204)*XX(214)-JVS(2258)*XX(217)-JVS(2327)*XX(218)&
              &-JVS(2437)*XX(220)-JVS(2469)*XX(221)-JVS(2558)*XX(222)-JVS(2594)*XX(223)-JVS(2710)*XX(224)-JVS(2782)*XX(225)&
              &-JVS(2865)*XX(226)-JVS(2945)*XX(227)-JVS(2967)*XX(228))/(JVS(2989))
  XX(230) = (X(230)-JVS(35)*XX(7)-JVS(67)*XX(13)-JVS(84)*XX(18)-JVS(93)*XX(21)-JVS(98)*XX(22)-JVS(184)*XX(27)-JVS(256)&
              &*XX(28)-JVS(318)*XX(29)-JVS(328)*XX(30)-JVS(333)*XX(31)-JVS(336)*XX(32)-JVS(345)*XX(33)-JVS(351)*XX(35)&
              &-JVS(353)*XX(36)-JVS(361)*XX(39)-JVS(363)*XX(40)-JVS(371)*XX(43)-JVS(376)*XX(45)-JVS(379)*XX(46)-JVS(390)&
              &*XX(49)-JVS(395)*XX(50)-JVS(400)*XX(51)-JVS(406)*XX(53)-JVS(411)*XX(54)-JVS(415)*XX(55)-JVS(424)*XX(57)&
              &-JVS(430)*XX(59)-JVS(434)*XX(60)-JVS(440)*XX(61)-JVS(444)*XX(62)-JVS(448)*XX(63)-JVS(452)*XX(64)-JVS(455)&
              &*XX(65)-JVS(460)*XX(66)-JVS(471)*XX(68)-JVS(475)*XX(69)-JVS(479)*XX(70)-JVS(482)*XX(71)-JVS(487)*XX(72)&
              &-JVS(491)*XX(73)-JVS(494)*XX(74)-JVS(497)*XX(75)-JVS(520)*XX(78)-JVS(526)*XX(79)-JVS(532)*XX(80)-JVS(537)&
              &*XX(81)-JVS(541)*XX(82)-JVS(546)*XX(83)-JVS(549)*XX(84)-JVS(553)*XX(85)-JVS(560)*XX(86)-JVS(564)*XX(87)&
              &-JVS(570)*XX(88)-JVS(575)*XX(89)-JVS(579)*XX(90)-JVS(584)*XX(91)-JVS(604)*XX(94)-JVS(617)*XX(96)-JVS(623)&
              &*XX(97)-JVS(632)*XX(98)-JVS(639)*XX(99)-JVS(644)*XX(100)-JVS(652)*XX(101)-JVS(658)*XX(102)-JVS(662)*XX(103)&
              &-JVS(670)*XX(104)-JVS(675)*XX(105)-JVS(682)*XX(106)-JVS(687)*XX(107)-JVS(691)*XX(108)-JVS(705)*XX(111)&
              &-JVS(709)*XX(112)-JVS(715)*XX(113)-JVS(731)*XX(116)-JVS(737)*XX(117)-JVS(742)*XX(118)-JVS(748)*XX(119)&
              &-JVS(755)*XX(120)-JVS(758)*XX(121)-JVS(762)*XX(122)-JVS(772)*XX(123)-JVS(775)*XX(124)-JVS(788)*XX(125)&
              &-JVS(792)*XX(126)-JVS(801)*XX(128)-JVS(808)*XX(129)-JVS(825)*XX(131)-JVS(833)*XX(132)-JVS(837)*XX(133)&
              &-JVS(841)*XX(134)-JVS(847)*XX(135)-JVS(852)*XX(136)-JVS(864)*XX(137)-JVS(869)*XX(138)-JVS(879)*XX(139)&
              &-JVS(890)*XX(140)-JVS(894)*XX(141)-JVS(918)*XX(142)-JVS(929)*XX(143)-JVS(939)*XX(144)-JVS(946)*XX(145)&
              &-JVS(953)*XX(146)-JVS(960)*XX(147)-JVS(977)*XX(148)-JVS(985)*XX(149)-JVS(992)*XX(150)-JVS(998)*XX(151)&
              &-JVS(1012)*XX(152)-JVS(1022)*XX(153)-JVS(1029)*XX(154)-JVS(1047)*XX(155)-JVS(1059)*XX(156)-JVS(1077)*XX(157)&
              &-JVS(1090)*XX(158)-JVS(1112)*XX(159)-JVS(1140)*XX(160)-JVS(1156)*XX(161)-JVS(1166)*XX(162)-JVS(1175)*XX(163)&
              &-JVS(1186)*XX(164)-JVS(1197)*XX(165)-JVS(1212)*XX(166)-JVS(1220)*XX(167)-JVS(1238)*XX(168)-JVS(1248)*XX(169)&
              &-JVS(1258)*XX(170)-JVS(1281)*XX(171)-JVS(1295)*XX(172)-JVS(1304)*XX(173)-JVS(1321)*XX(174)-JVS(1330)*XX(175)&
              &-JVS(1351)*XX(176)-JVS(1357)*XX(177)-JVS(1368)*XX(178)-JVS(1404)*XX(179)-JVS(1412)*XX(180)-JVS(1427)*XX(181)&
              &-JVS(1453)*XX(182)-JVS(1461)*XX(183)-JVS(1470)*XX(184)-JVS(1482)*XX(185)-JVS(1491)*XX(186)-JVS(1564)*XX(187)&
              &-JVS(1574)*XX(188)-JVS(1594)*XX(189)-JVS(1610)*XX(190)-JVS(1629)*XX(191)-JVS(1649)*XX(192)-JVS(1682)*XX(193)&
              &-JVS(1715)*XX(194)-JVS(1730)*XX(195)-JVS(1760)*XX(196)-JVS(1799)*XX(197)-JVS(1860)*XX(198)-JVS(1870)*XX(199)&
              &-JVS(1897)*XX(200)-JVS(1926)*XX(201)-JVS(1943)*XX(202)-JVS(1969)*XX(203)-JVS(1991)*XX(204)-JVS(2004)*XX(205)&
              &-JVS(2018)*XX(206)-JVS(2040)*XX(207)-JVS(2050)*XX(208)-JVS(2071)*XX(209)-JVS(2127)*XX(210)-JVS(2152)*XX(211)&
              &-JVS(2164)*XX(212)-JVS(2176)*XX(213)-JVS(2205)*XX(214)-JVS(2221)*XX(215)-JVS(2237)*XX(216)-JVS(2259)*XX(217)&
              &-JVS(2328)*XX(218)-JVS(2344)*XX(219)-JVS(2438)*XX(220)-JVS(2470)*XX(221)-JVS(2559)*XX(222)-JVS(2595)*XX(223)&
              &-JVS(2711)*XX(224)-JVS(2783)*XX(225)-JVS(2866)*XX(226)-JVS(2946)*XX(227)-JVS(2968)*XX(228)-JVS(2990)*XX(229))&
              &/(JVS(3168))
  XX(231) = (X(231)-JVS(36)*XX(7)-JVS(61)*XX(11)-JVS(73)*XX(15)-JVS(87)*XX(19)-JVS(185)*XX(27)-JVS(257)*XX(28)-JVS(319)&
              &*XX(29)-JVS(346)*XX(33)-JVS(380)*XX(46)-JVS(391)*XX(49)-JVS(396)*XX(50)-JVS(407)*XX(53)-JVS(412)*XX(54)&
              &-JVS(445)*XX(62)-JVS(472)*XX(68)-JVS(476)*XX(69)-JVS(480)*XX(70)-JVS(483)*XX(71)-JVS(542)*XX(82)-JVS(550)&
              &*XX(84)-JVS(554)*XX(85)-JVS(565)*XX(87)-JVS(571)*XX(88)-JVS(576)*XX(89)-JVS(580)*XX(90)-JVS(585)*XX(91)&
              &-JVS(618)*XX(96)-JVS(663)*XX(103)-JVS(692)*XX(108)-JVS(716)*XX(113)-JVS(721)*XX(114)-JVS(727)*XX(115)&
              &-JVS(732)*XX(116)-JVS(743)*XX(118)-JVS(749)*XX(119)-JVS(776)*XX(124)-JVS(793)*XX(126)-JVS(802)*XX(128)&
              &-JVS(826)*XX(131)-JVS(834)*XX(132)-JVS(838)*XX(133)-JVS(842)*XX(134)-JVS(848)*XX(135)-JVS(853)*XX(136)&
              &-JVS(865)*XX(137)-JVS(870)*XX(138)-JVS(880)*XX(139)-JVS(919)*XX(142)-JVS(930)*XX(143)-JVS(940)*XX(144)&
              &-JVS(947)*XX(145)-JVS(954)*XX(146)-JVS(961)*XX(147)-JVS(978)*XX(148)-JVS(986)*XX(149)-JVS(993)*XX(150)&
              &-JVS(999)*XX(151)-JVS(1013)*XX(152)-JVS(1023)*XX(153)-JVS(1030)*XX(154)-JVS(1048)*XX(155)-JVS(1060)*XX(156)&
              &-JVS(1078)*XX(157)-JVS(1091)*XX(158)-JVS(1113)*XX(159)-JVS(1141)*XX(160)-JVS(1157)*XX(161)-JVS(1167)*XX(162)&
              &-JVS(1176)*XX(163)-JVS(1187)*XX(164)-JVS(1198)*XX(165)-JVS(1213)*XX(166)-JVS(1221)*XX(167)-JVS(1239)*XX(168)&
              &-JVS(1259)*XX(170)-JVS(1282)*XX(171)-JVS(1296)*XX(172)-JVS(1305)*XX(173)-JVS(1322)*XX(174)-JVS(1331)*XX(175)&
              &-JVS(1352)*XX(176)-JVS(1369)*XX(178)-JVS(1405)*XX(179)-JVS(1413)*XX(180)-JVS(1428)*XX(181)-JVS(1454)*XX(182)&
              &-JVS(1471)*XX(184)-JVS(1483)*XX(185)-JVS(1565)*XX(187)-JVS(1575)*XX(188)-JVS(1595)*XX(189)-JVS(1630)*XX(191)&
              &-JVS(1650)*XX(192)-JVS(1683)*XX(193)-JVS(1716)*XX(194)-JVS(1731)*XX(195)-JVS(1761)*XX(196)-JVS(1800)*XX(197)&
              &-JVS(1861)*XX(198)-JVS(1871)*XX(199)-JVS(1898)*XX(200)-JVS(1927)*XX(201)-JVS(1944)*XX(202)-JVS(1970)*XX(203)&
              &-JVS(1992)*XX(204)-JVS(2005)*XX(205)-JVS(2019)*XX(206)-JVS(2041)*XX(207)-JVS(2051)*XX(208)-JVS(2072)*XX(209)&
              &-JVS(2128)*XX(210)-JVS(2153)*XX(211)-JVS(2165)*XX(212)-JVS(2177)*XX(213)-JVS(2206)*XX(214)-JVS(2222)*XX(215)&
              &-JVS(2238)*XX(216)-JVS(2260)*XX(217)-JVS(2329)*XX(218)-JVS(2345)*XX(219)-JVS(2439)*XX(220)-JVS(2471)*XX(221)&
              &-JVS(2560)*XX(222)-JVS(2596)*XX(223)-JVS(2712)*XX(224)-JVS(2784)*XX(225)-JVS(2867)*XX(226)-JVS(2947)*XX(227)&
              &-JVS(2969)*XX(228)-JVS(2991)*XX(229)-JVS(3169)*XX(230))/(JVS(3316))
  XX(232) = (X(232)-JVS(320)*XX(29)-JVS(374)*XX(44)-JVS(605)*XX(94)-JVS(653)*XX(101)-JVS(738)*XX(117)-JVS(798)*XX(127)&
              &-JVS(1092)*XX(158)-JVS(1297)*XX(172)-JVS(1306)*XX(173)-JVS(1332)*XX(175)-JVS(1370)*XX(178)-JVS(1429)*XX(181)&
              &-JVS(1455)*XX(182)-JVS(1566)*XX(187)-JVS(1762)*XX(196)-JVS(1899)*XX(200)-JVS(2129)*XX(210)-JVS(2207)*XX(214)&
              &-JVS(2261)*XX(217)-JVS(2330)*XX(218)-JVS(2346)*XX(219)-JVS(2440)*XX(220)-JVS(2472)*XX(221)-JVS(2561)*XX(222)&
              &-JVS(2597)*XX(223)-JVS(2713)*XX(224)-JVS(2785)*XX(225)-JVS(2868)*XX(226)-JVS(2948)*XX(227)-JVS(2970)*XX(228)&
              &-JVS(2992)*XX(229)-JVS(3170)*XX(230)-JVS(3317)*XX(231))/(JVS(3365))
  XX(233) = (X(233)-JVS(37)*XX(7)-JVS(258)*XX(28)-JVS(321)*XX(29)-JVS(347)*XX(33)-JVS(527)*XX(79)-JVS(676)*XX(105)&
              &-JVS(697)*XX(109)-JVS(702)*XX(110)-JVS(759)*XX(121)-JVS(763)*XX(122)-JVS(827)*XX(131)-JVS(895)*XX(141)&
              &-JVS(1093)*XX(158)-JVS(1142)*XX(160)-JVS(1168)*XX(162)-JVS(1249)*XX(169)-JVS(1283)*XX(171)-JVS(1298)*XX(172)&
              &-JVS(1323)*XX(174)-JVS(1371)*XX(178)-JVS(1462)*XX(183)-JVS(1472)*XX(184)-JVS(1484)*XX(185)-JVS(1567)*XX(187)&
              &-JVS(1576)*XX(188)-JVS(1596)*XX(189)-JVS(1611)*XX(190)-JVS(1684)*XX(193)-JVS(1717)*XX(194)-JVS(1763)*XX(196)&
              &-JVS(1801)*XX(197)-JVS(1862)*XX(198)-JVS(1900)*XX(200)-JVS(1928)*XX(201)-JVS(2006)*XX(205)-JVS(2020)*XX(206)&
              &-JVS(2042)*XX(207)-JVS(2052)*XX(208)-JVS(2073)*XX(209)-JVS(2130)*XX(210)-JVS(2154)*XX(211)-JVS(2166)*XX(212)&
              &-JVS(2178)*XX(213)-JVS(2208)*XX(214)-JVS(2223)*XX(215)-JVS(2239)*XX(216)-JVS(2262)*XX(217)-JVS(2331)*XX(218)&
              &-JVS(2347)*XX(219)-JVS(2441)*XX(220)-JVS(2473)*XX(221)-JVS(2562)*XX(222)-JVS(2598)*XX(223)-JVS(2714)*XX(224)&
              &-JVS(2786)*XX(225)-JVS(2869)*XX(226)-JVS(2949)*XX(227)-JVS(2971)*XX(228)-JVS(2993)*XX(229)-JVS(3171)*XX(230)&
              &-JVS(3318)*XX(231)-JVS(3366)*XX(232))/(JVS(3412))
  XX(234) = (X(234)-JVS(38)*XX(7)-JVS(64)*XX(12)-JVS(76)*XX(16)-JVS(90)*XX(20)-JVS(186)*XX(27)-JVS(322)*XX(29)-JVS(387)&
              &*XX(48)-JVS(392)*XX(49)-JVS(397)*XX(50)-JVS(408)*XX(53)-JVS(441)*XX(61)-JVS(449)*XX(63)-JVS(453)*XX(64)&
              &-JVS(456)*XX(65)-JVS(461)*XX(66)-JVS(468)*XX(67)-JVS(566)*XX(87)-JVS(581)*XX(90)-JVS(586)*XX(91)-JVS(613)&
              &*XX(95)-JVS(664)*XX(103)-JVS(706)*XX(111)-JVS(710)*XX(112)-JVS(722)*XX(114)-JVS(728)*XX(115)-JVS(733)*XX(116)&
              &-JVS(744)*XX(118)-JVS(750)*XX(119)-JVS(843)*XX(134)-JVS(849)*XX(135)-JVS(854)*XX(136)-JVS(866)*XX(137)&
              &-JVS(881)*XX(139)-JVS(891)*XX(140)-JVS(920)*XX(142)-JVS(931)*XX(143)-JVS(941)*XX(144)-JVS(955)*XX(146)&
              &-JVS(962)*XX(147)-JVS(979)*XX(148)-JVS(987)*XX(149)-JVS(1014)*XX(152)-JVS(1024)*XX(153)-JVS(1031)*XX(154)&
              &-JVS(1061)*XX(156)-JVS(1114)*XX(159)-JVS(1143)*XX(160)-JVS(1158)*XX(161)-JVS(1169)*XX(162)-JVS(1177)*XX(163)&
              &-JVS(1188)*XX(164)-JVS(1199)*XX(165)-JVS(1214)*XX(166)-JVS(1222)*XX(167)-JVS(1240)*XX(168)-JVS(1250)*XX(169)&
              &-JVS(1260)*XX(170)-JVS(1284)*XX(171)-JVS(1307)*XX(173)-JVS(1324)*XX(174)-JVS(1333)*XX(175)-JVS(1353)*XX(176)&
              &-JVS(1358)*XX(177)-JVS(1372)*XX(178)-JVS(1406)*XX(179)-JVS(1414)*XX(180)-JVS(1430)*XX(181)-JVS(1456)*XX(182)&
              &-JVS(1473)*XX(184)-JVS(1485)*XX(185)-JVS(1492)*XX(186)-JVS(1568)*XX(187)-JVS(1577)*XX(188)-JVS(1597)*XX(189)&
              &-JVS(1612)*XX(190)-JVS(1631)*XX(191)-JVS(1651)*XX(192)-JVS(1685)*XX(193)-JVS(1718)*XX(194)-JVS(1732)*XX(195)&
              &-JVS(1764)*XX(196)-JVS(1802)*XX(197)-JVS(1863)*XX(198)-JVS(1872)*XX(199)-JVS(1901)*XX(200)-JVS(1929)*XX(201)&
              &-JVS(1945)*XX(202)-JVS(1971)*XX(203)-JVS(1993)*XX(204)-JVS(2007)*XX(205)-JVS(2021)*XX(206)-JVS(2043)*XX(207)&
              &-JVS(2053)*XX(208)-JVS(2074)*XX(209)-JVS(2131)*XX(210)-JVS(2155)*XX(211)-JVS(2167)*XX(212)-JVS(2179)*XX(213)&
              &-JVS(2209)*XX(214)-JVS(2224)*XX(215)-JVS(2240)*XX(216)-JVS(2263)*XX(217)-JVS(2332)*XX(218)-JVS(2348)*XX(219)&
              &-JVS(2442)*XX(220)-JVS(2474)*XX(221)-JVS(2563)*XX(222)-JVS(2599)*XX(223)-JVS(2715)*XX(224)-JVS(2787)*XX(225)&
              &-JVS(2870)*XX(226)-JVS(2950)*XX(227)-JVS(2972)*XX(228)-JVS(2994)*XX(229)-JVS(3172)*XX(230)-JVS(3319)*XX(231)&
              &-JVS(3367)*XX(232)-JVS(3413)*XX(233))/(JVS(3494))
  XX(235) = (X(235)-JVS(187)*XX(27)-JVS(369)*XX(42)-JVS(484)*XX(71)-JVS(2264)*XX(217)-JVS(2333)*XX(218)-JVS(2443)&
              &*XX(220)-JVS(2475)*XX(221)-JVS(2564)*XX(222)-JVS(2600)*XX(223)-JVS(2716)*XX(224)-JVS(2788)*XX(225)-JVS(2871)&
              &*XX(226)-JVS(2951)*XX(227)-JVS(2973)*XX(228)-JVS(2995)*XX(229)-JVS(3173)*XX(230)-JVS(3320)*XX(231)-JVS(3368)&
              &*XX(232)-JVS(3414)*XX(233)-JVS(3495)*XX(234))/(JVS(3520))
  XX(236) = (X(236)-JVS(39)*XX(7)-JVS(188)*XX(27)-JVS(259)*XX(28)-JVS(323)*XX(29)-JVS(427)*XX(58)-JVS(457)*XX(65)&
              &-JVS(521)*XX(78)-JVS(614)*XX(95)-JVS(619)*XX(96)-JVS(633)*XX(98)-JVS(688)*XX(107)-JVS(789)*XX(125)-JVS(932)&
              &*XX(143)-JVS(942)*XX(144)-JVS(948)*XX(145)-JVS(1025)*XX(153)-JVS(1049)*XX(155)-JVS(1079)*XX(157)-JVS(1115)&
              &*XX(159)-JVS(1170)*XX(162)-JVS(1223)*XX(167)-JVS(1308)*XX(173)-JVS(1334)*XX(175)-JVS(1359)*XX(177)-JVS(1407)&
              &*XX(179)-JVS(1415)*XX(180)-JVS(1431)*XX(181)-JVS(1457)*XX(182)-JVS(1474)*XX(184)-JVS(1486)*XX(185)-JVS(1493)&
              &*XX(186)-JVS(1569)*XX(187)-JVS(1578)*XX(188)-JVS(1598)*XX(189)-JVS(1632)*XX(191)-JVS(1652)*XX(192)-JVS(1686)&
              &*XX(193)-JVS(1719)*XX(194)-JVS(1733)*XX(195)-JVS(1765)*XX(196)-JVS(1803)*XX(197)-JVS(1864)*XX(198)-JVS(1873)&
              &*XX(199)-JVS(1902)*XX(200)-JVS(1930)*XX(201)-JVS(1946)*XX(202)-JVS(1972)*XX(203)-JVS(1994)*XX(204)-JVS(2008)&
              &*XX(205)-JVS(2022)*XX(206)-JVS(2044)*XX(207)-JVS(2054)*XX(208)-JVS(2075)*XX(209)-JVS(2132)*XX(210)-JVS(2156)&
              &*XX(211)-JVS(2168)*XX(212)-JVS(2180)*XX(213)-JVS(2210)*XX(214)-JVS(2225)*XX(215)-JVS(2241)*XX(216)-JVS(2265)&
              &*XX(217)-JVS(2334)*XX(218)-JVS(2349)*XX(219)-JVS(2444)*XX(220)-JVS(2476)*XX(221)-JVS(2565)*XX(222)-JVS(2601)&
              &*XX(223)-JVS(2717)*XX(224)-JVS(2789)*XX(225)-JVS(2872)*XX(226)-JVS(2952)*XX(227)-JVS(2974)*XX(228)-JVS(2996)&
              &*XX(229)-JVS(3174)*XX(230)-JVS(3321)*XX(231)-JVS(3369)*XX(232)-JVS(3415)*XX(233)-JVS(3496)*XX(234)-JVS(3521)&
              &*XX(235))/(JVS(3575))
  XX(236) = XX(236)
  XX(235) = XX(235)-JVS(3574)*XX(236)
  XX(234) = XX(234)-JVS(3519)*XX(235)-JVS(3573)*XX(236)
  XX(233) = XX(233)-JVS(3493)*XX(234)-JVS(3518)*XX(235)-JVS(3572)*XX(236)
  XX(232) = XX(232)-JVS(3411)*XX(233)-JVS(3492)*XX(234)-JVS(3517)*XX(235)-JVS(3571)*XX(236)
  XX(231) = XX(231)-JVS(3364)*XX(232)-JVS(3410)*XX(233)-JVS(3491)*XX(234)-JVS(3516)*XX(235)-JVS(3570)*XX(236)
  XX(230) = XX(230)-JVS(3315)*XX(231)-JVS(3363)*XX(232)-JVS(3409)*XX(233)-JVS(3490)*XX(234)-JVS(3515)*XX(235)-JVS(3569)&
              &*XX(236)
  XX(229) = XX(229)-JVS(3167)*XX(230)-JVS(3314)*XX(231)-JVS(3362)*XX(232)-JVS(3408)*XX(233)-JVS(3489)*XX(234)-JVS(3514)&
              &*XX(235)-JVS(3568)*XX(236)
  XX(228) = XX(228)-JVS(2988)*XX(229)-JVS(3166)*XX(230)-JVS(3313)*XX(231)-JVS(3361)*XX(232)-JVS(3407)*XX(233)-JVS(3488)&
              &*XX(234)-JVS(3513)*XX(235)-JVS(3567)*XX(236)
  XX(227) = XX(227)-JVS(2965)*XX(228)-JVS(2987)*XX(229)-JVS(3165)*XX(230)-JVS(3312)*XX(231)-JVS(3360)*XX(232)-JVS(3406)&
              &*XX(233)-JVS(3487)*XX(234)-JVS(3512)*XX(235)-JVS(3566)*XX(236)
  XX(226) = XX(226)-JVS(2942)*XX(227)-JVS(2964)*XX(228)-JVS(2986)*XX(229)-JVS(3164)*XX(230)-JVS(3311)*XX(231)-JVS(3359)&
              &*XX(232)-JVS(3405)*XX(233)-JVS(3486)*XX(234)-JVS(3511)*XX(235)-JVS(3565)*XX(236)
  XX(225) = XX(225)-JVS(2861)*XX(226)-JVS(2941)*XX(227)-JVS(2963)*XX(228)-JVS(2985)*XX(229)-JVS(3163)*XX(230)-JVS(3310)&
              &*XX(231)-JVS(3358)*XX(232)-JVS(3404)*XX(233)-JVS(3485)*XX(234)-JVS(3510)*XX(235)-JVS(3564)*XX(236)
  XX(224) = XX(224)-JVS(2777)*XX(225)-JVS(2860)*XX(226)-JVS(2940)*XX(227)-JVS(3162)*XX(230)-JVS(3309)*XX(231)-JVS(3357)&
              &*XX(232)-JVS(3403)*XX(233)-JVS(3484)*XX(234)-JVS(3509)*XX(235)-JVS(3563)*XX(236)
  XX(223) = XX(223)-JVS(2704)*XX(224)-JVS(2776)*XX(225)-JVS(2859)*XX(226)-JVS(2939)*XX(227)-JVS(3161)*XX(230)-JVS(3308)&
              &*XX(231)-JVS(3356)*XX(232)-JVS(3402)*XX(233)-JVS(3483)*XX(234)-JVS(3562)*XX(236)
  XX(222) = XX(222)-JVS(2587)*XX(223)-JVS(2703)*XX(224)-JVS(2858)*XX(226)-JVS(2938)*XX(227)-JVS(3160)*XX(230)-JVS(3307)&
              &*XX(231)-JVS(3355)*XX(232)-JVS(3401)*XX(233)-JVS(3482)*XX(234)-JVS(3561)*XX(236)
  XX(221) = XX(221)-JVS(2550)*XX(222)-JVS(2702)*XX(224)-JVS(2857)*XX(226)-JVS(2937)*XX(227)-JVS(3159)*XX(230)-JVS(3306)&
              &*XX(231)-JVS(3354)*XX(232)-JVS(3400)*XX(233)-JVS(3481)*XX(234)-JVS(3560)*XX(236)
  XX(220) = XX(220)-JVS(2460)*XX(221)-JVS(2549)*XX(222)-JVS(2701)*XX(224)-JVS(2856)*XX(226)-JVS(2936)*XX(227)-JVS(3158)&
              &*XX(230)-JVS(3305)*XX(231)-JVS(3353)*XX(232)-JVS(3399)*XX(233)-JVS(3480)*XX(234)
  XX(219) = XX(219)-JVS(2427)*XX(220)-JVS(2459)*XX(221)-JVS(2548)*XX(222)-JVS(2586)*XX(223)-JVS(2700)*XX(224)-JVS(2775)&
              &*XX(225)-JVS(2855)*XX(226)-JVS(2935)*XX(227)-JVS(2962)*XX(228)-JVS(2984)*XX(229)-JVS(3157)*XX(230)-JVS(3304)&
              &*XX(231)-JVS(3352)*XX(232)-JVS(3398)*XX(233)-JVS(3479)*XX(234)-JVS(3508)*XX(235)-JVS(3559)*XX(236)
  XX(218) = XX(218)-JVS(2458)*XX(221)-JVS(2699)*XX(224)-JVS(2854)*XX(226)-JVS(2934)*XX(227)-JVS(3156)*XX(230)-JVS(3303)&
              &*XX(231)-JVS(3351)*XX(232)-JVS(3397)*XX(233)-JVS(3478)*XX(234)
  XX(217) = XX(217)-JVS(2315)*XX(218)-JVS(2426)*XX(220)-JVS(2457)*XX(221)-JVS(2585)*XX(223)-JVS(2698)*XX(224)-JVS(2774)&
              &*XX(225)-JVS(2853)*XX(226)-JVS(3155)*XX(230)-JVS(3302)*XX(231)-JVS(3477)*XX(234)-JVS(3558)*XX(236)
  XX(216) = XX(216)-JVS(2251)*XX(217)-JVS(2314)*XX(218)-JVS(2425)*XX(220)-JVS(2456)*XX(221)-JVS(2547)*XX(222)-JVS(2584)&
              &*XX(223)-JVS(2697)*XX(224)-JVS(2773)*XX(225)-JVS(2852)*XX(226)-JVS(2933)*XX(227)-JVS(2961)*XX(228)-JVS(2983)&
              &*XX(229)-JVS(3154)*XX(230)-JVS(3301)*XX(231)-JVS(3350)*XX(232)-JVS(3396)*XX(233)-JVS(3476)*XX(234)-JVS(3507)&
              &*XX(235)-JVS(3557)*XX(236)
  XX(215) = XX(215)-JVS(2232)*XX(216)-JVS(2250)*XX(217)-JVS(2313)*XX(218)-JVS(2424)*XX(220)-JVS(2455)*XX(221)-JVS(2546)&
              &*XX(222)-JVS(2583)*XX(223)-JVS(2696)*XX(224)-JVS(2772)*XX(225)-JVS(2851)*XX(226)-JVS(2932)*XX(227)-JVS(2960)&
              &*XX(228)-JVS(2982)*XX(229)-JVS(3153)*XX(230)-JVS(3300)*XX(231)-JVS(3349)*XX(232)-JVS(3395)*XX(233)-JVS(3475)&
              &*XX(234)-JVS(3506)*XX(235)-JVS(3556)*XX(236)
  XX(214) = XX(214)-JVS(2312)*XX(218)-JVS(2423)*XX(220)-JVS(2545)*XX(222)-JVS(2695)*XX(224)-JVS(2771)*XX(225)-JVS(2850)&
              &*XX(226)-JVS(2931)*XX(227)-JVS(3152)*XX(230)-JVS(3299)*XX(231)-JVS(3474)*XX(234)-JVS(3555)*XX(236)
  XX(213) = XX(213)-JVS(2196)*XX(214)-JVS(2311)*XX(218)-JVS(2339)*XX(219)-JVS(2422)*XX(220)-JVS(2544)*XX(222)-JVS(2582)&
              &*XX(223)-JVS(2694)*XX(224)-JVS(2770)*XX(225)-JVS(2849)*XX(226)-JVS(2930)*XX(227)-JVS(3151)*XX(230)-JVS(3298)&
              &*XX(231)-JVS(3394)*XX(233)-JVS(3473)*XX(234)-JVS(3505)*XX(235)-JVS(3554)*XX(236)
  XX(212) = XX(212)-JVS(2171)*XX(213)-JVS(2195)*XX(214)-JVS(2310)*XX(218)-JVS(2338)*XX(219)-JVS(2421)*XX(220)-JVS(2543)&
              &*XX(222)-JVS(2581)*XX(223)-JVS(2693)*XX(224)-JVS(2769)*XX(225)-JVS(2848)*XX(226)-JVS(2929)*XX(227)-JVS(3150)&
              &*XX(230)-JVS(3297)*XX(231)-JVS(3393)*XX(233)-JVS(3472)*XX(234)-JVS(3504)*XX(235)-JVS(3553)*XX(236)
  XX(211) = XX(211)-JVS(2194)*XX(214)-JVS(2309)*XX(218)-JVS(2420)*XX(220)-JVS(2542)*XX(222)-JVS(2580)*XX(223)-JVS(2692)&
              &*XX(224)-JVS(2768)*XX(225)-JVS(2847)*XX(226)-JVS(2928)*XX(227)-JVS(3149)*XX(230)-JVS(3296)*XX(231)-JVS(3392)&
              &*XX(233)-JVS(3471)*XX(234)-JVS(3552)*XX(236)
  XX(210) = XX(210)-JVS(2308)*XX(218)-JVS(2419)*XX(220)-JVS(2541)*XX(222)-JVS(2691)*XX(224)-JVS(2767)*XX(225)-JVS(2846)&
              &*XX(226)-JVS(2927)*XX(227)-JVS(3148)*XX(230)-JVS(3295)*XX(231)-JVS(3551)*XX(236)
  XX(209) = XX(209)-JVS(2116)*XX(210)-JVS(2307)*XX(218)-JVS(2418)*XX(220)-JVS(2540)*XX(222)-JVS(2690)*XX(224)-JVS(2766)&
              &*XX(225)-JVS(2845)*XX(226)-JVS(2926)*XX(227)-JVS(3147)*XX(230)-JVS(3294)*XX(231)-JVS(3391)*XX(233)-JVS(3470)&
              &*XX(234)-JVS(3550)*XX(236)
  XX(208) = XX(208)-JVS(2115)*XX(210)-JVS(2193)*XX(214)-JVS(2216)*XX(215)-JVS(2231)*XX(216)-JVS(2249)*XX(217)-JVS(2306)&
              &*XX(218)-JVS(2417)*XX(220)-JVS(2454)*XX(221)-JVS(2539)*XX(222)-JVS(2689)*XX(224)-JVS(2765)*XX(225)-JVS(2844)&
              &*XX(226)-JVS(2925)*XX(227)-JVS(2959)*XX(228)-JVS(2981)*XX(229)-JVS(3146)*XX(230)-JVS(3293)*XX(231)-JVS(3348)&
              &*XX(232)-JVS(3390)*XX(233)-JVS(3469)*XX(234)-JVS(3503)*XX(235)-JVS(3549)*XX(236)
  XX(207) = XX(207)-JVS(2305)*XX(218)-JVS(2337)*XX(219)-JVS(2416)*XX(220)-JVS(2538)*XX(222)-JVS(2579)*XX(223)-JVS(2688)&
              &*XX(224)-JVS(2764)*XX(225)-JVS(2843)*XX(226)-JVS(2924)*XX(227)-JVS(3145)*XX(230)-JVS(3292)*XX(231)-JVS(3389)&
              &*XX(233)-JVS(3468)*XX(234)-JVS(3502)*XX(235)-JVS(3548)*XX(236)
  XX(206) = XX(206)-JVS(2033)*XX(207)-JVS(2062)*XX(209)-JVS(2114)*XX(210)-JVS(2145)*XX(211)-JVS(2192)*XX(214)-JVS(2304)&
              &*XX(218)-JVS(2415)*XX(220)-JVS(2537)*XX(222)-JVS(2687)*XX(224)-JVS(2763)*XX(225)-JVS(2842)*XX(226)-JVS(2923)&
              &*XX(227)-JVS(3144)*XX(230)-JVS(3291)*XX(231)-JVS(3467)*XX(234)-JVS(3547)*XX(236)
  XX(205) = XX(205)-JVS(2013)*XX(206)-JVS(2032)*XX(207)-JVS(2061)*XX(209)-JVS(2113)*XX(210)-JVS(2144)*XX(211)-JVS(2191)&
              &*XX(214)-JVS(2303)*XX(218)-JVS(2414)*XX(220)-JVS(2536)*XX(222)-JVS(2686)*XX(224)-JVS(2762)*XX(225)-JVS(2841)&
              &*XX(226)-JVS(2922)*XX(227)-JVS(3143)*XX(230)-JVS(3290)*XX(231)-JVS(3466)*XX(234)-JVS(3546)*XX(236)
  XX(204) = XX(204)-JVS(2031)*XX(207)-JVS(2060)*XX(209)-JVS(2112)*XX(210)-JVS(2143)*XX(211)-JVS(2190)*XX(214)-JVS(2302)&
              &*XX(218)-JVS(2413)*XX(220)-JVS(2535)*XX(222)-JVS(2685)*XX(224)-JVS(2761)*XX(225)-JVS(2840)*XX(226)-JVS(2921)&
              &*XX(227)-JVS(3142)*XX(230)-JVS(3289)*XX(231)-JVS(3465)*XX(234)
  XX(203) = XX(203)-JVS(1983)*XX(204)-JVS(2059)*XX(209)-JVS(2111)*XX(210)-JVS(2189)*XX(214)-JVS(2301)*XX(218)-JVS(2412)&
              &*XX(220)-JVS(2534)*XX(222)-JVS(2684)*XX(224)-JVS(2760)*XX(225)-JVS(2839)*XX(226)-JVS(2920)*XX(227)-JVS(3141)&
              &*XX(230)-JVS(3288)*XX(231)-JVS(3464)*XX(234)
  XX(202) = XX(202)-JVS(2058)*XX(209)-JVS(2110)*XX(210)-JVS(2188)*XX(214)-JVS(2300)*XX(218)-JVS(2411)*XX(220)-JVS(2533)&
              &*XX(222)-JVS(2683)*XX(224)-JVS(2759)*XX(225)-JVS(2838)*XX(226)-JVS(2919)*XX(227)-JVS(3140)*XX(230)-JVS(3287)&
              &*XX(231)-JVS(3463)*XX(234)
  XX(201) = XX(201)-JVS(2299)*XX(218)-JVS(2410)*XX(220)-JVS(2532)*XX(222)-JVS(2682)*XX(224)-JVS(2758)*XX(225)-JVS(2837)&
              &*XX(226)-JVS(2918)*XX(227)-JVS(3139)*XX(230)-JVS(3286)*XX(231)
  XX(200) = XX(200)-JVS(2298)*XX(218)-JVS(2453)*XX(221)-JVS(2681)*XX(224)-JVS(2836)*XX(226)-JVS(2917)*XX(227)-JVS(3138)&
              &*XX(230)-JVS(3347)*XX(232)-JVS(3388)*XX(233)
  XX(199) = XX(199)-JVS(1882)*XX(200)-JVS(2187)*XX(214)-JVS(2215)*XX(215)-JVS(2230)*XX(216)-JVS(2248)*XX(217)-JVS(2297)&
              &*XX(218)-JVS(2409)*XX(220)-JVS(2531)*XX(222)-JVS(2578)*XX(223)-JVS(2680)*XX(224)-JVS(2757)*XX(225)-JVS(2835)&
              &*XX(226)-JVS(2916)*XX(227)-JVS(2958)*XX(228)-JVS(2980)*XX(229)-JVS(3137)*XX(230)-JVS(3285)*XX(231)-JVS(3346)&
              &*XX(232)-JVS(3462)*XX(234)-JVS(3501)*XX(235)-JVS(3545)*XX(236)
  XX(198) = XX(198)-JVS(2530)*XX(222)-JVS(2679)*XX(224)-JVS(2756)*XX(225)-JVS(2915)*XX(227)-JVS(3136)*XX(230)-JVS(3284)&
              &*XX(231)
  XX(197) = XX(197)-JVS(2296)*XX(218)-JVS(2408)*XX(220)-JVS(2529)*XX(222)-JVS(2678)*XX(224)-JVS(2834)*XX(226)-JVS(2914)&
              &*XX(227)-JVS(3135)*XX(230)-JVS(3283)*XX(231)
  XX(196) = XX(196)-JVS(2247)*XX(217)-JVS(2528)*XX(222)-JVS(2677)*XX(224)-JVS(2913)*XX(227)-JVS(2957)*XX(228)-JVS(2979)&
              &*XX(229)-JVS(3134)*XX(230)-JVS(3282)*XX(231)-JVS(3500)*XX(235)
  XX(195) = XX(195)-JVS(1784)*XX(197)-JVS(1839)*XX(198)-JVS(1912)*XX(201)-JVS(1960)*XX(203)-JVS(1982)*XX(204)-JVS(2109)&
              &*XX(210)-JVS(2407)*XX(220)-JVS(2527)*XX(222)-JVS(2676)*XX(224)-JVS(2755)*XX(225)-JVS(2912)*XX(227)-JVS(3133)&
              &*XX(230)-JVS(3281)*XX(231)-JVS(3461)*XX(234)
  XX(194) = XX(194)-JVS(1783)*XX(197)-JVS(1838)*XX(198)-JVS(2406)*XX(220)-JVS(2526)*XX(222)-JVS(2675)*XX(224)-JVS(2754)&
              &*XX(225)-JVS(2911)*XX(227)-JVS(3132)*XX(230)-JVS(3280)*XX(231)
  XX(193) = XX(193)-JVS(1837)*XX(198)-JVS(2108)*XX(210)-JVS(2186)*XX(214)-JVS(2405)*XX(220)-JVS(2525)*XX(222)-JVS(2753)&
              &*XX(225)-JVS(3131)*XX(230)-JVS(3279)*XX(231)
  XX(192) = XX(192)-JVS(1670)*XX(193)-JVS(1703)*XX(194)-JVS(1782)*XX(197)-JVS(1836)*XX(198)-JVS(2107)*XX(210)-JVS(2404)&
              &*XX(220)-JVS(2524)*XX(222)-JVS(2674)*XX(224)-JVS(2752)*XX(225)-JVS(2910)*XX(227)-JVS(3130)*XX(230)-JVS(3278)&
              &*XX(231)-JVS(3460)*XX(234)
  XX(191) = XX(191)-JVS(1643)*XX(192)-JVS(1669)*XX(193)-JVS(1702)*XX(194)-JVS(1781)*XX(197)-JVS(1835)*XX(198)-JVS(2106)&
              &*XX(210)-JVS(2403)*XX(220)-JVS(2523)*XX(222)-JVS(2673)*XX(224)-JVS(2751)*XX(225)-JVS(2909)*XX(227)-JVS(3129)&
              &*XX(230)-JVS(3277)*XX(231)-JVS(3459)*XX(234)
  XX(190) = XX(190)-JVS(2295)*XX(218)-JVS(2402)*XX(220)-JVS(2522)*XX(222)-JVS(2577)*XX(223)-JVS(2672)*XX(224)-JVS(2833)&
              &*XX(226)-JVS(2908)*XX(227)-JVS(3128)*XX(230)-JVS(3276)*XX(231)-JVS(3387)*XX(233)-JVS(3458)*XX(234)-JVS(3544)&
              &*XX(236)
  XX(189) = XX(189)-JVS(2214)*XX(215)-JVS(2246)*XX(217)-JVS(2671)*XX(224)-JVS(2750)*XX(225)-JVS(2907)*XX(227)-JVS(2956)&
              &*XX(228)-JVS(2978)*XX(229)-JVS(3127)*XX(230)-JVS(3499)*XX(235)-JVS(3543)*XX(236)
  XX(188) = XX(188)-JVS(1586)*XX(189)-JVS(1748)*XX(196)-JVS(2105)*XX(210)-JVS(2142)*XX(211)-JVS(2229)*XX(216)-JVS(2294)&
              &*XX(218)-JVS(2336)*XX(219)-JVS(2401)*XX(220)-JVS(2670)*XX(224)-JVS(2749)*XX(225)-JVS(2832)*XX(226)-JVS(2906)&
              &*XX(227)-JVS(3126)*XX(230)-JVS(3275)*XX(231)-JVS(3386)*XX(233)-JVS(3457)*XX(234)-JVS(3542)*XX(236)
  XX(187) = XX(187)-JVS(2669)*XX(224)-JVS(2905)*XX(227)-JVS(3125)*XX(230)
  XX(186) = XX(186)-JVS(1530)*XX(187)-JVS(1622)*XX(191)-JVS(1642)*XX(192)-JVS(1668)*XX(193)-JVS(1701)*XX(194)-JVS(1780)&
              &*XX(197)-JVS(1834)*XX(198)-JVS(1934)*XX(202)-JVS(1959)*XX(203)-JVS(1981)*XX(204)-JVS(2104)*XX(210)-JVS(2400)&
              &*XX(220)-JVS(2521)*XX(222)-JVS(2668)*XX(224)-JVS(2748)*XX(225)-JVS(2904)*XX(227)-JVS(3124)*XX(230)-JVS(3274)&
              &*XX(231)-JVS(3456)*XX(234)
  XX(185) = XX(185)-JVS(1529)*XX(187)-JVS(1585)*XX(189)-JVS(1747)*XX(196)-JVS(2103)*XX(210)-JVS(2293)*XX(218)-JVS(2399)&
              &*XX(220)-JVS(2667)*XX(224)-JVS(2747)*XX(225)-JVS(2831)*XX(226)-JVS(2903)*XX(227)-JVS(3123)*XX(230)-JVS(3273)&
              &*XX(231)-JVS(3385)*XX(233)-JVS(3455)*XX(234)-JVS(3541)*XX(236)
  XX(184) = XX(184)-JVS(1478)*XX(185)-JVS(1528)*XX(187)-JVS(1584)*XX(189)-JVS(1746)*XX(196)-JVS(2102)*XX(210)-JVS(2398)&
              &*XX(220)-JVS(2666)*XX(224)-JVS(2746)*XX(225)-JVS(2902)*XX(227)-JVS(3122)*XX(230)-JVS(3272)*XX(231)-JVS(3384)&
              &*XX(233)-JVS(3454)*XX(234)-JVS(3540)*XX(236)
  XX(183) = XX(183)-JVS(1527)*XX(187)-JVS(1601)*XX(190)-JVS(1667)*XX(193)-JVS(1700)*XX(194)-JVS(1779)*XX(197)-JVS(1833)&
              &*XX(198)-JVS(1911)*XX(201)-JVS(1998)*XX(205)-JVS(2012)*XX(206)-JVS(2030)*XX(207)-JVS(2057)*XX(209)-JVS(2101)&
              &*XX(210)-JVS(2141)*XX(211)-JVS(2158)*XX(212)-JVS(2170)*XX(213)-JVS(2185)*XX(214)-JVS(2292)*XX(218)-JVS(2397)&
              &*XX(220)-JVS(2520)*XX(222)-JVS(2665)*XX(224)-JVS(2745)*XX(225)-JVS(2830)*XX(226)-JVS(2901)*XX(227)-JVS(3121)&
              &*XX(230)-JVS(3271)*XX(231)-JVS(3383)*XX(233)-JVS(3453)*XX(234)-JVS(3539)*XX(236)
  XX(182) = XX(182)-JVS(2291)*XX(218)-JVS(2396)*XX(220)-JVS(2829)*XX(226)-JVS(3120)*XX(230)-JVS(3270)*XX(231)
  XX(181) = XX(181)-JVS(1881)*XX(200)-JVS(2184)*XX(214)-JVS(2290)*XX(218)-JVS(2519)*XX(222)-JVS(2744)*XX(225)-JVS(2828)&
              &*XX(226)-JVS(3119)*XX(230)-JVS(3345)*XX(232)-JVS(3538)*XX(236)
  XX(180) = XX(180)-JVS(1526)*XX(187)-JVS(1666)*XX(193)-JVS(1699)*XX(194)-JVS(1778)*XX(197)-JVS(1832)*XX(198)-JVS(1910)&
              &*XX(201)-JVS(1958)*XX(203)-JVS(1980)*XX(204)-JVS(2100)*XX(210)-JVS(2183)*XX(214)-JVS(2395)*XX(220)-JVS(2518)&
              &*XX(222)-JVS(2664)*XX(224)-JVS(2743)*XX(225)-JVS(2900)*XX(227)-JVS(3118)*XX(230)-JVS(3269)*XX(231)-JVS(3452)&
              &*XX(234)
  XX(179) = XX(179)-JVS(1525)*XX(187)-JVS(2394)*XX(220)-JVS(2517)*XX(222)-JVS(2899)*XX(227)-JVS(3117)*XX(230)-JVS(3268)&
              &*XX(231)
  XX(178) = XX(178)-JVS(1524)*XX(187)-JVS(1880)*XX(200)-JVS(2289)*XX(218)-JVS(2452)*XX(221)-JVS(2663)*XX(224)-JVS(2827)&
              &*XX(226)-JVS(2898)*XX(227)-JVS(3116)*XX(230)-JVS(3267)*XX(231)-JVS(3344)*XX(232)-JVS(3382)*XX(233)-JVS(3451)&
              &*XX(234)
  XX(177) = XX(177)-JVS(1388)*XX(179)-JVS(1523)*XX(187)-JVS(1621)*XX(191)-JVS(1641)*XX(192)-JVS(1665)*XX(193)-JVS(1698)&
              &*XX(194)-JVS(1777)*XX(197)-JVS(1831)*XX(198)-JVS(1909)*XX(201)-JVS(1933)*XX(202)-JVS(1957)*XX(203)-JVS(1979)&
              &*XX(204)-JVS(2099)*XX(210)-JVS(2393)*XX(220)-JVS(2516)*XX(222)-JVS(2662)*XX(224)-JVS(2742)*XX(225)-JVS(2897)&
              &*XX(227)-JVS(3115)*XX(230)-JVS(3266)*XX(231)-JVS(3450)*XX(234)
  XX(176) = XX(176)-JVS(1522)*XX(187)-JVS(1664)*XX(193)-JVS(1697)*XX(194)-JVS(1776)*XX(197)-JVS(1830)*XX(198)-JVS(2515)&
              &*XX(222)-JVS(2661)*XX(224)-JVS(3114)*XX(230)-JVS(3265)*XX(231)
  XX(175) = XX(175)-JVS(1434)*XX(182)-JVS(2245)*XX(217)-JVS(2288)*XX(218)-JVS(2392)*XX(220)-JVS(2451)*XX(221)-JVS(2576)&
              &*XX(223)-JVS(2660)*XX(224)-JVS(2741)*XX(225)-JVS(2826)*XX(226)-JVS(3113)*XX(230)-JVS(3264)*XX(231)-JVS(3449)&
              &*XX(234)-JVS(3537)*XX(236)
  XX(174) = XX(174)-JVS(1362)*XX(178)-JVS(1521)*XX(187)-JVS(1879)*XX(200)-JVS(2287)*XX(218)-JVS(2450)*XX(221)-JVS(2659)&
              &*XX(224)-JVS(2825)*XX(226)-JVS(2896)*XX(227)-JVS(3112)*XX(230)-JVS(3263)*XX(231)-JVS(3343)*XX(232)-JVS(3381)&
              &*XX(233)-JVS(3448)*XX(234)
  XX(173) = XX(173)-JVS(1433)*XX(182)-JVS(1745)*XX(196)-JVS(2098)*XX(210)-JVS(2286)*XX(218)-JVS(2391)*XX(220)-JVS(2575)&
              &*XX(223)-JVS(2658)*XX(224)-JVS(2740)*XX(225)-JVS(2824)*XX(226)-JVS(3111)*XX(230)-JVS(3262)*XX(231)-JVS(3447)&
              &*XX(234)-JVS(3536)*XX(236)
  XX(172) = XX(172)-JVS(1520)*XX(187)-JVS(1878)*XX(200)-JVS(2285)*XX(218)-JVS(2449)*XX(221)-JVS(2657)*XX(224)-JVS(2823)&
              &*XX(226)-JVS(2895)*XX(227)-JVS(3110)*XX(230)-JVS(3342)*XX(232)-JVS(3380)*XX(233)
  XX(171) = XX(171)-JVS(1315)*XX(174)-JVS(1361)*XX(178)-JVS(1519)*XX(187)-JVS(2656)*XX(224)-JVS(2822)*XX(226)-JVS(2894)&
              &*XX(227)-JVS(3109)*XX(230)-JVS(3261)*XX(231)-JVS(3341)*XX(232)-JVS(3379)*XX(233)-JVS(3446)*XX(234)
  XX(170) = XX(170)-JVS(1829)*XX(198)-JVS(2097)*XX(210)-JVS(2284)*XX(218)-JVS(2390)*XX(220)-JVS(2514)*XX(222)-JVS(2655)&
              &*XX(224)-JVS(2739)*XX(225)-JVS(2821)*XX(226)-JVS(2893)*XX(227)-JVS(3108)*XX(230)-JVS(3260)*XX(231)-JVS(3378)&
              &*XX(233)-JVS(3445)*XX(234)-JVS(3535)*XX(236)
  XX(169) = XX(169)-JVS(1600)*XX(190)-JVS(2283)*XX(218)-JVS(2389)*XX(220)-JVS(2513)*XX(222)-JVS(2574)*XX(223)-JVS(2654)&
              &*XX(224)-JVS(2820)*XX(226)-JVS(2892)*XX(227)-JVS(3107)*XX(230)-JVS(3259)*XX(231)-JVS(3444)*XX(234)-JVS(3534)&
              &*XX(236)
  XX(168) = XX(168)-JVS(1518)*XX(187)-JVS(2388)*XX(220)-JVS(2512)*XX(222)-JVS(2653)*XX(224)-JVS(2738)*XX(225)-JVS(2891)&
              &*XX(227)-JVS(3106)*XX(230)-JVS(3258)*XX(231)
  XX(167) = XX(167)-JVS(1432)*XX(182)-JVS(1744)*XX(196)-JVS(1828)*XX(198)-JVS(2282)*XX(218)-JVS(2387)*XX(220)-JVS(2573)&
              &*XX(223)-JVS(2652)*XX(224)-JVS(2737)*XX(225)-JVS(2819)*XX(226)-JVS(3105)*XX(230)-JVS(3257)*XX(231)-JVS(3443)&
              &*XX(234)-JVS(3533)*XX(236)
  XX(166) = XX(166)-JVS(1387)*XX(179)-JVS(1663)*XX(193)-JVS(1775)*XX(197)-JVS(1827)*XX(198)-JVS(2096)*XX(210)-JVS(2386)&
              &*XX(220)-JVS(2511)*XX(222)-JVS(2736)*XX(225)-JVS(3104)*XX(230)-JVS(3256)*XX(231)
  XX(165) = XX(165)-JVS(1517)*XX(187)-JVS(1662)*XX(193)-JVS(1826)*XX(198)-JVS(2056)*XX(209)-JVS(2095)*XX(210)-JVS(2385)&
              &*XX(220)-JVS(2510)*XX(222)-JVS(2651)*XX(224)-JVS(3103)*XX(230)-JVS(3255)*XX(231)-JVS(3442)*XX(234)
  XX(164) = XX(164)-JVS(1696)*XX(194)-JVS(1774)*XX(197)-JVS(1825)*XX(198)-JVS(1908)*XX(201)-JVS(2384)*XX(220)-JVS(2509)&
              &*XX(222)-JVS(2650)*XX(224)-JVS(2735)*XX(225)-JVS(3102)*XX(230)-JVS(3254)*XX(231)-JVS(3441)*XX(234)
  XX(163) = XX(163)-JVS(1418)*XX(181)-JVS(1516)*XX(187)-JVS(1583)*XX(189)-JVS(1743)*XX(196)-JVS(1865)*XX(199)-JVS(2244)&
              &*XX(217)-JVS(2572)*XX(223)-JVS(2649)*XX(224)-JVS(2955)*XX(228)-JVS(2977)*XX(229)-JVS(3101)*XX(230)-JVS(3253)&
              &*XX(231)-JVS(3532)*XX(236)
  XX(162) = XX(162)-JVS(1515)*XX(187)-JVS(1742)*XX(196)-JVS(2094)*XX(210)-JVS(2648)*XX(224)-JVS(2890)*XX(227)-JVS(3100)&
              &*XX(230)-JVS(3377)*XX(233)
  XX(161) = XX(161)-JVS(1514)*XX(187)-JVS(2055)*XX(209)-JVS(2093)*XX(210)-JVS(2508)*XX(222)-JVS(2647)*XX(224)-JVS(3099)&
              &*XX(230)-JVS(3252)*XX(231)
  XX(160) = XX(160)-JVS(2281)*XX(218)-JVS(2818)*XX(226)-JVS(3098)*XX(230)-JVS(3251)*XX(231)
  XX(159) = XX(159)-JVS(1824)*XX(198)-JVS(2383)*XX(220)-JVS(2646)*XX(224)-JVS(2734)*XX(225)-JVS(3097)*XX(230)
  XX(158) = XX(158)-JVS(1287)*XX(172)-JVS(1513)*XX(187)-JVS(1877)*XX(200)-JVS(2280)*XX(218)-JVS(2817)*XX(226)-JVS(3096)&
              &*XX(230)-JVS(3340)*XX(232)-JVS(3376)*XX(233)
  XX(157) = XX(157)-JVS(1876)*XX(200)-JVS(2279)*XX(218)-JVS(2448)*XX(221)-JVS(2816)*XX(226)-JVS(3095)*XX(230)-JVS(3339)&
              &*XX(232)
  XX(156) = XX(156)-JVS(1204)*XX(166)-JVS(1340)*XX(176)-JVS(2092)*XX(210)-JVS(2382)*XX(220)-JVS(2507)*XX(222)-JVS(2645)&
              &*XX(224)-JVS(2733)*XX(225)-JVS(3094)*XX(230)-JVS(3250)*XX(231)-JVS(3440)*XX(234)
  XX(155) = XX(155)-JVS(2278)*XX(218)-JVS(2815)*XX(226)-JVS(3093)*XX(230)-JVS(3531)*XX(236)
  XX(154) = XX(154)-JVS(1099)*XX(159)-JVS(1227)*XX(168)-JVS(1339)*XX(176)-JVS(1386)*XX(179)-JVS(1512)*XX(187)-JVS(1823)&
              &*XX(198)-JVS(1907)*XX(201)-JVS(1956)*XX(203)-JVS(1978)*XX(204)-JVS(2182)*XX(214)-JVS(2381)*XX(220)-JVS(2506)&
              &*XX(222)-JVS(2644)*XX(224)-JVS(2732)*XX(225)-JVS(3092)*XX(230)-JVS(3249)*XX(231)-JVS(3439)*XX(234)
  XX(153) = XX(153)-JVS(1620)*XX(191)-JVS(1640)*XX(192)-JVS(1661)*XX(193)-JVS(1695)*XX(194)-JVS(1822)*XX(198)-JVS(2505)&
              &*XX(222)-JVS(3091)*XX(230)-JVS(3248)*XX(231)
  XX(152) = XX(152)-JVS(1821)*XX(198)-JVS(2181)*XX(214)-JVS(2380)*XX(220)-JVS(2731)*XX(225)-JVS(3090)*XX(230)
  XX(151) = XX(151)-JVS(1123)*XX(160)-JVS(1146)*XX(161)-JVS(1190)*XX(165)-JVS(1385)*XX(179)-JVS(1660)*XX(193)-JVS(1820)&
              &*XX(198)-JVS(2091)*XX(210)-JVS(2140)*XX(211)-JVS(2379)*XX(220)-JVS(2504)*XX(222)-JVS(2643)*XX(224)-JVS(2730)&
              &*XX(225)-JVS(3089)*XX(230)-JVS(3247)*XX(231)-JVS(3438)*XX(234)
  XX(150) = XX(150)-JVS(1122)*XX(160)-JVS(1179)*XX(164)-JVS(1384)*XX(179)-JVS(1694)*XX(194)-JVS(1819)*XX(198)-JVS(1906)&
              &*XX(201)-JVS(2029)*XX(207)-JVS(2090)*XX(210)-JVS(2378)*XX(220)-JVS(2503)*XX(222)-JVS(2642)*XX(224)-JVS(2729)&
              &*XX(225)-JVS(3088)*XX(230)-JVS(3246)*XX(231)-JVS(3437)*XX(234)
  XX(149) = XX(149)-JVS(1203)*XX(166)-JVS(1383)*XX(179)-JVS(1659)*XX(193)-JVS(1693)*XX(194)-JVS(1773)*XX(197)-JVS(1818)&
              &*XX(198)-JVS(1955)*XX(203)-JVS(2089)*XX(210)-JVS(2641)*XX(224)-JVS(3087)*XX(230)-JVS(3245)*XX(231)-JVS(3436)&
              &*XX(234)
  XX(148) = XX(148)-JVS(1382)*XX(179)-JVS(1817)*XX(198)-JVS(2502)*XX(222)-JVS(2728)*XX(225)-JVS(3244)*XX(231)
  XX(147) = XX(147)-JVS(1001)*XX(152)-JVS(1202)*XX(166)-JVS(1381)*XX(179)-JVS(1658)*XX(193)-JVS(1692)*XX(194)-JVS(1772)&
              &*XX(197)-JVS(1816)*XX(198)-JVS(1954)*XX(203)-JVS(2088)*XX(210)-JVS(2377)*XX(220)-JVS(2640)*XX(224)-JVS(3086)&
              &*XX(230)-JVS(3243)*XX(231)-JVS(3435)*XX(234)
  XX(146) = XX(146)-JVS(1201)*XX(166)-JVS(1380)*XX(179)-JVS(1657)*XX(193)-JVS(1691)*XX(194)-JVS(1771)*XX(197)-JVS(1815)&
              &*XX(198)-JVS(1953)*XX(203)-JVS(2087)*XX(210)-JVS(2376)*XX(220)-JVS(2501)*XX(222)-JVS(2639)*XX(224)-JVS(3085)&
              &*XX(230)-JVS(3242)*XX(231)-JVS(3434)*XX(234)
  XX(145) = XX(145)-JVS(1408)*XX(180)-JVS(1511)*XX(187)-JVS(1722)*XX(195)-JVS(1952)*XX(203)-JVS(2028)*XX(207)-JVS(2139)&
              &*XX(211)-JVS(2169)*XX(213)-JVS(2375)*XX(220)-JVS(2638)*XX(224)-JVS(3084)*XX(230)-JVS(3241)*XX(231)
  XX(144) = XX(144)-JVS(1510)*XX(187)-JVS(1582)*XX(189)-JVS(2086)*XX(210)-JVS(2637)*XX(224)-JVS(2889)*XX(227)-JVS(3083)&
              &*XX(230)
  XX(143) = XX(143)-JVS(1098)*XX(159)-JVS(1509)*XX(187)-JVS(2500)*XX(222)-JVS(3082)*XX(230)-JVS(3240)*XX(231)
  XX(142) = XX(142)-JVS(1814)*XX(198)-JVS(2085)*XX(210)-JVS(2374)*XX(220)-JVS(2499)*XX(222)
  XX(141) = XX(141)-JVS(1121)*XX(160)-JVS(1465)*XX(184)-JVS(1477)*XX(185)-JVS(1570)*XX(188)-JVS(2138)*XX(211)-JVS(2213)&
              &*XX(215)-JVS(2243)*XX(217)-JVS(2277)*XX(218)-JVS(2335)*XX(219)-JVS(2373)*XX(220)-JVS(2498)*XX(222)-JVS(2814)&
              &*XX(226)-JVS(2888)*XX(227)-JVS(3081)*XX(230)-JVS(3239)*XX(231)-JVS(3375)*XX(233)
  XX(140) = XX(140)-JVS(1274)*XX(171)-JVS(1314)*XX(174)-JVS(1508)*XX(187)-JVS(2636)*XX(224)-JVS(2813)*XX(226)-JVS(2887)&
              &*XX(227)-JVS(3080)*XX(230)-JVS(3338)*XX(232)
  XX(139) = XX(139)-JVS(1379)*XX(179)-JVS(2372)*XX(220)-JVS(2497)*XX(222)-JVS(3079)*XX(230)-JVS(3238)*XX(231)
  XX(138) = XX(138)-JVS(871)*XX(139)-JVS(907)*XX(142)-JVS(950)*XX(146)-JVS(988)*XX(150)-JVS(1016)*XX(153)-JVS(1053)&
              &*XX(156)-JVS(1690)*XX(194)-JVS(1813)*XX(198)-JVS(1997)*XX(205)-JVS(2027)*XX(207)-JVS(2371)*XX(220)-JVS(2496)&
              &*XX(222)-JVS(2727)*XX(225)-JVS(3078)*XX(230)-JVS(3237)*XX(231)
  XX(137) = XX(137)-JVS(2370)*XX(220)-JVS(2495)*XX(222)-JVS(2726)*XX(225)-JVS(3077)*XX(230)-JVS(3236)*XX(231)
  XX(136) = XX(136)-JVS(921)*XX(143)-JVS(1097)*XX(159)-JVS(1338)*XX(176)-JVS(1770)*XX(197)-JVS(1951)*XX(203)-JVS(1977)&
              &*XX(204)-JVS(2369)*XX(220)-JVS(2635)*XX(224)-JVS(3076)*XX(230)-JVS(3235)*XX(231)-JVS(3433)*XX(234)
  XX(135) = XX(135)-JVS(1145)*XX(161)-JVS(1337)*XX(176)-JVS(1769)*XX(197)-JVS(1950)*XX(203)-JVS(1976)*XX(204)-JVS(2084)&
              &*XX(210)-JVS(2368)*XX(220)-JVS(2634)*XX(224)-JVS(3075)*XX(230)-JVS(3234)*XX(231)-JVS(3432)*XX(234)
  XX(134) = XX(134)-JVS(1226)*XX(168)-JVS(1336)*XX(176)-JVS(1905)*XX(201)-JVS(1949)*XX(203)-JVS(1975)*XX(204)-JVS(2083)&
              &*XX(210)-JVS(2367)*XX(220)-JVS(2633)*XX(224)-JVS(3074)*XX(230)-JVS(3233)*XX(231)-JVS(3431)*XX(234)
  XX(133) = XX(133)-JVS(906)*XX(142)-JVS(957)*XX(147)-JVS(994)*XX(151)-JVS(1000)*XX(152)-JVS(1015)*XX(153)-JVS(1052)&
              &*XX(156)-JVS(1656)*XX(193)-JVS(1812)*XX(198)-JVS(2011)*XX(206)-JVS(2137)*XX(211)-JVS(2366)*XX(220)-JVS(2494)&
              &*XX(222)-JVS(3073)*XX(230)-JVS(3232)*XX(231)
  XX(132) = XX(132)-JVS(1378)*XX(179)-JVS(1655)*XX(193)-JVS(1689)*XX(194)-JVS(1768)*XX(197)-JVS(1811)*XX(198)-JVS(2082)&
              &*XX(210)-JVS(3072)*XX(230)-JVS(3231)*XX(231)
  XX(131) = XX(131)-JVS(2276)*XX(218)-JVS(2812)*XX(226)-JVS(3071)*XX(230)-JVS(3230)*XX(231)
  XX(130) = XX(130)-JVS(884)*XX(140)-JVS(1273)*XX(171)-JVS(1313)*XX(174)-JVS(1507)*XX(187)-JVS(2632)*XX(224)-JVS(2811)&
              &*XX(226)-JVS(2886)*XX(227)-JVS(3337)*XX(232)
  XX(129) = XX(129)-JVS(966)*XX(148)-JVS(1120)*XX(160)-JVS(1377)*XX(179)-JVS(1810)*XX(198)-JVS(2493)*XX(222)-JVS(2725)&
              &*XX(225)-JVS(3070)*XX(230)-JVS(3229)*XX(231)
  XX(128) = XX(128)-JVS(905)*XX(142)-JVS(956)*XX(147)-JVS(981)*XX(149)-JVS(1051)*XX(156)-JVS(1619)*XX(191)-JVS(1639)&
              &*XX(192)-JVS(1654)*XX(193)-JVS(2010)*XX(206)-JVS(2136)*XX(211)-JVS(2365)*XX(220)-JVS(2492)*XX(222)-JVS(3069)&
              &*XX(230)-JVS(3228)*XX(231)
  XX(127) = XX(127)-JVS(1083)*XX(158)-JVS(1360)*XX(178)-JVS(1506)*XX(187)-JVS(2275)*XX(218)-JVS(2631)*XX(224)-JVS(2810)&
              &*XX(226)-JVS(2885)*XX(227)-JVS(3068)*XX(230)-JVS(3336)*XX(232)
  XX(126) = XX(126)-JVS(904)*XX(142)-JVS(1026)*XX(154)-JVS(1505)*XX(187)-JVS(1721)*XX(195)-JVS(1932)*XX(202)-JVS(1948)&
              &*XX(203)-JVS(1996)*XX(205)-JVS(2009)*XX(206)-JVS(2157)*XX(212)-JVS(2630)*XX(224)-JVS(3067)*XX(230)-JVS(3227)&
              &*XX(231)
  XX(125) = XX(125)-JVS(1741)*XX(196)-JVS(3066)*XX(230)-JVS(3226)*XX(231)
  XX(124) = XX(124)-JVS(903)*XX(142)-JVS(949)*XX(146)-JVS(980)*XX(149)-JVS(1618)*XX(191)-JVS(1638)*XX(192)-JVS(1688)&
              &*XX(194)-JVS(1995)*XX(205)-JVS(2026)*XX(207)-JVS(2364)*XX(220)-JVS(2491)*XX(222)-JVS(3065)*XX(230)-JVS(3225)&
              &*XX(231)
  XX(123) = XX(123)-JVS(1376)*XX(179)-JVS(1809)*XX(198)-JVS(2490)*XX(222)-JVS(2724)*XX(225)-JVS(3064)*XX(230)-JVS(3224)&
              &*XX(231)
  XX(122) = XX(122)-JVS(816)*XX(131)-JVS(1464)*XX(184)-JVS(1476)*XX(185)-JVS(1581)*XX(189)-JVS(1740)*XX(196)-JVS(2046)&
              &*XX(208)-JVS(2212)*XX(215)-JVS(2489)*XX(222)-JVS(2884)*XX(227)-JVS(3063)*XX(230)-JVS(3223)*XX(231)-JVS(3374)&
              &*XX(233)
  XX(121) = XX(121)-JVS(815)*XX(131)-JVS(1463)*XX(184)-JVS(1475)*XX(185)-JVS(1580)*XX(189)-JVS(1739)*XX(196)-JVS(2045)&
              &*XX(208)-JVS(2211)*XX(215)-JVS(2488)*XX(222)-JVS(2883)*XX(227)-JVS(3062)*XX(230)-JVS(3222)*XX(231)-JVS(3373)&
              &*XX(233)
  XX(120) = XX(120)-JVS(1119)*XX(160)-JVS(1252)*XX(170)-JVS(1808)*XX(198)-JVS(2081)*XX(210)-JVS(2487)*XX(222)-JVS(2629)&
              &*XX(224)-JVS(2723)*XX(225)-JVS(2882)*XX(227)-JVS(3061)*XX(230)
  XX(119) = XX(119)-JVS(1335)*XX(176)-JVS(1904)*XX(201)-JVS(1947)*XX(203)-JVS(1974)*XX(204)-JVS(2363)*XX(220)-JVS(2628)&
              &*XX(224)-JVS(3060)*XX(230)-JVS(3221)*XX(231)-JVS(3430)*XX(234)
  XX(118) = XX(118)-JVS(1096)*XX(159)-JVS(1225)*XX(168)-JVS(2486)*XX(222)-JVS(2627)*XX(224)-JVS(3059)*XX(230)-JVS(3220)&
              &*XX(231)-JVS(3429)*XX(234)
  XX(117) = XX(117)-JVS(1325)*XX(175)-JVS(1504)*XX(187)-JVS(1875)*XX(200)-JVS(2274)*XX(218)-JVS(2809)*XX(226)-JVS(2881)&
              &*XX(227)-JVS(3058)*XX(230)-JVS(3335)*XX(232)
  XX(116) = XX(116)-JVS(1095)*XX(159)-JVS(1224)*XX(168)-JVS(1767)*XX(197)-JVS(1973)*XX(204)-JVS(2626)*XX(224)-JVS(3057)&
              &*XX(230)-JVS(3219)*XX(231)-JVS(3428)*XX(234)
  XX(115) = XX(115)-JVS(1144)*XX(161)-JVS(1189)*XX(165)-JVS(2625)*XX(224)-JVS(3056)*XX(230)-JVS(3218)*XX(231)-JVS(3427)&
              &*XX(234)
  XX(114) = XX(114)-JVS(1178)*XX(164)-JVS(1903)*XX(201)-JVS(2624)*XX(224)-JVS(3055)*XX(230)-JVS(3217)*XX(231)-JVS(3426)&
              &*XX(234)
  XX(113) = XX(113)-JVS(828)*XX(132)-JVS(1200)*XX(166)-JVS(1766)*XX(197)-JVS(2080)*XX(210)-JVS(3054)*XX(230)-JVS(3216)&
              &*XX(231)
  XX(112) = XX(112)-JVS(745)*XX(119)-JVS(902)*XX(142)-JVS(1503)*XX(187)-JVS(1617)*XX(191)-JVS(1637)*XX(192)-JVS(2135)&
              &*XX(211)-JVS(2362)*XX(220)-JVS(2623)*XX(224)-JVS(3053)*XX(230)-JVS(3215)*XX(231)
  XX(111) = XX(111)-JVS(844)*XX(135)-JVS(901)*XX(142)-JVS(1502)*XX(187)-JVS(1616)*XX(191)-JVS(1636)*XX(192)-JVS(2025)&
              &*XX(207)-JVS(2361)*XX(220)-JVS(2622)*XX(224)-JVS(3052)*XX(230)-JVS(3214)*XX(231)
  XX(110) = XX(110)-JVS(1082)*XX(158)-JVS(1286)*XX(172)-JVS(1501)*XX(187)-JVS(2808)*XX(226)-JVS(3051)*XX(230)-JVS(3334)&
              &*XX(232)-JVS(3372)*XX(233)
  XX(109) = XX(109)-JVS(1081)*XX(158)-JVS(1285)*XX(172)-JVS(1500)*XX(187)-JVS(2807)*XX(226)-JVS(3050)*XX(230)-JVS(3333)&
              &*XX(232)-JVS(3371)*XX(233)
  XX(108) = XX(108)-JVS(1118)*XX(160)-JVS(1251)*XX(170)-JVS(1807)*XX(198)-JVS(2079)*XX(210)-JVS(2360)*XX(220)-JVS(2485)&
              &*XX(222)-JVS(2722)*XX(225)-JVS(3049)*XX(230)-JVS(3530)*XX(236)
  XX(107) = XX(107)-JVS(2273)*XX(218)-JVS(2571)*XX(223)-JVS(2806)*XX(226)-JVS(3048)*XX(230)-JVS(3213)*XX(231)
  XX(106) = XX(106)-JVS(900)*XX(142)-JVS(1615)*XX(191)-JVS(1635)*XX(192)-JVS(3047)*XX(230)-JVS(3212)*XX(231)
  XX(105) = XX(105)-JVS(1499)*XX(187)-JVS(2078)*XX(210)-JVS(2621)*XX(224)-JVS(2880)*XX(227)-JVS(3046)*XX(230)
  XX(104) = XX(104)-JVS(899)*XX(142)-JVS(1614)*XX(191)-JVS(1634)*XX(192)-JVS(3045)*XX(230)-JVS(3211)*XX(231)
  XX(103) = XX(103)-JVS(965)*XX(148)-JVS(2077)*XX(210)-JVS(2484)*XX(222)-JVS(3044)*XX(230)-JVS(3210)*XX(231)
  XX(102) = XX(102)-JVS(898)*XX(142)-JVS(1653)*XX(193)-JVS(2134)*XX(211)-JVS(2483)*XX(222)-JVS(3043)*XX(230)-JVS(3209)&
              &*XX(231)
  XX(101) = XX(101)-JVS(1080)*XX(158)-JVS(3042)*XX(230)-JVS(3332)*XX(232)
  XX(100) = XX(100)-JVS(897)*XX(142)-JVS(1687)*XX(194)-JVS(2024)*XX(207)-JVS(2482)*XX(222)-JVS(3041)*XX(230)-JVS(3208)&
              &*XX(231)
  XX(99) = XX(99)-JVS(1241)*XX(169)-JVS(1599)*XX(190)-JVS(2359)*XX(220)-JVS(2570)*XX(223)-JVS(3040)*XX(230)-JVS(3207)&
             &*XX(231)
  XX(98) = XX(98)-JVS(1066)*XX(157)-JVS(2805)*XX(226)-JVS(3039)*XX(230)
  XX(97) = XX(97)-JVS(765)*XX(123)-JVS(856)*XX(137)-JVS(964)*XX(148)-JVS(1613)*XX(191)-JVS(1633)*XX(192)-JVS(2481)&
             &*XX(222)-JVS(3038)*XX(230)-JVS(3206)*XX(231)
  XX(96) = XX(96)-JVS(2272)*XX(218)-JVS(2358)*XX(220)-JVS(2804)*XX(226)-JVS(3037)*XX(230)-JVS(3205)*XX(231)-JVS(3529)&
             &*XX(236)
  XX(95) = XX(95)-JVS(1720)*XX(195)-JVS(1931)*XX(202)-JVS(3204)*XX(231)
  XX(94) = XX(94)-JVS(1874)*XX(200)-JVS(2271)*XX(218)-JVS(2803)*XX(226)-JVS(2954)*XX(228)-JVS(2976)*XX(229)-JVS(3036)&
             &*XX(230)-JVS(3331)*XX(232)
  XX(93) = XX(93)-JVS(1065)*XX(157)-JVS(1498)*XX(187)-JVS(2270)*XX(218)-JVS(2620)*XX(224)-JVS(2802)*XX(226)-JVS(2879)&
             &*XX(227)-JVS(3035)*XX(230)
  XX(92) = XX(92)-JVS(2801)*XX(226)-JVS(3330)*XX(232)
  XX(91) = XX(91)-JVS(2133)*XX(211)-JVS(2619)*XX(224)-JVS(3034)*XX(230)-JVS(3203)*XX(231)-JVS(3425)*XX(234)
  XX(90) = XX(90)-JVS(2023)*XX(207)-JVS(2618)*XX(224)-JVS(3033)*XX(230)-JVS(3202)*XX(231)-JVS(3424)*XX(234)
  XX(89) = XX(89)-JVS(1579)*XX(189)-JVS(1738)*XX(196)-JVS(2228)*XX(216)-JVS(3032)*XX(230)-JVS(3201)*XX(231)
  XX(88) = XX(88)-JVS(1272)*XX(171)-JVS(1312)*XX(174)-JVS(2800)*XX(226)-JVS(3031)*XX(230)-JVS(3329)*XX(232)
  XX(87) = XX(87)-JVS(855)*XX(137)-JVS(963)*XX(148)-JVS(3030)*XX(230)-JVS(3200)*XX(231)
  XX(86) = XX(86)-JVS(896)*XX(142)-JVS(1050)*XX(156)-JVS(3029)*XX(230)-JVS(3199)*XX(231)
  XX(85) = XX(85)-JVS(1094)*XX(159)-JVS(1215)*XX(167)-JVS(1737)*XX(196)-JVS(2617)*XX(224)-JVS(3028)*XX(230)-JVS(3198)&
             &*XX(231)
  XX(84) = XX(84)-JVS(1299)*XX(173)-JVS(2076)*XX(210)-JVS(2357)*XX(220)-JVS(2569)*XX(223)-JVS(3027)*XX(230)-JVS(3197)&
             &*XX(231)
  XX(83) = XX(83)-JVS(1497)*XX(187)-JVS(2227)*XX(216)-JVS(2269)*XX(218)-JVS(2799)*XX(226)-JVS(2878)*XX(227)-JVS(3026)&
             &*XX(230)
  XX(82) = XX(82)-JVS(2242)*XX(217)-JVS(2568)*XX(223)-JVS(3025)*XX(230)-JVS(3196)*XX(231)
  XX(81) = XX(81)-JVS(1064)*XX(157)-JVS(2447)*XX(221)-JVS(3024)*XX(230)-JVS(3370)*XX(233)
  XX(80) = XX(80)-JVS(764)*XX(123)-JVS(2480)*XX(222)-JVS(3023)*XX(230)-JVS(3195)*XX(231)
  XX(79) = XX(79)-JVS(2721)*XX(225)-JVS(3022)*XX(230)-JVS(3194)*XX(231)
  XX(78) = XX(78)-JVS(624)*XX(98)-JVS(2446)*XX(221)-JVS(2798)*XX(226)
  XX(77) = XX(77)-JVS(883)*XX(140)-JVS(1271)*XX(171)-JVS(2616)*XX(224)-JVS(2797)*XX(226)-JVS(3021)*XX(230)-JVS(3328)&
             &*XX(232)-JVS(3423)*XX(234)
  XX(76) = XX(76)-JVS(1496)*XX(187)
  XX(75) = XX(75)-JVS(2268)*XX(218)-JVS(2479)*XX(222)-JVS(2796)*XX(226)-JVS(3020)*XX(230)-JVS(3193)*XX(231)-JVS(3528)&
             &*XX(236)
  XX(74) = XX(74)-JVS(634)*XX(99)-JVS(1495)*XX(187)-JVS(2356)*XX(220)-JVS(2877)*XX(227)-JVS(3019)*XX(230)-JVS(3527)&
             &*XX(236)
  XX(73) = XX(73)-JVS(1063)*XX(157)-JVS(2615)*XX(224)-JVS(2795)*XX(226)-JVS(3018)*XX(230)
  XX(72) = XX(72)-JVS(1375)*XX(179)-JVS(1806)*XX(198)-JVS(2355)*XX(220)-JVS(2876)*XX(227)-JVS(3192)*XX(231)-JVS(3422)&
             &*XX(234)
  XX(71) = XX(71)-JVS(2567)*XX(223)-JVS(3017)*XX(230)-JVS(3191)*XX(231)-JVS(3498)*XX(235)
  XX(70) = XX(70)-JVS(1417)*XX(181)-JVS(2975)*XX(229)-JVS(3016)*XX(230)-JVS(3190)*XX(231)
  XX(69) = XX(69)-JVS(1736)*XX(196)-JVS(2953)*XX(228)-JVS(3015)*XX(230)-JVS(3189)*XX(231)
  XX(68) = XX(68)-JVS(1735)*XX(196)-JVS(2226)*XX(216)-JVS(3014)*XX(230)-JVS(3188)*XX(231)
  XX(67) = XX(67)-JVS(1270)*XX(171)-JVS(1311)*XX(174)-JVS(2614)*XX(224)-JVS(3421)*XX(234)
  XX(66) = XX(66)-JVS(1734)*XX(196)-JVS(2613)*XX(224)-JVS(3013)*XX(230)-JVS(3187)*XX(231)
  XX(65) = XX(65)-JVS(2354)*XX(220)-JVS(2612)*XX(224)-JVS(3012)*XX(230)-JVS(3186)*XX(231)
  XX(64) = XX(64)-JVS(1416)*XX(181)-JVS(2611)*XX(224)-JVS(3011)*XX(230)-JVS(3185)*XX(231)
  XX(63) = XX(63)-JVS(2566)*XX(223)-JVS(2610)*XX(224)-JVS(3010)*XX(230)-JVS(3184)*XX(231)
  XX(62) = XX(62)-JVS(2609)*XX(224)-JVS(2875)*XX(227)-JVS(3009)*XX(230)-JVS(3183)*XX(231)
  XX(61) = XX(61)-JVS(2608)*XX(224)-JVS(3008)*XX(230)-JVS(3420)*XX(234)
  XX(60) = XX(60)-JVS(1117)*XX(160)-JVS(1805)*XX(198)-JVS(2720)*XX(225)-JVS(3007)*XX(230)
  XX(59) = XX(59)-JVS(2267)*XX(218)-JVS(2478)*XX(222)-JVS(2794)*XX(226)-JVS(3006)*XX(230)-JVS(3182)*XX(231)
  XX(58) = XX(58)-JVS(2353)*XX(220)-JVS(2607)*XX(224)-JVS(2874)*XX(227)-JVS(3181)*XX(231)-JVS(3526)*XX(236)
  XX(57) = XX(57)-JVS(515)*XX(78)-JVS(1062)*XX(157)-JVS(2445)*XX(221)-JVS(2793)*XX(226)-JVS(3005)*XX(230)
  XX(56) = XX(56)-JVS(1269)*XX(171)-JVS(2792)*XX(226)
  XX(55) = XX(55)-JVS(2266)*XX(218)-JVS(2477)*XX(222)-JVS(2791)*XX(226)-JVS(3004)*XX(230)-JVS(3180)*XX(231)
  XX(54) = XX(54)-JVS(2719)*XX(225)-JVS(3003)*XX(230)-JVS(3525)*XX(236)
  XX(53) = XX(53)-JVS(3179)*XX(231)-JVS(3419)*XX(234)
  XX(52) = XX(52)-JVS(2606)*XX(224)-JVS(2718)*XX(225)-JVS(2873)*XX(227)-JVS(3524)*XX(236)
  XX(51) = XX(51)-JVS(1116)*XX(160)-JVS(2352)*XX(220)-JVS(3002)*XX(230)-JVS(3178)*XX(231)
  XX(50) = XX(50)-JVS(3177)*XX(231)-JVS(3418)*XX(234)
  XX(49) = XX(49)-JVS(3176)*XX(231)-JVS(3417)*XX(234)
  XX(48) = XX(48)-JVS(882)*XX(140)-JVS(1268)*XX(171)-JVS(3416)*XX(234)
  XX(47) = XX(47)-JVS(1267)*XX(171)-JVS(3327)*XX(232)
  XX(46) = XX(46)-JVS(1266)*XX(171)-JVS(3001)*XX(230)
  XX(45) = XX(45)-JVS(3000)*XX(230)-JVS(3175)*XX(231)-JVS(3326)*XX(232)-JVS(3523)*XX(236)
  XX(44) = XX(44)-JVS(2605)*XX(224)-JVS(3325)*XX(232)
  XX(43) = XX(43)-JVS(388)*XX(49)-JVS(1374)*XX(179)-JVS(1804)*XX(198)-JVS(2351)*XX(220)
  XX(42) = XX(42)-JVS(2604)*XX(224)-JVS(3497)*XX(235)
  XX(41) = XX(41)-JVS(464)*XX(67)-JVS(1310)*XX(174)
  XX(40) = XX(40)-JVS(1265)*XX(171)-JVS(2999)*XX(230)-JVS(3522)*XX(236)
  XX(39) = XX(39)-JVS(393)*XX(50)-JVS(1373)*XX(179)-JVS(2350)*XX(220)
  XX(38) = XX(38)-JVS(1494)*XX(187)
  XX(37) = XX(37)-JVS(463)*XX(67)-JVS(1264)*XX(171)-JVS(1309)*XX(174)
  XX(36) = XX(36)-JVS(2998)*XX(230)-JVS(3324)*XX(232)
  XX(35) = XX(35)-JVS(2997)*XX(230)-JVS(3323)*XX(232)
  XX(34) = XX(34)-JVS(462)*XX(67)
  XX(33) = XX(33)
  XX(32) = XX(32)
  XX(31) = XX(31)
  XX(30) = XX(30)
  XX(29) = XX(29)
  XX(28) = XX(28)
  XX(27) = XX(27)
  XX(26) = XX(26)
  XX(25) = XX(25)
  XX(24) = XX(24)
  XX(23) = XX(23)
  XX(22) = XX(22)
  XX(21) = XX(21)
  XX(20) = XX(20)
  XX(19) = XX(19)
  XX(18) = XX(18)
  XX(17) = XX(17)
  XX(16) = XX(16)
  XX(15) = XX(15)
  XX(14) = XX(14)
  XX(13) = XX(13)
  XX(12) = XX(12)
  XX(11) = XX(11)
  XX(10) = XX(10)
  XX(9) = XX(9)
  XX(8) = XX(8)
  XX(7) = XX(7)
  XX(6) = XX(6)
  XX(5) = XX(5)-JVS(114)*XX(27)-JVS(436)*XX(61)-JVS(2603)*XX(224)
  XX(4) = XX(4)-JVS(113)*XX(27)-JVS(435)*XX(61)-JVS(2602)*XX(224)
  XX(3) = XX(3)-JVS(1263)*XX(171)-JVS(2790)*XX(226)
  XX(2) = XX(2)-JVS(1262)*XX(171)-JVS(3322)*XX(232)
  XX(1) = XX(1)-JVS(1261)*XX(171)
      
END SUBROUTINE KppSolveTR

! End of KppSolveTR function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
! 
! BLAS_UTIL - BLAS-LIKE utility functions
!   Arguments :
! 
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

!--------------------------------------------------------------
!
! BLAS/LAPACK-like subroutines used by the integration algorithms
! It is recommended to replace them by calls to the optimized
!      BLAS/LAPACK library for your machine
!
!  (C) Adrian Sandu, Aug. 2004
!      Virginia Polytechnic Institute and State University
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE WCOPY(N,X,incX,Y,incY)
!--------------------------------------------------------------
!     copies a vector, x, to a vector, y:  y <- x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL  SCOPY(N,X,1,Y,1)   or   CALL  DCOPY(N,X,1,Y,1)
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N)

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = X(i)
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i) = X(i)
        Y(i + 1) = X(i + 1)
        Y(i + 2) = X(i + 2)
        Y(i + 3) = X(i + 3)
        Y(i + 4) = X(i + 4)
        Y(i + 5) = X(i + 5)
        Y(i + 6) = X(i + 6)
        Y(i + 7) = X(i + 7)
      END DO

      END SUBROUTINE WCOPY


!--------------------------------------------------------------
      SUBROUTINE WAXPY(N,Alpha,X,incX,Y,incY)
!--------------------------------------------------------------
!     constant times a vector plus a vector: y <- y + Alpha*x
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SAXPY(N,Alpha,X,1,Y,1) or  CALL DAXPY(N,Alpha,X,1,Y,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,incY,M,MP1,N
      REAL(kind=dp) :: X(N),Y(N),Alpha
      REAL(kind=dp), PARAMETER :: ZERO = 0.0_dp

      IF (Alpha .EQ. ZERO) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,4)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = Y(i) + Alpha*X(i)
        END DO
        IF( N .LT. 4 ) RETURN
      END IF
      MP1 = M + 1
      DO i = MP1,N,4
        Y(i) = Y(i) + Alpha*X(i)
        Y(i + 1) = Y(i + 1) + Alpha*X(i + 1)
        Y(i + 2) = Y(i + 2) + Alpha*X(i + 2)
        Y(i + 3) = Y(i + 3) + Alpha*X(i + 3)
      END DO
      
      END SUBROUTINE WAXPY



!--------------------------------------------------------------
      SUBROUTINE WSCAL(N,Alpha,X,incX)
!--------------------------------------------------------------
!     constant times a vector: x(1:N) <- Alpha*x(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SSCAL(N,Alpha,X,1) or  CALL DSCAL(N,Alpha,X,1)
!--------------------------------------------------------------

      INTEGER  :: i,incX,M,MP1,N
      REAL(kind=dp)  :: X(N),Alpha
      REAL(kind=dp), PARAMETER  :: ZERO=0.0_dp, ONE=1.0_dp

      IF (Alpha .EQ. ONE) RETURN
      IF (N .LE. 0) RETURN

      M = MOD(N,5)
      IF( M .NE. 0 ) THEN
        IF (Alpha .EQ. (-ONE)) THEN
          DO i = 1,M
            X(i) = -X(i)
          END DO
        ELSEIF (Alpha .EQ. ZERO) THEN
          DO i = 1,M
            X(i) = ZERO
          END DO
        ELSE
          DO i = 1,M
            X(i) = Alpha*X(i)
          END DO
        END IF
        IF( N .LT. 5 ) RETURN
      END IF
      MP1 = M + 1
      IF (Alpha .EQ. (-ONE)) THEN
        DO i = MP1,N,5
          X(i)     = -X(i)
          X(i + 1) = -X(i + 1)
          X(i + 2) = -X(i + 2)
          X(i + 3) = -X(i + 3)
          X(i + 4) = -X(i + 4)
        END DO
      ELSEIF (Alpha .EQ. ZERO) THEN
        DO i = MP1,N,5
          X(i)     = ZERO
          X(i + 1) = ZERO
          X(i + 2) = ZERO
          X(i + 3) = ZERO
          X(i + 4) = ZERO
        END DO
      ELSE
        DO i = MP1,N,5
          X(i)     = Alpha*X(i)
          X(i + 1) = Alpha*X(i + 1)
          X(i + 2) = Alpha*X(i + 2)
          X(i + 3) = Alpha*X(i + 3)
          X(i + 4) = Alpha*X(i + 4)
        END DO
      END IF

      END SUBROUTINE WSCAL

!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WLAMCH( C )
!--------------------------------------------------------------
!     returns epsilon machine
!     after LAPACK
!     replace this by the function from the optimized LAPACK implementation:
!          CALL SLAMCH('E') or CALL DLAMCH('E')
!--------------------------------------------------------------
!      USE gckpp_Precision

      CHARACTER ::  C
      INTEGER    :: i
      REAL(kind=dp), SAVE  ::  Eps
      REAL(kind=dp)  ::  Suma
      REAL(kind=dp), PARAMETER  ::  ONE=1.0_dp, HALF=0.5_dp
      LOGICAL, SAVE   ::  First=.TRUE.

!$OMP THREADPRIVATE( Eps, First )      

      IF (First) THEN
        First = .FALSE.
        Eps = HALF**(16)
        DO i = 17, 80
          Eps = Eps*HALF
          CALL WLAMCH_ADD(ONE,Eps,Suma)
          IF (Suma.LE.ONE) GOTO 10
        END DO
        PRINT*,'ERROR IN WLAMCH. EPS < ',Eps
        RETURN
10      Eps = Eps*2
        i = i-1      
      END IF

      WLAMCH = Eps

      END FUNCTION WLAMCH
     
      SUBROUTINE WLAMCH_ADD( A, B, Suma )
!      USE gckpp_Precision
      
      REAL(kind=dp) A, B, Suma
      Suma = A + B

      END SUBROUTINE WLAMCH_ADD
!--------------------------------------------------------------


!--------------------------------------------------------------
      SUBROUTINE SET2ZERO(N,Y)
!--------------------------------------------------------------
!     copies zeros into the vector y:  y <- 0
!     after BLAS
!--------------------------------------------------------------
      
      INTEGER ::  i,M,MP1,N
      REAL(kind=dp) ::  Y(N)
      REAL(kind=dp), PARAMETER :: ZERO = 0.0d0

      IF (N.LE.0) RETURN

      M = MOD(N,8)
      IF( M .NE. 0 ) THEN
        DO i = 1,M
          Y(i) = ZERO
        END DO
        IF( N .LT. 8 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,8
        Y(i)     = ZERO
        Y(i + 1) = ZERO
        Y(i + 2) = ZERO
        Y(i + 3) = ZERO
        Y(i + 4) = ZERO
        Y(i + 5) = ZERO
        Y(i + 6) = ZERO
        Y(i + 7) = ZERO
      END DO

      END SUBROUTINE SET2ZERO


!--------------------------------------------------------------
      REAL(kind=dp) FUNCTION WDOT (N, DX, incX, DY, incY) 
!--------------------------------------------------------------
!     dot produce: wdot = x(1:N)*y(1:N) 
!     only for incX=incY=1
!     after BLAS
!     replace this by the function from the optimized BLAS implementation:
!         CALL SDOT(N,X,1,Y,1) or  CALL DDOT(N,X,1,Y,1)
!--------------------------------------------------------------
!      USE messy_mecca_kpp_Precision
!--------------------------------------------------------------
      IMPLICIT NONE
      INTEGER :: N, incX, incY
      REAL(kind=dp) :: DX(N), DY(N) 

      INTEGER :: i, IX, IY, M, MP1, NS
                                 
      WDOT = 0.0D0 
      IF (N .LE. 0) RETURN 
      IF (incX .EQ. incY) IF (incX-1) 5,20,60 
!                                                                       
!     Code for unequal or nonpositive increments.                       
!                                                                       
    5 IX = 1 
      IY = 1 
      IF (incX .LT. 0) IX = (-N+1)*incX + 1 
      IF (incY .LT. 0) IY = (-N+1)*incY + 1 
      DO i = 1,N 
        WDOT = WDOT + DX(IX)*DY(IY) 
        IX = IX + incX 
        IY = IY + incY 
      END DO 
      RETURN 
!                                                                       
!     Code for both increments equal to 1.                              
!                                                                       
!     Clean-up loop so remaining vector length is a multiple of 5.      
!                                                                       
   20 M = MOD(N,5) 
      IF (M .EQ. 0) GO TO 40 
      DO i = 1,M 
         WDOT = WDOT + DX(i)*DY(i) 
      END DO 
      IF (N .LT. 5) RETURN 
   40 MP1 = M + 1 
      DO i = MP1,N,5 
          WDOT = WDOT + DX(i)*DY(i) + DX(i+1)*DY(i+1) + DX(i+2)*DY(i+2) +  &
                   DX(i+3)*DY(i+3) + DX(i+4)*DY(i+4)                   
      END DO 
      RETURN 
!                                                                       
!     Code for equal, positive, non-unit increments.                    
!                                                                       
   60 NS = N*incX 
      DO i = 1,NS,incX 
        WDOT = WDOT + DX(i)*DY(i) 
      END DO 

      END FUNCTION WDOT                                          


!--------------------------------------------------------------
      SUBROUTINE WADD(N,X,Y,Z)
!--------------------------------------------------------------
!     adds two vectors: z <- x + y
!     BLAS - like
!--------------------------------------------------------------
!     USE gckpp_Precision
      
      INTEGER :: i, M, MP1, N
      REAL(kind=dp) :: X(N),Y(N),Z(N)

      IF (N.LE.0) RETURN

      M = MOD(N,5)
      IF( M /= 0 ) THEN
         DO i = 1,M
            Z(i) = X(i) + Y(i)
         END DO
         IF( N < 5 ) RETURN
      END IF    
      MP1 = M+1
      DO i = MP1,N,5
         Z(i)     = X(i)     + Y(i)
         Z(i + 1) = X(i + 1) + Y(i + 1)
         Z(i + 2) = X(i + 2) + Y(i + 2)
         Z(i + 3) = X(i + 3) + Y(i + 3)
         Z(i + 4) = X(i + 4) + Y(i + 4)
      END DO

      END SUBROUTINE WADD
      
      
      
!--------------------------------------------------------------
      SUBROUTINE WGEFA(N,A,Ipvt,info)
!--------------------------------------------------------------
!     WGEFA FACTORS THE MATRIX A (N,N) BY
!           GAUSS ELIMINATION WITH PARTIAL PIVOTING
!     LINPACK - LIKE 
!--------------------------------------------------------------
!
      INTEGER       :: N,Ipvt(N),info
      REAL(kind=dp) :: A(N,N)
      REAL(kind=dp) :: t, dmax, da
      INTEGER       :: j,k,l
      REAL(kind=dp), PARAMETER :: ZERO = 0.0, ONE = 1.0

      info = 0

size: IF (n > 1) THEN
      
col:  DO k = 1, n-1

!        find l = pivot index
!        l = idamax(n-k+1,A(k,k),1) + k - 1
         l = k; dmax = abs(A(k,k))
         DO j = k+1,n
            da = ABS(A(j,k))
            IF (da > dmax) THEN
              l = j; dmax = da
            END IF
         END DO
         Ipvt(k) = l

!        zero pivot implies this column already triangularized
         IF (ABS(A(l,k)) < TINY(ZERO)) THEN
            info = k
            return
         ELSE   
            IF (l /= k) THEN
               t = A(l,k); A(l,k) = A(k,k); A(k,k) = t
            END IF
            t = -ONE/A(k,k)
            CALL WSCAL(n-k,t,A(k+1,k),1)
            DO j = k+1, n
               t = A(l,j)
               IF (l /= k) THEN
                  A(l,j) = A(k,j); A(k,j) = t
               END IF
               CALL WAXPY(n-k,t,A(k+1,k),1,A(k+1,j),1)
            END DO         
         END IF
         
       END DO col
       
      END IF size
      
      Ipvt(N) = N
      IF (ABS(A(N,N)) == ZERO) info = N
      
      END SUBROUTINE WGEFA


!--------------------------------------------------------------
      SUBROUTINE WGESL(Trans,N,A,Ipvt,b)
!--------------------------------------------------------------
!     WGESL solves the system
!     a * x = b  or  trans(a) * x = b
!     using the factors computed by WGEFA.
!
!     Trans      = 'N'   to solve  A*x = b ,
!                = 'T'   to solve  transpose(A)*x = b
!     LINPACK - LIKE 
!--------------------------------------------------------------

      INTEGER       :: N,Ipvt(N)
      CHARACTER     :: trans
      REAL(kind=dp) :: A(N,N),b(N)
      REAL(kind=dp) :: t
      INTEGER       :: k,kb,l

      
      SELECT CASE (Trans)

      CASE ('n','N')  !  Solve  A * x = b

!        first solve  L*y = b
         IF (n >= 2) THEN
          DO k = 1, n-1
            l = Ipvt(k)
            t = b(l)
            IF (l /= k) THEN
               b(l) = b(k)
               b(k) = t
            END IF
            CALL WAXPY(n-k,t,a(k+1,k),1,b(k+1),1)
          END DO
         END IF
!        now solve  U*x = y
         DO kb = 1, n
            k = n + 1 - kb
            b(k) = b(k)/a(k,k)
            t = -b(k)
            CALL WAXPY(k-1,t,a(1,k),1,b(1),1)
         END DO
      
      CASE ('t','T')  !  Solve transpose(A) * x = b

!        first solve  trans(U)*y = b
         DO k = 1, n
            t = WDOT(k-1,a(1,k),1,b(1),1)
            b(k) = (b(k) - t)/a(k,k)
         END DO
!        now solve trans(L)*x = y
         IF (n >= 2) THEN
         DO kb = 1, n-1
            k = n - kb
            b(k) = b(k) + WDOT(n-k,a(k+1,k),1,b(k+1),1)
            l = Ipvt(k)
            IF (l /= k) THEN
               t = b(l); b(l) = b(k); b(k) = t
            END IF
         END DO
         END IF
   
      END SELECT

      END SUBROUTINE WGESL
! End of BLAS_UTIL function
! ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~



END MODULE gckpp_LinearAlgebra

